/* File: defines.h */

/*
 * Copyright (c) 1997 Ben Harrison, James E. Wilson, Robert A. Koeneke
 *
 * This software may be copied and distributed for educational, research,
 * and not for profit purposes provided that this copyright and statement
 * are included in all such copies.  Other copyrights may also apply.
 */

/* Purpose: global constants and macro definitions */


/*
 * Do not edit this file unless you know *exactly* what you are doing.
 *
 * Some of the values in this file were chosen to preserve game balance,
 * while others are hard-coded based on the format of old save-files, the
 * definition of arrays in various places, mathematical properties, fast
 * computation, storage limits, or the format of external text files.
 *
 * Changing some of these values will induce crashes or memory errors or
 * savefile mis-reads.  Most of the comments in this file are meant as
 * reminders, not complete descriptions, and even a complete knowledge
 * of the source may not be sufficient to fully understand the effects
 * of changing certain definitions.
 *
 * Lastly, note that the code does not always use the symbolic constants
 * below, and sometimes uses various hard-coded values that may not even
 * be defined in this file, but which may be related to definitions here.
 * This is of course bad programming practice, but nobody is perfect...
 *
 * For example, there are MANY things that depend on the screen being
 * 80x24, with the top line used for messages, the bottom line being
 * used for status, and exactly 22 lines used to show the dungeon.
 * Just because your screen can hold 46 lines does not mean that the
 * game will work if you try to use 44 lines to show the dungeon.
 *
 * You have been warned.
 */


/*
 * Name of the version/variant
 */
#define VERSION_NAME "Hengband"



/*
 * "Program Version Number" of the game
 *
 * FAKE_VER_MAJOR=1,2 were reserved for ZAngband version 1.x.x/2.x.x .
 *
 * Program Version of Hengband version is
 *   "(FAKE_VER_MAJOR-10).(FAKE_VER_MINOR).(FAKE_VER_PATCH)".
 */
///\sysdel 131117 o[W폜
#if 0
#define FAKE_VERSION   0
#define FAKE_VER_MAJOR 12
#define FAKE_VER_MINOR 1
#define FAKE_VER_PATCH 2
#endif

/*
 * "Savefile Version Number" for Hengband 1.1.1 and later
 *
 * First three digits may be same as the Program Version.  But not
 * always same.  It means that newer version may preserves lower
 * compatibility with the older version.
 *
 * For example, newer Hengband 1.4.4 creates savefiles marked with
 * Savefile Version 1.4.0.0 .  It means that Hengband 1.4.0 can load a
 * savefile of Hengband 1.4.4 (lower compatibility!).
 *
 * Upper compatibility is always guaranteed.
 */
///sys131117 FAKE_VERSION̒萔
#define H_VER_MAJOR 1
#define H_VER_MINOR 1
#define H_VER_PATCH 53
#define H_VER_EXTRA 1

/*:::Abv[hɂ͕KRgAEg遟:::*/
//#define SCORE_SERVER_TEST
/*:::Abv[hɂ͕KRgAEg遟:::*/

///\131117 sysdel
//#define ANGBAND_2_8_1
//#define ZANGBAND

/*
 * Number of grids in each block (vertically)
 * Probably hard-coded to 11, see "generate.c"
 */
#define BLOCK_HGT	11

/*
 * Number of grids in each block (horizontally)
 * Probably hard-coded to 11, see "generate.c"
 */
#define BLOCK_WID	11


/*
 * Number of grids in each panel (vertically)
 * Must be a multiple of BLOCK_HGT
 */
#define PANEL_HGT	11

/*
 * Number of grids in each panel (horizontally)
 * Must be a multiple of BLOCK_WID
 */
#define PANEL_WID	33


/*
 * Number of grids used to display the dungeon (vertically).
 * Must be a multiple of 11, probably hard-coded to 22.
 */
#define SCREEN_HGT      22

/*
 * Number of grids used to display the dungeon (horizontally).
 * Must be a multiple of 33, probably hard-coded to 66.
 */
#define SCREEN_WID      66


/*
 * Maximum dungeon height in grids, must be a multiple of SCREEN_HGT,
 * probably hard-coded to SCREEN_HGT * 3.
 */
#define MAX_HGT         66

/*
 * Maximum dungeon width in grids, must be a multiple of SCREEN_WID,
 * probably hard-coded to SCREEN_WID * 3.
 */
#define MAX_WID         198


/*
 * Quest constants
 */
#define MIN_RANDOM_QUEST    40
//#define MAX_RANDOM_QUEST    49
#define MAX_RANDOM_QUEST    48

/* Check is the quest index is "fixed" */
#define is_fixed_quest_idx(Q_IDX) (((Q_IDX) < MIN_RANDOM_QUEST) || ((Q_IDX) > MAX_RANDOM_QUEST))

/*:::Extra[h̃NG@*/
#define INSIDE_EXTRA_QUEST (EXTRA_MODE && p_ptr->inside_quest >= MIN_RANDOM_QUEST && p_ptr->inside_quest <= MAX_RANDOM_QUEST )
//Hack - Extra[h̃NG̃tA 10-90K10K@NGXgLɂ邽ߒڃn[hR[fBO
#define EXTRA_QUEST_FLOOR (EXTRA_MODE && dun_level < 100 && !(dun_level%10)) 

///del 폜\
#define QUEST_TOWER1         5
#define QUEST_TOWER2         6
#define QUEST_TOWER3         7

#define QUEST_HOME1			1
#define QUEST_ORC			2
#define QUEST_HOME2			3
#define QUEST_HOME3			4
#define QUEST_KAPPA			5
#define QUEST_MIMIC			6
#define QUEST_DEATHSWORD	7
#define QUEST_SEWER			8
#define QUEST_DOOM1			9
#define QUEST_TUPAI			10
#define QUEST_CLONE			11
#define QUEST_CHAOS_WYRM	12
#define QUEST_OLD_WILLOW	13
#define QUEST_SHOOTINGSTAR   14
#define QUEST_KYOMARU		15
#define QUEST_SENNIN		16
#define QUEST_GRAVEDANCER	17
#define QUEST_OOGAME		18
#define QUEST_OLDCASTLE		19
#define QUEST_LOOKING_GLASS	20
#define QUEST_FLAN			21
#define QUEST_KILL_MOKO		22
#define QUEST_KILL_GUYA		23
#define QUEST_MITHRIL		24
#define QUEST_DOOM2			25
#define QUEST_LIVE			26
#define QUEST_DARKELF		27
#define QUEST_CRYPT			28
#define QUEST_KANASUWA		29
#define QUEST_HANAMI		30
#define QUEST_KORI			31
#define QUEST_WANTED_SEIJA	32
#define QUEST_SPAWNING_PIT	33
#define QUEST_SATORI		34
#define QUEST_WANTED_SUMIREKO	35
#define QUEST_HECATIA			36
#define QUEST_YUKARI         37
#define QUEST_OBERON         38
#define QUEST_SERPENT        39
//40-48̓NG
#define QUEST_MOON_VAULT     50
#define QUEST_MARICON     51
#define QUEST_VAULT			52 //V󕨌
#define QUEST_KAGUYA		53 //܂̓
#define QUEST_SHELOB		54 //VFuގ
#define QUEST_TYPHOON		55 //\΍C@Vp
#define QUEST_TORRENT		56 //}
#define QRKDR		(p_ptr->inside_quest == QUEST_TORRENT)
#define QUEST_MORIYA_1		57 //̍T
#define QUEST_OKINA			58
#define QUEST_KOSUZU		59 //鎸H
#define QUEST_DREAMDWELLER	60 //v1.1.42 NGXgu͌v
#define QUEST_DELIVER_EEL	61 //v1.1.48 NGXgu^̏Cv

//v1.1.24 }NGXgł̃^[ȉœ
#define QT_TURN1			250
#define QT_TURN2			500
#define QT_TURN3			1000


/*
 * Arena constants
 */
#define MAX_ARENA_MONS		41	/* -KMW- */
#define ARENA_DEFEATED_OLD_VER (-(MAX_SHORT))


/*
 * Total number of stores (see "store.c", etc)
 */
#define MAX_STORES      10

/*
 * Number of buildings
 */
#define MAX_BLDG		32

/*
 * Store types
 */
///bldg X̎
#define STORE_GENERAL   0 /*:::GݓX*/
#define STORE_ARMOURY   1
#define STORE_WEAPON    2
#define STORE_TEMPLE    3 /*:::@@X/ɕύX\*/
#define STORE_ALCHEMIST 4 /*:::BpX@@BXɕύX\聩Xɂ*/
#define STORE_MAGIC     5
#define STORE_BLACK     6
#define STORE_HOME      7
#define STORE_BOOK      8
#define STORE_MUSEUM    9


#define BUILDING_NON_MEMBER 0
#define BUILDING_MEMBER     1
#define BUILDING_OWNER      2

/*
 * Total number of owners per store (see "store.c", etc)
 */
#define MAX_OWNERS      32

/*
 * Maximum number of player "sex" types (see "table.c", etc)
 */
#define MAX_SEXES            2


#define MAX_SEIKAKU          14

/* The number of "patrons" available (for Chaos Warriors) */
#define MAX_PATRON          16

/* Number of entries in the sanity-blast descriptions */
#define MAX_SAN_HORROR 20
#define MAX_SAN_FUNNY 22
#define MAX_SAN_COMMENT 5

/* Chaos Warrior: Reward types: */
#define REW_POLY_SLF    1
#define REW_GAIN_EXP    2
#define REW_LOSE_EXP    3
#define REW_GOOD_OBJ    4
#define REW_GREA_OBJ    5
#define REW_CHAOS_WP    6
#define REW_GOOD_OBS    7
#define REW_GREA_OBS    8
#define REW_TY_CURSE    9
#define REW_SUMMON_M    10
#define REW_H_SUMMON    11
#define REW_DO_HAVOC    12
#define REW_GAIN_ABL    13
#define REW_LOSE_ABL    14
#define REW_RUIN_ABL    15
#define REW_AUGM_ABL    16
#define REW_POLY_WND    17
#define REW_HEAL_FUL    18
#define REW_HURT_LOT    19
#define REW_CURSE_WP    20
#define REW_CURSE_AR    21
#define REW_PISS_OFF    22
#define REW_WRATH       23
#define REW_DESTRUCT    24
#define REW_GENOCIDE    25
#define REW_MASS_GEN    26
#define REW_DISPEL_C    27
#define REW_UNUSED_1    28
#define REW_UNUSED_2    29
#define REW_UNUSED_3    30
#define REW_UNUSED_4    31
#define REW_UNUSED_5    32
#define REW_IGNORE      33
#define REW_SER_UNDE    34
#define REW_SER_DEMO    35
#define REW_SER_MONS    36

/* Chaos mutations */

/* "Activatable" mutations must be in MUT1_* */
//#define MUT1_SPIT_ACID                0x00000001L
#define MUT1_BR_ACID                    0x00000001L
#define MUT1_BR_FIRE                    0x00000002L
#define MUT1_HYPN_GAZE                  0x00000004L
#define MUT1_TELEKINES                  0x00000008L
#define MUT1_VTELEPORT                  0x00000010L /* Voluntary teleport */
#define MUT1_MIND_BLST                  0x00000020L
//#define MUT1_RADIATION                0x00000040L
#define MUT1_BR_ELEC                    0x00000040L
#define MUT1_VAMPIRISM                  0x00000080L
//#define MUT1_SMELL_MET                  0x00000100L
#define MUT1_ACCELERATION               0x00000100L
//#define MUT1_SMELL_MON                  0x00000200L
#define MUT1_BEAST_EAR            0x00000200L
#define MUT1_BLINK                      0x00000400L
#define MUT1_EAT_ROCK                   0x00000800L
#define MUT1_SWAP_POS                   0x00001000L
//#define MUT1_SHRIEK                     0x00002000L
#define MUT1_BR_SOUND                   0x00002000L
//#define MUT1_ILLUMINE                   0x00004000L
#define MUT1_BR_COLD                    0x00004000L
//#define MUT1_DET_CURSE                  0x00008000L
#define MUT1_DET_ITEM                   0x00008000L
#define MUT1_BERSERK                    0x00010000L
//#define MUT1_POLYMORPH                  0x00020000L
#define MUT1_BR_POIS                    0x00020000L
#define MUT1_MIDAS_TCH                  0x00040000L
#define MUT1_GROW_MOLD                  0x00080000L
#define MUT1_RESIST                     0x00100000L
#define MUT1_EARTHQUAKE                 0x00200000L
#define MUT1_EAT_MAGIC                  0x00400000L
//#define MUT1_WEIGH_MAG                  0x00800000L
#define MUT1_RAISE_WOOD                 0x00800000L
#define MUT1_STERILITY                  0x01000000L
#define MUT1_PANIC_HIT                  0x02000000L
#define MUT1_DAZZLE                     0x04000000L
#define MUT1_LASER_EYE                  0x08000000L
#define MUT1_RECALL                     0x10000000L
//#define MUT1_BANISH                     0x20000000L
#define MUT1_ID_MUSHROOM                0x20000000L
//#define MUT1_COLD_TOUCH                 0x40000000L
#define MUT1_DANMAKU                    0x40000000L

/*:::ˑRψٕύXɔMUT1̈ԍŌ폜@ǉȂUR}h̕ӂɒ*/
//#define MUT1_LAUNCHER                   0x80000000L /*:::̐lintŉ߂畉ɂȂă[`ヌCVɍsȂ̂ŕʂ̐l𖳗ĎsĂ炵*/

/* Randomly activating mutations must be MUT2_* */
#define MUT2_BERS_RAGE                  0x00000001L
#define MUT2_COWARDICE                  0x00000002L
#define MUT2_RTELEPORT                  0x00000004L /* Random teleport, instability */
#define MUT2_ALCOHOL                    0x00000008L
#define MUT2_HALLU                      0x00000010L
//#define MUT2_FLATULENT                  0x00000020L
#define MUT2_YAKU                       0x00000020L
//#define MUT2_SCOR_TAIL                  0x00000040L
#define MUT2_HARDHEAD                   0x00000040L
#define MUT2_HORNS                      0x00000080L
//#define MUT2_BEAK                       0x00000100L
#define MUT2_BIGHORN                    0x00000100L
#define MUT2_ATT_DEMON                  0x00000200L
#define MUT2_PROD_MANA                  0x00000400L
#define MUT2_SPEED_FLUX                 0x00000800L
#define MUT2_BANISH_ALL                 0x00001000L
#define MUT2_EAT_LIGHT                  0x00002000L
//#define MUT2_TRUNK                      0x00004000L
#define MUT2_TAIL                       0x00004000L
#define MUT2_ATT_ANIMAL                 0x00008000L
//#define MUT2_TENTACLES                  0x00010000L
#define MUT2_BIGTAIL                    0x00010000L

#define MUT2_RAW_CHAOS                  0x00020000L
#define MUT2_NORMALITY                  0x00040000L
#define MUT2_WRAITH                     0x00080000L
//#define MUT2_POLY_WOUND                 0x00100000L
#define MUT2_ATT_GHOST                  0x00100000L
//#define MUT2_WASTING                    0x00200000L
#define MUT2_ATT_KWAI                   0x00200000L
#define MUT2_ATT_DRAGON                 0x00400000L
//#define MUT2_WEIRD_MIND                 0x00800000L
#define MUT2_XOM                        0x00800000L
//#define MUT2_NAUSEA                     0x01000000L
#define MUT2_BIRDBRAIN                  0x01000000L
#define MUT2_CHAOS_GIFT                 0x02000000L
#define MUT2_WALK_SHAD                  0x04000000L
#define MUT2_WARNING                    0x08000000L
#define MUT2_INVULN                     0x10000000L
//#define MUT2_SP_TO_HP                   0x20000000L
#define MUT2_ASTHMA                     0x20000000L
//#define MUT2_HP_TO_SP                   0x40000000L
#define MUT2_THE_WORLD                  0x40000000L
#define MUT2_DISARM                     0x80000000L



/* Other mutations will be mainly in MUT3_* */

#define MUT3_HYPER_STR                  0x00000001L
#define MUT3_PUNY                       0x00000002L
#define MUT3_HYPER_INT                  0x00000004L
#define MUT3_MORONIC                    0x00000008L
#define MUT3_RESILIENT                  0x00000010L
//#define MUT3_XTRA_FAT                 0x00000020L
#define MUT3_WARNING                    0x00000020L
#define MUT3_ALBINO                     0x00000040L
//#define MUT3_FLESH_ROT                0x00000080L
#define MUT3_SPEEDSTER                  0x00000080L
//#define MUT3_SILLY_VOI                0x00000100L
#define MUT3_RES_WATER                  0x00000100L
#define MUT3_BLANK_FAC                  0x00000200L
//#define MUT3_ILL_NORM                   0x00000400L
#define MUT3_HURT_LITE                  0x00000400L

#define MUT3_XTRA_EYES                  0x00000800L
#define MUT3_MAGIC_RES                  0x00001000L
#define MUT3_XTRA_NOIS                  0x00002000L
//#define MUT3_INFRAVIS                   0x00004000L
#define MUT3_BYDO                       0x00004000L
//#define MUT3_XTRA_LEGS                  0x00008000L
#define MUT3_FISH_TAIL                  0x00008000L
//#define MUT3_SHORT_LEG                  0x00010000L
#define MUT3_PEGASUS                    0x00010000L
#define MUT3_ACID_SCALES                0x00020000L
#define MUT3_ELEC_SCALES                0x00040000L
#define MUT3_FIRE_SCALES                0x00080000L
#define MUT3_COLD_SCALES                0x00100000L
#define MUT3_POIS_SCALES                0x00200000L

//#define MUT3_ELEC_TOUC                  0x00020000L
//#define MUT3_FIRE_BODY                  0x00040000L
//#define MUT3_WART_SKIN                  0x00080000L
//#define MUT3_SCALES                     0x00100000L
//#define MUT3_IRON_SKIN                  0x00200000L
#define MUT3_WINGS                      0x00400000L
#define MUT3_FEARLESS                   0x00800000L
//#define MUT3_REGEN                      0x01000000L
#define MUT3_FEVER                      0x01000000L

#define MUT3_ESP                        0x02000000L
#define MUT3_LIMBER                     0x04000000L
#define MUT3_ARTHRITIS                  0x08000000L
#define MUT3_BAD_LUCK                   0x10000000L
#define MUT3_VULN_ELEM                  0x20000000L
#define MUT3_MOTION                     0x40000000L
#define MUT3_GOOD_LUCK                  0x80000000L


/* Monk martial arts... */
# define MAX_MA 17
# define MA_KNEE 1
# define MA_SLOW 2

/* Mindcraft */
#define MAX_MIND_POWERS  21

/* Hallucination stuff */
#ifdef JP
#define MAX_SILLY_ATTACK 41
#else
#define MAX_SILLY_ATTACK 29
#endif

#define MIND_MINDCRAFTER    0
#define MIND_KI             1
#define MIND_BERSERKER      2
#define MIND_MIRROR_MASTER  3
#define MIND_NINJUTSU       4


/*
 * Size of memory reserved for initialization of some arrays
 */
///mod150908 TOꂽӂname_sizẽȂȂBPɒǉĖȂ̂ǂ͒mȂB

#define FAKE_NAME_SIZE  60 * 1024L
#define FAKE_TEXT_SIZE 300 * 1024L
//#define FAKE_NAME_SIZE  40 * 1024L
//#define FAKE_TEXT_SIZE 150 * 1024L
#define FAKE_TAG_SIZE   10 * 1024L


/*
 * Maximum number of high scores in the high score file
 */
#define MAX_HISCORES    999


/*
 * Maximum dungeon level.  The player can never reach this level
 * in the dungeon, and this value is used for various calculations
 * involving object and monster creation.  It must be at least 100.
 * Setting it below 128 may prevent the creation of some objects.
 */
#define MAX_DEPTH       128


/*
 * Maximum number of saved floors.
 */
#define MAX_SAVED_FLOORS       20


/*
 * Maximum size of the "lite" array (see "cave.c")
 * Note that the "lite radius" will NEVER exceed 14, and we would
 * never require more than 581 entries in the array for circular "lite".
 */
#define LITE_MAX 600

/*
 * Maximum size of the "mon_lite" array (see "cave.c")
 * Note that the "view radius" will NEVER exceed 20, monster illumination
 * flags are dependent on CAVE_VIEW, and even if the "view" was octagonal,
 * we would never require more than 1520 entries in the array.
 */
#define MON_LITE_MAX 1536

/*
 * Maximum size of the "view" array (see "cave.c")
 * Note that the "view radius" will NEVER exceed 20, and even if the "view"
 * was octagonal, we would never require more than 1520 entries in the array.
 */
#define VIEW_MAX 1536

/*
 * Maximum size of the "temp" array (see "cave.c")
 * We must be as large as "VIEW_MAX" and "LITE_MAX" for proper functioning
 * of "update_view()" and "update_lite()".  We must also be as large as the
 * largest illuminatable room, but no room is larger than 800 grids.  We
 * must also be large enough to allow "good enough" use as a circular queue,
 * to calculate monster flow, but note that the flow code is "paranoid".
 */
#define TEMP_MAX 2298

/*
 * Maximum size of the "redraw" array (see "cave.c")
 * We must be large for proper functioning of delayed redrawing.
 * We must also be as large as two times of the largest view area.
 * Note that maximum view grids are 1149 entries.
 */
#define REDRAW_MAX 2298


/*
 * Number of keymap modes
 */
#define KEYMAP_MODES	2

/*
 * Mode for original keyset commands
 */
#define KEYMAP_MODE_ORIG	0

/*
 * Mode for roguelike keyset commands
 */
#define KEYMAP_MODE_ROGUE	1


/*
 * OPTION: Maximum number of macros (see "io.c")
 * Default: assume at most 256 macros are used
 */
#define MACRO_MAX       256

/*
 * OPTION: Maximum number of "quarks" (see "io.c")
 * Default: assume at most 512 different inscriptions are used
 */
///mod151231 傫₵Bggf_color[]s16bȂ̂ł̐lEB
//Ñgp1MBقǑ邩Ȃ܂薳낤B
#define QUARK_MAX       32767
//#define QUARK_MAX       768
/* Was 512... 256 quarks added for random artifacts */

/*
 * OPTION: Maximum number of messages to remember (see "io.c")
 * Default: assume maximal memorization of 2048 total messages
 */
#define MESSAGE_MAX     2048

/*
 * OPTION: Maximum space for the message text buffer (see "io.c")
 * Default: assume that each of the 2048 messages is repeated an
 * average of three times, and has an average length of 48
 */
#define MESSAGE_BUF     32768


/*
 * Maximum value storable in a "byte" (hard-coded)
 */
#define MAX_UCHAR       255

/*
 * Maximum value storable in a "s16b" (hard-coded)
 */
#define MAX_SHORT       32767

/*
 * Maximum length of object's name
 */
#define MAX_NLEN        160

/*
 * Special internal key
 */
#define SPECIAL_KEY_QUEST    255
#define SPECIAL_KEY_BUILDING 254
#define SPECIAL_KEY_STORE    253
#define SPECIAL_KEY_QUIT     252

/*
 * Store constants
 */
#define STORE_INVEN_MAX 24              /* Max number of discrete objs in inven */
#define STORE_CHOICES   48              /* Number of items to choose stock from */
#define STORE_OBJ_LEVEL 5               /* Magic Level for normal stores */
#define STORE_TURNOVER  9               /* Normal shop turnover, per day */
#define STORE_MIN_KEEP  6               /* Min slots to "always" keep full */
#define STORE_MAX_KEEP  18              /* Max slots to "always" keep full */
#define STORE_SHUFFLE   21              /* 1/Chance (per day) of an owner changing */
#define STORE_TICKS     1000            /* Number of ticks between turnovers */
#define BATTLE_MON_TICKS	300
#define STORE_MUSEUM_PAGES	500		//ق̃y[W

/*
 * Random energy
 */
//fPpOǉ
#define ENERGY_NEED() ((p_ptr->pclass == CLASS_EIKI) ? 100 : randnor(100, 25))


/*
 * Extract energy from speed (Assumes that SPEED is unsigned)
 */
#define SPEED_TO_ENERGY(SPEED) \
	(((SPEED) > 199) ? 49 : extract_energy[(SPEED)])


/*
 * Misc constants
 */
#define TOWN_DAWN         10000    /* Number of ticks from dawn to dawn XXX */
#define TURNS_PER_TICK    10L      /* Number of energy-gain-turns per ticks */
#define MAX_DAYS          20000    /* Maximum days */
#define BREAK_GLYPH       550      /* Rune of protection resistance */
#define BREAK_MINOR_GLYPH 299      /* For explosive runes */
#define BTH_PLUS_ADJ       3       /* Adjust BTH per plus-to-hit */
#define MON_MULT_ADJ  	   8       /* High value slows multiplication */
#define MON_SUMMON_ADJ	   2       /* Adjust level of summoned creatures */
#define MON_DRAIN_LIFE	   2       /* Percent of player exp drained per hit */
#define USE_DEVICE    	   3       /* x> Harder devices x< Easier devices     */


/* "Biases" for random artifact gen */
/*:::ɃNXŌ肳邩A\͒lϐtɃ_ŕt*/

#define BIAS_ELEC            1
#define BIAS_POIS            2
#define BIAS_FIRE            3
#define BIAS_COLD            4
#define BIAS_ACID            5
#define BIAS_STR             6
#define BIAS_INT             7
#define BIAS_WIS             8
#define BIAS_DEX             9
#define BIAS_CON            10
#define BIAS_CHR            11
#define BIAS_CHAOS          12
#define BIAS_PRIESTLY       13
#define BIAS_NECROMANTIC    14
#define BIAS_LAW            15
#define BIAS_ROGUE          16
#define BIAS_MAGE           17
#define BIAS_WARRIOR        18
#define BIAS_RANGER         19
#define ARTIFACT_BIAS_MAX	19


/*** Pet constants ***/


/*
 * Commands
 */
#define PET_DISMISS		1
#define PET_TARGET		2
#define PET_STAY_CLOSE		3
#define PET_FOLLOW_ME		4
#define PET_SEEK_AND_DESTROY	5
#define PET_ALLOW_SPACE		6
#define PET_STAY_AWAY		7
#define PET_OPEN_DOORS          8
#define PET_TAKE_ITEMS		9
#define PET_TELEPORT		10
#define PET_ATTACK_SPELL	11
#define PET_SUMMON_SPELL	12
#define PET_BALL_SPELL		13
#define PET_RIDING		14
#define PET_NAME		15
#define PET_RYOUTE		16

/*
 * Follow distances
 */
#define PET_CLOSE_DIST				1
#define PET_FOLLOW_DIST				6
#define PET_SEEK_DIST				10
#define PET_DESTROY_DIST			255
#define PET_SPACE_DIST				(-10)
#define PET_AWAY_DIST				(-25)

/*:::ybgւ̖*/
#define PF_OPEN_DOORS   0x0001
#define PF_PICKUP_ITEMS 0x0002
#define PF_TELEPORT     0x0004
#define PF_ATTACK_SPELL 0x0008
#define PF_SUMMON_SPELL 0x0010
#define PF_BALL_SPELL   0x0020
#define PF_RYOUTE       0x0040

/*:::莝\ǂijĂȂǂj*/
#define CAN_TWO_HANDS_WIELDING() ((!p_ptr->riding || (p_ptr->pet_extra_flags & PF_RYOUTE) || CLASS_RIDING_BACKDANCE) && !check_invalidate_inventory(INVEN_RARM) && !check_invalidate_inventory(INVEN_LARM) )


/*
 * There is a 1/20 (5%) chance of inflating the requested object_level
 * during the creation of an object (see "get_obj_num()" in "object.c").
 * Lower values yield better objects more often.
 */
/*:::x[XACe̐xu[Xgm(1/n)BihbvƂ͊֌WȂ炵*/
#define GREAT_OBJ       10

/*
 * There is a 1/25 (4%) chance of inflating the requested monster_level
 * during the creation of a monsters (see "get_mon_num()" in "monster.c").
 * Lower values yield harder monsters more often.
 */
#define NASTY_MON_BASE     25
#define NASTY_MON_MAX      3
#define NASTY_MON_PLUS_MAX 25

/* 1/x chance of hurting even if invulnerable! */
#define PENETRATE_INVULNERABILITY 13



/*
 * Refueling constants
 */
#define FUEL_TORCH      5000    /* Maximum amount of fuel in a torch */
#define FUEL_LAMP       15000   /* Maximum amount of fuel in a lantern */


/*
 * More maximum values
 */
#define MAX_SIGHT       20      /* Maximum view distance */
#define MAX_RANGE       (p_ptr->inside_battle ? 36 : 18)      /* Maximum range (spells, etc) */
#define AAF_LIMIT       100     /* Limit of sensing radius */



/*
 * The town starts out with 4 residents during the day
 */
#define MIN_M_ALLOC_TD          4

/*
 * The town starts out with 8 residents during the night
 */
#define MIN_M_ALLOC_TN          8


/*
 * A monster can only "multiply" (reproduce) if there are fewer than 100
 * monsters on the level capable of such spontaneous reproduction.  This
 * is a hack which prevents the "m_list[]" array from exploding due to
 * reproducing monsters.  Messy, but necessary.
 */
#define MAX_REPRO       100


/*
 * Player constants
 */
#define PY_MAX_EXP      99999999L       /* Maximum exp */
#define PY_MAX_GOLD     999999999L      /* Maximum gold */
#define PY_MAX_LEVEL    50              /* Maximum level */

/*
 * Player "food" crucial values
 */
#define PY_FOOD_MAX     15000   /* Food value (Bloated) */
#define PY_FOOD_FULL    10000   /* Food value (Normal) */
#define PY_FOOD_ALERT   2000    /* Food value (Hungry) */
#define PY_FOOD_WEAK    1000    /* Food value (Weak) */
#define PY_FOOD_FAINT   500     /* Food value (Fainting) */
#define PY_FOOD_STARVE  100     /* Food value (Starving) */

/*
 * Player regeneration constants
 */
#define PY_REGEN_NORMAL         197     /* Regen factor*2^16 when full */
#define PY_REGEN_WEAK           98      /* Regen factor*2^16 when weak */
#define PY_REGEN_FAINT          33      /* Regen factor*2^16 when fainting */
#define PY_REGEN_HPBASE         1442    /* Min amount hp regen*2^16 */
#define PY_REGEN_MNBASE         524     /* Min amount mana regen*2^16 */

/*
 * Possible realms that can be chosen;
 * currently used only by birth.c and tables.c
 */
#if 0
#define CH_NONE         0x00
#define CH_LIFE         0x01
#define CH_SORCERY      0x02
#define CH_NATURE       0x04
#define CH_CHAOS        0x08
#define CH_DEATH        0x10
#define CH_TRUMP        0x20
#define CH_ARCANE       0x40
#define CH_ENCHANT      0x80
#define CH_DAEMON       0x100
#define CH_CRUSADE      0x200

#define CH_MUSIC        0x08000	/* This is 16th bit */
#define CH_HISSATSU     0x10000
#define CH_HEX          0x20000
#endif

/*
 * Magic realms
 */
///realm

#define REALM_NONE         0
/*
#define REALM_LIFE         1
#define REALM_SORCERY      2
#define REALM_NATURE       3
#define REALM_CHAOS        4
#define REALM_DEATH        5
#define REALM_TRUMP        6
#define REALM_ARCANE       7
#define REALM_CRAFT      8
#define REALM_DAEMON       9
#define REALM_CRUSADE      10
#define MAX_MAGIC          10
#define MIN_TECHNIC        16
#define REALM_MUSIC        16
#define REALM_HISSATSU     17
#define REALM_HEX          18
#define MAX_REALM          18
*/
///realm item
//#define VALID_REALM        (MAX_REALM + MAX_MAGIC - MIN_TECHNIC + 1)
//#define NUM_TECHNIC        (MAX_REALM - MIN_TECHNIC + 1)

///realm p̂̔p
//#define is_magic(A) ((((A) > REALM_NONE) && ((A) < MAX_MAGIC + 1)) ? TRUE : FALSE)
//#define is_magic(A) (( ((A) > REALM_NONE) && ((A) < MAX_MAGIC + 1)) ? TRUE : FALSE)
//#define tval2realm(A) ((A) - TV_LIFE_BOOK + 1)
//#define technic2magic(A)      (is_magic(A) ? (A) : (A) - MIN_TECHNIC + 1 + MAX_MAGIC)
#define is_good_realm(REALM)   ((REALM) >= TV_BOOK_MYSTIC && (REALM) <= TV_BOOK_NATURE)
#define is_evil_realm(REALM)   ((REALM) >= TV_BOOK_TRANSFORM && (REALM) <= TV_BOOK_CHAOS)

/*
 * Magic-books for the realms
 */
///item TVAL realm
//#define REALM1_BOOK     (p_ptr->realm1 + TV_LIFE_BOOK - 1)
//#define REALM2_BOOK     (p_ptr->realm2 + TV_LIFE_BOOK - 1)


/*
 * Mode constant for do_spell()
 */
#define SPELL_NAME   0
#define SPELL_DESC   1
#define SPELL_INFO   2
#define SPELL_CAST   3
#define SPELL_FAIL   4
#define SPELL_STOP   5
#define SPELL_CONT   6
#define SPELL_CHECK  7


/*
 * Maximum number of "normal" pack slots, and the index of the "overflow"
 * slot, which can hold an item, but only temporarily, since it causes the
 * pack to "overflow", dropping the "last" item onto the ground.  Since this
 * value is used as an actual slot, it must be less than "INVEN_RARM" (below).
 * Note that "INVEN_PACK" is probably hard-coded by its use in savefiles, and
 * by the fact that the screen can only show 23 items plus a one-line prompt.
 */
/*:::inventory[23](24Ԗ)̃Cxg̓ACeӂp̈ꎞ̈*/
/*:::pack_overflow()Q*/
#define INVEN_PACK              23

/*
 * Indexes used for various "equipment" slots (hard-coded by savefiles, etc).
 */
#define INVEN_RARM      24
#define INVEN_LARM      25
#define INVEN_RIBBON    26
//#define INVEN_BOW       26
#define INVEN_RIGHT     27
#define INVEN_LEFT      28
#define INVEN_NECK      29
#define INVEN_LITE      30
#define INVEN_BODY      31
#define INVEN_OUTER     32
#define INVEN_HEAD      33
#define INVEN_HANDS     34
#define INVEN_FEET      35

/*
 * used for get_random_ego()
 */
/*:::GSɎgꑕʒl@*/
#define INVEN_EGO_AMMO     23
#define INVEN_EGO_BOW     22
#define INVEN_EGO_GUN     21

/*
 * Total number of inventory slots (hard-coded).
 */
#define INVEN_TOTAL     36

/*
 * Fake inventory slot for selecting force (hard-coded).
 */
#define INVEN_FORCE     1111


/*
 * Indexes of the various "stats" (hard-coded by savefiles, etc).
 */
#define A_STR   0
#define A_INT   1
#define A_WIS   2
#define A_DEX   3
#define A_CON   4
#define A_CHR   5

/*
 * Player sex constants (hard-coded by save-files, arrays, etc)
 */
#define SEX_FEMALE              0
#define SEX_MALE                1


/*
 * Player race constants (hard-coded by save-files, arrays, etc)
 */
#define RACE_HUMAN				0
#define RACE_YOUKAI             1
#define RACE_HALF_YOUKAI        2
#define RACE_SENNIN             3
#define RACE_TENNIN             4
#define RACE_FAIRY              5
#define RACE_KAPPA              6
#define RACE_MAGICIAN           7
#define RACE_KARASU_TENGU       8
#define RACE_HAKUROU_TENGU      9
#define RACE_ONI			    10
#define RACE_DEATH              11
#define RACE_WARBEAST           12
#define RACE_TSUKUMO            13
#define RACE_ANDROID            14 /*:::dl`*/
#define RACE_GYOKUTO            15
#define RACE_YOUKO              16
#define RACE_YAMAWARO           17
#define RACE_BAKEDANUKI         18
#define RACE_NINGYO             19
#define RACE_HOFGOBLIN          20
#define RACE_NYUDOU             21
#define RACE_IMP                22
#define RACE_GOLEM              23
#define RACE_KOBITO             24
#define RACE_ZOMBIE             25
#define RACE_VAMPIRE            26
#define RACE_SPECTRE            27
#define RACE_STRAYGOD           28
#define RACE_DAIYOUKAI          29
#define RACE_DEMIGOD			30
#define RACE_LUNARIAN			31

/*:::̉̔ԍɓւƐVKQ[ɂ͊֌WȂZ[uf[^݊ȂȂBӁB*/
//LCN̎푰IMAX_BIRTH_RACESłȂtOŏ悤ɂ΂H
#define RACE_NINJA              32
#define RACE_HALF_GHOST         33
#define RACE_GREATER_LILLIPUT   34
#define RACE_LICH               35
#define RACE_ULTIMATE           36
#define RACE_DEITY				37
#define RACE_JK					38
#define RACE_HOURAI				39
#define RACE_MAGIC_JIZO			40


//#define RACE_HALF_ELF         1
//#define RACE_ELF              2
//#define RACE_HOBBIT              3
//#define RACE_GNOME               4
//#define RACE_DWARF               5
//#define RACE_HALF_ORC            6
//#define RACE_HALF_TROLL          7
//#define RACE_AMBERITE            8
//#define RACE_HIGH_ELF            9
//#define RACE_BARBARIAN          10
//#define RACE_HALF_OGRE          11
//#define RACE_HALF_GIANT         12
//#define RACE_HALF_TITAN         13
//#define RACE_CYCLOPS            14
//#define RACE_YEEK               15
//#define RACE_KLACKON            16
//#define RACE_KOBOLD             17
//#define RACE_NIBELUNG           18
//#define RACE_DARK_ELF           19
//#define RACE_DRACONIAN          20
//#define RACE_MIND_FLAYER        21
//#define RACE_IMP                22
//#define RACE_GOLEM              23
//#define RACE_SKELETON           24
//#define RACE_ZOMBIE             25
//#define RACE_VAMPIRE            26
//#define RACE_SPECTRE            27
//#define RACE_SPRITE             28

//#define RACE_BEASTMAN           29
#define RACE_ENT                99
#define RACE_ANGEL              98
//#define RACE_DEMON              32
//#define RACE_DUNADAN            33
//#define RACE_S_FAIRY            34
//#define RACE_KUTAR              35
//#define RACE_ANDROID            36

//؂̎푰ϗe󂯂Ȃ푰
#define NO_CHANGE_RACE			(p_ptr->prace == RACE_ANDROID || p_ptr->prace == RACE_DEITY || p_ptr->prace == RACE_STRAYGOD || p_ptr->prace == RACE_HOURAI)

/*
 * Maximum number of player "race" types (see "table.c", etc)
 */

//race 푰64ވȏɂȂƂ́Ap_ptr->old_race1/2gȂƂȂB
#define MAX_RACES               41

///mod140115 LCNɂ͉̒lgƂɂBj[Nv[[p푰푰ϗep푰͂̒lɂB
#define MAX_BIRTH_RACES               32


/*
 * Player class constants (hard-coded by save-files, arrays, etc)
 */
#define CLASS_WARRIOR            0
#define CLASS_MAGE               1
#define CLASS_PRIEST             2
#define CLASS_ROGUE              3
#define CLASS_RANGER             4
#define CLASS_PALADIN            5
#define CLASS_TEACHER	         6
#define CLASS_MAID			     7
#define CLASS_MONK               249//ޔ
#define CLASS_MARTIAL_ARTIST	8
#define CLASS_MINDCRAFTER        9
#define CLASS_HIGH_MAGE         10
#define CLASS_CIVILIAN          11
#define CLASS_SYUGEN            12
#define CLASS_MAGIC_KNIGHT      13


#define CLASS_IMITATOR          254//ꎞޔ
#define CLASS_BEASTMASTER       253//ꎞޔ
#define CLASS_SORCERER          14
#define CLASS_ARCHER            15
#define CLASS_MAGIC_EATER       16
#define CLASS_ENGINEER          17
#define CLASS_BARD              251//ꎞޔ
#define CLASS_LIBRARIAN			18
#define CLASS_RED_MAGE          252//ꎞޔ
#define CLASS_SAMURAI           19
#define CLASS_SOLDIER			20
#define CLASS_FORCETRAINER	    247//ޔ
#define CLASS_CHEMIST			21
#define CLASS_BLUE_MAGE         248//ޔ
#define CLASS_CAVALRY           22
#define CLASS_TSUKUMO_MASTER	23
//mp~ꐫiƂĎƂ̂߂ɏ͉Ă
#define CLASS_BERSERKER         255//ꎞޔ

//#define CLASS_SMITH             24
#define CLASS_SH_DEALER         24 //Ó
#define CLASS_JEWELER         25
#define CLASS_MIRROR_MASTER     250//ꎞޔ
#define CLASS_NINJA             26
#define CLASS_SNIPER            27
#define CLASS_OUTSIDER			28

#define CLASS_RUMIA             29
#define CLASS_YOUMU             30
#define CLASS_TEWI              31
#define CLASS_UDONGE            32
#define CLASS_IKU               33
#define CLASS_KOMACHI           34
#define CLASS_KOGASA            35
#define CLASS_KASEN             36
#define CLASS_SUIKA             37
#define CLASS_MARISA            38
#define CLASS_WAKASAGI          39
#define CLASS_KOISHI            40
#define CLASS_MOMIZI			41
#define CLASS_SEIGA				42
#define CLASS_CIRNO				43
#define CLASS_ORIN				44
#define CLASS_SHINMYOUMARU		45
#define CLASS_NAZRIN			46
#define CLASS_LETTY				47
#define CLASS_YOSHIKA			48
#define CLASS_PATCHOULI			49
#define CLASS_AYA				50
#define CLASS_BANKI				51
#define CLASS_MYSTIA			52
#define CLASS_FLAN				53
#define CLASS_SHOU				54
#define CLASS_MEDICINE			55
#define	CLASS_YUYUKO			56
#define CLASS_SATORI			57
#define CLASS_KYOUKO			58
#define CLASS_TOZIKO			59
#define CLASS_LILY_WHITE		60
#define CLASS_KISUME			61
#define CLASS_HATATE			62
#define CLASS_MIKO				63
#define CLASS_KOKORO			64
#define CLASS_WRIGGLE			65
#define CLASS_YUUKA				66
#define CLASS_CHEN				67
#define CLASS_MURASA			68
#define CLASS_KEINE				69
#define CLASS_REIMU				70
#define CLASS_YUGI				71
#define CLASS_KAGEROU			72
#define CLASS_SHIZUHA			73
#define CLASS_SANAE				74
#define CLASS_MINORIKO			75
#define CLASS_REMY				76
#define CLASS_NITORI			77
#define CLASS_BYAKUREN			78
#define CLASS_SUWAKO			79
#define CLASS_NUE				80
#define CLASS_SEIJA				81
#define CLASS_UTSUHO			82
#define CLASS_YAMAME			83
#define CLASS_RAN				84
#define CLASS_EIKI				85
#define CLASS_TENSHI			86
#define CLASS_MEIRIN			87
#define CLASS_PARSEE			88
#define CLASS_SHINMYOU_2		89
#define CLASS_SUMIREKO			90
#define CLASS_ICHIRIN			91
#define CLASS_MOKOU				92
#define CLASS_KANAKO			93
#define CLASS_FUTO				94
#define CLASS_SUNNY				95
#define CLASS_LUNAR				96
#define CLASS_STAR				97
#define CLASS_ALICE				98
#define CLASS_LUNASA			99
#define CLASS_MERLIN			100
#define CLASS_LYRICA			101
#define CLASS_IS_PRISM_SISTERS	(p_ptr->pclass == CLASS_LUNASA || p_ptr->pclass == CLASS_MERLIN || p_ptr->pclass == CLASS_LYRICA)
#define CLASS_CLOWNPIECE		102
#define CLASS_DOREMY			103
#define CLASS_BENBEN			104
#define CLASS_YATSUHASHI		105
#define CLASS_HINA				106
#define CLASS_SAKUYA			107
#define CLASS_3_FAIRIES			108
#define CLASS_RAIKO				109
#define CLASS_MAMIZOU			110
#define CLASS_YUKARI			111
#define CLASS_RINGO				112
#define CLASS_SEIRAN			113
#define CLASS_EIRIN				114
#define CLASS_KAGUYA			115
#define CLASS_SAGUME			116
#define CLASS_REISEN2			117
#define CLASS_TOYOHIME			118
#define CLASS_YORIHIME			119
#define CLASS_JUNKO				120
#define CLASS_HECATIA			121
#define CLASS_NEMUNO			122
#define CLASS_AUNN				123
#define CLASS_NARUMI			124
#define CLASS_KOSUZU			125
#define CLASS_LARVA				126
#define CLASS_MAI				127
#define CLASS_SATONO			128
#define CLASS_VFS_CLOWNPIECE	129
#define CLASS_JYOON				130
#define CLASS_SHION				131
#define CLASS_OKINA				132

/*Maximum number of player "class" types (see "table.c", etc)*/
/*:::class_info[]̍ڐ CLASS_**̍ŏI+1@LCÑNXbirth.cMAX_CLASS_CHOICEȂ̂Œ*/
//#define MAX_CLASS            28
#define MAX_CLASS            133

//v1.1.41 ƗT̋Ruwŗxvɂ邽߂̔
#define CLASS_RIDING_BACKDANCE	(p_ptr->pclass == CLASS_MAI || p_ptr->pclass == CLASS_SATONO)




///mod140817 ̊֌WɋVlȊO̐E֏
/*:::ygn̐EƔp*/
#define CHECK_MUSIC_CLASS	(p_ptr->pclass == CLASS_BARD || p_ptr->pclass == CLASS_MYSTIA || p_ptr->pclass == CLASS_KYOUKO || p_ptr->pclass == CLASS_LUNASA || p_ptr->pclass == CLASS_MERLIN || p_ptr->pclass == CLASS_LYRICA || p_ptr->pclass == CLASS_BENBEN || p_ptr->pclass == CLASS_YATSUHASHI || p_ptr->pclass == CLASS_RAIKO)

/*:::tnE̐EƔ@realm_aptitude[14]0łȂE͖蒲܃Vsǂ߂*/
#define CHECK_MAKEDRUG_CLASS (cp_ptr->realm_aptitude[TV_BOOK_MEDICINE] || is_special_seikaku(SEIKAKU_SPECIAL_UDONGE)) 

#define SEIKAKU_FUTUU	 0
#define SEIKAKU_CHIKARA	 1
#define SEIKAKU_KIREMONO 2
#define SEIKAKU_SHIAWASE 3
#define SEIKAKU_SUBASI	 4
#define SEIKAKU_INOCHI	 5
#define SEIKAKU_TRIGGER	 6
//#define SEIKAKU_NAMAKE	 7
#define SEIKAKU_ELEGANT	 7
#define SEIKAKU_SEXY	 8
#define SEIKAKU_LUCKY	 9
#define SEIKAKU_GAMAN	 10
#define SEIKAKU_MUNCHKIN 11
#define SEIKAKU_SPECIAL 12
#define SEIKAKU_COLLECTOR 255
#define SEIKAKU_BERSERK 13

#define SEIKAKU_SPECIAL_NONE		0
#define SEIKAKU_SPECIAL_CIRNO		1
#define SEIKAKU_SPECIAL_PATCHOULI	2
#define SEIKAKU_SPECIAL_NARUMI		3
#define SEIKAKU_SPECIAL_UDONGE		4
#define SEIKAKU_SPECIAL_SUMIREKO	5

#define MAX_SEIKAKU_SPECIAL			6 //̍ő+1




/*** Screen Locations ***/

/*
 * Some screen locations for various display routines
 * Currently, row 8 and 15 are the only "blank" rows.
 * That leaves a "border" around the "stat" values.
 */
#define ROW_DIFFICULTY                1
#define COL_DIFFICULTY                0     

#define ROW_SCORE                2
#define COL_SCORE                0     

//#define ROW_RACE                1
#define ROW_RACE                4
#define COL_RACE                0       /* <race name> */

/*#define ROW_CLASS               2 */
/*#define COL_CLASS               0 */      /* <class name> */

//#define ROW_TITLE               2
#define ROW_TITLE               5
#define COL_TITLE               0       /* <title> or <mode> */

/*#define ROW_SEIKAKU		4 */
/*#define COL_SEIKAKU      	0*/	/* <seikaku> */

//#define ROW_DAY                 21
#define ROW_DAY                 24
#define COL_DAY                 0       /* day */

//#define ROW_DUNGEON             22
#define ROW_DUNGEON             25
#define COL_DUNGEON             0       /* dungeon */

//#define ROW_LEVEL               3
#define ROW_LEVEL               6
#define COL_LEVEL               0       /* "LEVEL xxxxxx" */

//#define ROW_EXP                 4
#define ROW_EXP                 7
#define COL_EXP                 0       /* "EXP xxxxxxxx" */

//#define ROW_GOLD                5
#define ROW_GOLD                8
#define COL_GOLD                0       /* "AU xxxxxxxxx" */

//#define ROW_EQUIPPY             6
#define ROW_EQUIPPY             9
#define COL_EQUIPPY             0       /* equippy chars */

//#define ROW_STAT                7
#define ROW_STAT                10
#define COL_STAT                0       /* "xxx   xxxxxx" */

//#define ROW_AC                  13
#define ROW_AC                  16
#define COL_AC                  0       /* "Cur AC xxxxx" */

//#define ROW_HPMP                14
#define ROW_HPMP                17
#define COL_HPMP                0

//#define ROW_CURHP               14
#define ROW_CURHP               17
#define COL_CURHP               0       /* "Cur HP xxxxx" */

//#define ROW_CURSP               15
#define ROW_CURSP               18
#define COL_CURSP               0       /* "Cur SP xxxxx" */

//#define ROW_RIDING_INFO          16
#define ROW_RIDING_INFO          19
#define COL_RIDING_INFO          0       /* "xxxxxxxxxxxx" */

//#define ROW_INFO                17
#define ROW_INFO                20
#define COL_INFO                0       /* "xxxxxxxxxxxx" */

#define ROW_MAP						0
///mod140126 ʍL鏈
//#define COL_MAP                  12
#define COL_MAP                  20

//#define ROW_CUT                 18
#define ROW_CUT                 21
#define COL_CUT                 0       /* <cut> */

//#define ROW_STUN                19
#define ROW_STUN                22
#define COL_STUN                0       /* <stun> */

//#define ROW_HUNGRY              20
#define ROW_HUNGRY              23
#define COL_HUNGRY              0       /* "Weak" / "Hungry" / "Full" / "Gorged" */

//#define ROW_STATE               20
#define ROW_STATE               23
#define COL_STATE                4      /* <state> */

///mod150114 ړԕ\
#define ROW_MOVESTATE               23
#define COL_MOVESTATE                8      /* <state> */


#define ROW_SPEED               (-1)
#define COL_SPEED               (-24)      /* "Slow (-NN)" or "Fast (+NN)" */

#define ROW_STUDY               (-1)
#define COL_STUDY               (-13)      /* "Study" */

#define ROW_DEPTH               (-1)
#define COL_DEPTH               (-8)      /* "Lev NNN" / "NNNN ft" */

#define ROW_STATBAR             (-1)
#define COL_STATBAR              0
#define MAX_COL_STATBAR         (-26)


/*
 * Number of feats we change to (Excluding default). Used in f_info.txt.
 */
#define MAX_FEAT_STATES	 8


/*
 * Wilderness terrains
 */
#define TERRAIN_EDGE             0 /* Edge of the World */
#define TERRAIN_TOWN             1 /* Town */
#define TERRAIN_DEEP_WATER       2 /* Deep water */
#define TERRAIN_SHALLOW_WATER    3 /* Shallow water */
#define TERRAIN_SWAMP            4 /* Swamp */
#define TERRAIN_DIRT             5 /* Dirt */
#define TERRAIN_GRASS            6 /* Grass */
#define TERRAIN_TREES            7 /* Trees */
#define TERRAIN_DESERT           8 /* Desert */
#define TERRAIN_SHALLOW_LAVA     9 /* Shallow lava */
#define TERRAIN_DEEP_LAVA       10 /* Deep lava */
#define TERRAIN_MOUNTAIN        11 /* Mountain */
//v1.1.32 ȊXpn`ǉ
#define TERRAIN_SPECIAL_TOWN    12 


#define MAX_WILDERNESS          13 /* Maximum wilderness index */


/*
 * Feature flags - should be used instead of feature indexes unless generating.
 * Originally from UnAngband, and modified into TR-like style in Hengband
 */


#define FF_LOS           0
#define FF_PROJECT       1 /*:::ڍוsB{gȂǂʉ߉\Ȓn`SʁH*/
#define FF_MOVE          2
#define FF_PLACE         3 //ڍוs@X^[zuĂ悢n`HH
#define FF_DROP          4
#define FF_SECRET        5
#define FF_NOTICE        6
#define FF_REMEMBER      7
#define FF_OPEN          8
#define FF_CLOSE         9
#define FF_BASH          10
#define FF_SPIKE         11/*:::Œ肳ꂽhA/Œ\ȃhA?*/
#define FF_DISARM        12
#define FF_STORE         13
#define FF_TUNNEL        14
#define FF_MAY_HAVE_GOLD 15
#define FF_HAS_GOLD      16
#define FF_HAS_ITEM      17
#define FF_DOOR          18
#define FF_TRAP          19
#define FF_STAIRS        20
#define FF_GLYPH         21
#define FF_LESS          22
#define FF_MORE          23/*:::ʂ̊KɑtO@gbvhAEKiȂ*/
#define FF_AVOID_RUN     24
#define FF_FLOOR         25
#define FF_WALL          26
#define FF_PERMANENT     27
#define FF_BOMB			 28 //X^[Tt@CApe
#define FF_ELDER_SIGN    29 //_̈ 
/* #define FF_XXX02         30 */
#define FF_HIT_TRAP      31

/* #define FF_BRIDGE        32 */
/* #define FF_RIVER         33 */
/* #define FF_LAKE          34 */
/* #define FF_BRIDGED       35 */
/* #define FF_COVERED       36 */
#define FF_GLOW          37
#define FF_ENSECRET      38
#define FF_WATER         39
#define FF_LAVA          40
/*:::SHALLOWDEEP͐Ɨn̗Ɏg炵*/
#define FF_SHALLOW       41
#define FF_DEEP          42
/* #define FF_FILLED        43 */
#define FF_HURT_ROCK     44/*:::Ηn/n\ȕ*/
/* #define FF_HURT_FIRE     45 */
/* #define FF_HURT_COLD     46 */
/* #define FF_HURT_ACID     47 */
/* #define FF_ICE           48 */
/* #define FF_ACID          49 */
/* #define FF_OIL           50 */
///mod150719 zsǉ
#define FF_PLATE    51
/* #define FF_CAN_CLIMB     52 */
#define FF_CAN_FLY       53
#define FF_CAN_SWIM      54
#define FF_CAN_PASS      55
/* #define FF_CAN_OOZE      56 */
#define FF_CAN_DIG       57
/* #define FF_HIDE_ITEM     58 */
/* #define FF_HIDE_SNEAK    59 */
/* #define FF_HIDE_SWIM     60 */
/* #define FF_HIDE_DIG      61 */
/* #define FF_KILL_HUGE     62 */
/* #define FF_KILL_MOVE     63 */

/* #define FF_PICK_TRAP     64 */
/* #define FF_PICK_DOOR     65 */
/* #define FF_ALLOC         66 */
/* #define FF_CHEST         67 */
/* #define FF_DROP_1D2      68 */
/* #define FF_DROP_2D2      69 */
/* #define FF_DROP_GOOD     70 */
/* #define FF_DROP_GREAT    71 */
/* #define FF_HURT_POIS     72 */
/* #define FF_HURT_ELEC     73 */
/* #define FF_HURT_WATER    74 */
/* #define FF_HURT_BWATER   75 */
/* #define FF_USE_FEAT      76 */
/* #define FF_GET_FEAT      77 */
/* #define FF_GROUND        78 */
/* #define FF_OUTSIDE       79 */
/* #define FF_EASY_HIDE     80 */
/* #define FF_EASY_CLIMB    81 */
/* #define FF_MUST_CLIMB    82 */
#define FF_TREE          83
/* #define FF_NEED_TREE     84 */
/* #define FF_BLOOD         85 */
/* #define FF_DUST          86 */
/* #define FF_SLIME         87 */
#define FF_PLANT         88
///mod150412 }ǉ
#define FF_SPIDER_NEST_1    89
///mod160319 ĂȂǂ̗Ƃ
#define FF_TEWI_PIT			90
#define FF_HANAKOSAN		91
#define FF_PORTAL			92

/* #define FF_INSTANT       90 */
/* #define FF_EXPLODE       91 */
/* #define FF_TIMED         92 */
/* #define FF_ERUPT         93 */
/* #define FF_STRIKE        94 */
/* #define FF_SPREAD        95 */

#define FF_SPECIAL       96
#define FF_HURT_DISI     97
#define FF_QUEST_ENTER   98
#define FF_QUEST_EXIT    99
#define FF_QUEST         100
#define FF_SHAFT         101
#define FF_MOUNTAIN      102
#define FF_BLDG          103
#define FF_MINOR_GLYPH   104
#define FF_PATTERN       105
#define FF_TOWN          106
#define FF_ENTRANCE      107
#define FF_MIRROR        108
#define FF_UNPERM        109
#define FF_TELEPORTABLE  110
#define FF_CONVERT       111
#define FF_GLASS         112

#define FF_FLAG_MAX      113
#define FF_FLAG_SIZE     (1 + ((FF_FLAG_MAX - 1) / 32))

/* Which features are dynamic */
#define have_dynamic_flags(ARRAY) \
	(!!((ARRAY)[(FF_INSTANT / 32)] & \
	    ((1UL << (FF_INSTANT % 32)) | \
	     (1UL << (FF_EXPLODE % 32)) | \
	     (1UL << (FF_TIMED % 32)) | \
	     (1UL << (FF_ERUPT % 32)) | \
	     (1UL << (FF_STRIKE % 32)) | \
	     (1UL << (FF_SPREAD % 32)))))


/*
 * Feature action flags
 */
#define FAF_DESTROY     0x01
#define FAF_NO_DROP     0x02
#define FAF_CRASH_GLASS 0x04


/*
 * Bit flags for teleportation
 */
#define TELEPORT_NONMAGICAL 0x00000001 /*:::@ɊȂe|[g@EBU[hR}hAgAhȂ*/
#define TELEPORT_PASSIVE    0x00000002 /*:::e|AEFCAgbvA_[Ȃǂɂe|[g*/
#define TELEPORT_DEC_VALOUR 0x00000004
///mod140222 KׂɌĂԁ@łȂΎs
#define TELEPORT_FORCE_NEXT 0x00000008
#define	TELEPORT_ANYPLACE	0x00000010 //e|łȂX^[̂Ȃ}bvȂǂւłe|[gĂ܂Be|[^[sp
#define TELEPORT_IGNORE_MON 0x00000020 //e|\ɃX^[𖳎

/* Types of doors */
#define DOOR_DEFAULT    -1
#define DOOR_DOOR        0
#define DOOR_GLASS_DOOR  1
#define DOOR_CURTAIN     2

#define MAX_DOOR_TYPES   3

#define feat_locked_door_random(DOOR_TYPE) \
	(feat_door[(DOOR_TYPE)].num_locked ? \
	 feat_door[(DOOR_TYPE)].locked[randint0(feat_door[(DOOR_TYPE)].num_locked)] : feat_none)

#define feat_jammed_door_random(DOOR_TYPE) \
	(feat_door[(DOOR_TYPE)].num_jammed ? \
	 feat_door[(DOOR_TYPE)].jammed[randint0(feat_door[(DOOR_TYPE)].num_jammed)] : feat_none)


/* Types of normal traps */
#define NOT_TRAP        -1
#define TRAP_TRAPDOOR    0
#define TRAP_PIT         1
#define TRAP_SPIKED_PIT  2
#define TRAP_POISON_PIT  3
#define TRAP_TY_CURSE    4
#define TRAP_TELEPORT    5
#define TRAP_FIRE        6
#define TRAP_ACID        7
#define TRAP_SLOW        8
#define TRAP_LOSE_STR    9
#define TRAP_LOSE_DEX   10
#define TRAP_LOSE_CON   11
#define TRAP_BLIND      12
#define TRAP_CONFUSE    13
#define TRAP_POISON     14
#define TRAP_SLEEP      15
#define TRAP_TRAPS      16
#define TRAP_ALARM      17

//̐lf_info.txtSUBTYPE_??̒lɈvĂB
//ǉƂobject2.cMAX_NORMAL_TRAPSӂɂ

/* Types of special traps */
#define TRAP_OPEN       18
#define TRAP_ARMAGEDDON 19
#define TRAP_PIRANHA    20

//v1.1.24
#define TRAP_BEAM		21



/* Maximum locked/jammed doors */
#define MAX_LJ_DOORS 8


/* Types of pattern tiles */
#define NOT_PATTERN_TILE      -1
#define PATTERN_TILE_START    0
#define PATTERN_TILE_1        1
#define PATTERN_TILE_2        2
#define PATTERN_TILE_3        3
#define PATTERN_TILE_4        4
#define PATTERN_TILE_END      5
#define PATTERN_TILE_OLD      6
#define PATTERN_TILE_TELEPORT 7
#define PATTERN_TILE_WRECKED  8


/* Types of conversions */
#define CONVERT_TYPE_FLOOR   0
#define CONVERT_TYPE_WALL    1
#define CONVERT_TYPE_INNER   2
#define CONVERT_TYPE_OUTER   3
#define CONVERT_TYPE_SOLID   4
#define CONVERT_TYPE_STREAM1 5
#define CONVERT_TYPE_STREAM2 6


/*
 * Bit flags for the *_can_enter() and monster_can_cross_terrain()
 */
#define CEM_RIDING              0x0001
#define CEM_P_CAN_ENTER_PATTERN 0x0002


/* Lighting levels of features' attr and char */

#define F_LIT_STANDARD 0 /* Standard */
#define F_LIT_LITE     1 /* Brightly lit */
#define F_LIT_DARK     2 /* Darkened */

#define F_LIT_NS_BEGIN 1 /* Nonstandard */
#define F_LIT_MAX      3


/*** Artifact indexes (see "lib/edit/a_info.txt") ***/

#define ART_ELENDIL              2
#define ART_JUDGE                3
#define ART_NARYA				10
#define ART_NENYA				11
#define ART_POWER               13
#define ART_AHO                 14
#define ART_PALANTIR			15

#define ART_SOULKEEPER			19
#define ART_JULIAN              23

#define ART_SHIVA_JACKET		26
#define ART_THORIN				29
#define ART_BERUTHIEL			34
#define ART_SHIVA_SHOES			61

#define ART_ICANUS              128
#define ART_INDRA               32
#define ART_CHAOS               33
#define ART_TERROR              40
#define ART_AMBER               41
#define ART_COLLUIN				43
#define ART_TUOR				49
#define ART_CAMBELEG			50

#define ART_STONEMASK           141
#define ART_JACK                42
#define ART_LUTHIEN				48

#define ART_HEAVENLY_MAIDEN     216
#define ART_CORWIN              53
#define ART_THANOS				56
#define ART_CAINE               63
#define ART_FIONA               68
#define ART_CALRIS              69
#define ART_GRAYSWANDIR         70
#define ART_NOTHUNG             72
#define ART_TWILIGHT            76
#define ART_AGLARANG			78
#define ART_WEREWINDLE          81
#define ART_CHAINSWORD          82
#define ART_VORPAL_BLADE        89
#define ART_GLAIVE_PAIN          91
#define ART_GUNGNIR				94
#define ART_THE_DAWN			107
#define ART_KUSANAGI            125
#define ART_RAZORBACK			126
#define ART_GIL_GALAD			134
#define ART_CHARIOT				136
#define ART_MURAMASA            139
#define ART_LAPUTA				142
#define ART_MAGATAMA			144
#define ART_ZANTETSU            145
#define ART_KAGAMI				146
#define ART_SOULCRUSH           149
#define ART_GURENKI				155
#define ART_TONBO				156
#define ART_MUSASI_KATANA       164
#define ART_MUSASI_WAKIZASI     165
#define ART_QUICKTHORN          167
#define ART_TINYTHORN           168
#define ART_EXCALIBUR			169
#define ART_EXCALIBUR_J         171
#define ART_HAKABUSA			177
#define ART_STORMBRINGER        178
#define ART_NARSIL              179
#define ART_BARD_BOW			122
#define ART_NIGHT                199

#define ART_DESTINY             95
#define ART_HAGEN               96
#define ART_BLOOD               186
#define ART_GROND               108
#define ART_HURIN				130
#define ART_MJOLLNIR            132
#define ART_WINBLOWS            135
#define ART_XIAOLONG            140
#define ART_NYOIBOU				152
#define ART_ANUBIS				153
#define ART_HYOUSIGI            162
#define ART_SHUTEN_DOJI         181
#define ART_G_HAMMER            182
#define ART_CHINGRONG			187
#define ART_AMENONUBOKO			188
#define ART_AEGISFANG           193
#define ART_GOTHMOG             196
#define ART_FUNDIN              198
#define ART_SACRED_KNIGHT		201
#define ART_HARNESS_HELL		202
#define ART_CHARMED_PENDANT		203
#define ART_BARD                122
#define ART_BRAND               123
#define ART_CRIMSON             16
#define ART_GOGO				204
#define ART_ROBIN_HOOD          205
#define ART_AESCULAPIUS			209
#define ART_BARD_ARROW          148
#define ART_ELMI				212

#define ART_ODUNU				228
#define ART_MENPO				229
#define ART_QUEEN_OF_RED		231
#define ART_WRIST				232
#define ART_HAGOROMO_MOON		234
#define ART_YUUKA				235
#define ART_HISOU				236

#define ART_ROUKANKEN			237
#define ART_HAKUROUKEN			238
#define ART_ZANMATOU			240
#define ART_CROWBAR				242
#define ART_OUJAKU				243
#define ART_ALHAZRED			244
#define ART_JINKONTOU			245
#define ART_IBUKI				246
#define ART_METALHAND			247
#define ART_ROBERTA				248
#define ART_WALTER				249
#define ART_HOUTOU				250
#define ART_YORIMASA			251
#define ART_NAZRIN				252
#define ART_DAIKOKU				254
#define ART_BELTHRO				121
#define ART_YOICHI				143
#define ART_SANAGI				255
#define ART_KRONOS				256
#define ART_MASKET				257
#define ART_SHINMYOUMARU		258
#define ART_BLOODYMOON			186
#define ART_GOKASHITIKIN		259
#define ART_AMENOKAGAMI		260
#define ART_KUKAI			261
#define ART_DEATH_CSYTHE	262
#define ART_CHICKEN_KNIFE	263
#define ART_BISYAMON	264
#define ART_SAIGYOU		265
#define ART_MARIO		266
#define ART_ECSEDI		267
#define ART_SEIMEI		269
#define ART_ASTARTE			274
#define ART_AMENOHABAKIRI	275
#define ART_ZYOGA			276
#define ART_NAUSICAA			277
#define ART_HOSHIGUMA		278
#define ART_IDUNOME			279
#define ART_HIRAISHI		280
#define ART_TRAPEZOHEDRON	281
#define ART_EIKI			282
#define ART_CADUCEUS		283
#define ART_CLOWNPIECE		284 //NEs[X̏@ꏈɂxtra4-1
#define ART_HECATIA			285 //TVc
#define ART_SARASVATI		286
#define ART_YUKARI			287
#define ART_HARMONIA		288
#define ART_KAGUYA_DRAGON	289 //̋
#define ART_KAGUYA_HOURAI	290 //H̋ʂ̎}
#define ART_KAGUYA_HOTOKE	291 //̌΂̔
#define ART_KAGUYA_HINEZUMI	292 //Αl̔
#define ART_KAGUYA_TSUBAME	293 //̎qL

#define ART_TOYOHIME		294
#define ART_BUCKLAND		295
#define ART_GRIMOIRE_OF_MARISA	297
#define ART_YAKUZAGUN_1		299
#define ART_YAKUZAGUN_2		300
#define ART_BFG9000			301
#define ART_3DPRINTER_GUN	304
#define ART_FREEZER			307
#define ART_RAT				308
#define ART_AMANOMAKAKO		309
#define ART_YORIHIME		310
#define ART_SHIOMITSUTAMA	311

#define ART_MURASAME		313
#define ART_BEPPIN			316
#define ART_BLACK_ROD		320
#define ART_KODUCHI_TENGU	323
#define ART_KINTAROU		326
#define ART_KUKAI_KASA		327
#define ART_HYAKKI			328
#define ART_RED_SHOES		329
#define ART_ANDVARI			330

/*** Ego-Item indexes (see "lib/edit/e_info.txt") ***/
#define EGO_BOW_ACCURACY	1
#define EGO_BOW_VELOCITY	2
#define EGO_BOW_EX_MIGHT	3
#define EGO_BOW_EX_SHOTS	4
#define EGO_BOW_WARRIOR		5
#define EGO_BOW_HUNTER		6

#define EGO_ARROW_HUNTER	7
#define EGO_ARROW_HOLY		8
#define EGO_ARROW_DRAGONSLAY	9
#define EGO_ARROW_ELEC		10
#define EGO_ARROW_FIRE		11
#define EGO_ARROW_COLD		12
#define EGO_ARROW_AMANOZYAKU	13

#define EGO_ARROW_POIS		182


#define EGO_WEAPON_HERO		14
#define EGO_WEAPON_DEFENDER	15
#define EGO_WEAPON_ONI		16
#define EGO_WEAPON_SHARP	17
#define EGO_WEAPON_EXSHARP	18
#define EGO_WEAPON_EXATTACK	19
#define EGO_WEAPON_FORCE	20
#define EGO_WEAPON_QUAKE	21
#define EGO_WEAPON_BRANDACID	22
#define EGO_WEAPON_BRANDELEC	23
#define EGO_WEAPON_BRANDFIRE	24
#define EGO_WEAPON_BRANDCOLD	25
#define EGO_WEAPON_BRANDPOIS	26
#define EGO_WEAPON_BRANDELEM	27
#define EGO_WEAPON_VAMP		28
#define EGO_WEAPON_SUI_RYU	29
#define EGO_WEAPON_RYU_JIN	30
#define EGO_WEAPON_HAKUREI	31
#define EGO_WEAPON_GHOST	32
#define EGO_WEAPON_DEMON	33
#define EGO_WEAPON_DEMONLORD	34
#define EGO_WEAPON_CHAOS	35
#define EGO_WEAPON_GODEATER	36
#define EGO_WEAPON_HUNTER	37
#define EGO_WEAPON_GHOSTBUSTER	38
#define EGO_WEAPON_YOUKAITAIZI	39
#define EGO_WEAPON_DEMONSLAY	40
#define EGO_WEAPON_DRAGONSLAY	41
#define EGO_WEAPON_MURDERER	42

#define EGO_BODY_NINGYO		43
#define EGO_BODY_KAPPA		44
#define EGO_BODY_GATEKEEPER	45
#define EGO_BODY_FAIRY		46
#define EGO_BODY_HEAVEN		47
#define EGO_BODY_ONI		48
#define EGO_BODY_TENGU		49
#define EGO_BODY_KISHIN		50
#define EGO_BODY_MAKAISHIN	51
#define EGO_BODY_HASHIHIME	52
#define EGO_BODY_GHOST		53

#define EGO_SHIELD_ELEMENT	54
#define EGO_SHIELD_HAKUROU	55
#define EGO_SHIELD_DEFENDER	56
#define EGO_SHIELD_ORLEANS	57
#define EGO_SHIELD_DULLAHAN	58
#define EGO_SHIELD_GHOST	59

#define EGO_HEAD_TEACHER	60
#define EGO_HEAD_WITCH		61
#define EGO_HEAD_TEN_NIN	62
#define EGO_HEAD_REAPER		63
#define EGO_HEAD_MAGI		64
#define EGO_HEAD_TENGU		65
#define EGO_HEAD_DEFENDER	66
#define EGO_HEAD_ONI		67
#define EGO_HEAD_BEAST		68
#define EGO_HEAD_SATORI		69
#define EGO_HEAD_PRINCESS	70
#define EGO_HEAD_POLTERGEIST	71
#define EGO_HEAD_FOOL		72
#define EGO_HEAD_TATARI		73

#define EGO_HEAD_CLOWN		184 ///mod150918ǉ

#define EGO_CLOAK_PATROL	74
#define EGO_CLOAK_OPTICAL	75
#define EGO_CLOAK_NIGHT		76
#define EGO_CLOAK_SAINT		77
#define EGO_CLOAK_ZIGOKUGARASU	78
#define EGO_CLOAK_RYUUGUU	79
#define EGO_CLOAK_YUKIONNA	80
#define EGO_CLOAK_VAMPIRE	81
#define EGO_CLOAK_TUTIGUMO	82
#define EGO_CLOAK_GHOST		83

#define EGO_HANDS_FAIRY		84
#define EGO_HANDS_KAAPPA	85
#define EGO_HANDS_MASTER	86
#define EGO_HANDS_MUSOU		87//
#define EGO_HANDS_ONI		88
#define EGO_HANDS_IMP		89
#define EGO_HANDS_JIANGSHI	90
#define EGO_HANDS_FORBIDDEN	91

#define EGO_BOOTS_FAIRY		92
#define EGO_BOOTS_D_FAIRY	93
#define EGO_BOOTS_KAPPA		94
#define EGO_BOOTS_RAVEN		95
#define EGO_BOOTS_TSUKUMO	96
#define EGO_BOOTS_KASYA		97
#define EGO_BOOTS_WANDERING	98
#define EGO_BOOTS_GHOST		99
#define EGO_BOOTS_YAKU		100

#define EGO_SHATTERED		101
#define EGO_BLASTED		102

#define EGO_LITE_BRIGHT		103
#define EGO_LITE_ILLUMINATION	104
#define EGO_LITE_BEAST		105
#define EGO_LITE_LONG		106
#define EGO_LITE_DARKNESS	107
#define EGO_LITE_IMMORTAL	108

#define EGO_RING_HERO		109
#define EGO_RING_MUSOU		110
#define EGO_RING_SYURA		111
#define EGO_RING_EXTRA_AC	112
#define EGO_RING_BO_MISS_1	113
#define EGO_RING_BO_MANA	114
#define EGO_RING_BA_FIRE_1	115
#define EGO_RING_BA_COLD_2	116
#define EGO_RING_BA_ELEC_2	117
#define EGO_RING_BA_ACID_1	118
#define EGO_RING_BA_MANA	119
#define EGO_RING_DOUBLESPEED	120
#define EGO_RING_HUNTER		121
#define EGO_RING_PERFECTMAID	122
#define EGO_RING_TADIKARAO	123
#define EGO_RING_REGEN		124
#define EGO_RING_LIGHT		125
#define EGO_RING_DETECTALLMON	126
#define EGO_RING_STEALTH	127
#define EGO_RING_TELE_OTHER	128
#define EGO_RING_ACCURACY	129
#define EGO_RING_DAMAGE		130
#define EGO_RING_RESISTLIGHT	131
#define EGO_RING_RESISTDARK	132
#define EGO_RING_WIZARDRY	133
#define EGO_RING_GALAXY		134
#define EGO_RING_GALAXY2	135
#define EGO_RING_DRAIN_EXP	136
#define EGO_RING_PACIFIST	137
#define EGO_RING_AGGRAVATE	138
#define EGO_RING_TY_CURSE	139
#define EGO_RING_RES_TIME	140
#define EGO_RING_TELE_RANDOM	141
#define EGO_RING_ALBINO		142

#define EGO_AMU_SENNIN		143
#define EGO_AMU_RES_TIME	144
#define EGO_AMU_DRAIN_EXP	145
#define EGO_AMU_STUPIDITY	146
#define EGO_AMU_AGGRAVATE	147
#define EGO_AMU_TY_CURSE	148
#define EGO_AMU_PROTECTION	149
#define EGO_AMU_IDENTIFY	150
#define EGO_AMU_DEFENDER	151
#define EGO_AMU_OPPOSE		152
#define EGO_AMU_STEALTH		153
#define EGO_AMU_PHASE_DOOR	154
#define EGO_AMU_NORANDOMTELE	155
#define EGO_AMU_D_DOOR		156
#define EGO_AMU_LEVITATION	157
#define EGO_AMU_HIGH_MAGI	158
#define EGO_AMU_OFTHEMOON	159
#define EGO_AMU_DETECTION	160
#define EGO_AMU_RES_FIRE        161
#define EGO_AMU_RES_FIRE_       162
#define EGO_AMU_RES_COLD        163
#define EGO_AMU_RES_COLD_       164
#define EGO_AMU_RES_ELEC        165
#define EGO_AMU_RES_ELEC_       166
#define EGO_AMU_RES_ACID        167
#define EGO_AMU_RES_ACID_       168
#define EGO_RIBBON_RED		169
#define EGO_RIBBON_PURPLE	170
#define EGO_RIBBON_YELLOW	171
#define EGO_RIBBON_BLUE		172
#define EGO_RIBBON_GREEN	173
#define EGO_RIBBON_ORANGE	174

#define EGO_RIBBON_WHITE	175
#define EGO_RIBBON_CHARM	176

#define EGO_RIBBON_RAINBOW	177
#define EGO_RIBBON_BLACK	178
#define EGO_RIBBON_BRIGHT	179
#define EGO_RIBBON_PATTERN	180
#define EGO_RIBBON_BLOOD	181

#define EGO_WEAPON_FUJIN	183
#define EGO_HEAD_CLOWN		184

#define EGO_GUN_LOWQUALITY	185
#define EGO_GUN_MAGATSUHI	186
#define EGO_GUN_WALTER		187
#define EGO_GUN_MOON		188
#define EGO_GUN_THOUSAND	189
#define EGO_GUN_FLAME		190
#define EGO_GUN_PLASMA		191
#define EGO_GUN_KAPPA		192
#define EGO_GUN_YATAGARASU	193
#define EGO_GUN_M_SCIENTIST	194
//v1.1.17
#define EGO_JUNKO_PURIFIED	195
//v1.1.48
#define EGO_BODY_POVERTY	196


/* Activation effects for random artifacts */
#define ACT_SUNLIGHT            1
#define ACT_BO_MISS_1           2
#define ACT_BA_POIS_1           3
#define ACT_BO_ELEC_1           4
#define ACT_BO_ACID_1           5
#define ACT_BO_COLD_1           6
#define ACT_BO_FIRE_1           7
#define ACT_BA_COLD_1           8
#define ACT_BA_FIRE_1           9
#define ACT_DRAIN_1             10
#define ACT_BA_COLD_2           11
#define ACT_BA_ELEC_2           12
#define ACT_DRAIN_2             13
#define ACT_VAMPIRE_1           14
#define ACT_BO_MISS_2           15
#define ACT_BA_FIRE_3           16
#define ACT_BA_COLD_3           17
#define ACT_BA_ELEC_3           18
#define ACT_WHIRLWIND           19
#define ACT_VAMPIRE_2           20
#define ACT_CALL_CHAOS          21
#define ACT_ROCKET              22
#define ACT_DISP_EVIL           23
#define ACT_BA_MISS_3           24
#define ACT_DISP_GOOD           25
#define ACT_BO_MANA             26
#define ACT_BA_FIRE_2           27
#define ACT_BA_WATER            28
#define ACT_BA_STAR             29
#define ACT_BA_DARK             30
#define ACT_BA_MANA             31
#define ACT_PESTICIDE           32
#define ACT_BLINDING_LIGHT      33
#define ACT_BIZARRE             34
#define ACT_CAST_BA_STAR        35
#define ACT_BLADETURNER         36
#define ACT_BA_ACID_1           37
#define ACT_BR_FIRE             38
#define ACT_BR_COLD             39
#define ACT_BR_DRAGON           40
/* 33 - 50 unused */
#define ACT_CONFUSE             51
#define ACT_SLEEP               52
#define ACT_QUAKE               53
#define ACT_TERROR              54
#define ACT_TELE_AWAY           55
#define ACT_BANISH_EVIL         56
#define ACT_GENOCIDE            57
#define ACT_MASS_GENO           58
#define ACT_SCARE_AREA          59
#define ACT_AGGRAVATE           60
/* 59 - 64 unused */
#define ACT_CHARM_ANIMAL        65
#define ACT_CHARM_UNDEAD        66
#define ACT_CHARM_OTHER         67
#define ACT_CHARM_ANIMALS       68
#define ACT_CHARM_OTHERS        69
#define ACT_SUMMON_ANIMAL       70
#define ACT_SUMMON_PHANTOM      71
#define ACT_SUMMON_ELEMENTAL    72
#define ACT_SUMMON_DEMON        73
#define ACT_SUMMON_UNDEAD       74
#define ACT_SUMMON_HOUND        75
#define ACT_SUMMON_DAWN         76
#define ACT_SUMMON_OCTOPUS      77
/* 76 - 80 unused */
#define ACT_CHOIR_SINGS         80
#define ACT_CURE_LW             81
#define ACT_CURE_MW             82
#define ACT_CURE_POISON         83
#define ACT_REST_LIFE           84
#define ACT_REST_ALL            85
#define ACT_CURE_700            86
#define ACT_CURE_1000           87
#define ACT_CURING              88
#define ACT_CURE_MANA_FULL      89
/* 90 unused */
#define ACT_ESP                 91
#define ACT_BERSERK             92
#define ACT_PROT_EVIL           93
#define ACT_RESIST_ALL          94
#define ACT_SPEED               95
#define ACT_XTRA_SPEED          96
#define ACT_WRAITH              97
#define ACT_INVULN              98
#define ACT_HELO                99
#define ACT_HELO_SPEED          100
#define ACT_RESIST_ACID         101
#define ACT_RESIST_FIRE         102
#define ACT_RESIST_COLD         103
#define ACT_RESIST_ELEC         104
#define ACT_RESIST_POIS         105
/* 106 - 110 unused */
#define ACT_LIGHT               111
#define ACT_MAP_LIGHT           112
#define ACT_DETECT_ALL          113
#define ACT_DETECT_XTRA         114
#define ACT_ID_FULL             115
#define ACT_ID_PLAIN            116
#define ACT_RUNE_EXPLO          117
#define ACT_RUNE_PROT           118
#define ACT_SATIATE             119
#define ACT_DEST_DOOR           120
#define ACT_STONE_MUD           121
#define ACT_RECHARGE            122
#define ACT_ALCHEMY             123
#define ACT_DIM_DOOR            124
#define ACT_TELEPORT            125
#define ACT_RECALL              126
#define ACT_JUDGE               127
#define ACT_TELEKINESIS         128
#define ACT_DETECT_UNIQUE       129
#define ACT_ESCAPE              130
#define ACT_DISP_CURSE_XTRA     131
#define ACT_BRAND_FIRE_BOLTS    132
#define ACT_RECHARGE_XTRA       133
#define ACT_LORE                134
#define ACT_SHIKOFUMI           135
#define ACT_PHASE_DOOR          136
#define ACT_DETECT_ALL_MONS     137
#define ACT_ULTIMATE_RESIST     138

///mod140115 ǉ
#define ACT_NERUNERUNERUNE  140
#define ACT_ALTER_REALITY	141
#define ACT_KOGASA_LASER	142
#define ACT_KOGASA_ROCKET	143
///mod140325 ǉ
#define ACT_HYPER_BERSERK	144
#define ACT_DRINK			145
#define ACT_ROBERTA			146
#define ACT_WALTER			147
#define ACT_DETECT_ITEM			148
#define ACT_SANAGI			149 //VڈӐ_̓S
#define ACT_DER_FREISCHUTZ  150
#define ACT_GOKASHITIKIN	151
#define ACT_SUMMON_FOUNTAIN	152
#define ACT_TORNADO			153
#define ACT_TRAPEZOHEDRON	154
#define ACT_DETECT_ARTIFACT	155
#define ACT_LUNATIC_TIME	156
#define ACT_SUMMON_GHOSTS  157
#define ACT_TRANSPORT_ITEM  158
#define ACT_TOYOHIME		159
#define ACT_MIGHTY_THROW	160
#define ACT_FINAL_STRIKE	161
#define ACT_GUN_VARIABLE	162
#define ACT_YAKUZA_GUN		163
#define ACT_BFG9000			164
#define ACT_BAROQUE			165
#define ACT_HARKONNEN2		166
#define ACT_SHIOMITSUTAMA	167
#define ACT_DAZZLE			168
#define ACT_MID_RANGE_ATTACK	169
#define ACT_BO_INACT		170
#define ACT_MATARA			171
#define ACT_HYAKKIYAKOU		172
#define ACT_SWORD_DANCE		173


#define ACT_CAST_OFF            250
#define ACT_FISHING             251
#define ACT_INROU               252
#define ACT_MURAMASA            253
#define ACT_BLOODY_MOON         254
#define ACT_CRIMSON             255

/*** Object "tval" and "sval" codes ***/


/*
 * The values for the "tval" field of various objects.
 *
 * This value is the primary means by which items are sorted in the
 * player inventory, followed by "sval" and "cost".
 *
 * Note that a "BOW" with tval = 19 and sval S = 10*N+P takes a missile
 * weapon with tval = 16+N, and does (xP) damage when so combined.  This
 * fact is not actually used in the source, but it kind of interesting.
 *
 * Note that as of 2.7.8, the "item flags" apply to all items, though
 * only armor and weapons and a few other items use any of these flags.
 */
/*:::ACe啪IDB*/
/*:::tval_to_attr[128]char tval_to_char[128]łɎgĂ̂ŁA128𒴂Ɣɖʓ|ɂȂB*/


//TVAL:
#define MIN_MAGIC			1

#define TV_BOOK_ELEMENT		1
#define TV_BOOK_FORESEE		2
#define TV_BOOK_ENCHANT		3
#define TV_BOOK_SUMMONS		4

#define TV_BOOK_MYSTIC		5
#define TV_BOOK_LIFE		6
#define TV_BOOK_PUNISH		7
#define TV_BOOK_NATURE		8

#define TV_BOOK_TRANSFORM	9
#define TV_BOOK_DARKNESS	10	
#define TV_BOOK_NECROMANCY	11
#define TV_BOOK_CHAOS		12

#define MAX_MAGIC          12 //OCCULT@ɂ邪AMAX_MAGIC͓ȂǂBOőΉ悤B

#define TV_BOOK_HISSATSU	13
#define TV_BOOK_MEDICINE	14
#define TV_BOOK_OCCULT		15
#define TV_BOOK_END		15

///mod151226 14256ɂBZR}h炵gĂȂȂ͂H
#define TV_BOOK_MUSIC	256 


#define TV_GOLD			16

#define OBJ_GOLD_LIST   53     /* First "gold" entry *//*:::TVALłȂk_idx*/
#define MAX_GOLD        18      /* Number of "gold" entries */

#define TV_BULLET		20
#define TV_ARROW		21
#define TV_BOLT			22

#define TV_KNIFE		23
#define TV_SWORD		24
#define TV_KATANA		25
#define TV_HAMMER		26
#define TV_STICK		27
#define TV_AXE			28
#define TV_SPEAR		29
#define TV_POLEARM		30

#define TV_BOW			31
#define TV_CROSSBOW		32
#define TV_GUN			33

//v1.1.32 MAGICBOOKMAGICITEM אڍUɎgȂɎ̑SʂɂBO}AۂȂ
#define TV_MAGICITEM		34 
// MAGICWEAPONOTHERWEAPON̈Ⴂ͐BBMAGICWEAPONm\ˑ_[W̑אڍUACeɂ悤Ɠ͎vĂɂȂ߁B
#define TV_MAGICWEAPON		35
#define TV_OTHERWEAPON		36

#define TV_SHIELD		37
#define TV_RIBBON		38
#define TV_LITE			39
#define TV_CLOTHES		40
#define TV_ARMOR		41
#define TV_DRAG_ARMOR		42
#define TV_CLOAK		43
#define TV_HEAD			44
#define TV_GLOVES		45
#define TV_BOOTS		46

#define TV_RING			47
#define TV_AMULET		48
#define TV_WHISTLE		49
#define TV_MASK			50 //p

#define TV_STAFF		55

#define TV_MACHINE		57

#define TV_CHEST		60
#define TV_FIGURINE		61
#define TV_PHOTO		62 
#define TV_CAPTURE		63 //d{

#define TV_WAND			65
#define TV_ROD			66
#define TV_BUNBUN		67 //XBV
#define TV_KAKASHI		68 //ԉʎqO
#define TV_ITEMCARD		69 //ACeJ[h

#define TV_SCROLL		70

#define TV_SOUVENIR		72
#define TV_MATERIAL		73
#define TV_MUSHROOM		74
#define TV_POTION		75
#define TV_FLASK		76
#define TV_SOFTDRINK		77
#define TV_ALCOHOL		78
#define TV_SWEETS		79
#define TV_FOOD			80

#define TV_COMPOUND		81 //tɂ鍇ACe

//{Ɨp
/*
#define TV_LIFE_BOOK    90
#define TV_SORCERY_BOOK 91
#define TV_NATURE_BOOK  92
#define TV_CHAOS_BOOK   93
#define TV_DEATH_BOOK   94
#define TV_TRUMP_BOOK   95
#define TV_ARCANE_BOOK  96
#define TV_CRAFT_BOOK 97
#define TV_DAEMON_BOOK  98
#define TV_CRUSADE_BOOK 99
#define TV_MUSIC_BOOK   105
#define TV_HISSATSU_BOOK 106
#define TV_HEX_BOOK     107
*/

#define TV_EQUIP_BEGIN    TV_BULLET
#define TV_EQUIP_END      TV_WHISTLE
#define TV_MISSILE_BEGIN  TV_BULLET
#define TV_MISSILE_END    TV_BOLT
#define TV_WEARABLE_BEGIN TV_KNIFE
#define TV_WEARABLE_END   TV_AMULET
#define TV_WEAPON_BEGIN   TV_KNIFE
#define TV_WEAPON_END     TV_GUN

//lookup_kind()łǂSVALłƂg
#define SV_ANY 					255

//SVAL:㎿hbv̖{ TV:1-13
#define SV_BOOK_MIN_GOOD    2

//SVAL:ʂƒe TV:20-22
#define SV_AMMO_LIGHT		0	//ʏ
#define SV_AMMO_NORMAL		1	//|S̖
#define SV_AMMO_HEAVY		2	//ǔ̖

//SVAL:Z TV:23
#define SV_WEAPON_BROKEN_DAGGER	1
#define SV_WEAPON_KNIFE		2
#define SV_WEAPON_DAGGER		3
#define SV_WEAPON_MAIN_GAUCHE		4
#define SV_WEAPON_YAMAGATANA		5
#define SV_WEAPON_TANTO		6
#define SV_WEAPON_NINJA_SWORD		7
#define SV_WEAPON_HAYABUSA		8
#define SV_WEAPON_DRAGON_DAGGER	9
#define SV_WEAPON_DOKUBARI		10
#define SV_WEAPON_VAJRA		11 //v1.1.31 ƌ؋n


//SVAL: TV:24
#define SV_WEAPON_BROKEN_SWORD		1	
#define SV_WEAPON_RAPIER		2
#define SV_WEAPON_SHORT_SWORD		3
#define SV_WEAPON_SABRE		4
#define SV_WEAPON_SCIMITAR		5
#define SV_WEAPON_LONG_SWORD		6
#define SV_WEAPON_BASTARD_SWORD	7
#define SV_WEAPON_CLAYMORE		8
#define SV_WEAPON_GREAT_SWORD		9
#define SV_WEAPON_EXECUTIONERS_SWORD	10
#define SV_WEAPON_BLADE_OF_CHAOS	11
#define SV_WEAPON_HIHIIROKANE		12

//SVAL: TV:25
#define SV_WEAPON_BROKEN_KATANA	1	
#define SV_WEAPON_SHORT_KATANA		2
#define SV_WEAPON_KATANA		3
#define SV_WEAPON_GREAT_KATANA		4
#define SV_WEAPON_ANCIENT_KATANA	5
#define SV_WEAPON_EVIL_KATANA		6

//SVAL:݊ TV:26
#define SV_WEAPON_SPANNER		1	
#define SV_WEAPON_MACE			2	
#define SV_WEAPON_MORNING_STAR		3	
#define SV_WEAPON_FLAIL		4	
#define SV_WEAPON_WAR_HAMMER		5	
#define SV_WEAPON_BALL_AND_CHAIN	6	
#define SV_WEAPON_KANASAIBOU		7
#define SV_WEAPON_KINE				8

//SVAL:_ TV:27
#define SV_WEAPON_BROKEN_STICK		1
#define SV_WEAPON_FLOWER		2
#define SV_WEAPON_WIZSTAFF		3
#define SV_WEAPON_QUARTERSTAFF		4
#define SV_WEAPON_SIXFEET		5
#define SV_WEAPON_SYAKUJYOU		6
#define SV_WEAPON_NUNCHAKU		7
#define SV_WEAPON_IRONSTICK		8
#define SV_WEAPON_OONUSA		9
#define SV_WEAPON_GROND		10
#define SV_WEAPON_KOGASA		11

//SVAL: TV:28
#define SV_WEAPON_PICK			1
#define SV_WEAPON_FARANCESCA		2
#define SV_WEAPON_HATCHET		3
#define SV_WEAPON_BROAD_AXE		4
#define SV_WEAPON_BATTLE_AXE		5
#define SV_WEAPON_LOCHABER_AXE		6
#define SV_WEAPON_GREAT_AXE		7
#define SV_WEAPON_MASAKARI		8
#define SV_WEAPON_NATA			9

//SVAL: TV:29
#define SV_WEAPON_JAVELIN		1
#define SV_WEAPON_SPEAR		2
#define SV_WEAPON_AWL_PIKE		3
#define SV_WEAPON_LONG_SPEAR		4
#define SV_WEAPON_LANCE		5
#define SV_WEAPON_HEAVY_LANCE		6
#define SV_WEAPON_TRIFURCATE_SPEAR	7

//SVAL: TV:30
#define SV_WEAPON_GLAIVE		1	
#define SV_WEAPON_NAGINATA		2
#define SV_WEAPON_LUCERNE_HAMMER	3
#define SV_WEAPON_WAR_SCYTHE		4
#define SV_WEAPON_HALBERD 		5
#define SV_WEAPON_SCYTHE_OF_SLICING	6

//SVAL:| TV:31
#define SV_FIRE_SHORT_BOW		1	
#define SV_FIRE_LONG_BOW		2

//SVAL:NX{E TV:32
#define SV_FIRE_LIGHT_CROSSBOW	1	
#define SV_FIRE_HEAVY_CROSSBOW	2

//SVAL:e TV:33
#define SV_FIRE_GUN_LUNATIC		1 //ieBbNK
#define SV_FIRE_GUN_HUNTING		2 //e
#define SV_FIRE_GUN_HANDGUN		3 //e
#define SV_FIRE_GUN_INFANTRY	4 //e
#define SV_FIRE_GUN_CRIMSON		5 //ie(INSTA_ART)
#define SV_FIRE_GUN_MUSKET		6 //}XPbge
#define SV_FIRE_GUN_SHOTGUN	7 //Uee
#define SV_FIRE_GUN_MAGNUM	8 //}Oie
#define SV_FIRE_GUN_LASER	9 //e
#define SV_FIRE_GUN_ROCKET	10 //P

#define SV_FIRE_GUN_MAX		10 //gun_base_param_table[]̔zTCY object_prepł̐+1ȏsval̏e悤ƂG[ɂ

//SVAL:}WbNACe TV:34
#define SV_MAGICITEM_MARISA	1
#define SV_MAGICITEM_MATARA	2
#define SV_MAGICITEM_HYAKKI	3

//SVAL: TV:35
#define SV_MAGICWEAPON_FUN	1

//SVAL:̑ TV:36
#define SV_OTHERWEAPON_FISHING	1
#define SV_OTHERWEAPON_NEEDLE	2

//SVAL: TV:37
#define SV_SMALL_LEATHER_SHIELD          1
#define SV_LARGE_LEATHER_SHIELD          2
#define SV_SMALL_METAL_SHIELD            3
#define SV_LARGE_METAL_SHIELD            4
#define SV_KNIGHT_SHIELD                 5
#define SV_MIRROR_SHIELD                 6
#define SV_DRAGON_SHIELD                 7
#define SV_YATA_MIRROR                   8
#define SV_SAKAZUKI						9
#define SV_HACHI						10

//SVAL:{ TV:38
#define SV_RIBBON          1
#define SV_HACHIMAKI          2
#define SV_SCARF            3
#define SV_BIG_RIBBON          4


//SVAL: TV:39
#define SV_LITE_TORCH                    1
#define SV_LITE_LANTERN                  2
#define SV_LITE_FEANOR                   3
#define SV_LITE_EDISON                   4
#define SV_LITE_GALADRIEL                5
#define SV_LITE_ELENDIL                  6
#define SV_LITE_JUDGE                    7
#define SV_LITE_LORE                     8
#define SV_LITE_PALANTIR                 9
#define SV_LITE_FLY_STONE                10
#define SV_LITE_ANDON            	 11
#define SV_LITE_HOUTOU            	 12
#define SV_LITE_SANAGI				13
#define SV_LITE_TRAPEZOHEDRON		14
#define SV_LITE_DRAGON					15


//SVAL: TV:40
#define SV_CLOTHES			1
#define SV_CLOTH_ROBE			2
#define SV_CLOTH_MAID			3
#define SV_CLOTH_DOUGI			4
#define SV_CLOTH_DRESS			5
#define SV_CLOTH_EASTERN		6
#define SV_CLOTH_SUIT			7
#define SV_CLOTH_DOUSHI			8
#define SV_CLOTH_KUROSHOUZOKU		9
#define SV_CLOTH_SYUGEN			10
#define SV_CLOTH_PADDED			11
#define SV_CLOTH_LEATHER		12
#define SV_CLOTH_MIKO			13
#define SV_CLOTH_T_SHIRT		14
#define SV_CLOTH_WORKER		15

//SVAL:Z TV:41
#define SV_ARMOR_TUB			1
#define SV_ARMOR_LEATHER		2
#define SV_ARMOR_SCALE			3
#define SV_ARMOR_CHAIN			4
#define SV_ARMOR_BRIGANDINE		5
#define SV_ARMOR_PARTIAL_PLATE		6
#define SV_ARMOR_OOYOROI		7
#define SV_ARMOR_FULL_PLATE		8
#define SV_ARMOR_MITHRIL_CHAIN		9
#define SV_ARMOR_MITHRIL_PLATE		10

//SVAL:hSZ TV:42
#define SV_DRAGARMOR_BLACK		1
#define SV_DRAGARMOR_BLUE		2
#define SV_DRAGARMOR_WHITE		3
#define SV_DRAGARMOR_RED		4
#define SV_DRAGARMOR_GREEN		5
#define SV_DRAGARMOR_MULTI		6
#define SV_DRAGARMOR_BRONZE		7
#define SV_DRAGARMOR_SILVER		8
#define SV_DRAGARMOR_GOLD		9
#define SV_DRAGARMOR_LAW		10
#define SV_DRAGARMOR_CHAOS		11
#define SV_DRAGARMOR_BALANCE		12
#define SV_DRAGARMOR_SPACE		13
#define SV_DRAGARMOR_DIAMOND		14
#define SV_DRAGARMOR_POWER		15


//SVAL:N[N TV:43
#define SV_CLOAK			1
#define SV_CLOAK_MANTLE			2
#define SV_CLOAK_FUR			3
#define SV_CLOAK_HAGOROMO		4
#define SV_CLOAK_STEALTH		5
#define SV_CLOAK_SHADOW			6
#define SV_CLOAK_CAPE			7

//SVAL: TV:44
#define SV_HEAD_HAT			1
#define SV_HEAD_TOKIN			2
#define SV_HEAD_DRESS			3
#define SV_HEAD_WITCH			4
#define SV_HEAD_LEATHER			5
#define SV_HEAD_MASK			6
#define SV_HEAD_METALCAP		7
#define SV_HEAD_STARHELM		8
#define SV_HEAD_STEELHELM		9
#define SV_HEAD_GOLDCROWN		10
#define SV_HEAD_JEWELCROWN		11
#define SV_HEAD_DRAGONHELM		12
#define SV_HEAD_IRONCROWN		13
#define SV_HEAD_KASA			14

//SVAL: TV:45
#define SV_HAND_GLOVES			1
#define SV_HAND_DRESSGLOVES		2
#define SV_HAND_LEATHERGLOVES		3
#define SV_HAND_CESTIS			4
#define SV_HAND_ARMGUARDS		5
#define SV_HAND_GAUNTLETS		6
#define SV_HAND_DRAGONGLOVES		7
#define SV_HAND_WRISTUNIT		8

//SVAL: TV:46
#define SV_LEG_SHOES			1
#define SV_LEG_WARAZI			2
#define SV_LEG_GETA			3
#define SV_LEG_BOOTS			4
#define SV_LEG_LEATHERBOOTS		5
#define SV_LEG_METALSHODBOOTS		6
#define SV_LEG_SABATON			7
#define SV_LEG_DRAGONBOOTS		8

//SVAL:w TV:47
#define SV_RING_AGGRAVATION              1
#define SV_RING_WEAKNESS                 2
#define SV_RING_STUPIDITY                3
#define SV_RING_TELEPORTATION            4
#define SV_RING_WOE                      5
#define SV_RING_MIGHTY_THROW             6
#define SV_RING_LEVITATION_FALL          7
#define SV_RING_RESIST_FIRE              8
#define SV_RING_RESIST_COLD              9
#define SV_RING_STR                     10
#define SV_RING_DEX                     11
#define SV_RING_CON                     12
#define SV_RING_SPEED                   13
#define SV_RING_ATTACKS                 14
#define SV_RING_PROTECTION              15
#define SV_RING_ELEC                    16
#define SV_RING_ACID                    17
#define SV_RING_FLAMES                  18
#define SV_RING_ICE                     19
#define SV_RING_RESIST_POIS             20
#define SV_RING_FREE_ACTION             21
#define SV_RING_SEE_INVIS               22
#define SV_RING_SEARCHING               23
#define SV_RING_ACCURACY                24
#define SV_RING_DAMAGE                  25
#define SV_RING_SLAYING                 26
#define SV_RING_FRAKIR                  27
#define SV_RING_TULKAS                  28
#define SV_RING_NARYA                   29
#define SV_RING_NENYA                   30
#define SV_RING_VILYA                   31
#define SV_RING_POWER                   32
#define SV_RING_RES_FEAR                33
#define SV_RING_RES_LD                  34
#define SV_RING_RES_NETHER              35
#define SV_RING_RES_WATER               36
#define SV_RING_RES_SOUND               37
#define SV_RING_RES_CONFUSION           38
#define SV_RING_RES_SHARDS              39
#define SV_RING_RES_DISENCHANT          40
#define SV_RING_RES_CHAOS               41
#define SV_RING_RES_BLINDNESS           42
//#define SV_RING_RES_HOLY                43 //A~Ɉړ
#define SV_RING_ANDVARI                 43 //v1.1.48ǉ
#define SV_RING_LORDLY                  44
#define SV_RING_AHO                     45
#define SV_RING_SHOTS                   46
#define SV_RING_SUSTAIN                 47
#define SV_RING_DEC_MANA                48
#define SV_RING_WARNING                 49
#define SV_RING_MUSCLE                  50

//SVAL:A~bg TV:48
#define SV_AMULET_TELEPORT               1
#define SV_AMULET_RESIST_ELEC            2
#define SV_AMULET_SLOW_DIGEST            3 //ɂȂĂ
#define SV_AMULET_RESIST_ACID            4
#define SV_AMULET_SEARCHING              5
#define SV_AMULET_BRILLIANCE             6
#define SV_AMULET_CHARISMA               7
#define SV_AMULET_THE_MAGI               8
#define SV_AMULET_REFLECTION             9
#define SV_AMULET_CARLAMMAS             10
#define SV_AMULET_INGWE                 11
#define SV_AMULET_DWARVES               12
#define SV_AMULET_NO_MAGIC              13
#define SV_AMULET_NO_TELE               14
#define SV_AMULET_RESISTANCE            15
#define SV_AMULET_TELEPATHY             16
#define SV_AMULET_FARAMIR               17
#define SV_AMULET_BOROMIR               18
#define SV_AMULET_MAGATAMA              19
#define SV_AMULET_DOOM                  20
#define SV_AMULET_INTELLIGENCE          21
#define SV_AMULET_WISDOM                22
#define SV_AMULET_MAGIC_MASTERY         23
#define SV_AMULET_NIGHT                 24
#define SV_AMULET_SACRED                25
#define SV_AMULET_OFTHEHELL             26
#define SV_AMULET_CHARMED               27
#define SV_AMULET_GOGO                  28
#define SV_AMULET_RES_HOLY              29
#define SV_AMULET_PENDULUM              30
#define SV_AMULET_HARMONIA				31
#define SV_AMULET_KOYASUGAI				32
#define SV_AMULET_FOX					33
#define SV_AMULET_HAKUREI				34
#define SV_AMULET_SHIOMITSUTAMA			35


///SVALJ:TVAL49
#define SV_WHISTLE                  	1

///SVAL:TVAL55
#define SV_STAFF_SLOWNESS                1
#define SV_STAFF_HASTE_MONSTERS          2
#define SV_STAFF_SUMMONING               3
#define SV_STAFF_TELEPORTATION           4
#define SV_STAFF_IDENTIFY                5
#define SV_STAFF_REMOVE_CURSE            6
#define SV_STAFF_STARLITE                7
#define SV_STAFF_LITE                    8
#define SV_STAFF_MAPPING                 9
#define SV_STAFF_DETECT_GOLD            10
#define SV_STAFF_DETECT_ITEM            11
#define SV_STAFF_DETECT_TRAP            12
#define SV_STAFF_DETECT_DOOR            13
#define SV_STAFF_DETECT_INVIS           14
#define SV_STAFF_DETECT_EVIL            15
#define SV_STAFF_CURE_LIGHT             16
#define SV_STAFF_CURING                 17
#define SV_STAFF_HEALING                18
#define SV_STAFF_THE_MAGI               19
#define SV_STAFF_SLEEP_MONSTERS         20
#define SV_STAFF_SLOW_MONSTERS          21
#define SV_STAFF_SPEED                  22
#define SV_STAFF_PROBING                23
#define SV_STAFF_DISPEL_EVIL            24
#define SV_STAFF_POWER                  25
#define SV_STAFF_HOLINESS               26
#define SV_STAFF_GENOCIDE               27
#define SV_STAFF_EARTHQUAKES            28
#define SV_STAFF_DESTRUCTION            29
#define SV_STAFF_DARKNESS               30
#define SV_STAFF_MSTORM                 31
#define SV_STAFF_NOTHING                32
//ɏǉꍇpt␳ׂ̃[`啝ɏKvB0Ȃ炽Ԃ󂢂ĂB

//SVAL:@B TV:57
#define SV_MACHINE_WATERGUN	0
#define SV_MACHINE_SHIRIKO		1
#define SV_MACHINE_LIGHTBOMB	2		
#define SV_MACHINE_DRILLARM	3
#define SV_MACHINE_FLAME		4
#define SV_MACHINE_RADAR1		5
#define SV_MACHINE_TORPEDO		6	
#define SV_MACHINE_J_HAMMER	7	
#define SV_MACHINE_ROCKETEER	8	
#define SV_MACHINE_MOTORGUN	9	
#define SV_MACHINE_LASERGUN	10	
#define SV_MACHINE_SCOUTER	11	
#define SV_MACHINE_BARRIER1	12	
#define SV_MACHINE_MEGACLASH	13	
#define SV_MACHINE_RADAR2		14
#define SV_MACHINE_PLASMAGUN	15	
#define SV_MACHINE_TELEPORTER	16	
#define SV_MACHINE_CANNON		17	
#define SV_MACHINE_PHONON_MASER	18	
#define SV_MACHINE_ACCELERATOR	19	
#define SV_MACHINE_GATLINGGUN	20	
#define SV_MACHINE_BARRIER2		21	
#define SV_MACHINE_E_CAN		22	
#define SV_MACHINE_BARRIER3	23	
#define SV_MACHINE_ROCKET_6	24	
#define SV_MACHINE_MIDAS_HAND	25	
#define SV_MACHINE_NEUTRINOGUN	26	
#define SV_MACHINE_WAVEMOTION	27	
#define SV_MACHINE_TWILIGHT_ZONE	28	
#define SV_MACHINE_N_E_P		29

#define MAX_MACHINE 30 //@B̎
#define MAX_MACHINE_SUPPLY 14 //@B̔R̎

//SVAL: TV:60

#define SV_CHEST_RUIN	        0
#define SV_CHEST_S_WOOD		1	        
#define SV_CHEST_S_IRON		2
#define SV_CHEST_S_STEEL	3
#define SV_CHEST_MIN_LARGE      4//pH
#define SV_CHEST_L_WOOD		5
#define SV_CHEST_L_IRON		6
#define SV_CHEST_L_STEEL	7

#define SV_CHEST_MARIPO_01	11
#define SV_CHEST_MARIPO_02	12
#define SV_CHEST_MARIPO_03	13
#define SV_CHEST_MARIPO_04	14
#define SV_CHEST_MARIPO_05	15
#define SV_CHEST_MARIPO_06	16
#define SV_CHEST_MARIPO_07	17
#define SV_CHEST_MARIPO_08	18
#define SV_CHEST_MARIPO_09	19
#define SV_CHEST_MARIPO_10	20
#define SV_CHEST_MARIPO_11	21
#define SV_CHEST_MARIPO_12	22
#define SV_CHEST_MARIPO_13	23
#define SV_CHEST_MARIPO_14	24
#define SV_CHEST_MARIPO_15	25
#define SV_CHEST_MARIPO_16	26
#define SV_CHEST_MARIPO_17	27
#define SV_CHEST_MARIPO_18	28
#define SV_CHEST_MARIPO_19	29
#define SV_CHEST_MARIPO_20	30
#define SV_CHEST_MARIPO_21	31
#define SV_CHEST_MARIPO_22	32
#define SV_CHEST_MARIPO_23	33
#define SV_CHEST_MARIPO_24	34

#define SV_CHEST_DEBUG		39

//ÂV
#define SV_CHEST_OLDCASTLE	40
//~Ȁ
#define SV_CHEST_REMY	41
//N[nV
#define SV_CHEST_CLONE	42
//hSގV
#define SV_CHEST_FAIRY	43
//gւ̎hqV
#define SV_CHEST_EIRIN	44
//nx}V
#define SV_CHEST_BYAKUREN	45
//qˎ҂߂܂
#define SV_CHEST_SEIJA	46
//ϒK푈
#define SV_CHEST_KORI	47
//TgRtNg
#define SV_CHEST_SATORI	48
//lȂĕ|Ȃ
#define SV_CHEST_GRASSROOT	49

#define SV_CHEST_KANDUME        50
//؂D͂Ĉ
#define SV_CHEST_HECATIA        51
//}
#define SV_CHEST_YAMAME			52
//x
#define SV_CHEST_SUPPLY		53
//푰/NXNGXgVp
#define SV_CHEST_SPECIAL_QUEST	54
//v1.1.24 }NGXgp
#define SV_CHEST_TORRENT		55
//v1.1.36 鎸HNGXgp
#define SV_CHEST_KOSUZU			56
//v1.1.42 œ|NGXgp
#define SV_CHEST_DREAM			57

//SVAL:l` TV:61
#define SV_FIGURINE_NORMAL	0

//SVAL:ʐ^ TV:62
#define SV_PHOTO_NORMAL         0
#define SV_PHOTO_NIGHTMARE		1

//SVAL:d{ TV:63
#define SV_CAPTURE_NONE		0

//SVAL@_:TVAL65
#define SV_WAND_HEAL_MONSTER             0
#define SV_WAND_HASTE_MONSTER            1
#define SV_WAND_CLONE_MONSTER            2
#define SV_WAND_TELEPORT_AWAY            3
#define SV_WAND_DISARMING                4
#define SV_WAND_TRAP_DOOR_DEST           5
#define SV_WAND_STONE_TO_MUD             6
#define SV_WAND_LITE                     7
#define SV_WAND_SLEEP_MONSTER            8
#define SV_WAND_SLOW_MONSTER             9
#define SV_WAND_CONFUSE_MONSTER         10
#define SV_WAND_FEAR_MONSTER            11
#define SV_WAND_DRAIN_LIFE              12
#define SV_WAND_POLYMORPH               13
#define SV_WAND_STINKING_CLOUD          14
#define SV_WAND_MAGIC_MISSILE           15
#define SV_WAND_ACID_BOLT               16
#define SV_WAND_CHARM_MONSTER           17
#define SV_WAND_FIRE_BOLT               18
#define SV_WAND_COLD_BOLT               19
#define SV_WAND_ACID_BALL               20
#define SV_WAND_ELEC_BALL               21
#define SV_WAND_FIRE_BALL               22
#define SV_WAND_COLD_BALL               23
#define SV_WAND_WONDER                  24
#define SV_WAND_DISINTEGRATE            25
#define SV_WAND_DRAGON_FIRE             26
#define SV_WAND_DRAGON_COLD             27
#define SV_WAND_DRAGON_BREATH           28
#define SV_WAND_ROCKETS                 29
#define SV_WAND_STRIKING                30
#define SV_WAND_GENOCIDE                31
//32ȏǉꍇpt␳ׂ̃[`啝ɏKvB


//SVALbh:TVAL66
#define SV_ROD_DETECT_TRAP               0
#define SV_ROD_DETECT_DOOR               1
#define SV_ROD_IDENTIFY                  2
#define SV_ROD_RECALL                    3
#define SV_ROD_ILLUMINATION              4
#define SV_ROD_MAPPING                   5
#define SV_ROD_DETECTION                 6
#define SV_ROD_PROBING                   7
#define SV_ROD_CURING                    8
#define SV_ROD_HEALING                   9
#define SV_ROD_RESTORATION              10
#define SV_ROD_SPEED                    11
#define SV_ROD_PESTICIDE                12
#define SV_ROD_MIN_DIRECTION			12//pB牺̓^[Qbgwv..łȂ
#define SV_ROD_TELEPORT_AWAY            13
#define SV_ROD_DISARMING                14
#define SV_ROD_LITE                     15
#define SV_ROD_SLEEP_MONSTER            16
#define SV_ROD_SLOW_MONSTER             17
#define SV_ROD_DRAIN_LIFE               18
#define SV_ROD_POLYMORPH                19
#define SV_ROD_ACID_BOLT                20
#define SV_ROD_ELEC_BOLT                21
#define SV_ROD_FIRE_BOLT                22
#define SV_ROD_COLD_BOLT                23
#define SV_ROD_ACID_BALL                24
#define SV_ROD_ELEC_BALL                25
#define SV_ROD_FIRE_BALL                26
#define SV_ROD_COLD_BALL                27
#define SV_ROD_HAVOC                    28
#define SV_ROD_STONE_TO_MUD             29
#define SV_ROD_AGGRAVATE                30
//32ȏǉꍇpt␳ׂ̃[`啝ɏKvB

#define SV_ITEMCARD	1

//SVAL:TVAL70
#define SV_SCROLL_DARKNESS               0
#define SV_SCROLL_AGGRAVATE_MONSTER      1
#define SV_SCROLL_CURSE_ARMOR            2
#define SV_SCROLL_CURSE_WEAPON           3
#define SV_SCROLL_SUMMON_MONSTER         4
#define SV_SCROLL_SUMMON_UNDEAD          5
#define SV_SCROLL_SUMMON_PET             6
#define SV_SCROLL_TRAP_CREATION          7
#define SV_SCROLL_PHASE_DOOR             8
#define SV_SCROLL_TELEPORT               9
#define SV_SCROLL_TELEPORT_LEVEL        10
#define SV_SCROLL_WORD_OF_RECALL        11
#define SV_SCROLL_IDENTIFY              12
#define SV_SCROLL_STAR_IDENTIFY         13
#define SV_SCROLL_REMOVE_CURSE          14
#define SV_SCROLL_STAR_REMOVE_CURSE     15
#define SV_SCROLL_ENCHANT_ARMOR         16
#define SV_SCROLL_ENCHANT_WEAPON_TO_HIT 17
#define SV_SCROLL_ENCHANT_WEAPON_TO_DAM 18

#define SV_SCROLL_STAR_ENCHANT_ARMOR    20
#define SV_SCROLL_STAR_ENCHANT_WEAPON   21
#define SV_SCROLL_RECHARGING            22
#define SV_SCROLL_MUNDANITY             23
#define SV_SCROLL_LIGHT                 24
#define SV_SCROLL_MAPPING               25
#define SV_SCROLL_DETECT_GOLD           26
#define SV_SCROLL_DETECT_ITEM           27
#define SV_SCROLL_DETECT_TRAP           28
#define SV_SCROLL_DETECT_DOOR           29
#define SV_SCROLL_DETECT_INVIS          30

#define SV_SCROLL_HOLY_CHANT            34

#define SV_SCROLL_MONSTER_CONFUSION     36
#define SV_SCROLL_PROTECTION_FROM_EVIL  37
#define SV_SCROLL_RUNE_OF_PROTECTION    38
#define SV_SCROLL_TRAP_DOOR_DESTRUCTION 39

#define SV_SCROLL_STAR_DESTRUCTION      41
#define SV_SCROLL_DISPEL_UNDEAD         42
#define SV_SCROLL_SPELL                 43
#define SV_SCROLL_GENOCIDE              44
#define SV_SCROLL_MASS_GENOCIDE         45
#define SV_SCROLL_ACQUIREMENT           46
#define SV_SCROLL_STAR_ACQUIREMENT      47
#define SV_SCROLL_FIRE                  48
#define SV_SCROLL_ICE                   49
#define SV_SCROLL_CHAOS                 50
#define SV_SCROLL_RUMOR                 51
#define SV_SCROLL_ARTIFACT              52
#define SV_SCROLL_RESET_RECALL          53
#define SV_SCROLL_SUMMON_KIN            54

//SVAL:ACeTV:72
#define SV_SOUVENIR_GAMEBOY             1
#define SV_SOUVENIR_ILMENITE            2
#define SV_SOUVENIR_PHOENIX_FEATHER     3
#define SV_SOUVENIR_SMARTPHONE		    4
#define SV_SOUVENIR_KAPPA_5				5
#define SV_SOUVENIR_PRISM				6
#define SV_SOUVENIR_KAPPA_ARM			7
#define SV_SOUVENIR_BIG_EGG				8
#define SV_SOUVENIR_ASIA				9
#define SV_SOUVENIR_ULTRASONIC			10
#define SV_SOUVENIR_STARS_AND_STRIPES	11
#define SV_SOUVENIR_OUIJA_BOARD			12
#define SV_SOUVENIR_KINKAKUJI			13
#define SV_SOUVENIR_KESERAN_PASARAN		14
#define SV_SOUVENIR_MARISA_TUBO			15 //v1.1.18
#define SV_SOUVENIR_DOUJU				16 //v1.1.19
#define SV_SOUVENIR_MORINJI				17 //v1.1.42
#define SV_SOUVENIR_SHILVER_KEY			18

//SVAL:fTV:73
#define SV_MATERIAL_HIKARIGOKE            1
#define SV_MATERIAL_STONE                 2
#define SV_MATERIAL_HEMATITE              3
#define SV_MATERIAL_MAGNETITE             4
#define SV_MATERIAL_ARSENIC               5
#define SV_MATERIAL_MERCURY               6
#define SV_MATERIAL_MITHRIL               7
#define SV_MATERIAL_ADAMANTITE            8
#define SV_MATERIAL_DRAGONNAIL            9
#define SV_MATERIAL_DRAGONSCALE          10
#define SV_MATERIAL_GELSEMIUM            11
#define SV_MATERIAL_GARNET               12
#define SV_MATERIAL_AMETHYST             13
#define SV_MATERIAL_AQUAMARINE           14
#define SV_MATERIAL_DIAMOND              15
#define SV_MATERIAL_EMERALD              16
#define SV_MATERIAL_MOONSTONE            17
#define SV_MATERIAL_RUBY                 18
#define SV_MATERIAL_PERIDOT              19
#define SV_MATERIAL_SAPPHIRE             20
#define SV_MATERIAL_OPAL                 21
#define SV_MATERIAL_TOPAZ                22
#define SV_MATERIAL_LAPISLAZULI          23
#define SV_MATERIAL_METEORICIRON         24
#define SV_MATERIAL_HIHIIROKANE          25
#define SV_MATERIAL_SCRAP_IRON          26
#define SV_MATERIAL_MOTOR_BULLET		27 //$3000
#define SV_MATERIAL_GATLING_BULLET		28 //$30000
#define SV_MATERIAL_CANNONBALL			29 //$15000
#define SV_MATERIAL_ICESCALE			30
#define SV_MATERIAL_NIGHTMARE_FRAGMENT	31
#define SV_MATERIAL_HOPE_FRAGMENT		32
#define SV_MATERIAL_MYSTERIUM			33//~XeE
#define SV_MATERIAL_COAL		 		34//Y
#define SV_MATERIAL_TAKAKUSAGORI		35//Š|
#define SV_MATERIAL_IZANAGIOBJECT		36//ɜQ
#define SV_MATERIAL_ISHIZAKURA	 		37//΍
#define SV_MATERIAL_BROKEN_NEEDLE 		38//܂ꂽj
#define SV_MATERIAL_NINOMIYA			39 //{Y(_~[ACe)


//SVAL:LmRTV:74
#define SV_MUSHROOM_POISON                   0
#define SV_MUSHROOM_BLINDNESS                1
#define SV_MUSHROOM_PARANOIA                 2
#define SV_MUSHROOM_CONFUSION                3
#define SV_MUSHROOM_HALLUCINATION            4
#define SV_MUSHROOM_PARALYSIS                5
#define SV_MUSHROOM_WEAKNESS                 6
#define SV_MUSHROOM_SICKNESS                 7
#define SV_MUSHROOM_STUPIDITY                8
#define SV_MUSHROOM_NAIVETY                  9
#define SV_MUSHROOM_UNHEALTH                10
#define SV_MUSHROOM_DISEASE                 11
#define SV_MUSHROOM_CURE_POISON             12
#define SV_MUSHROOM_CURE_BLINDNESS          13
#define SV_MUSHROOM_CURE_PARANOIA           14
#define SV_MUSHROOM_CURE_CONFUSION          15
#define SV_MUSHROOM_CURE_SERIOUS            16
#define SV_MUSHROOM_RESTORE_STR             17
#define SV_MUSHROOM_RESTORE_CON             18
#define SV_MUSHROOM_RESTORING               19
#define SV_MUSHROOM_MANA             20
#define SV_MUSHROOM_BERSERK               21
#define SV_MUSHROOM_MON_RED             22
#define SV_MUSHROOM_MON_WHITE             23
#define SV_MUSHROOM_MON_BLUE             24
#define SV_MUSHROOM_MON_BLACK             25
#define SV_MUSHROOM_MON_GREEN             26
#define SV_MUSHROOM_MON_GAUDY             27
#define SV_MUSHROOM_MON_GRAY             28
#define SV_MUSHROOM_MON_CLEAR             29
#define SV_MUSHROOM_MON_SUPER             30
#define SV_MUSHROOM_MON_L_BLUE             31
#define SV_MUSHROOM_PUFFBALL			32 //v1.1.43 IjtXx

//SVAL:TVAL75
#define SV_POTION_SLOWNESS               4
#define SV_POTION_POISON                 6
#define SV_POTION_BLINDNESS              7
#define SV_POTION_SLEEP                 11
#define SV_POTION_LOSE_MEMORIES         13
#define SV_POTION_RUINATION             15
#define SV_POTION_DEC_STR               16
#define SV_POTION_DEC_INT               17
#define SV_POTION_DEC_WIS               18
#define SV_POTION_DEC_DEX               19
#define SV_POTION_DEC_CON               20
#define SV_POTION_DEC_CHR               21
#define SV_POTION_DETONATIONS           22
#define SV_POTION_DEATH                 23
#define SV_POTION_INFRAVISION           24
#define SV_POTION_DETECT_INVIS          25
#define SV_POTION_SLOW_POISON           26
#define SV_POTION_CURE_POISON           27
#define SV_POTION_BOLDNESS              28
#define SV_POTION_SPEED                 29
#define SV_POTION_RESIST_HEAT           30
#define SV_POTION_RESIST_COLD           31
#define SV_POTION_HEROISM               32
#define SV_POTION_BESERK_STRENGTH       33
#define SV_POTION_CURE_LIGHT            34
#define SV_POTION_CURE_SERIOUS          35
#define SV_POTION_CURE_CRITICAL         36
#define SV_POTION_HEALING               37
#define SV_POTION_STAR_HEALING          38
#define SV_POTION_LIFE                  39
#define SV_POTION_RESTORE_MANA          40
#define SV_POTION_RESTORE_EXP           41
#define SV_POTION_RES_STR               42
#define SV_POTION_RES_INT               43
#define SV_POTION_RES_WIS               44
#define SV_POTION_RES_DEX               45
#define SV_POTION_RES_CON               46
#define SV_POTION_RES_CHR               47
#define SV_POTION_INC_STR               48
#define SV_POTION_INC_INT               49
#define SV_POTION_INC_WIS               50
#define SV_POTION_INC_DEX               51
#define SV_POTION_INC_CON               52
#define SV_POTION_INC_CHR               53
#define SV_POTION_AUGMENTATION          55
#define SV_POTION_ENLIGHTENMENT         56
#define SV_POTION_STAR_ENLIGHTENMENT    57
#define SV_POTION_SELF_KNOWLEDGE        58
#define SV_POTION_EXPERIENCE            59
#define SV_POTION_RESISTANCE            60
#define SV_POTION_CURING                61
#define SV_POTION_INVULNERABILITY       62
#define SV_POTION_NEW_LIFE              63
#define SV_POTION_NEO_TSUYOSHI          64
#define SV_POTION_TSUYOSHI              65
#define SV_POTION_POLYMORPH             66
#define SV_POTION_NANIKASUZUSHIKUNARU	67
#define SV_POTION_POISON2				68
#define SV_POTION_LOVE			69 //

//ER TV:76
#define SV_FLASK_OIL		0 
#define SV_FLASK_BATTERY		1 //$500
#define SV_FLASK_ROCKET		2 //$2000
#define SV_FLASK_ENERGY_RED	3 //$3000
#define SV_FLASK_ENERGY_BLUE	4 //$4000
#define SV_FLASK_ENERGY_WHITE	5 //$6000
#define SV_FLASK_ENERGY_BLACK	6 //$8000
#define SV_FLASK_ENERGY_PARTICLE	7 //$100000
#define SV_FLASK_ENERGY_WAVEMOTION	8 //$300000
#define SV_FLASK_ENERGY_HYPERSPACE	9 //$500000

//SVAL ݕiȊOj:TVAL77
#define SV_DRINK_WATER                  0
#define SV_DRINK_APPLE_JUICE            1
#define SV_DRINK_SLIME_MOLD             2
#define SV_DRINK_GRAPE_JUICE             3
#define SV_DRINK_SALT_WATER             4


//SVAL :TVAL78
#define SV_ALCOHOL_BEER		1
#define SV_ALCOHOL_GINZYOU	2
#define SV_ALCOHOL_ONIKOROSHI	3
#define SV_ALCOHOL_GOLDEN_MEAD	4
#define SV_ALCOHOL_STRONGWINE	5
#define SV_ALCOHOL_MAGGOT_BEER		6
#define SV_ALCOHOL_ORC	7
#define SV_ALCOHOL_1420	8
#define SV_ALCOHOL_MOON	9
#define SV_ALCOHOL_KUMO	10
#define SV_ALCOHOL_90	11
#define SV_ALCOHOL_SCARLET	12
#define SV_ALCOHOL_DOBUROKU	13
#define SV_ALCOHOL_SYOUTYUU	14
#define SV_ALCOHOL_PONSYU	15
#define SV_ALCOHOL_KOKO	16
#define SV_ALCOHOL_NECTAR	17
#define SV_ALCOHOL_TUTINOKO	18
#define SV_ALCOHOL_APPLE	19
#define SV_ALCOHOL_SYUTYUU	20
#define SV_ALCOHOL_NIHONKAI	21
#define SV_ALCOHOL_SUZUME	22
#define SV_ALCOHOL_EIRIN	23
#define SV_ALCOHOL_KAPPA	24
#define SV_ALCOHOL_TRUE_ONIKOROSHI	25
#define SV_ALCOHOL_MARISA	26
#define SV_ALCOHOL_KUSHINADA	27
#define SV_ALCOHOL_REISYU	28
#define SV_ALCOHOL_MANZAIRAKU	29
#define SV_ALCOHOL_UMESHU	30
#define SV_ALCOHOL_MAMUSHI	31







//SVAL َq:TVAL79
#define SV_SWEET_COOKIE  	        1
#define SV_SWEET_POTATO  	        2
#define SV_SWEETS_MIRACLE_FRUIT		3
#define SV_SWEETS_DANGO				4
#define SV_SWEETS_PEACH				5
#define SV_SWEETS_MANJYU			6

//SVAL H:TVAL80
#define SV_FOOD_RATION                  0
#define SV_FOOD_HARDBUSC                1
#define SV_FOOD_VENISON                 2
#define SV_FOOD_SLIMEMOLD               3
#define SV_FOOD_SENTAN  	        4
#define SV_FOOD_CUCUMBER  	        5
#define SV_FOOD_ABURAAGE  	        6
#define SV_FOOD_EEL					7


//tpiSVAL Tval:81
#define SV_COMPOUND_MOLOTOV_COCKTAIL	1 //Ήr
#define SV_COMPOUND_STRONG_ACID			2 //_
#define SV_COMPOUND_MUSCLE_DRUG			3 //ؓ
#define SV_COMPOUND_BREATH_OF_FIRE		4 //ΐ
#define SV_COMPOUND_NINGYO				5 //l
#define SV_COMPOUND_GELSEMIUM_TEA		6 //QZ~EGKX̂
#define SV_COMPOUND_NIGHTMARE			7 //iCgA
#define SV_COMPOUND_NECOMIMI			8 //lR~~
#define SV_COMPOUND_KOKUSHI				9 //mo̖
#define SV_COMPOUND_STAR_FEEDING		10 //*h{*
#define SV_COMPOUND_METAMOR_BEAST		11 //b
#define SV_COMPOUND_YOKOSHIMA			12 //œt
#define SV_COMPOUND_STAR_DETORNATION	13 //**̖
#define SV_COMPOUND_TITAN				14 //l̖
#define SV_COMPOUND_ICHIKORORI			15 //leC`R̖
#define SV_COMPOUND_SUPER_SPEED			16 //V
#define SV_COMPOUND_ANTIMATTER			17 //
#define SV_COMPOUND_METAMOR_DRAGON		18 //
#define SV_COMPOUND_HOURAI				19 //H̖
#define SV_COMPOUND_MAGICAL_ECO_BOMB	20 //}WJYpėp{
#define SV_COMPOUND_SAIBAIMAN			21 //͔|}
#define SV_COMPOUND_JEKYLL				22 //WLm̖
#define SV_COMPOUND_HAPPY				23 //K
#define SV_COMPOUND_MICRO_OCSIGEN		24 //~NILVQ
#define SV_COMPOUND_VLADIMIR			25 //L旧̐pĈΞ֒ee(pł͂Ȃ)
#define SV_COMPOUND_MEDICINE_CHEST		26 //fBX`FXg()Ɏg_~[ACe

/*** General flag values ***/


/*
 * Special cave grid flags
 */
#define CAVE_MARK       0x0001    /* memorized feature *//*:::̃}XLĂ*/
#define CAVE_GLOW       0x0002    /* self-illuminating *//*:::ŏĂH*/
#define CAVE_ICKY       0x0004    /* part of a vault */
#define CAVE_ROOM       0x0008    /* part of a room */
#define CAVE_LITE       0x0010    /* lite flag  *//*:::C~l[VȂǂŏƂ炳ĂH*/
#define CAVE_VIEW       0x0020    /* view flag *//*:::ʂĂH*/
#define CAVE_TEMP       0x0040    /* temp flag */
#define CAVE_XTRA       0x0080    /* misc flag */
#define CAVE_MNLT       0x0100    /* Illuminated by monster */
#define CAVE_MNDK       0x8000    /* Darken by monster */

/* Used only while cave generation */
#define CAVE_FLOOR      0x0200
#define CAVE_EXTRA      0x0400
#define CAVE_INNER      0x0800
#define CAVE_OUTER      0x1000
#define CAVE_SOLID      0x2000
#define CAVE_VAULT      0x4000
#define CAVE_MASK (CAVE_FLOOR | CAVE_EXTRA | CAVE_INNER | CAVE_OUTER | CAVE_SOLID | CAVE_VAULT)

/* Used only after cave generation */
#define CAVE_KNOWN      0x0200    /* Directly viewed or map detected flag */
#define CAVE_NOTE       0x0400    /* Flag for delayed visual update (needs note_spot()) */
#define CAVE_REDRAW     0x0800    /* Flag for delayed visual update (needs lite_spot()) */
#define CAVE_OBJECT     0x1000    /* Mirror, glyph, etc. */
#define CAVE_UNSAFE     0x2000    /* Might have trap */
#define CAVE_IN_DETECT  0x4000    /* trap detected area (inner circle only) */


/*
 * Bit flags for the "project()" function
 *
 *   JUMP: Jump directly to the target location (this is a hack)
 *   BEAM: Work as a beam weapon (affect every grid passed through)
 *   THRU: Continue "through" the target (used for "bolts"/"beams")
 *   STOP: Stop as soon as we hit a monster (used for "bolts")
 *   GRID: Affect each grid in the "blast area" in some way
 *   ITEM: Affect each object in the "blast area" in some way
 *   KILL: Affect each monster in the "blast area" in some way
 *   HIDE: Hack -- disable "visual" feedback from projection
 *   DISI: Disintegrate non-permanent features
 *   PLAYER: Main target is player (used for riding player)
 *   AIMED: Target is only player or monster, so don't affect another.
 *          Depend on PROJECT_PLAYER.
 *          (used for minimum (rad == 0) balls on riding player)
 *   REFLECTABLE: Refrectable spell attacks (used for "bolts")
 *   NO_HANGEKI: Avoid counter attacks of monsters
 *   PATH: Only used for printing project path
 *   FAST: Hide "visual" of flying bolts until blast
 */
#define PROJECT_JUMP        0x01/*:::^[Qbgĝ悤ɈBꂪGɓĂX^[̎voȂǂ͕\ȂBEUȂ*/
#define PROJECT_BEAM        0x02/*:::r[*/
#define PROJECT_THRU        0x04/*:::ђʂHr[ƂǂႤ̂*/
#define PROJECT_STOP        0x08
#define PROJECT_GRID        0x10
#define PROJECT_ITEM        0x20/*:::ACej󂷂*/
#define PROJECT_KILL        0x40/*:::X^[iƁjɃ_[W^*/
#define PROJECT_HIDE        0x80/*:::GtFNg\Ȃ*/
#define PROJECT_DISI        0x100/*:::HǂnH*/
#define PROJECT_PLAYER      0x200/*:::e󂯂U*/
#define PROJECT_AIMED       0x400/*:::_U@*/
#define PROJECT_REFLECTABLE 0x800 /*:::ˉ\@{glƂĂgĂ炵̂Ńr[REFLECTABLEɂ邱Ƃ͂łȂƎv*/
#define PROJECT_NO_HANGEKI  0x1000 /*:::X^[̃JE^[̑ΏۂɂȂȂ*/
#define PROJECT_PATH        0x2000
#define PROJECT_FAST        0x4000
#define PROJECT_LOS         0x8000
#define PROJECT_MASTERSPARK 0x10000 ///mod140326 }X^[Xp[NȂǂ̋僌[U[
//#define PROJECT_MADAN       0x20000 ///mod140517 e̎ˎ v1.1.44ŃtOp~execute_restartable_project()gƂɂ
#define PROJECT_OPT         0x40000 ///mod140829 J^fBIvgbN en_猩郉_ȃX^[ɌĈxĔ
#define PROJECT_COMPRESS    0x80000 ///mod150308 eꕶRvbT[@㉺ɂȂ
#define PROJECT_FUTO		0x100000 //zspꏈ@M̏Ŏ~܂
#define PROJECT_FINAL		0x200000 //uCWOX^[p@˒

//^intŎg邱Ƃ̂0x80000000`̂͂܂


/*
 * Special caster ID for project()
 */
#define PROJECT_WHO_UNCTRL_POWER -1
#define PROJECT_WHO_GLASS_SHARDS -2
#define PROJECT_WHO_OMIKUJI_HELL -3 //勥݂
#define PROJECT_WHO_SUICIDAL_FIRE -4 //g
#define PROJECT_WHO_EXPLODE_BOMB -5 //X^[Tt@CAe
#define PROJECT_WHO_DEEPECO_BOMB -6 //fB[vGRWJ{
#define PROJECT_WHO_CONTACT_YOG		 -7
#define PROJECT_WHO_TRAP_BEAM	-8

/*
 * Bit flags for the "enchant()" function
 */
#define ENCH_TOHIT      0x01 /* Enchant to hit */
#define ENCH_TODAM      0x02 /* Enchant to damage */
#define ENCH_TOAC       0x04 /* Enchant to AC */
#define ENCH_FORCE      0x08 /* Force enchantment */

/*
 * Bit flags for the "target_set" function XXX XXX XXX
 *
 *      KILL: Target monsters
 *      LOOK: Describe grid fully
 *      XTRA: Currently unused flag
 *      GRID: Select from all grids
 */
#define TARGET_KILL             0x01
#define TARGET_LOOK             0x02
#define TARGET_XTRA             0x04
#define TARGET_GRID             0x08


/*
 * Bit flags for control of get_check_strict()
 */
#define CHECK_OKAY_CANCEL 0x01
#define CHECK_NO_ESCAPE   0x02
#define CHECK_NO_HISTORY  0x04
#define CHECK_DEFAULT_Y   0x08


/*
 * Some bit-flags for the "smart" field
 */
#define SM_RES_ACID             0x00000001
#define SM_RES_ELEC             0x00000002
#define SM_RES_FIRE             0x00000004
#define SM_RES_COLD             0x00000008
#define SM_RES_POIS             0x00000010
#define SM_RES_NETH             0x00000020
#define SM_RES_LITE             0x00000040
#define SM_RES_DARK             0x00000080
#define SM_RES_FEAR             0x00000100
#define SM_RES_CONF             0x00000200
#define SM_RES_CHAOS            0x00000400
#define SM_RES_DISEN            0x00000800
#define SM_RES_BLIND            0x00001000
//#define SM_RES_NEXUS            0x00002000
#define SM_RES_TIME             0x00002000
#define SM_RES_SOUND            0x00004000
#define SM_RES_SHARD            0x00008000
#define SM_OPP_ACID             0x00010000
#define SM_OPP_ELEC             0x00020000
#define SM_OPP_FIRE             0x00040000
#define SM_OPP_COLD             0x00080000
#define SM_OPP_POIS             0x00100000
//#define SM_OPP_XXX1             0x00200000 /* (unused) */
#define SM_RES_HOLY             0x00200000
#define SM_CLONED               0x00400000 /* XXX Cloned */
#define SM_PET                  0x00800000 /* XXX Pet */
#define SM_IMM_ACID             0x01000000
#define SM_IMM_ELEC             0x02000000
#define SM_IMM_FIRE             0x04000000
#define SM_IMM_COLD             0x08000000
#define SM_FRIENDLY             0x10000000 /* XXX Friendly */
#define SM_IMM_REFLECT          0x20000000
#define SM_IMM_FREE             0x40000000
//#define SM_IMM_MANA             0x80000000 //smarttOȂȂ̂ō폜@܂債e͂Ȃ낤B
#define SM_RES_WATER             0x80000000


/*
 * Bit flags for the "get_item" function
 */
#define USE_EQUIP	0x01	/* Allow equip items */
#define USE_INVEN	0x02	/* Allow inven items */
#define USE_FLOOR	0x04	/* Allow floor items */


/*
 * Bit flags for the "p_ptr->notice" variable
 */
#define PN_COMBINE      0x00000001L     /* Combine the pack */
#define PN_REORDER      0x00000002L     /* Reorder the pack */
#define PN_AUTODESTROY  0x00000004L     /* Auto-destroy marked item */
/* xxx (many) */


/*
 * Bit flags for the "p_ptr->update" variable
 */
#define PU_BONUS        0x00000001L     /* Calculate bonuses */
#define PU_TORCH        0x00000002L     /* Calculate torch radius */
/* xxx (many) */
#define PU_HP           0x00000010L     /* Calculate chp and mhp */
#define PU_MANA         0x00000020L     /* Calculate csp and msp */
#define PU_SPELLS       0x00000040L     /* Calculate spells */
/* xxx (many) */
/* xxx (many) */
#define PU_UN_VIEW      0x00010000L     /* Forget view */
#define PU_UN_LITE      0x00020000L     /* Forget lite */
/* xxx (many) */
#define PU_VIEW         0x00100000L     /* Update view */
#define PU_LITE         0x00200000L     /* Update lite */
#define PU_MON_LITE     0x00400000L     /* Monster illumination */
#define PU_DELAY_VIS    0x00800000L     /* Mega-Hack -- Delayed visual update */
#define PU_MONSTERS     0x01000000L     /* Update monsters */
#define PU_DISTANCE     0x02000000L     /* Update distances */
/* xxx */
#define PU_FLOW         0x10000000L     /* Update flow */
/* xxx (many) */


/*
 * Bit flags for the "p_ptr->redraw" variable
 */
#define PR_MISC         0x00000001L     /* Display Race/Class */
#define PR_TITLE        0x00000002L     /* Display Title */
#define PR_LEV          0x00000004L     /* Display Level */
#define PR_EXP          0x00000008L     /* Display Experience */
#define PR_STATS        0x00000010L     /* Display Stats */
#define PR_ARMOR        0x00000020L     /* Display Armor */
#define PR_HP           0x00000040L     /* Display Hitpoints */
#define PR_MANA         0x00000080L     /* Display Mana */
#define PR_GOLD         0x00000100L     /* Display Gold */
#define PR_DEPTH        0x00000200L     /* Display Depth */
#define PR_EQUIPPY      0x00000400L     /* Display equippy chars */
#define PR_HEALTH       0x00000800L     /* Display Health Bar */
#define PR_CUT          0x00001000L     /* Display Extra (Cut) */
#define PR_STUN         0x00002000L     /* Display Extra (Stun) */
#define PR_HUNGER       0x00004000L     /* Display Extra (Hunger) */
#define PR_STATUS       0x00008000L     /* Display Status Bar */
#define PR_XXX0         0x00010000L     /* (unused) */
#define PR_UHEALTH      0x00020000L     /* Display Uma Health Bar */
#define PR_XXX1         0x00040000L     /* (unused) */
#define PR_XXX2         0x00080000L     /* (unused) */
#define PR_STATE        0x00100000L     /* Display Extra (State) */
#define PR_SPEED        0x00200000L     /* Display Extra (Speed) */
#define PR_STUDY        0x00400000L     /* Display Extra (Study) */
#define PR_IMITATION    0x00800000L     /* Display Extra (Imitation) */
#define PR_EXTRA        0x01000000L     /* Display Extra Info */
#define PR_BASIC        0x02000000L     /* Display Basic Info */
#define PR_MAP          0x04000000L     /* Display Map */
#define PR_WIPE         0x08000000L     /* Hack -- Total Redraw */
/* xxx */
/* xxx */
/* xxx */
/* xxx */

/*
 * Bit flags for the "p_ptr->window" variable (etc)
 */
/*:::TuEBhEptO*/
#define PW_INVEN        0x00000001L     /* Display inven/equip */
#define PW_EQUIP        0x00000002L     /* Display equip/inven */
#define PW_SPELL        0x00000004L     /* Display spell list */
#define PW_PLAYER       0x00000008L     /* Display character */
#define PW_MONSTER_LIST 0x00000010L     /* Display monster list */
/* xxx */
/* xxx */
#define PW_MESSAGE      0x00000040L     /* Display messages */
#define PW_OVERHEAD     0x00000080L     /* Display overhead view */
#define PW_MONSTER      0x00000100L     /* Display monster recall */
#define PW_OBJECT       0x00000200L     /* Display object recall */
#define PW_DUNGEON      0x00000400L     /* Display dungeon view */
#define PW_SNAPSHOT     0x00000800L     /* Display snap-shot */
#define PW_FLOOR_ITEM_LIST	0x00001000L	/*:::ACeꗗ*/
/* xxx */
#define PW_BORG_1       0x00004000L     /* Display borg messages */
#define PW_BORG_2       0x00008000L     /* Display borg status */

/*
 * Bit flags for the place_monster_???() (etc)
 */
#define PM_ALLOW_SLEEP    0x00000001
#define PM_ALLOW_GROUP    0x00000002
#define PM_FORCE_FRIENDLY 0x00000004
#define PM_FORCE_PET      0x00000008
#define PM_NO_KAGE        0x00000010
#define PM_NO_PET         0x00000020
#define PM_ALLOW_UNIQUE   0x00000040
#define PM_IGNORE_TERRAIN 0x00000080
#define PM_HASTE          0x00000100
#define PM_KAGE           0x00000200
#define PM_MULTIPLY       0x00000400
#define PM_EPHEMERA       0x00000800
#define PM_NO_ENERGY      0x00001000 //ɍs͂`[WȂ
#define PM_ALLOW_SPECIAL_UNIQUE	0x00002000 //_j[NȂǂ̓ꃆj[N


/* Bit flags for monster_desc() */
#define MD_OBJECTIVE      0x00000001 /* Objective (or Reflexive) */
#define MD_POSSESSIVE     0x00000002 /* Possessive (or Reflexive) */
#define MD_INDEF_HIDDEN   0x00000004 /* Use indefinites for hidden monsters ("something") */
#define MD_INDEF_VISIBLE  0x00000008 /* Use indefinites for visible monsters ("a kobold") */
#define MD_PRON_HIDDEN    0x00000010 /* Pronominalize hidden monsters */
#define MD_PRON_VISIBLE   0x00000020 /* Pronominalize visible monsters */
#define MD_ASSUME_HIDDEN  0x00000040 /* Assume the monster is hidden */
#define MD_ASSUME_VISIBLE 0x00000080 /* Assume the monster is visible */
#define MD_TRUE_NAME      0x00000100 /* Chameleon's true name */
#define MD_IGNORE_HALLU   0x00000200 /* Ignore hallucination, and penetrate shape change */


/*
 * Bit flags for object_desc()
 */
#define OD_NAME_ONLY        0x00000001  /* Omit values, pval, inscription */
#define OD_NAME_AND_ENCHANT 0x00000002  /* Omit pval, inscription */
#define OD_OMIT_INSCRIPTION 0x00000004  /* Omit inscription */
#define OD_OMIT_PREFIX      0x00000008  /* Omit numeric prefix */
#define OD_NO_PLURAL        0x00000010  /* Don't use plural */
#define OD_STORE            0x00000020  /* Assume to be aware and known */
#define OD_NO_FLAVOR        0x00000040  /* Allow to hidden flavor */
#define OD_FORCE_FLAVOR     0x00000080  /* Get un-shuffled flavor name */

///mod140607 ̕Ƀ_CX{[iXƂ\邽߂ɒǉ
#define OD_WEAPON_RARM		0x00000100
#define OD_WEAPON_LARM		0x00000200



/*
 * Bit flags for the "p_ptr->special_attack" variable. -LM-
 *
 * Note:  The elemental and poison attacks should be managed using the 
 * function "set_ele_attack", in spell2.c.  This provides for timeouts and
 * prevents the player from getting more than one at a time.
 */
#define ATTACK_CONFUSE		0x00000001
#define ATTACK_XXX1		0x00000002
#define ATTACK_FORCE	0x00000004
#define ATTACK_DARK	    0x00000008
#define ATTACK_ACID		0x00000010
#define ATTACK_ELEC		0x00000020
#define ATTACK_FIRE		0x00000040
#define ATTACK_COLD		0x00000080
#define ATTACK_POIS		0x00000100
#define ATTACK_HOLY		0x00000200
#define ATTACK_SUIKEN		0x00000400
///mod140725 @mp
#define ATTACK_FORESIGHT	0x00000800
#define ATTACK_UNSUMMON		0x00001000
#define ATTACK_INC_DICES	0x00002000
#define ATTACK_CHAOS		0x00004000
//v1.1.22 mwbhVbgspecial_attackɂĂ݂
#define ATTACK_HEAD_SHOT	0x00008000
//v1.1.35 lm
#define ATTACK_VORPAL		0x00010000
//v1.1.46 U[h
#define ATTACK_WASTE_MONEY	0x00020000


/*:::player_type.special_defenceɓĂƖƉuH*/
#define DEFENSE_ACID		0x00000001
#define DEFENSE_ELEC		0x00000002
#define DEFENSE_FIRE		0x00000004
#define DEFENSE_COLD		0x00000008
#define DEFENSE_POIS		0x00000010
///mod140211 lfƉû߂ɒǉ ̒lset_ele_immune()ACID`COLDɒu
#define DEFENSE_4ELEM		0x00000020

#define KAMAE_GENBU             0x00000020
#define KAMAE_BYAKKO            0x00000040
#define KAMAE_SEIRYU            0x00000080
#define KAMAE_SUZAKU            0x00000100
#define KATA_IAI                0x00000200
#define KATA_FUUJIN             0x00000400
#define KATA_KOUKIJIN           0x00000800
#define KATA_MUSOU              0x00001000
#define NINJA_KAWARIMI          0x00002000
#define NINJA_S_STEALTH         0x00004000
#define MUSOU_TENSEI			0x00008000 //얲̖zV
#define NUE_UNDEFINED           0x00010000
#define SD_METAMORPHOSIS		0x00020000 //h~[ϐg
#define SD_SAKUYA_WORLD			0x00040000 //̐E
#define SD_HINA_NINGYOU			0x00080000 //􂢂̐l`
#define SD_OPTICAL_STEALTH		0x00100000 //wʁ@ꕔ̈ꎞB̂ƂONɂȂ莋EɗȂȓGɌʂȂ
#define SD_EIBON_WHEEL			0x00200000 //GC{̖̎ԗ
#define SD_MANA_SHIELD			0x00400000 //v1.1.27@EK[h
#define SD_STATUE_FORM			0x00800000 //uΑv
#define SD_HELLFIRE_BARRIER		0x01000000 //uN~iTFCVv
#define SD_EVIL_UNDULATION_1	0x02000000 //ǂ񂰓ꐫiuCrAW[Vv
#define SD_EVIL_UNDULATION_2	0x04000000
#define SD_EVIL_UNDULATION_3	0x08000000
#define CHECK_EVIL_UNDULATION_MASK 0x0E000000


#define MAX_KAMAE 4
#define KAMAE_MASK (KAMAE_GENBU | KAMAE_BYAKKO | KAMAE_SEIRYU | KAMAE_SUZAKU)

#define MAX_KATA 4
#define KATA_MASK (KATA_IAI | KATA_FUUJIN | KATA_KOUKIJIN | KATA_MUSOU)

//v1.1.13 p_ptr->special_flagsɎgtO
#define SPF_ORBITAL_TRAP 0x01 //LPu]㩁v
#define SPF_IGNORE_METAMOR_TIME	0x02 //h~[E@X^[ϐg̎Ԑ𖳎



#define ACTION_NONE     0
#define ACTION_SEARCH   1
#define ACTION_REST     2
#define ACTION_LEARN    3
#define ACTION_FISH     4
#define ACTION_KAMAE    5
#define ACTION_KATA     6
#define ACTION_SING     7
#define ACTION_HAYAGAKE 8
#define ACTION_SPELL    9

/* Empty hand status */
#define EMPTY_HAND_NONE 0x0000 /* Both hands are used */
#define EMPTY_HAND_LARM 0x0001 /* Left hand is empty */
#define EMPTY_HAND_RARM 0x0002 /* Right hand is empty */

/*** General index values ***/


/*
 * Legal restrictions for "summon_specific()"
 */
#define SUMMON_ANT                  11
#define SUMMON_SPIDER               12
#define SUMMON_HOUND                13
#define SUMMON_HYDRA                14
#define SUMMON_ANGEL                15
#define SUMMON_DEMON                16
#define SUMMON_UNDEAD               17
#define SUMMON_DRAGON               18
#define SUMMON_HI_UNDEAD            21
#define SUMMON_HI_DRAGON            22
#define SUMMON_HI_DEMON             23
#define SUMMON_AMBERITES            31
#define SUMMON_UNIQUE               32
#define SUMMON_BIZARRE1             33
#define SUMMON_BIZARRE2             34
#define SUMMON_BIZARRE3             35
#define SUMMON_BIZARRE4             36
#define SUMMON_BIZARRE5             37
#define SUMMON_BIZARRE6             38
#define SUMMON_CYBER                39
#define SUMMON_KIN                  40
#define SUMMON_DAWN                 41
#define SUMMON_ANIMAL               42
#define SUMMON_ANIMAL_RANGER        43
/*#define SUMMON_HI_UNDEAD_NO_UNIQUES 44*/
/*#define SUMMON_HI_DRAGON_NO_UNIQUES 45*/
/*#define SUMMON_NO_UNIQUES           46*/
#define SUMMON_PHANTOM              47
/*#define SUMMON_ELEMENTAL_NO_UNIQUES 48*/
#define SUMMON_BLUE_HORROR          49
#define SUMMON_LIVING               50
#define SUMMON_HI_DRAGON_LIVING     51
#define SUMMON_GOLEM                52
#define SUMMON_ELEMENTAL            53
#define SUMMON_VORTEX               54
#define SUMMON_HYBRID               55
#define SUMMON_BIRD                 56
/*#define SUMMON_AQUATIC_NO_UNIQUES   57*/
#define SUMMON_KAMIKAZE             58
#define SUMMON_KAMIKAZE_LIVING      59
#define SUMMON_MANES                60
#define SUMMON_LOUSE                61
#define SUMMON_GUARDIANS            62
#define SUMMON_KNIGHTS              63
#define SUMMON_EAGLES               64
#define SUMMON_PIRANHAS             65
#define SUMMON_ARMAGE_GOOD          66
#define SUMMON_ARMAGE_EVIL          67
#define SUMMON_KWAI					68
#define SUMMON_DOLLS				69
#define SUMMON_GHOST				70
#define SUMMON_DEITY				71
#define SUMMON_GREATER_DEMON		72
#define SUMMON_LIB_GOLEM			73
#define SUMMON_DEATH				74
//#define SUMMON_GUARDIANS2           75
#define SUMMON_SKELETON				76
#define SUMMON_INSANITY				77
#define SUMMON_INSANITY2			78
#define SUMMON_INSANITY3			79
#define SUMMON_SNAKE			80
#define SUMMON_FAIRY			81
#define SUMMON_HUMANOID			82
#define SUMMON_PHANTASMAGORIA	83//J
#define SUMMON_UNDEAD_DRAGON	84
#define SUMMON_HOLY_ANIMAL	85//b
#define SUMMON_BYAKHEE	86
#define SUMMON_ZOMBIE_FAIRY		87
#define SUMMON_MUSHROOM			88
#define SUMMON_MORGOTH_MINION	89
#define SUMMON_DESIRE			90
#define SUMMON_MAGICSIGN			91
#define SUMMON_MINI_SUIKA		92
#define SUMMON_TANUKI		93
#define SUMMON_GYOKUTO		94
#define SUMMON_RAT			95
#define SUMMON_REMY_BAT		96
#define SUMMON_ORCS			97
#define SUMMON_LUNARIAN		98
#define SUMMON_TOYOHIME_TROOPS	99
#define SUMMON_TSUKUMO		100

/*
 * Spell types used by project(), and related functions.
 */

#define GF_TSUKUMO_STORM -1 //project_hack2()p萔
#define GF_YUKARI_STORM -2 //project_hack2()p萔
#define GF_KINKAKUJI	-3	//project_hack2()p萔

///res mon magic 
#define GF_ELEC         1
#define GF_POIS         2
#define GF_ACID         3
#define GF_COLD         4
#define GF_FIRE         5
#define GF_PSY_SPEAR    9
#define GF_MISSILE      10
#define GF_ARROW        11
#define GF_PLASMA       12
/* Replaced with GF_HOLY_FIRE and GF_HELL_FIRE */
/* #define GF_HOLY_ORB     13 */
#define GF_WATER        14
#define GF_LITE         15
#define GF_DARK         16
/*:::M_̓GɂȂM炵*/
#define GF_LITE_WEAK    17
#define GF_DARK_WEAK    18
#define GF_SHARDS       20
#define GF_SOUND        21
#define GF_CONFUSION    22
#define GF_FORCE        23
/*:::x*/
#define GF_INACT     24
#define GF_MANA         26
#define GF_METEOR       27
/*:::Ɋ*/
#define GF_ICE          28
#define GF_CHAOS        30
/*:::n*/
#define GF_NETHER       31
#define GF_DISENCHANT   32
#define GF_NEXUS        33
#define GF_TIME         34
#define GF_GRAVITY      35
/*:::Ηn*/
#define GF_KILL_WALL    40
/*:::gbvEhAj*/
#define GF_KILL_DOOR    41
/*:::gbv*/
#define GF_KILL_TRAP    42
#define GF_MAKE_WALL    45
#define GF_MAKE_DOOR    46
#define GF_MAKE_TRAP    47
#define GF_MAKE_TREE    48
#define GF_OLD_CLONE    51
/*:::`FWX^[*/
#define GF_OLD_POLY             52
/*:::̗͉񕜂̖Ȃ*/
#define GF_OLD_HEAL             53
#define GF_OLD_SPEED    54
#define GF_OLD_SLOW             55
#define GF_OLD_CONF             56
#define GF_OLD_SLEEP    57
#define GF_OLD_DRAIN    58
/*:::푰AEFC*/
#define GF_AWAY_UNDEAD  61
#define GF_AWAY_EVIL    62
#define GF_AWAY_ALL     63
/*:::푰֋|*/
#define GF_TURN_UNDEAD  64
#define GF_TURN_EVIL    65
#define GF_TURN_ALL     66
#define GF_DISP_UNDEAD  67
/*:::푰փ_[W*/
#define GF_DISP_EVIL    68
#define GF_DISP_ALL 69
#define GF_DISP_DEMON   70      /* New types for Zangband begin here... */
#define GF_DISP_LIVING  71
#define GF_ROCKET       72
#define GF_NUKE         73
#define GF_MAKE_GLYPH   74
#define GF_STASIS       75 /*:::X^[~@A_ЁAfȂ*/
#define GF_STONE_WALL   76
#define GF_DEATH_RAY    77
#define GF_STUN         78
#define GF_HOLY_FIRE    79
#define GF_HELL_FIRE    80
#define GF_DISINTEGRATE 81 /*:::*/
#define GF_CHARM        82
#define GF_CONTROL_UNDEAD   83
#define GF_CONTROL_ANIMAL   84
#define GF_PSI         85
#define GF_PSI_DRAIN   86
#define GF_TELEKINESIS  87/*:::OՌe@_[W^NO1/4ŋ7̃e|[g*/
#define GF_JAM_DOOR     88
#define GF_DOMINATION   89/*:::_xz@ybg݂@Afbhf[ɂ͖*/
#define GF_DISP_GOOD    90
#define GF_DRAIN_MANA   91
#define GF_MIND_BLAST   92/*:::_U@f[AfbhEj[NEϐɂ͌ʔ*/
#define GF_BRAIN_SMASH  93/*:::_Űق*/
#define GF_CAUSE_1      94/*:::yǂ̎􂢁@wĎ􂢂*/
#define GF_CAUSE_2      95/*:::dǂ̎􂢁@wċ낵*/
#define GF_CAUSE_3      96/*:::vǂ̎􂢁@w낵Ɏ*/
#define GF_CAUSE_4      97/*:::E*/
#define GF_HAND_DOOM    98/*:::jł̎*/
#define GF_CAPTURE      99/*:::X^[{[*/
#define GF_ANIM_DEAD   100
#define GF_CONTROL_LIVING   101
#define GF_IDENTIFY    102
#define GF_ATTACK      103
#define GF_ENGETSU     104/*:::pƂ̌fȂ*/
#define GF_GENOCIDE    105
#define GF_PHOTO       106/*:::LOBe*/
#define GF_CONTROL_DEMON   107
#define GF_LAVA_FLOW   108
#define GF_BLOOD_CURSE 109/*:::̎􂢁ḯHj*/
#define GF_SEEKER 110
#define GF_SUPER_RAY 111
#define GF_STAR_HEAL 112
#define GF_WATER_FLOW   113
#define GF_CRUSADE     114/*:::@Pǎxzybgp*/
#define GF_STASIS_EVIL 115
#define GF_WOUNDS      116

///mod131229 G̍Up̐Vǉ MAX_GF117123
//ύXƂspell-xx.prfgf_desc[]ύX邱
#define GF_DISTORTION		117
#define GF_COSMIC_HORROR	118
#define GF_PUNISH_1			119
#define GF_PUNISH_2			120
#define GF_PUNISH_3			121
#define GF_PUNISH_4			122
///mod140103 ɒǉ max125
#define GF_POLLUTE			123
#define GF_TORNADO			124
///mod140103 ɒǉ max127
#define GF_KYUTTOSHITEDOKA_N 125
#define GF_WINDCUTTER		126

#define GF_REDEYE		127//ǂ񂰂Ȃǂ̔_U

#define GF_RYUURI		128//p
#define GF_SLOW_TWINE   129 //߂Ȃǂ̃XEX^[
#define GF_POSSESSION	130
#define GF_SOULSTEAL	131

#define GF_NIGHTMARE	132
#define GF_TRAIN	133
#define GF_DISP_KWAI	134
#define GF_NORTHERN		135
#define GF_BANKI_BEAM	136 //Ԕ؊̓r[
#define GF_N_E_P		137
#define GF_HOUTOU		138
#define GF_BANKI_BEAM2	139 //Ԕ؊̓r[2
#define GF_CHARM_PALADIN	140
#define GF_SATORI		141 //euX[j[p
#define GF_MAKE_FLOWER	142
#define GF_KOKORO		143	//ʍ쐬p
#define GF_MOSES		144 //c̊Cp@ɃNeBJAȊOɐAnnʂɂ
#define GF_REDMAGIC		145 //~Ap@\Ԃn̍
#define GF_GUNGNIR		146 //~Ap@\Ԃ̌
#define GF_WALL_TO_DOOR	147
#define GF_STASIS_DRAGON 148
#define GF_CHARM_C		149
#define GF_CHARM_J		150
#define GF_CHARM_B		151
#define GF_MAKE_SPIDER_NEST	152
#define GF_THROW_PLATE	153
#define GF_BLAZINGSTAR	154
#define GF_SOULSCULPTURE 155
#define GF_YAKU			156 //p
#define GF_STEAM		157 //C
#define GF_SEIRAN_BEAM	158 //u͌v
#define GF_PURIFY		159 //
#define GF_SPECIAL_SHOT 160 //eɂˌ
#define GF_YOUMU		161 //duZav
#define GF_STASIS_LIVING 162 //p
#define GF_LUNATIC_TORCH	163 //NEs[X̏

#define MAX_GF			164

/*
 * Some things which induce learning
 */
#define DRS_ACID         1
#define DRS_ELEC         2
#define DRS_FIRE         3
#define DRS_COLD         4
#define DRS_POIS         5
#define DRS_NETH         6
#define DRS_LITE         7
#define DRS_DARK         8
#define DRS_FEAR         9
#define DRS_CONF        10
#define DRS_CHAOS       11
#define DRS_DISEN       12
#define DRS_BLIND       13
#define DRS_NEXUS       14
#define DRS_SOUND       15
#define DRS_SHARD       16

///mod140406 ǉ
#define DRS_TIME		17
#define DRS_HOLY		18
#define DRS_WATER		19
//#define DRS_INSANITY    20 SMARTtOɋ󂫂Ȃ璆~



#define DRS_FREE        30
#define DRS_MANA        31
#define DRS_REFLECT     32



#define DAMAGE_FORCE    1 /*:::̌*/
#define DAMAGE_GENO     2 /*:::E̎ɂ_[W*/
#define DAMAGE_LOSELIFE 3 
#define DAMAGE_ATTACK   4 /*:::G̍U*/
#define DAMAGE_NOESCAPE 5 /*:::㩁EI[_[WEꕔ̊ZȂ*/
#define DAMAGE_USELIFE  6 /*:::HP閂@⃌CVgƂ*/


/*
 * Game generated inscription indices. These are stored in the object,
 * and are used to index the string array from tables.c.
 */

#define FEEL_NONE              0
#define FEEL_BROKEN            1
#define FEEL_TERRIBLE          2
#define FEEL_WORTHLESS         3
#define FEEL_CURSED            4
#define FEEL_UNCURSED          5
#define FEEL_AVERAGE           6
#define FEEL_GOOD              7
#define FEEL_EXCELLENT         8
#define FEEL_SPECIAL           9

#define FEEL_MAX               9


/*
 * Chest trap flags (see "tables.c")
 */
#define CHEST_LOSE_STR          0x0001
#define CHEST_LOSE_CON          0x0002
#define CHEST_POISON            0x0004
#define CHEST_PARALYZE          0x0008
#define CHEST_EXPLODE           0x0010
#define CHEST_SUMMON            0x0020
#define CHEST_SCATTER           0x0040
#define CHEST_E_SUMMON          0x0080
#define CHEST_BIRD_STORM        0x0100
#define CHEST_H_SUMMON          0x0200
#define CHEST_RUNES_OF_EVIL     0x0400
#define CHEST_ALARM             0x0800


/*
 * Special Object Flags
 */
/*:::ӒxAsǕitOȂ*/

/*:::ȈՊӒ*/
#define IDENT_SENSE     0x01    /* Item has been "sensed" */
/*:::XŌIĒli܂tOH*/
#define IDENT_FIXED     0x02    /* Item has been "haggled" */ 
/*:::̏Ȃ*/
#define IDENT_EMPTY     0x04    /* Item charges are known */
/*:::ӒH*/
#define IDENT_KNOWN     0x08    /* Item abilities are known */
/*:::X̏iHƂɂ͏Ă悤*/
#define IDENT_STORE     0x10    /* Item is storebought !!!! */
/*::: *Ӓ* ς݃ACe*/
#define IDENT_MENTAL    0x20    /* Item information is known */
#if 0
#define IDENT_CURSED    0x40    /* Item is temporarily cursed */
#endif
#define IDENT_BROKEN    0x80    /* Item is permanently worthless */


/* 
 * How object is marked (flags in object_type.mark)
 * OM_FOUND --- original boolean flag
 * OM_NOMSG --- temporary flag to suppress messages which were
 *              already printed in autopick_pickup_items().
 */
/*:::tAɗĂ̂LĂ*/
#define OM_FOUND        0x01    /* original boolean flag */
/*:::EɂutOH*/
#define OM_NOMSG        0x02    /* temporary flag to suppress messages */
#define OM_NO_QUERY     0x04    /* Query for auto-pick was already answered as 'No' */
/*:::j󔻒肳ꂽACe*/
#define OM_AUTODESTROY  0x08    /* Destroy later to avoid illegal inventry shift */
/*:::mFiEHu肵Hڍוsj*/
#define OM_TOUCHED      0x10    /* Object was touched by player */
/*:::tO@ǐ_ĺXɔACe@JԂŖǐ_l҂̂}~*/
//̌sۓWNGXg̔zuACeɂǉ
//󕨌ɃNǴȂ̓A[eBt@Ngɂǉ
#define OM_SPECIAL_FLAG	0x20	

/*
 * Special Monster Flags
 */
///mod140517 mflagu32bɊgZ[u悤ɂB

#define MFLAG_VIEW		     0x00000001    /* Monster is in line of sight */
/*:::EUȂǂ̏̂߈ꎞIɎgtO*/
#define MFLAG_TEMP			0x00000002    /* Monster is marked for project_hack() */

///mod140517 ꎞI݁BKړŏłX^[{[ɓ炸ɃybgŃRXgႢBdt̕gȂ
#define MFLAG_EPHEMERA		0x00000004    
#define MFLAG_NUE_UNKNOWN		0x00000008    /*:::ʂ̕s̎d񂾓G*/
/*:::ꂽ΂̃X^[ɂ͂̃tOāA1^[̏ȂH*/
#define MFLAG_BORN			0x00000010    /* Monster is still being born */
#define MFLAG_NICE			0x00000020    /* Monster is still being nice */
#define MFLAG_SPECIAL		0x00000040    /*:::EƂƓtO@PłɋGAAҖߒ̕tr_AHXq̗U铔ɗUꂽG*/
#define MFLAG_SPECIAL2		0x00000080    /*:::푰ƓtO@@głɖ͂zGAǐ_lłɉ񕜂GA*/
#define MFLAG_AISATSU_DONE	0x00000100	  /*:::RF1_AISATSUX^[sItO*/
#define MFLAG_NO_SPELL		0x00000200	  /*:::@𕕂ꂽԁ@fP̃^IuEt*/

#define MFLAG_EX_RESTRICT	0x00000400	/*:::Extra[hŃ_Wɐꂽ񃆃j[NX^[ɕtB|̌olƃACeȂB*/
//v1.1.12 CZ̃tFgt@Co[
#define MFLAG_FEMTO_FIBER	0x00000800

///mod150614 VZꏈprbgtO
#define	MFLAG_BATTLE_MON_TEAM_A	0x00001000
#define	MFLAG_BATTLE_MON_TEAM_B	0x00002000
#define	MFLAG_BATTLE_MON_TEAM_C	0x00004000
#define	MFLAG_BATTLE_MON_TEAM_D	0x00008000
#define	MFLAG_BATTLE_MON_MASK	0x0000F000

//v1.1.43 NEs[X̏ɂ苶Cɖ`ĂtO
#define MFLAG_LUNATIC_TORCH		0x00010000	
//v1.1.46 ̓ZuAu\[g[U[vŎɜ߂ꂽԁB
//̃tO̓tAɊɜ߂ꂽX^[邩ǂ̔ɂgB
#define MFLAG_POSSESSED_BY_SHION 0x00020000


#define MFLAG2_KAGE      0x01    /* Monster is kage */
#define MFLAG2_NOPET     0x02    /* Cannot make monster pet */
/*:::Eϐ*/
#define MFLAG2_NOGENO    0x04    /* Cannot genocide */
#define MFLAG2_CHAMELEON 0x08    /* Monster is chameleon */
#define MFLAG2_NOFLOW    0x10    /* Monster is in no_flow_by_smell mode *//*:::̓ǂȂEEH*/
#define MFLAG2_SHOW      0x20    /* Monster is recently memorized */
#define MFLAG2_MARK      0x40    /* Monster is currently memorized */


/*
 * Object flags
 *
 * Old variables for object flags such as flags1, flags2, and flags3
 * are obsolated.  Now single array flgs[TR_FLAG_SIZE] contains all
 * object flags.  And each flag is refered by single index number
 * instead of a bit mask.
 *
 * Therefore it's very easy to add a lot of new flags; no one need to
 * worry about in which variable a new flag should be put, nor to
 * modify a huge number of files all over the source directory at once
 * to add new flag variables such as flags4, flags5, etc...
 *
 * All management of flags is now treated using a set of macros
 * instead of bit operations.
 * Note: These macros are using division, modulo, and bit shift
 * operations, and it seems that these operations are rather slower
 * than original bit operation.  But since index numbers are almost
 * always given as constant, such slow operations are performed in the
 * compile time.  So there is no problem on the speed.
 *
 * Exceptions of new flag management is a set of flags to control
 * object generation and the curse flags.  These are not yet rewritten
 * in new index form; maybe these have no merit of rewriting.
 */

#define have_flag(ARRAY, INDEX) !!((ARRAY)[(INDEX)/32] & (1L << ((INDEX)%32)))
#define add_flag(ARRAY, INDEX) ((ARRAY)[(INDEX)/32] |= (1L << ((INDEX)%32)))
#define remove_flag(ARRAY, INDEX) ((ARRAY)[(INDEX)/32] &= ~(1L << ((INDEX)%32)))
///mod131228 TRtOւɔύX
//#define is_pval_flag(INDEX) ((TR_STR <= (INDEX) && (INDEX) <= TR_MAGIC_MASTERY) || (TR_STEALTH <= (INDEX) && (INDEX) <= TR_BLOWS))
//#define have_pval_flags(ARRAY) !!((ARRAY)[0] & (0x00003f7f))
#define is_pval_flag(INDEX) (TR_STR <= (INDEX) && (INDEX) <= TR_BLOWS)
#define have_pval_flags(ARRAY) !!((ARRAY)[0] & (0x00001fff))


///res mon item ACetO@ϐƂXCGƂɕύX


//VACeptO
#define TR_STR                 0      /* STR += "pval" */
#define TR_INT                 1      /* INT += "pval" */
#define TR_WIS                 2      /* WIS += "pval" */
#define TR_DEX                 3      /* DEX += "pval" */
#define TR_CON                 4      /* CON += "pval" */
#define TR_CHR                 5      /* CHR += "pval" */

#define TR_MAGIC_MASTERY       6      /*:::\+=PVAL */
#define TR_STEALTH             7      /* Stealth += "pval" */
#define TR_SEARCH              8      /* Search += "pval" */
#define TR_INFRA               9      /* Infra += "pval" */
#define TR_TUNNEL              10     /* Tunnel += "pval" */
#define TR_SPEED               11     /* Speed += "pval" */
#define TR_BLOWS               12     /* Blows += "pval" */

#define TR_CHAOTIC             13
#define TR_VAMPIRIC            14
#define TR_FORCE_WEAPON        15     /* Later */
#define TR_VORPAL              16     /* Later */
#define TR_EX_VORPAL           17     /* Later */
#define TR_IMPACT              18     /* Cause Earthquakes */
#define TR_BRAND_POIS          19
#define TR_BRAND_ACID          20
#define TR_BRAND_ELEC          21
#define TR_BRAND_FIRE          22
#define TR_BRAND_COLD          23

//ʓ|Ȃ̂œIɂEVIL: GOOD:ƂĂ
#define TR_SLAY_EVIL	       24
#define TR_SLAY_GOOD           25
#define TR_SLAY_ANIMAL         26
#define TR_SLAY_HUMAN          27
#define TR_SLAY_UNDEAD         28
#define TR_SLAY_DRAGON         29
#define TR_SLAY_DEITY          30
#define TR_SLAY_DEMON          31
#define TR_SLAY_KWAI           32

#define TR_KILL_EVIL           33
#define TR_KILL_GOOD           34
#define TR_KILL_ANIMAL         35
#define TR_KILL_HUMAN          36
#define TR_KILL_UNDEAD         37
#define TR_KILL_DRAGON         38
#define TR_KILL_DEITY          39
#define TR_KILL_DEMON          40
#define TR_KILL_KWAI           41

#define TR_ESP_EVIL            42
#define TR_ESP_GOOD            43
#define TR_ESP_ANIMAL          44
#define TR_ESP_HUMAN           45
#define TR_ESP_UNDEAD          46
#define TR_ESP_DRAGON          47
#define TR_ESP_DEITY           48
#define TR_ESP_DEMON           49
#define TR_ESP_KWAI            50
#define TR_ESP_NONLIVING       51
#define TR_ESP_UNIQUE          52

#define TR_SUST_STR            53
#define TR_SUST_INT            54
#define TR_SUST_WIS            55
#define TR_SUST_DEX            56
#define TR_SUST_CON            57
#define TR_SUST_CHR            58

#define TR_EASY_SPELL          59
#define TR_DEC_MANA            60     
#define TR_XTRA_MIGHT          61     /* Bows get extra multiplier */
#define TR_XTRA_SHOTS          62     /* Bows get extra shots */

#define TR_THROW               63     /* Later */
#define TR_RIDING              64
#define TR_REFLECT             65     /* Reflect 'bolts' */

#define TR_IM_ACID             66
#define TR_IM_ELEC             67
#define TR_IM_FIRE             68
#define TR_IM_COLD             69
#define TR_RES_ACID            70
#define TR_RES_ELEC            71
#define TR_RES_FIRE            72
#define TR_RES_COLD            73
#define TR_RES_POIS            74

#define TR_RES_LITE            75
#define TR_RES_DARK            76
#define TR_RES_SHARDS          77
#define TR_RES_SOUND           78
#define TR_RES_NETHER          79
#define TR_RES_WATER           80
#define TR_RES_CHAOS           81
#define TR_RES_DISEN           82
#define TR_RES_HOLY            83
#define TR_RES_TIME            84

#define TR_FREE_ACT            85     /* Free Action */
#define TR_RES_FEAR            86     /* Added for Zangband */
#define TR_RES_BLIND           87
#define TR_RES_CONF            88
#define TR_RES_INSANITY        89

#define TR_LEVITATION          90     /* Feather Falling */
#define TR_SEE_INVIS           91     /* See Invisible */
#define TR_SLOW_DIGEST         92     /* Item slows down digestion */
#define TR_REGEN               93     /* Item induces regeneration */
#define TR_LITE                94     /* Permanent Light */
#define TR_WARNING             95     /* Warning */
#define TR_BLESSED             96     /* Item is Blessed */
#define TR_TELEPORT            97     /* Item teleports player */

#define TR_GENZI	       98	/*:::񓁗yieBɘa ɂ̂ݕt*/
#define TR_SPEEDSTER           99     /*:::ړԌ */
#define TR_TELEPATHY           100     /* Telepathy */

#define TR_SH_FIRE             101     /* Immolation (Fire) */
#define TR_SH_ELEC             102     /* Electric Sheath */
#define TR_SH_COLD             103     /* cold aura */
#define TR_NO_TELE             104     /* Anti-teleportation */
#define TR_NO_MAGIC            105     /* Anti-magic */

#define TR_TY_CURSE            106     /* The Ancient Curse */
#define TR_AGGRAVATE           107     /* Item aggravates monsters */
#define TR_DRAIN_EXP           108     /* Item drains Experience */
#define TR_ADD_L_CURSE         109
#define TR_ADD_H_CURSE         110

#define TR_IGNORE_ACID         111     /* Item ignores Acid Damage */
#define TR_IGNORE_ELEC         112     /* Item ignores Elec Damage */
#define TR_IGNORE_FIRE         113     /* Item ignores Fire Damage */
#define TR_IGNORE_COLD         114     /* Item ignores Cold Damage */

#define TR_ACTIVATE            115      /* Item can be activated */
#define TR_MATERIAL	       116      /*:::fނƂčޗɂȂ*/
#define TR_USABLE	       117      /*:::uR}hŎg*/
#define TR_BOOMERANG	       118      /*:::ԂĂ镐*/
#define TR_READABLE	       119	/*:::rR}hœǂ߂*/

#define TR_SPECIAL_KOKORO		120		/*:::̖ʐp POWERFULtOێ*/
//bptO@tOƏd
#define TR_ES_ATTACK           106     /* Fake flag for Smith */
#define TR_ES_AC               107     /* Fake flag for Smith */

#define TR_SHOW_MODS           122     /* Always show Tohit/Todam */
#define TR_HIDE_TYPE           123     /* Hide "pval" description */
#define TR_FULL_NAME           124
#define TR_FIXED_FLAVOR        125


#define TR_FLAG_MAX            126
#define TR_FLAG_SIZE           4



//gen_flags֌W̃tOl
#define TRG_INSTA_ART           0x00000001L     /* Item must be an artifact */
#define TRG_QUESTITEM           0x00000002L     /* quest level item -KMW- */
#define TRG_XTRA_POWER          0x00000004L     /* Extra power */
#define TRG_ONE_SUSTAIN         0x00000008L     /* One sustain */
#define TRG_XTRA_RES_OR_POWER   0x00000010L     /* Extra resistance or power */
#define TRG_XTRA_H_RES          0x00000020L     /* Extra high resistance */
#define TRG_XTRA_E_RES          0x00000040L     /* Extra element resistance */
#define TRG_XTRA_L_RES          0x00000080L     /* Extra lordly resistance */
#define TRG_XTRA_D_RES          0x00000100L     /* Extra dragon resistance */
#define TRG_XTRA_RES            0x00000200L     /* Extra resistance */
#define TRG_CURSED              0x00000400L     /* Item is Cursed */
#define TRG_HEAVY_CURSE         0x00000800L     /* Item is Heavily Cursed */
#define TRG_PERMA_CURSE         0x00001000L     /* Item is Perma Cursed */
#define TRG_RANDOM_CURSE0       0x00002000L     /* Item is Random Cursed */
#define TRG_RANDOM_CURSE1       0x00004000L     /* Item is Random Cursed */
#define TRG_RANDOM_CURSE2       0x00008000L     /* Item is Random Cursed */
#define TRG_XTRA_DICE           0x00010000L     /* Extra dice */


#define MAX_CURSE 17
/*:::i̎ curse_flag*/
#define TRC_CURSED              0x00000001L
#define TRC_HEAVY_CURSE         0x00000002L
#define TRC_PERMA_CURSE         0x00000004L
#define TRC_XXX1                0x00000008L
#define TRC_TY_CURSE            0x00000010L
#define TRC_AGGRAVATE           0x00000020L
#define TRC_DRAIN_EXP           0x00000040L
#define TRC_SLOW_REGEN          0x00000080L
#define TRC_ADD_L_CURSE         0x00000100L
#define TRC_ADD_H_CURSE         0x00000200L
#define TRC_CALL_ANIMAL         0x00000400L
#define TRC_CALL_DEMON          0x00000800L
#define TRC_CALL_DRAGON         0x00001000L
#define TRC_COWARDICE           0x00002000L
#define TRC_TELEPORT            0x00004000L
#define TRC_LOW_MELEE           0x00008000L
#define TRC_LOW_AC              0x00010000L
#define TRC_LOW_MAGIC           0x00020000L
#define TRC_FAST_DIGEST         0x00040000L
#define TRC_DRAIN_HP            0x00080000L
#define TRC_DRAIN_MANA          0x00100000L

#define TRC_TELEPORT_SELF       0x00000001L
#define TRC_STORMBRINGER        0x00000002L

#define TRC_SPECIAL_MASK \
	(TRC_TY_CURSE | TRC_AGGRAVATE)

#define TRC_HEAVY_MASK   \
	(TRC_TY_CURSE | TRC_AGGRAVATE | TRC_DRAIN_EXP | TRC_ADD_H_CURSE | \
	 TRC_CALL_DEMON | TRC_CALL_DRAGON | TRC_TELEPORT)

#define TRC_P_FLAG_MASK  \
	(TRC_TELEPORT_SELF | TRC_STORMBRINGER | \
	 TRC_TY_CURSE | TRC_DRAIN_EXP | TRC_ADD_L_CURSE | TRC_ADD_H_CURSE | \
	 TRC_CALL_ANIMAL | TRC_CALL_DEMON | TRC_CALL_DRAGON | TRC_COWARDICE | \
	 TRC_TELEPORT | TRC_DRAIN_HP | TRC_DRAIN_MANA)



/*
 * Bit flags for apply_magic() (etc)
 */
/*::::A[eBt@NgɂȂȂHɃLN^[쐬񑕔i̐Ɏg悤@*/
#define AM_NO_FIXED_ART 0x00000001 /* Don't allow roll for fixed artifacts */
#define AM_GOOD         0x00000002 /* Generate good items */
#define AM_GREAT        0x00000004 /* Generate great items */
#define AM_SPECIAL      0x00000008 /* Generate artifacts (for debug mode only) */
#define AM_CURSED       0x00000010 /* Generate cursed/worthless items */
#define AM_FORCE_NORMAL 0x00000020 /*:::rollpower0ɂȂĐBLCNpB*/


/*** Monster blow constants ***/


/*
 * New monster blow methods
 */
#define RBM_HIT          1
#define RBM_TOUCH        2
#define RBM_PUNCH        3
#define RBM_KICK         4
#define RBM_CLAW         5
#define RBM_BITE         6
#define RBM_STING        7
#define RBM_SLASH        8
#define RBM_BUTT         9/*:::pœ˂*/
#define RBM_CRUSH       10
#define RBM_ENGULF      11
#define RBM_CHARGE      12/*:::悱*/
#define RBM_CRAWL       13
#define RBM_DROOL       14/*:::悾𐂂炷*/
#define RBM_SPIT        15/*:::΂f*/
#define RBM_EXPLODE     16
#define RBM_GAZE        17
#define RBM_WAIL        18/*:::*/
#define RBM_SPORE       19/*:::Eq΂*/
//v1.1.32 XXX4DANCE
#define RBM_DANCE       20
#define RBM_BEG         21/*:::*/
#define RBM_INSULT      22
#define RBM_MOAN        23/*:::߂*/
#define RBM_SHOW        24/*:::̂*/
///mod131230 X^[U@ǉ@ÔRBM_SHOOT(2540)̑Oɑ}
#define RBM_SPEAR		25/*:::˂*/
#define RBM_BOOK		26/*:::{ŉ*/
#define RBM_MOFUMOFU	27/*:::KŃtt*/
#define RBM_SQUEEZE		28/*:::ߕt*/
#define RBM_DRAG		29/*:::荞*/
#define RBM_INJECT		30/*:::˂*/
#define RBM_SMILE		31/*:::΂*/
#define RBM_HEADBUTT	32/*:::˂*/
#define RBM_FLASH		33/*:::*/
#define RBM_HOWL		34/*:::i*/
#define RBM_WHISPER		35/*:::₭*/
#define RBM_PRESS		36/*:::ׂ*/
#define RBM_POINT		37/*:::w*/
#define RBM_STRIKE		38/*:::ł*/
#define RBM_PLAY		39/*:::t*/
#define RBM_SHOOT       40/*:::ʏUł͎gȂ@ˌ郂X^[̂Ƃŏ̍Uɂݒ肵Ă*/


/*
 * New monster blow effects
 */
#define RBE_HURT         1
#define RBE_POISON       2/*:::łɖ`@_[W͑ϐŌyȂ*/
#define RBE_UN_BONUS     3/*:::򉻑Ō*/
#define RBE_UN_POWER     4/*:::͂z*/
#define RBE_EAT_GOLD     5
#define RBE_EAT_ITEM     6
#define RBE_EAT_FOOD     7
#define RBE_EAT_LITE     8
#define RBE_ACID         9
#define RBE_ELEC        10
#define RBE_FIRE        11
#define RBE_COLD        12
#define RBE_BLIND       13
#define RBE_CONFUSE     14
#define RBE_TERRIFY     15
#define RBE_PARALYZE    16
#define RBE_LOSE_STR    17
#define RBE_LOSE_INT    18
#define RBE_LOSE_WIS    19
#define RBE_LOSE_DEX    20
#define RBE_LOSE_CON    21
#define RBE_LOSE_CHR    22
#define RBE_LOSE_ALL    23
#define RBE_SHATTER     24/*:::ӂ*/
#define RBE_EXP_10      25
#define RBE_EXP_20      26
#define RBE_EXP_40      27
#define RBE_EXP_80      28
#define RBE_DISEASE     29/*:::aCɂ*/
#define RBE_TIME        30
#define RBE_EXP_VAMP    31/*:::͂z*/
#define RBE_DR_MANA     32/*:::͂z*/
#define RBE_SUPERHURT   33
#define RBE_INERTIA     34/*:::*/
#define RBE_STUN        35/*:::NO*/
///mod131230 Uʒǉ
#define RBE_CHAOS        36/*:::JIXōU*/
#define RBE_ELEMENT      37/*:::Ggi_fjōU*/
#define RBE_MUTATE       38/*:::ˑRψقU*/
#define RBE_SMITE        39/*:::򉻂*/
#define RBE_DROWN        40/*:::Mꂳ*/
#define RBE_KILL         41/*:::ɗU*/
#define RBE_CURSE        42/*:::*/
#define RBE_PHOTO        43/*:::ʐ^Be*/
#define RBE_MELT         44/*:::*/
#define RBE_BLEED        45/*:::𕉂킹*/
#define RBE_INSANITY     46/*:::C炷*/
#define RBE_HUNGER     47/*::: v1.1.32ǉ@󕠂炷*/

#define MAX_RBE				48 //mbe_info[]𑝂₵YȂ悤ɐݒ肵Ƃ

/*** Monster flag values (hard-coded) ***/

///mod131231 VX^[tO
/*
 * New monster race bit flags
 */
#define RF1_UNIQUE              0x00000001  /* Unique Monster */
#define RF1_QUESTOR             0x00000002  /* Quest Monster */
#define RF1_MALE                0x00000004  /* Male gender */
#define RF1_FEMALE              0x00000008  /* Female gender */
#define RF1_CHAR_CLEAR          0x00000010  /* Absorbs symbol */
#define RF1_SHAPECHANGER        0x00000020  /* TY: shapechanger */
#define RF1_ATTR_CLEAR          0x00000040  /* Absorbs color */
#define RF1_ATTR_MULTI          0x00000080  /* Changes color */
#define RF1_FORCE_DEPTH         0x00000100  /* Start at "correct" depth */
#define RF1_FORCE_MAXHP         0x00000200  /* Start with max hitpoints */
#define RF1_FORCE_SLEEP         0x00000400  /* Start out sleeping */
#define RF1_FORCE_EXTRA         0x00000800  /* Start out something */
#define RF1_ATTR_SEMIRAND       0x00001000  /* Color is determined semi-randomly */
#define RF1_FRIENDS             0x00002000  /* Arrive with some friends *//*:::WcŌ*/
#define RF1_ESCORT              0x00004000  /* Arrive with an escort */
#define RF1_ESCORTS             0x00008000  /* Arrive with some escorts */
#define RF1_NEVER_BLOW          0x00010000  /* Never make physical blow */
#define RF1_NEVER_MOVE          0x00020000  /* Never make physical move */
#define RF1_RAND_25             0x00040000  /* Moves randomly (25%) */
#define RF1_RAND_50             0x00080000  /* Moves randomly (50%) */
#define RF1_ONLY_GOLD           0x00100000  /* Drop only gold */
#define RF1_ONLY_ITEM           0x00200000  /* Drop only items */
#define RF1_DROP_60             0x00400000  /* Drop an item/gold (60%) */
#define RF1_DROP_90             0x00800000  /* Drop an item/gold (90%) */
#define RF1_DROP_1D2            0x01000000  /* Drop 1d2 items/gold */
#define RF1_DROP_2D2            0x02000000  /* Drop 2d2 items/gold */
#define RF1_DROP_3D2            0x04000000  /* Drop 3d2 items/gold */
#define RF1_DROP_4D2            0x08000000  /* Drop 4d2 items/gold */
#define RF1_DROP_GOOD           0x10000000  /* Drop good items */
#define RF1_DROP_GREAT          0x20000000  /* Drop great items */
#define RF1_FLAG_50F            0x40000000  /* m[}ȉ̓Փxɂ50Fȉł͏oɂ */
#define RF1_AISATSU             0x80000000  /* tAŏGΑA܂s */

/*
 * New monster race bit flags
 */
#define RF2_STUPID          0x00000001  /* Monster is stupid */
#define RF2_SMART           0x00000002  /* Monster is smart */
#define RF2_CAN_SPEAK       0x00000004  /* TY: can speak */
#define RF2_REFLECTING      0x00000008  /* Reflects bolts */
#define RF2_INVISIBLE       0x00000010  /* Monster avoids vision */
#define RF2_COLD_BLOOD      0x00000020  /* Monster avoids infra */
#define RF2_EMPTY_MIND      0x00000040  /* Monster avoids telepathy */
#define RF2_WEIRD_MIND      0x00000080  /* Monster avoids telepathy? */
#define RF2_MULTIPLY        0x00000100  /* Monster reproduces */
#define RF2_REGENERATE      0x00000200  /* Monster regenerates */
#define RF2_CHAR_MULTI      0x00000400  /* (Not implemented) */
#define RF2_ATTR_ANY        0x00000800  /* TY: Attr_any */
#define RF2_POWERFUL        0x00001000  /* Monster has strong breath */
#define RF2_ELDRITCH_HORROR 0x00002000  /* Sanity-blasting horror    */
#define RF2_AURA_FIRE       0x00004000  /* Burns in melee */
#define RF2_AURA_ELEC       0x00008000  /* Shocks in melee */
#define RF2_OPEN_DOOR       0x00010000  /* Monster can open doors */
#define RF2_BASH_DOOR       0x00020000  /* Monster can bash doors */
#define RF2_PASS_WALL       0x00040000  /* Monster can pass walls */
#define RF2_KILL_WALL       0x00080000  /* Monster can destroy walls */
#define RF2_MOVE_BODY       0x00100000  /* Monster can move monsters */
#define RF2_KILL_BODY       0x00200000  /* Monster can kill monsters */
#define RF2_TAKE_ITEM       0x00400000  /* Monster can pick up items */
#define RF2_KILL_ITEM       0x00800000  /* Monster can crush items */
#define RF2_AURA_COLD       0x01000000  /*XI[@RF3ړĂ*/
#define RF2_TROPHY          0x02000000  /*:::|牽ʂȃACe𗎂ƂX^[HgȂC*/
#define RF2_SMART_EX        0x04000000  /*:::ʌȍs[`̃X^[*/
#define RF2_TELE_AFTER      0x08000000  /*:::ǔe|[g*/
#define RF2_GIGANTIC        0x10000000  /*:::ȃX^[*/  
#define RF2_PHANTOM         0x20000000  /*:::e@tAړŏACeƂȂȂ*/
#define RF2_EPHEMERA        0x40000000  /*:::ꎞI݁@tAړŏ*/
#define RF2_QUANTUM         0x80000000  /* Monster has quantum behavior */

/*
 * New monster race bit flags
 */
#define RF3_KWAI            0x00000001  /*:::d*/
#define RF3_DEITY           0x00000002  /*:::_i*/
#define RF3_DEMIHUMAN       0x00000004  /*:::l^@lXCESP*/
#define RF3_DRAGON          0x00000008  /* Dragon */
#define RF3_DEMON           0x00000010  /* Demon */
#define RF3_UNDEAD          0x00000020  /* Undead */
#define RF3_NONLIVING       0x00000040  /* TY: Non-Living (?) */ //ƈړ
#define RF3_ANIMAL          0x00000080  /* Animal */
#define RF3_HUMAN           0x00000100  /*::: l RF2ړĂ*/
#define RF3_FAIRY           0x00000200  /*:::d*/
#define RF3_XXXXX           0x00000400  
#define RF3_ANG_CHAOS       0x00000800  /*::: א EVILύX */
#define RF3_ANG_COSMOS		0x00001000  /*:::  GOODύX */
#define RF3_ANG_AMBER       0x00002000  /*::: Ao[̉ */
#define RF3_ANG_WARLIKE     0x00004000  /*::: S@DI */
#define RF3_ANG_NEUTRAL     0x00008000  /*::: S@ */
#define RF3_ANG_FRIENDLY    0x00010000  /*::: S@FDI */
#define RF3_GEN_HUMAN       0x00020000  /*::: zlԑ*/
#define RF3_GEN_KWAI        0x00040000  /*::: zd*/
#define RF3_GEN_NEUTRAL     0x00080000  /*::: z*/
#define RF3_GEN_WARLIKE     0x00100000  /*::: zDI*/
#define RF3_GEN_FRIENDLY    0x00200000  /*::: z*/
#define RF3_GEN_MOON        0x00400000  /*::: mod160811 zʐ*/
#define RF3_XXX23           0x00800000
#define RF3_XXX24           0x01000000
#define RF3_XXX25           0x02000000
#define RF3_XXX26           0x04000000
#define RF3_WANTED          0x08000000  /*:::܋NGXg̑Ώ*/
#define RF3_NO_FEAR         0x10000000  /* Cannot be scared */
#define RF3_NO_STUN         0x20000000  /* Cannot be stunned */
#define RF3_NO_CONF         0x40000000  /* Cannot be confused and resist confusion */
#define RF3_NO_SLEEP        0x80000000  /* Cannot be slept */

///mod160703 Xuz̏Zlv𔻕ʂ邽߂̃}XNǉ
#define RF3_GEN_MASK		(RF3_GEN_HUMAN | RF3_GEN_KWAI | RF3_GEN_NEUTRAL | RF3_GEN_WARLIKE | RF3_GEN_FRIENDLY | RF3_GEN_MOON)

/*
 * New monster race bit flags
 */
/*:::̃tO̖@́ug̓I\́vƂ݂ȂA@ȂǂŏႤ*/
#define RF4_SHRIEK          0x00000001  /*:::с@E̓GNɕύX*/
#define RF4_DANMAKU         0x00000002  /*:::e*/
#define RF4_DISPEL          0x00000004  /* Dispel magic */
#define RF4_ROCKET          0x00000008  /*:::Pbg@j+ɂ悤*/
#define RF4_SHOOT           0x00000010  /*:::ˌⓊ@LɂĂ͏e@e|˂ɂȂ悤ɂ悤*/
#define RF4_BR_HOLY         0x00000020  /*:::ȂuX*/
#define RF4_BR_HELL         0x00000040  /*:::n̋Ɖ΂̃uX*/
#define RF4_BR_AQUA         0x00000080  /*:::ANAuX*/
#define RF4_BR_ACID         0x00000100  /* Breathe Acid */
#define RF4_BR_ELEC         0x00000200  /* Breathe Elec */
#define RF4_BR_FIRE         0x00000400  /* Breathe Fire */
#define RF4_BR_COLD         0x00000800  /* Breathe Cold */
#define RF4_BR_POIS         0x00001000  /* Breathe Poison */
#define RF4_BR_NETH         0x00002000  /* Breathe Nether */
#define RF4_BR_LITE         0x00004000  /* Breathe Lite */
#define RF4_BR_DARK         0x00008000  /* Breathe Dark */
#define RF4_WAVEMOTION      0x00010000  /*:::gC@uXύX*/
#define RF4_BR_SOUN         0x00020000  /* Breathe Sound */
#define RF4_BR_CHAO         0x00040000  /* Breathe Chaos */
#define RF4_BR_DISE         0x00080000  /* Breathe Disenchant */
#define RF4_BR_NEXU         0x00100000  /*:::ʍuX@ϐ̋̓uXɂ\*/
#define RF4_BR_TIME         0x00200000  /* Breathe Time */
#define RF4_BR_INER         0x00400000  /* Breathe Inertia */
#define RF4_BR_GRAV         0x00800000  /* Breathe Gravity */
#define RF4_BR_SHAR         0x01000000  /* Breathe Shards */
#define RF4_BR_PLAS         0x02000000  /*:::vY}uX@ύX\*/
#define RF4_BA_FORCE        0x04000000  /*:::tH[XuXCe*/
#define RF4_BR_MANA         0x08000000  /* Breathe Mana */
#define RF4_SPECIAL2        0x10000000  /*˔\ʍs2*/
#define RF4_BR_NUKE         0x20000000  /*:::ːpuXjM̃uXiΉ+M)*/
#define RF4_BA_CHAO         0x40000000  /* TY: Logrus Ball */
#define RF4_BR_DISI         0x80000000  /* Breathe Disintegration */

/*
 * New monster race bit flags
 */
#define RF5_BA_ACID         0x00000001  /* Acid Ball */
#define RF5_BA_ELEC         0x00000002  /* Elec Ball */
#define RF5_BA_FIRE         0x00000004  /* Fire Ball */
#define RF5_BA_COLD         0x00000008  /* Cold Ball */
#define RF5_BA_POIS         0x00000010  /* Poison Ball */
#define RF5_BA_NETH         0x00000020  /* Nether Ball */
#define RF5_BA_WATE         0x00000040  /* Water Ball */
#define RF5_BA_MANA         0x00000080  /* Mana Storm */
#define RF5_BA_DARK         0x00000100  /* Darkness Storm */
#define RF5_DRAIN_MANA      0x00000200  /* Drain Mana */
#define RF5_MIND_BLAST      0x00000400  /* Blast Mind */
#define RF5_BRAIN_SMASH     0x00000800  /* Smash Brain */
#define RF5_CAUSE_1         0x00001000  /* Cause Light Wound */
#define RF5_CAUSE_2         0x00002000  /* Cause Serious Wound */
#define RF5_CAUSE_3         0x00004000  /* Cause Critical Wound */
#define RF5_CAUSE_4         0x00008000  /* Cause Mortal Wound */
#define RF5_BO_ACID         0x00010000  /* Acid Bolt */
#define RF5_BO_ELEC         0x00020000  /* Elec Bolt (unused) */
#define RF5_BO_FIRE         0x00040000  /* Fire Bolt */
#define RF5_BO_COLD         0x00080000  /* Cold Bolt */
#define RF5_BA_LITE         0x00100000  /* StarBurst */
#define RF5_BO_NETH         0x00200000  /* Nether Bolt */
#define RF5_BO_WATE         0x00400000  /* Water Bolt */
#define RF5_BO_MANA         0x00800000  /* Mana Bolt */
#define RF5_BO_PLAS         0x01000000  /* Plasma Bolt */
#define RF5_BO_ICEE         0x02000000  /* Ice Bolt */
#define RF5_MISSILE         0x04000000  /* Magic Missile */
#define RF5_SCARE           0x08000000  /* Frighten Player */
#define RF5_BLIND           0x10000000  /* Blind Player */
#define RF5_CONF            0x20000000  /* Confuse Player */
#define RF5_SLOW            0x40000000  /* Slow Player */
#define RF5_HOLD            0x80000000  /* Paralyze Player */

/*
 * New monster race bit flags
 */
#define RF6_HASTE           0x00000001  /* Speed self */
#define RF6_HAND_DOOM       0x00000002  /* Hand of Doom */
#define RF6_HEAL            0x00000004  /* Heal self */
#define RF6_INVULNER        0x00000008  /* INVULNERABILITY! */
#define RF6_BLINK           0x00000010  /* Teleport Short */
#define RF6_TPORT           0x00000020  /* Teleport Long */
#define RF6_WORLD           0x00000040  /* world */
#define RF6_SPECIAL         0x00000080  /*:::ʂȍs*/
#define RF6_TELE_TO         0x00000100  /* Move player to monster */
#define RF6_TELE_AWAY       0x00000200  /* Move player far away */
#define RF6_TELE_LEVEL      0x00000400  /* e|x@p~H */
#define RF6_PSY_SPEAR       0x00000800  /* Psyco-spear */
#define RF6_DARKNESS        0x00001000  /* Create Darkness */
#define RF6_TRAPS           0x00002000  /* Create Traps */
#define RF6_FORGET          0x00004000  /* Cause amnesia */
#define RF6_COSMIC_HORROR   0x00008000  /*:::ҕRY~bNEz[*/
#define RF6_S_KIN           0x00010000  /* Summon "kin" */
#define RF6_S_CYBER         0x00020000  /* Summon Cyberdemons! */
#define RF6_S_MONSTER       0x00040000  /* Summon Monster */
#define RF6_S_MONSTERS      0x00080000  /* Summon Monsters */
#define RF6_S_ANT           0x00100000  /* Summon Ants */
#define RF6_S_SPIDER        0x00200000  /* Summon Spiders */
#define RF6_S_HOUND         0x00400000  /* Summon Hounds */
#define RF6_S_HYDRA         0x00800000  /* Summon Hydras */
#define RF6_S_ANGEL         0x01000000  /* Summon Angel */
#define RF6_S_DEMON         0x02000000  /* Summon Demon */
#define RF6_S_UNDEAD        0x04000000  /* Summon Undead */
#define RF6_S_DRAGON        0x08000000  /* Summon Dragon */
#define RF6_S_HI_UNDEAD     0x10000000  /* Summon Greater Undead */
#define RF6_S_HI_DRAGON     0x20000000  /* Summon Ancient Dragon */
#define RF6_S_AMBERITES     0x40000000  /* Summon Amberites */
#define RF6_S_UNIQUE        0x80000000  /* Summon Unique Monster */

/*
 * New monster race bit flags
 */
/*:::ԂɊւtO@F̃tOr_flagsƂċLȂ*/
#define RF7_AQUATIC             0x00000001  /* Aquatic monster */
#define RF7_CAN_SWIM            0x00000002  /* Monster can swim */
#define RF7_CAN_FLY             0x00000004  /* Monster can fly */
#define RF7_FRIENDLY            0x00000008  /*:::RF3̗FDƓ폜\*/
#define RF7_NAZGUL              0x00000010  /* Is a "Nazgul" unique */
#define RF7_UNIQUE2             0x00000020  /* Fake unique */
#define RF7_RIDING              0x00000040  /* Good for riding */
#define RF7_KAGE                0x00000080  /* Is kage */
/*:::HAS_LITE͐QĂƂ͌ʂȂ*/
#define RF7_HAS_LITE_1          0x00000100  /* Monster carries light */
#define RF7_SELF_LITE_1         0x00000200  /* Monster lights itself */
#define RF7_HAS_LITE_2          0x00000400  /* Monster carries light */
#define RF7_SELF_LITE_2         0x00000800  /* Monster lights itself */
#define RF7_GUARDIAN            0x00001000  /* Guardian of a dungeon */
#define RF7_CHAMELEON           0x00002000  /* Chameleon can change */
#define RF7_KILL_EXP            0x00004000  /* No exp until you kill it */
#define RF7_TANUKI              0x00008000  /* Tanuki disguise */
#define RF7_HAS_DARK_1          0x00010000  /* Monster carries darkness */
#define RF7_SELF_DARK_1         0x00020000  /* Monster darkens itself */
#define RF7_HAS_DARK_2          0x00040000  /* Monster carries darkness */
#define RF7_SELF_DARK_2         0x00080000  /* Monster darkens itself */
#define RF7_FULL_MOON           0x00100000  /*:::p[Abv*/
#define RF7_FROM_HELL           0x00200000  /*:::_*/
#define RF7_VARIABLE			0x00400000	/*:::σp[^X^[*/
#define RF7_DOPPELGANGER		0x00800000	//hbyQK[
#define RF7_ONLY_RIDING         0x01000000  //v1.1.24 Rp

/*:::ԂɊւtO@F̃tOr_flagsƂċLȂ*/
/*
 * Monster race flags
 */
#define RF8_WILD_ONLY           0x00000001/*:::rɂoȂ*/
#define RF8_WILD_TOWN           0x00000002/*:::ɏZ*/
#define RF8_XXX8X02             0x00000004
#define RF8_WILD_SHORE          0x00000008
#define RF8_WILD_OCEAN          0x00000010
#define RF8_WILD_WASTE          0x00000020
#define RF8_WILD_WOOD           0x00000040
#define RF8_WILD_VOLCANO        0x00000080
#define RF8_XXX8X08             0x00000100
#define RF8_WILD_MOUNTAIN       0x00000200
#define RF8_WILD_GRASS          0x00000400
#define RF8_STAY_AT_HOME1       0x00000800/*:::w_WȊOł̓AeB4{*/
#define RF8_STAY_AT_HOME2       0x00001000/*:::w_WȊOł̓AeB10{*/
#define RF8_STAY_AT_HOME3       0x00002000/*:::w_WȊOł͏oȂ*/


#define RF8_WILD_ALL            0x80000000/*:::XArnAXAnŏo*/

/*:::V@ptO*/
#define RF9_FIRE_STORM          0x00000001/*:::̗ NO.192*/
#define RF9_ICE_STORM           0x00000002/*:::X̗ 193*/
#define RF9_THUNDER_STORM       0x00000004/*:::̗ 194*/
#define RF9_ACID_STORM          0x00000008/*:::_̗ 195*/
#define RF9_TOXIC_STORM         0x00000010/*:::őf̗ 196*/
#define RF9_BA_POLLUTE          0x00000020/*:::̋ 197*/
#define RF9_BA_DISI             0x00000040/*:::q 198*/
#define RF9_BA_HOLY             0x00000080/*:::ǰׂ 199*/
#define RF9_BA_METEOR           0x00000100/*:::eIXgCN No.200*/
#define RF9_BA_DISTORTION       0x00000200/*:::Ԙc 201*/
#define RF9_PUNISH_1            0x00000400/*:::ޖ1 202*/
#define RF9_PUNISH_2            0x00000800/*:::ޖ2 203*/
#define RF9_PUNISH_3            0x00001000/*:::ޖ3 204*/
#define RF9_PUNISH_4            0x00002000/*:::ޖ4 205*/
#define RF9_BO_HOLY             0x00004000/*:::jׂ̃{g206*/
#define RF9_GIGANTIC_LASER      0x00008000/*:::僌[U[*/
#define RF9_BO_SOUND            0x00010000/*:::̃{g208*/
#define RF9_S_ANIMAL            0x00020000/*::: 209*/
#define RF9_BEAM_LITE           0x00040000/*:::[U[@No.210*/
#define RF9_SONICWAVE           0x00080000/*:::g(\)*/
#define RF9_HELLFIRE            0x00100000/*:::wt@CA 212*/
#define RF9_HOLYFIRE            0x00200000/*:::z[[t@CA 213*/
#define RF9_FINALSPARK          0x00400000/*:::t@CiXp[N 214*/
#define RF9_TORNADO             0x00800000/*::: 215*/
#define RF9_DESTRUCTION         0x01000000/*:::*j* 216*/
#define RF9_S_DEITY             0x02000000/*:::_i 217*/
#define RF9_S_HI_DEMON          0x04000000/*:::ʈ 218*/
#define RF9_S_KWAI              0x08000000/*:::d 219*/
#define RF9_TELE_APPROACH       0x10000000/*:::אڃe|[g 220*/
#define RF9_TELE_HI_APPROACH    0x20000000/*:::EO̗אڃe|[g 221*/
#define RF9_MAELSTROM           0x40000000/*:::CVg 222*/
#define RF9_ALARM               0x80000000/*:::ӂ̓GN+E 223*/

/*
 * Monster bit flags of racial resistances
 * Note: Resist confusion was merged to RFR_NO_CONF
 */
#define RFR_IM_ACID         0x00000001  /* Resist acid */
#define RFR_IM_ELEC         0x00000002  /* Resist elec */
#define RFR_IM_FIRE         0x00000004  /* Resist fire */
#define RFR_IM_COLD         0x00000008  /* Resist cold */
#define RFR_IM_POIS         0x00000010  /* Resist poison */
#define RFR_RES_LITE        0x00000020  /* Resist lite */
#define RFR_RES_DARK        0x00000040  /* Resist dark */
#define RFR_RES_NETH        0x00000080  /* Resist nether */
#define RFR_RES_WATE        0x00000100  /* Resist water */
//#define RFR_RES_PLAS        0x00000200  /* Resist plasma */
#define RFR_RES_SHAR        0x00000400  /* Resist shards */
#define RFR_RES_SOUN        0x00000800  /* Resist sound */
#define RFR_RES_CHAO        0x00001000  /* Resist chaos */
#define RFR_RES_HOLY        0x00002000  /*::: Resist HOLYFIRE */
#define RFR_RES_DISE        0x00004000  /* Resist disenchantment */
//#define RFR_RES_WALL        0x00008000  /* Resist force */
#define RFR_RES_INER        0x00010000  /* Resist inertia */
#define RFR_RES_TIME        0x00020000  /* Resist time */
//#define RFR_RES_GRAV        0x00040000  /* Resist gravity */
#define RFR_RES_ALL         0x00080000  /* Resist all */
#define RFR_RES_TELE        0x00100000  /* Resist teleportation */
#define RFR_XXX21           0x00200000
#define RFR_XXX22           0x00400000
#define RFR_XXX23           0x00800000
#define RFR_HURT_HOLY       0x01000000  /*:::j׎_*/
#define RFR_HURT_HELL       0x02000000  /*:::wt@CA_*/
#define RFR_HURT_WATER      0x04000000  /*:::_*/
#define RFR_HURT_ELEC       0x08000000  /*:::d_ǉ*/
#define RFR_HURT_COLD       0x10000000  /*:::C_ RF3ړĂ*/
#define RFR_HURT_FIRE       0x20000000  /*:::Ή_@RF3ړĂ*/
#define RFR_HURT_ROCK       0x40000000  /*:::Ηn_ RF3ړĂ*/
#define RFR_HURT_LITE       0x80000000  /*:::_ RF3ړĂ*/



///sys 牺΂炭X^[̍U@tOp̃}XN

///mod131231 X^[tOύXɔAÂ̂Ƃ肠
/*
 * Hack -- choose "intelligent" spells when desperate
 * Including "summon" spells
 */
/*:::SMARTtOGHP10%ȉɂȂƂ1/2̊młɂ閂@gȂȂ*/
#define RF4_INT_MASK \
	(RF4_SUMMON_MASK | RF4_DISPEL)

#define RF5_INT_MASK \
	(RF5_SUMMON_MASK | \
	 RF5_HOLD | RF5_SLOW | RF5_CONF | RF5_BLIND | RF5_SCARE)

#define RF6_INT_MASK \
	(RF6_SUMMON_MASK | \
	 RF6_BLINK | RF6_TPORT | RF6_TELE_LEVEL | RF6_TELE_AWAY | \
	 RF6_HEAL | RF6_INVULNER | RF6_HASTE | RF6_TRAPS)

#define RF9_INT_MASK (RF9_DESTRUCTION | RF9_SUMMON_MASK | RF9_ALARM)

/*
 * Hack -- spells that cannot be used while player riding on the monster
 */
#define RF4_RIDING_MASK \
	(RF4_SHRIEK)

#define RF5_RIDING_MASK 0UL

#define RF6_RIDING_MASK \
	(RF6_BLINK | RF6_TPORT | RF6_TRAPS | RF6_DARKNESS | RF6_SPECIAL)

#define RF9_RIDING_MASK (RF9_TELE_APPROACH | RF9_TELE_HI_APPROACH | RF9_ALARM)


/*
 * Hack -- "bolt" spells that may hurt fellow monsters
 * Currently "bolt" spells are included in "attack"
 */
#define RF4_BOLT_MASK \
	(RF4_ROCKET | RF4_SHOOT | RF4_DANMAKU)

#define RF5_BOLT_MASK \
	(RF5_BO_ACID | RF5_BO_ELEC | RF5_BO_FIRE | RF5_BO_COLD | \
	 RF5_BO_NETH | RF5_BO_WATE | RF5_BO_MANA | RF5_BO_PLAS | \
	 RF5_BO_ICEE | RF5_MISSILE)

#define RF6_BOLT_MASK 0UL
#define RF9_BOLT_MASK (RF9_BO_HOLY | RF9_BO_SOUND)

/*
 * Hack -- "beam" spells that may hurt fellow monsters
 * Currently "beam" spells are included in "attack"
 */
#define RF4_BEAM_MASK 0UL

#define RF5_BEAM_MASK 0UL

#define RF6_BEAM_MASK (RF6_PSY_SPEAR)

//CVg͎S{[őΏۂɎːʂĂȂƓȂr[
#define RF9_BEAM_MASK (RF9_BEAM_LITE | RF9_GIGANTIC_LASER | RF9_FINALSPARK | RF9_MAELSTROM)

/*
 * Hack -- "ball" spells that may hurt friends
 * Including "radius 4 ball" and "breath" spells
 * Currently "ball" spells are included in "attack"
 */
#define RF4_BALL_MASK (RF4_BIG_BALL_MASK | RF4_BREATH_MASK | RF4_ROCKET | RF4_BA_FORCE)
//	 RF4_ROCKET | RF4_BA_NUKE)


#define RF5_BALL_MASK \
	(RF5_BIG_BALL_MASK | RF5_BREATH_MASK | \
	 RF5_BA_ACID | RF5_BA_ELEC | RF5_BA_FIRE | RF5_BA_COLD | \
	 RF5_BA_POIS | RF5_BA_NETH)

#define RF6_BALL_MASK \
	(RF6_BIG_BALL_MASK | RF6_BREATH_MASK)

#define RF9_BALL_MASK ( RF9_BIG_BALL_MASK | RF9_BA_HOLY)

/*
 * Hack -- "ball" spells with radius 4 that may hurt friends
 * Currently "radius 4 ball" spells are included in "ball"
 */
#define RF4_BIG_BALL_MASK \
	(RF4_BA_CHAO | RF4_WAVEMOTION)

#define RF5_BIG_BALL_MASK \
	(RF5_BA_LITE | RF5_BA_DARK | RF5_BA_WATE | RF5_BA_MANA)

#define RF6_BIG_BALL_MASK 0UL

#define RF9_BIG_BALL_MASK (	RF9_FIRE_STORM | RF9_ICE_STORM | RF9_THUNDER_STORM | \
							RF9_ACID_STORM | RF9_TOXIC_STORM | RF9_BA_METEOR | \
							RF9_BA_DISI | RF9_BA_POLLUTE | RF9_TORNADO | RF9_HELLFIRE | RF9_HOLYFIRE | RF9_BA_DISTORTION)


/*
 * Hack -- "breath" spells that may hurt friends
 * Currently "breath" spells are included in "ball" and "non-magic"
 */
#define RF4_BREATH_MASK \
	(RF4_BR_ACID | RF4_BR_ELEC | RF4_BR_FIRE | RF4_BR_COLD | \
	 RF4_BR_POIS | RF4_BR_NETH | RF4_BR_LITE | RF4_BR_DARK | \
	 RF4_BR_SOUN | RF4_BR_CHAO | RF4_BR_DISE | RF4_BR_HOLY | \
	 RF4_BR_NEXU | RF4_BR_SHAR | RF4_BR_TIME | RF4_BR_INER | \
	 RF4_BR_GRAV | RF4_BR_PLAS | RF4_BR_MANA | RF4_BR_HELL | \
	 RF4_BR_NUKE | RF4_BR_DISI | RF4_BR_AQUA)

//#define RF4_BREATH_MASK \
//	(RF4_BR_ACID | RF4_BR_ELEC | RF4_BR_FIRE | RF4_BR_COLD | \
//	 RF4_BR_POIS | RF4_BR_NETH | RF4_BR_LITE | RF4_BR_DARK | \
//	 RF4_BR_CONF | RF4_BR_SOUN | RF4_BR_CHAO | RF4_BR_DISE | \
//	 RF4_BR_NEXU | RF4_BR_SHAR | RF4_BR_TIME | RF4_BR_INER | \
//	 RF4_BR_GRAV | RF4_BR_PLAS | RF4_BR_WALL | RF4_BR_MANA | \
//	 RF4_BR_NUKE | RF4_BR_DISI)

#define RF5_BREATH_MASK 0UL

#define RF6_BREATH_MASK 0UL

#define RF9_BREATH_MASK 0UL


/*
 * Hack -- "summon" spells
 * Currently "summon" spells are included in "intelligent" and "indirect"
 */
#define RF4_SUMMON_MASK 0UL

#define RF5_SUMMON_MASK 0UL

#define RF6_SUMMON_MASK \
	(RF6_S_KIN | RF6_S_CYBER | RF6_S_MONSTER | RF6_S_MONSTERS | RF6_S_ANT | \
	 RF6_S_SPIDER | RF6_S_HOUND | RF6_S_HYDRA | RF6_S_ANGEL | RF6_S_DEMON | \
	 RF6_S_UNDEAD | RF6_S_DRAGON | RF6_S_HI_UNDEAD | RF6_S_HI_DRAGON | \
	 RF6_S_AMBERITES | RF6_S_UNIQUE)

#define RF9_SUMMON_MASK (RF9_S_KWAI | RF9_S_HI_DEMON | RF9_S_DEITY | RF9_S_ANIMAL)

/*
 * Hack -- "attack" spells
 * Including "bolt", "beam" and "ball" spells
 */
#define RF4_ATTACK_MASK \
	(RF4_BOLT_MASK | RF4_BEAM_MASK | RF4_BALL_MASK | RF4_DISPEL)

#define RF5_ATTACK_MASK \
	(RF5_BOLT_MASK | RF5_BEAM_MASK | RF5_BALL_MASK | \
	 RF5_DRAIN_MANA | RF5_MIND_BLAST | RF5_BRAIN_SMASH | \
	 RF5_CAUSE_1 | RF5_CAUSE_2 | RF5_CAUSE_3 | RF5_CAUSE_4 | \
	 RF5_SCARE | RF5_BLIND | RF5_CONF | RF5_SLOW | RF5_HOLD)

#define RF6_ATTACK_MASK \
	(RF6_BOLT_MASK | RF6_BEAM_MASK | RF6_BALL_MASK | \
	 RF6_HAND_DOOM | RF6_TELE_TO | RF6_TELE_AWAY | RF6_TELE_LEVEL | \
	 RF6_DARKNESS | RF6_TRAPS | RF6_FORGET | RF6_COSMIC_HORROR)

#define RF9_ATTACK_MASK \
	(RF9_BOLT_MASK | RF9_BEAM_MASK | RF9_BALL_MASK | RF9_PUNISH_1 | RF9_PUNISH_2 | RF9_PUNISH_3 | RF9_PUNISH_4)

/*
 * Hack -- "indirect" spells
 * Including "summon" spells
 */
#define RF4_INDIRECT_MASK \
	(RF4_SUMMON_MASK | RF4_SHRIEK)

#define RF5_INDIRECT_MASK \
	(RF5_SUMMON_MASK)

#define RF6_INDIRECT_MASK \
	(RF6_SUMMON_MASK | \
	 RF6_HASTE | RF6_HEAL | RF6_INVULNER | RF6_BLINK | RF6_WORLD | RF6_TPORT)
//	 RF6_TPORT | RF6_RAISE_DEAD)

#define RF9_INDIRECT_MASK 	(RF9_SUMMON_MASK | RF9_DESTRUCTION | RF9_TELE_APPROACH | RF9_TELE_HI_APPROACH | RF9_ALARM)

/*
 * Hack -- "non-magic" spells
 * Including "breath" spells
 */
//v1.1.45 e폜
#define RF4_NOMAGIC_MASK \
	(RF4_BREATH_MASK | RF4_SHRIEK | RF4_ROCKET | RF4_SHOOT | RF4_SPECIAL2)

#define RF5_NOMAGIC_MASK \
	(RF5_BREATH_MASK)

#define RF6_NOMAGIC_MASK \
	(RF6_BREATH_MASK | RF6_SPECIAL)

#define RF9_NOMAGIC_MASK 0UL


/*
 * Hack -- "torch" masks
 */
#define RF7_LITE_MASK \
	(RF7_HAS_LITE_1 | RF7_SELF_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_2)

#define RF7_DARK_MASK \
	(RF7_HAS_DARK_1 | RF7_SELF_DARK_1 | RF7_HAS_DARK_2 | RF7_SELF_DARK_2)

#define RF7_HAS_LD_MASK \
	(RF7_HAS_LITE_1 | RF7_HAS_LITE_2 | RF7_HAS_DARK_1 | RF7_HAS_DARK_2)

#define RF7_SELF_LD_MASK \
	(RF7_SELF_LITE_1 | RF7_SELF_LITE_2 | RF7_SELF_DARK_1 | RF7_SELF_DARK_2)

/*
 * Hack -- effective elemental and poison immunity mask
 */
#define RFR_EFF_IM_ACID_MASK  (RFR_IM_ACID | RFR_RES_ALL)
#define RFR_EFF_IM_ELEC_MASK  (RFR_IM_ELEC | RFR_RES_ALL)
#define RFR_EFF_IM_FIRE_MASK  (RFR_IM_FIRE | RFR_RES_ALL)
#define RFR_EFF_IM_COLD_MASK  (RFR_IM_COLD | RFR_RES_ALL)
#define RFR_EFF_IM_POIS_MASK  (RFR_IM_POIS | RFR_RES_ALL)
#define RFR_EFF_RES_SHAR_MASK (RFR_RES_SHAR | RFR_RES_ALL)
#define RFR_EFF_RES_CHAO_MASK (RFR_RES_CHAO | RFR_RES_ALL)
//#define RFR_EFF_RES_NEXU_MASK (RFR_RES_NEXU | RFR_RES_ALL)
#define RFR_EFF_RES_NEXU_MASK (RFR_RES_TIME | RFR_RES_ALL)


#define MR1_SINKA 0x01


#define is_friendly(A) \
	 (bool)(((A)->smart & SM_FRIENDLY) ? TRUE : FALSE)

#define is_friendly_idx(IDX) \
	 (bool)((IDX) > 0 && is_friendly(&m_list[(IDX)]))

#define is_pet(A) \
	 (bool)(((A)->smart & SM_PET) ? TRUE : FALSE)

/*:::GΔ@FDIłybgłȂ*/
#define is_hostile(A) \
	 (bool)((is_friendly(A) || is_pet(A)) ? FALSE : TRUE)

/* Hack -- Determine monster race appearance index is same as race index */
/*:::^kLʗp@JI͌Ȃ͂*/
#define is_original_ap(A) \
	 (bool)(((A)->ap_r_idx == (A)->r_idx) ? TRUE : FALSE)

#define is_original_ap_and_seen(A) \
	 (bool)((A)->ml && !p_ptr->image && ((A)->ap_r_idx == (A)->r_idx))

/*
 * Is the monster seen by the player?
 */
#define is_seen(A) \
	((bool)((A)->ml && (!ignore_unview || p_ptr->inside_battle || \
	 (player_can_see_bold((A)->fy, (A)->fx) && projectable(py, px, (A)->fy, (A)->fx)))))


/*** Option Definitions ***/


#define OPT_PAGE_INPUT          1
#define OPT_PAGE_MAPSCREEN      2
#define OPT_PAGE_TEXT           3
#define OPT_PAGE_GAMEPLAY       4
#define OPT_PAGE_DISTURBANCE    5
#define OPT_PAGE_BIRTH          6
#define OPT_PAGE_AUTODESTROY    7
#define OPT_PAGE_PLAYRECORD    10

#define OPT_PAGE_JAPANESE_ONLY 99


/*** Macro Definitions ***/


/*
 * Hack -- The main "screen"
 */
#define term_screen     (angband_term[0])


/*
 * Determine if a given inventory item is "aware"
 */
#define object_is_aware(T) \
    (k_info[(T)->k_idx].aware)

/*
 * Determine if a given inventory item is "tried"
 */
#define object_is_tried(T) \
    (k_info[(T)->k_idx].tried)


/*
 * Determine if a given inventory item is "known"
 * Test One -- Check for special "known" tag
 * Test Two -- Check for "Easy Know" + "Aware"
 */
#define object_is_known(T) \
    (((T)->ident & (IDENT_KNOWN)) || \
     (k_info[(T)->k_idx].easy_know && k_info[(T)->k_idx].aware))


/*
 * Return the "attr" for a given item.
 * Use "flavor" if available.
 * Default to user definitions.
 */
///del131221 ̔p~
/*
#define object_attr(T) \
	((k_info[(T)->k_idx].flavor) ? \
	 (k_info[k_info[(T)->k_idx].flavor].x_attr) : \
	 ((!(T)->k_idx || ((T)->tval != TV_CORPSE) || ((T)->sval != SV_CORPSE) || \
	   (k_info[(T)->k_idx].x_attr != TERM_DARK)) ? \
	  (k_info[(T)->k_idx].x_attr) : (r_info[(T)->pval].x_attr)))
*/
#define object_attr(T) \
	((k_info[(T)->k_idx].flavor) ? \
	 (k_info[k_info[(T)->k_idx].flavor].x_attr) : \
	 ((!(T)->k_idx || \
	   (k_info[(T)->k_idx].x_attr != TERM_DARK)) ? \
	  (k_info[(T)->k_idx].x_attr) : (r_info[(T)->pval].x_attr)))


/*
 * Return the "char" for a given item.
 * Use "flavor" if available.
 * Default to user definitions.
 */
#define object_char(T) \
	((k_info[(T)->k_idx].flavor) ? \
	 (k_info[k_info[(T)->k_idx].flavor].x_char) : \
	 (k_info[(T)->k_idx].x_char))


/*
 * Artifacts use the "name1" field
 */
#define object_is_fixed_artifact(T) \
	((T)->name1 ? TRUE : FALSE)

/*
 * Ego-Items use the "name2" field
 */
#define object_is_ego(T) \
	((T)->name2 ? TRUE : FALSE)


/*
 * Broken items.
 */
#define object_is_broken(T) \
	((T)->ident & (IDENT_BROKEN))

/*
 * Cursed items.
 */
#define object_is_cursed(T) \
	((T)->curse_flags)


/*
 * Convert an "attr"/"char" pair into a "pict" (P)
 */
#define PICT(A,C) \
	((((u16b)(A)) << 8) | ((byte)(C)))

/*
 * Convert a "pict" (P) into an "attr" (A)
 */
#define PICT_A(P) \
	((byte)((P) >> 8))

/*
 * Convert a "pict" (P) into an "char" (C)
 */
#define PICT_C(P) \
	((char)((byte)(P)))


/*
 * Convert a "location" (Y,X) into a "grid" (G)
 */
#define GRID(Y,X) \
	(256 * (Y) + (X))

/*
 * Convert a "grid" (G) into a "location" (Y)
 */
#define GRID_Y(G) \
	((int)((G) / 256U))

/*
 * Convert a "grid" (G) into a "location" (X)
 */
#define GRID_X(G) \
	((int)((G) % 256U))


/*
 * Determines if a map location is fully inside the outer walls
 */
#define in_bounds(Y,X) \
   (((Y) > 0) && ((X) > 0) && ((Y) < cur_hgt-1) && ((X) < cur_wid-1))

/*
 * Determines if a map location is on or inside the outer walls
 */
#define in_bounds2(Y,X) \
   (((Y) >= 0) && ((X) >= 0) && ((Y) < cur_hgt) && ((X) < cur_wid))

/*
 * Determines if a map location is on or inside the outer walls
 * (unsigned version)
 */
#define in_bounds2u(Y,X) \
   (((Y) < cur_hgt) && ((X) < cur_wid))

/*
 * Determines if a map location is currently "on screen" -RAK-
 * Note that "panel_contains(Y,X)" always implies "in_bounds2(Y,X)".
 */
#define panel_contains(Y,X) \
  (((Y) >= panel_row_min) && ((Y) <= panel_row_max) && \
   ((X) >= panel_col_min) && ((X) <= panel_col_max))


/*
 * Determine if player is on this grid
 */
#define player_bold(Y,X) \
	(((Y) == py) && ((X) == px))


/*
 * Grid based version of "player_bold()"
 */
#define player_grid(C) \
	((C) == &cave[py][px])


#define cave_have_flag_bold(Y,X,INDEX) \
	(have_flag(f_info[cave[(Y)][(X)].feat].flags, (INDEX)))


#define cave_have_flag_grid(C,INDEX) \
	(have_flag(f_info[(C)->feat].flags, (INDEX)))


/*
 * Determine if a "feature" supports "los"
 */
#define feat_supports_los(F) \
	(have_flag(f_info[(F)].flags, FF_LOS))


/*
 * Determine if a "legal" grid supports "los"
 */
#define cave_los_bold(Y,X) \
	(feat_supports_los(cave[(Y)][(X)].feat))

#define cave_los_grid(C) \
	(feat_supports_los((C)->feat))


/*
 * Determine if a "legal" grid is a "clean" floor grid
 * Determine if terrain-change spells are allowed in a grid.
 *
 * Line 1 -- forbid non-floors
 * Line 2 -- forbid object terrains
 * Line 3 -- forbid normal objects
 */
#define cave_clean_bold(Y,X) \
	(cave_have_flag_bold((Y), (X), FF_FLOOR) && \
	 !(cave[Y][X].info & CAVE_OBJECT) && \
	  (cave[Y][X].o_idx == 0))


/*
 * Determine if an object can be dropped on a "legal" grid
 *
 * Line 1 -- forbid non-drops
 * Line 2 -- forbid object terrains
 */
	/*:::x,yn`ȂǃACeuȂꏊȂǂ`FbNH*/
#define cave_drop_bold(Y,X) \
	(cave_have_flag_bold((Y), (X), FF_DROP) && \
	 !(cave[Y][X].info & CAVE_OBJECT))


/*
 * Determine if a "legal" grid is an "empty" floor grid
 * Determine if monsters are allowed to move into a grid
 *
 * Line 1 -- forbid non-placement grids
 * Line 2 -- forbid normal monsters
 * Line 3 -- forbid the player
 */
#define cave_empty_bold(Y,X) \
	(cave_have_flag_bold((Y), (X), FF_PLACE) && \
	 !(cave[Y][X].m_idx) && \
	 !player_bold(Y,X))


/*
 * Determine if a "legal" grid is an "empty" floor grid
 * Determine if monster generation is allowed in a grid
 *
 * Line 1 -- forbid non-empty grids
 * Line 2 -- forbid trees while dungeon generation
 */
#define cave_empty_bold2(Y,X) \
	(cave_empty_bold(Y,X) && \
	 (character_dungeon || !cave_have_flag_bold((Y), (X), FF_TREE)))


/*
 * Determine if a "legal" grid is an "naked" floor grid
 *
 * Line 1 -- forbid non-clean gird
 * Line 2 -- forbid monsters
 * Line 3 -- forbid the player
 */
#define cave_naked_bold(Y,X) \
	(cave_clean_bold(Y,X) && \
	 !(cave[Y][X].m_idx) && \
	 !player_bold(Y,X))


/*
 * Determine if a "legal" grid is "permanent"
 *
 * Line 1 -- permanent flag
 */
#define cave_perma_bold(Y,X) \
	(cave_have_flag_bold((Y), (X), FF_PERMANENT))


/*
 * Grid based version of "cave_empty_bold()"
 */
#define cave_empty_grid(C) \
	(cave_have_flag_grid((C), FF_PLACE) && \
	 !((C)->m_idx) && \
	 !player_grid(C))


/*
 * Grid based version of "cave_perma_bold()"
 */
#define cave_perma_grid(C) \
	(cave_have_flag_grid((C), FF_PERMANENT))


#define pattern_tile(Y,X) \
	(cave_have_flag_bold((Y), (X), FF_PATTERN))

/*
 * Does the grid stop disintegration?
 */
#define cave_stop_disintegration(Y,X) \
	(!cave_have_flag_bold((Y), (X), FF_PROJECT) && \
	 (!cave_have_flag_bold((Y), (X), FF_HURT_DISI) || \
	  cave_have_flag_bold((Y), (X), FF_PERMANENT)))


/*
 * Determine if a "legal" grid is within "los" of the player
 *
 * Note the use of comparison to zero to force a "boolean" result
 */
#define player_has_los_grid(C) \
    (((C)->info & (CAVE_VIEW)) != 0)

/*
 * Determine if a "legal" grid is within "los" of the player
 *
 * Note the use of comparison to zero to force a "boolean" result
 */
/*:::̈ʒu王ʂĂ邩肷Bтcave[][].infoCAVE_VIEW藎肷̂H*/
#define player_has_los_bold(Y,X) \
    (((cave[Y][X].info & (CAVE_VIEW)) != 0) || p_ptr->inside_battle)


/*
 * Determine if a "feature" is "permanent wall"
 */
#define permanent_wall(F) \
	(have_flag((F)->flags, FF_WALL) && \
	 have_flag((F)->flags, FF_PERMANENT))

/*
 * Get feature mimic from f_info[] (applying "mimic" field)
 */
/*:::cave_type.mimicmimic̒lf_info[].mimicAȂcave_type.featf_info[].mimicԂ*/
#define get_feat_mimic(C) \
	(f_info[(C)->mimic ? (C)->mimic : (C)->feat].mimic)

/*:::playtimeXV*/
//playtiméAplaytime += (ݎ-Oplaytimes(start_time))ƂvZŌ܂B
//ʂ(ݎ-Jn)ɂȂŔA
//start_timeɌݎZbgΎEҏWȂǂ̂Ƃ̎Ԍo߂Zbgł悤ɂ邽߂ƎvB
#define update_playtime() \
{\
	u32b tmp;\
	if(!start_time)msg_format("ERROR:start_timeݒ̂܂update_playtime()Ă΂ꂽ");\
	tmp = time(NULL);\
	playtime += (tmp - start_time);\
	start_time = tmp;\
}

/*
 * Hack -- Prepare to use the "Secure" routines
 */
#if defined(SET_UID) && defined(SECURE)
extern int PlayerUID;@
# define getuid() PlayerUID
# define geteuid() PlayerUID
#endif



/*** Color constants ***/


/*
 * Angband "attributes" (with symbols, and base (R,G,B) codes)
 *
 * The "(R,G,B)" codes are given in "fourths" of the "maximal" value,
 * and should "gamma corrected" on most (non-Macintosh) machines.
 */
/*:::r_infoDs̐Fw蕶ϊAr_ptr->d_attrɊi[*/
#define TERM_DARK                0  /* 'd' */   /* 0,0,0 */
#define TERM_WHITE               1  /* 'w' */   /* 4,4,4 */
#define TERM_SLATE               2  /* 's' */   /* 2,2,2 */
#define TERM_ORANGE              3  /* 'o' */   /* 4,2,0 */
#define TERM_RED                 4  /* 'r' */   /* 3,0,0 */
#define TERM_GREEN               5  /* 'g' */   /* 0,2,1 */
#define TERM_BLUE                6  /* 'b' */   /* 0,0,4 */
#define TERM_UMBER               7  /* 'u' */   /* 2,1,0 */
#define TERM_L_DARK              8  /* 'D' */   /* 1,1,1 */
#define TERM_L_WHITE             9  /* 'W' */   /* 3,3,3 */
#define TERM_VIOLET             10  /* 'v' */   /* 4,0,4 */
#define TERM_YELLOW             11  /* 'y' */   /* 4,4,0 */
#define TERM_L_RED              12  /* 'R' */   /* 4,0,0 */
#define TERM_L_GREEN            13  /* 'G' */   /* 0,4,0 */
#define TERM_L_BLUE             14  /* 'B' */   /* 0,4,4 */
#define TERM_L_UMBER            15  /* 'U' */   /* 3,2,1 */


/*
 * Not using graphical tiles for this feature?
 */
#define is_ascii_graphics(A) (!((A) & 0x80))


/*** Sound constants ***/


/*
 * Mega-Hack -- some primitive sound support (see "main-win.c")
 *
 * Some "sound" constants for "Term_xtra(TERM_XTRA_SOUND, val)"
 */
#define SOUND_HIT        1
#define SOUND_MISS       2
#define SOUND_FLEE       3
#define SOUND_DROP       4
#define SOUND_KILL       5
#define SOUND_LEVEL      6
#define SOUND_DEATH      7
#define SOUND_STUDY      8
#define SOUND_TELEPORT   9
#define SOUND_SHOOT     10
#define SOUND_QUAFF     11
#define SOUND_ZAP       12
#define SOUND_WALK      13
#define SOUND_TPOTHER   14
#define SOUND_HITWALL   15
#define SOUND_EAT       16
#define SOUND_STORE1    17
#define SOUND_STORE2    18
#define SOUND_STORE3    19
#define SOUND_STORE4    20
#define SOUND_DIG       21
#define SOUND_OPENDOOR  22
#define SOUND_SHUTDOOR  23
#define SOUND_TPLEVEL   24
#define SOUND_SCROLL	25
#define SOUND_BUY	    26
#define SOUND_SELL	    27
#define SOUND_WARN	    28
#define SOUND_ROCKET    29 /* Somebody's shooting rockets */
#define SOUND_N_KILL    30 /* The player kills a non-living/undead monster */
#define SOUND_U_KILL    31 /* The player kills a unique */
#define SOUND_QUEST     32 /* The player has just completed a quest */
#define SOUND_HEAL      33 /* The player was healed a little bit */
#define SOUND_X_HEAL    34 /* The player was healed full health */
#define SOUND_BITE      35 /* A monster bites you */
#define SOUND_CLAW      36 /* A monster claws you */
#define SOUND_M_SPELL   37 /* A monster casts a miscellaneous spell */
#define SOUND_SUMMON    38 /* A monster casts a summoning spell  */
#define SOUND_BREATH    39 /* A monster breathes */
#define SOUND_BALL      40 /* A monster casts a ball / bolt spell */
#define SOUND_M_HEAL    41 /* A monster heals itself somehow */
#define SOUND_ATK_SPELL 42 /* A monster casts a misc. offensive spell */
#define SOUND_EVIL      43 /* Something nasty has just happened! */
#define SOUND_TOUCH     44 /* A monster touches you */
#define SOUND_STING     45 /* A monster stings you */
#define SOUND_CRUSH     46 /* A monster crushes / envelopes you */
#define SOUND_SLIME     47 /* A monster drools/spits/etc on you */
#define SOUND_WAIL      48 /* A monster wails */
#define SOUND_WINNER    49 /* Just won the game! */
#define SOUND_FIRE      50 /* An item was burned  */
#define SOUND_ACID      51 /* An item was destroyed by acid */
#define SOUND_ELEC      52 /* An item was destroyed by electricity */
#define SOUND_COLD      53 /* An item was shattered */
#define SOUND_ILLEGAL   54 /* Illegal command attempted */
#define SOUND_FAIL      55 /* Fail to get a spell off / activate an item */
#define SOUND_WAKEUP    56 /* A monster wakes up */
#define SOUND_INVULN    57 /* Invulnerability! */
#define SOUND_FALL      58 /* Falling through a trapdoor... */
#define SOUND_PAIN      59 /* A monster is in pain! */
#define SOUND_DESTITEM  60 /* An item was destroyed by misc. means */
#define SOUND_MOAN      61 /* A monster makes a moan/beg/insult attack */
#define SOUND_SHOW      62 /* A monster makes a "show" attack */
#define SOUND_UNUSED    63 /* (no sound for gaze attacks) */
#define SOUND_EXPLODE   64 /* Something (or somebody) explodes */
#define SOUND_GLASS     65 /* A glass feature was crashed */

/*
 * Mega-Hack -- maximum known sounds
 */
#define SOUND_MAX 66

#define MAX_VIRTUE 18

#define V_COMPASSION	    1
#define V_HONOUR	    2
#define V_JUSTICE	    3
#define V_SACRIFICE	    4
#define V_KNOWLEDGE	    5
#define V_FAITH 	    6
#define V_ENLIGHTEN	    7
#define V_ENCHANT	    8
#define V_CHANCE	    9
#define V_NATURE	   10
#define V_HARMONY	   11
#define V_VITALITY	   12
#define V_UNLIFE	   13
#define V_PATIENCE	   14
#define V_TEMPERANCE	   15
#define V_DILIGENCE	   16
#define V_VALOUR	   17
#define V_INDIVIDUALISM    18


/*** Hack ***/


/*
 * Hack -- attempt to reduce various values
 */
#ifdef ANGBAND_LITE
# undef MACRO_MAX
# define MACRO_MAX      128
# undef QUARK_MAX
# define QUARK_MAX      128
# undef MESSAGE_MAX
# define MESSAGE_MAX    128
# undef MESSAGE_BUF
# define MESSAGE_BUF    4096
#endif


/*
 * Buildings actions
 */
#define BACT_NOTHING                 0
#define BACT_RESEARCH_ITEM           1
#define BACT_TOWN_HISTORY            2
#define BACT_RACE_LEGENDS            3
#define BACT_GREET_KING              4
#define BACT_KING_LEGENDS            5
#define BACT_QUEST                   6
//#define BACT_XXX_UNUSED              7
#define BACT_TALK_KAGEROU              7
#define BACT_POSTER                  8
//#define BACT_ARENA_RULES             9
#define BACT_RUMORS_NEW				9
#define BACT_ARENA                  10
#define BACT_ARENA_LEGENDS          11
///mod140103 J@X@ꉞg݂Ă
#define BACT_MARIPO_GAIN			12
#define BACT_MARIPO_CHANGE			13
//#define BACT_IN_BETWEEN             12
//#define BACT_GAMBLE_RULES           13
#define BACT_KORIN_MAKEOVER			14
//#define BACT_CRAPS                  14
//#define BACT_SPIN_WHEEL             15
#define BACT_HEALING_PLUS           15
//#define BACT_DICE_SLOTS             16
#define BACT_TALK_KAGUYA             16 //PƘb
#define BACT_REST                   17
#define BACT_FOOD                   18
#define BACT_RUMORS                 19
#define BACT_RESEARCH_MONSTER       20
#define BACT_COMPARE_WEAPONS        21
#define BACT_LEGENDS                22
#define BACT_ENCHANT_WEAPON         23
#define BACT_ENCHANT_ARMOR          24
#define BACT_RECHARGE               25
#define BACT_IDENTS                 26
//#define BACT_LEARN                  27
#define BACT_BARTER					27
#define BACT_HEALING                28
#define BACT_RESTORE                29
#define BACT_ENCHANT_ARROWS         30
#define BACT_ENCHANT_BOW            31
#define BACT_GREET                  32
#define BACT_RECALL                 33
#define BACT_TELEPORT_LEVEL         34
#define BACT_LOSE_MUTATION          35
#define BACT_BATTLE                 36
//#define BACT_TSUCHINOKO             37
#define BACT_RYUUJIN             37
//#define BACT_TARGET                 38
#define BACT_GLASSROOTS_RUMOR       38
//#define BACT_KUBI                   39
#define BACT_KANKIN                 40
#define BACT_HEIKOUKA               41
#define BACT_TELE_TOWN              42
#define BACT_POKER                  43
#define BACT_IDENT_ONE              44
#define BACT_RECHARGE_ALL           45
#define BACT_EVAL_AC		        46
#define BACT_BROKEN_WEAPON          47
#define BACT_ARCHER_GUILD_GUIDE	   	48
#define BACT_ARCHER_GUILD_ARROW_ENC	49
#define BACT_ARCHER_GUILD_ARROW_EGO	50
#define BACT_REMOVE_CURSE			51
#define BACT_ESCAPE_FROM_GENSOUKYOU	52 //Olp@ރR}h
#define BACT_SELL_CURIOSITY			53
#define BACT_MAKE_MACHINE			54
#define BACT_BUY_MACHINE_SUPPLY		55
#define BACT_ENGINEER_GUILD_GUIDE	56
#define BACT_SMITH_GUILD	57
#define BACT_SMITH_GUILD_GUIDE	58
#define BACT_REIMU_FORTUNETELLER	59
#define BACT_REIMU_DEITY_CHECK		60
#define BACT_THROW_OSAISEN			61
#define BACT_CHECK_OSAISEN			62
#define BACT_BATTLE_MON_GAMBLING	63
#define BACT_MARISA_MAKE_MAGIC_RECIPE	64
#define BACT_MARISA_READ_MEMO		65
#define BACT_MARISA_EXTRACT_MATERIAL	66
#define BACT_MARISA_CHECK_ESSENCE	67
#define BACT_MARISA_MAKE_MAGIC		68
#define BACT_MARISA_CARRY_MAGIC		69
#define BACT_MARISA_CHECK_MAGIC		70
#define BACT_PRISM_CLASS_CHANGE		71
#define BACT_HINA_MAKE_MONEY		72
#define BACT_COMPOUND_DRUG			73
#define BACT_CHECK_DRUG_RECIPE		74
#define BACT_KOGASA_SMITH			75
#define BACT_EX_SEARCH_AROUND		76
#define BACT_BUY_HINA_NINGYOU		77
#define BACT_ITEM_TRANSFER			78
#define BACT_ITEMCARD_TRADING		79
#define BACT_ORIN_DELIVER_ITEM		80
#define BACT_ROPE_WAY				81
#define BACT_HELLO_WORK				82
#define BACT_NIGHTMARE_DIARY		83 //v1.1.51

//*::: MAX_BACT͌ݓɎgĂȂ炵*/
#define MAX_BACT                    	83

/*
 * Quest status
 */
#define QUEST_STATUS_UNTAKEN              0
#define QUEST_STATUS_TAKEN                1/*:::NGXg*/
#define QUEST_STATUS_COMPLETED            2/*:::*/
#define QUEST_STATUS_REWARDED             3/*:::񍐍ρAV҂*/
#define QUEST_STATUS_FINISHED             4/*:::Vς*/
#define QUEST_STATUS_FAILED               5/*:::sAAĂȂ*/
#define QUEST_STATUS_FAILED_DONE          6/*:::sAA*/
#define QUEST_STATUS_STAGE_COMPLETED      7/*:::pHetÅtO*/


/*
 * Quest type
 */
#define QUEST_TYPE_KILL_LEVEL                1
#define QUEST_TYPE_KILL_ANY_LEVEL            2
#define QUEST_TYPE_FIND_ARTIFACT             3
#define QUEST_TYPE_FIND_EXIT                 4
#define QUEST_TYPE_KILL_NUMBER               5
#define QUEST_TYPE_KILL_ALL                  6
#define QUEST_TYPE_RANDOM                    7
#define QUEST_TYPE_TOWER                     8
///mod140514 ACeTNGXg
#define QUEST_TYPE_DELIVER_ITEM             9
/*:::_Wɒʏ퐶胆j[NNGXgB*/
/*:::j[NꏏɎw肵ȂƂȂB*/
/*:::Yj[Nr_infoWANTEDtOĂKvAYNGXĝ܂Œʏ퐶ȂB*/
#define QUEST_TYPE_BOUNTY_HUNT	10
#define QUEST_TYPE_FIND_OBJECT             11
//_A[eBt@NgTBȂ̕󕨌ɗp
#define QUEST_TYPE_FIND_RANDOM_ARTIFACT            12

/*
 * Initialization flags
 */
#define INIT_NAME_ONLY          0x01
#define INIT_SHOW_TEXT          0x02
#define INIT_ASSIGN             0x04
#define INIT_CREATE_DUNGEON     0x08	/*:::tOF_WSH*/
#define INIT_ONLY_FEATURES      0x10	/*:::tOF_W̒n`̂ݍH*/
#define INIT_ONLY_BUILDINGS     0x20

/*
 * Quest flags
 */
#define QUEST_FLAG_SILENT  0x01 /* no messages fro completion */
#define QUEST_FLAG_PRESET  0x02 /* quest is outside the main dungeon */
#define QUEST_FLAG_ONCE    0x04 /* quest is marked finished after leaving */
#define QUEST_FLAG_TOWER   0x08 /* Tower quest is special */
///mod140113 Ē\ȃNGXgɓxڈȍ~ɓACeĂȂ悤ɂ邽߂̃tOǉ
//Ē\ȃNGXgBKiƂ̃tOBNGXgݒt@CŃtOEăACezuObh̏ɂB
#define QUEST_FLAG_RETRY   0x10
///mod140629 `[NGXg@ǂɖ(F̃tO̓NGXgV)
#define QUEST_FLAG_TEAM_A	0x20
#define QUEST_FLAG_TEAM_B	0x40
#define QUEST_FLAG_SPECIAL	0x80 //̌sۓWNG@㩔ς݃tO

/*
 * Available graphic modes
 */
#define GRAPHICS_NONE       0
#define GRAPHICS_ORIGINAL   1
#define GRAPHICS_ADAM_BOLT  2

/*
 * Modes for the random name generator
 */
#define NAME_DWARF  1
#define NAME_ELF    2
#define NAME_GNOME  3
#define NAME_HOBBIT 4
#define NAME_HUMAN  5
#define NAME_ORC    6

#ifdef JP
#define JVERB_AND 1
#define JVERB_TO  2
#define JVERB_OR  3
#endif

/*
 * Modes for the tokenizer
 */
#define TOKENIZE_CHECKQUOTE 0x01  /* Special handling of single quotes */

/*
 * Parse errors
 */
#define PARSE_ERROR_GENERIC                  1
#define PARSE_ERROR_ABSOLETE_FILE            2
#define PARSE_ERROR_MISSING_RECORD_HEADER    3
#define PARSE_ERROR_NON_SEQUENTIAL_RECORDS   4
#define PARSE_ERROR_INVALID_FLAG             5
#define PARSE_ERROR_UNDEFINED_DIRECTIVE      6
#define PARSE_ERROR_OUT_OF_MEMORY            7
#define PARSE_ERROR_OUT_OF_BOUNDS            8
#define PARSE_ERROR_TOO_FEW_ARGUMENTS        9
#define PARSE_ERROR_UNDEFINED_TERRAIN_TAG   10
#define PARSE_ERROR_WANTED_UNIQUE   11

#define PARSE_ERROR_MAX                     12

#define GINOU_SUDE       0
#define GINOU_NITOURYU   1
#define GINOU_RIDING      2

/* Proficiency level */
#define EXP_LEVEL_UNSKILLED 0
#define EXP_LEVEL_BEGINNER  1
#define EXP_LEVEL_SKILLED   2
#define EXP_LEVEL_EXPERT    3
#define EXP_LEVEL_MASTER    4

/* Proficiency of weapons and misc. skills (except riding) */
#define WEAPON_EXP_UNSKILLED     0
#define WEAPON_EXP_BEGINNER   4000
#define WEAPON_EXP_SKILLED    6000
#define WEAPON_EXP_EXPERT     7000
#define WEAPON_EXP_MASTER     8000

/* Proficiency of riding */
#define RIDING_EXP_UNSKILLED     0
#define RIDING_EXP_BEGINNER    500
#define RIDING_EXP_SKILLED    2000
#define RIDING_EXP_EXPERT     5000
#define RIDING_EXP_MASTER     8000

/* Proficiency of spells */
#define SPELL_EXP_UNSKILLED      0
#define SPELL_EXP_BEGINNER     900
#define SPELL_EXP_SKILLED     1200
#define SPELL_EXP_EXPERT      1400
#define SPELL_EXP_MASTER      1600

#define NO_TOWN 6	/*:::_W̒ȂǓp?*/
//#define SECRET_TOWN 5 /*:::̊Xɂ͊XړłȂƂɎgĂ@Y̊Xԍ*/

#define NIKKI_HIGAWARI     0
#define NIKKI_BUNSHOU      1
#define NIKKI_ART          2
#define NIKKI_UNIQUE       3
#define NIKKI_FIX_QUEST_C  4
#define NIKKI_FIX_QUEST_F  5
#define NIKKI_RAND_QUEST_C 6
#define NIKKI_RAND_QUEST_F 7
#define NIKKI_MAXDEAPTH    8
#define NIKKI_TRUMP        9
#define NIKKI_STAIR       10
#define NIKKI_RECALL      11
#define NIKKI_TO_QUEST    12
#define NIKKI_TELE_LEV    13
#define NIKKI_BUY         14
#define NIKKI_SELL        15
#define NIKKI_ARENA       16
#define NIKKI_HANMEI      17
#define NIKKI_LEVELUP     18
#define NIKKI_GAMESTART   19
#define NIKKI_WIZ_TELE    20
#define NIKKI_NAMED_PET   21
#define NIKKI_PAT_TELE    22

#define RECORD_NAMED_PET_NAME        0
#define RECORD_NAMED_PET_UNNAME      1
#define RECORD_NAMED_PET_DISMISS     2
#define RECORD_NAMED_PET_DEATH       3
#define RECORD_NAMED_PET_MOVED       4
#define RECORD_NAMED_PET_LOST_SIGHT  5
#define RECORD_NAMED_PET_DESTROY     6
#define RECORD_NAMED_PET_EARTHQUAKE  7
#define RECORD_NAMED_PET_GENOCIDE    8
#define RECORD_NAMED_PET_WIZ_ZAP     9
#define RECORD_NAMED_PET_TELE_LEVEL  10
#define RECORD_NAMED_PET_BLAST       11
#define RECORD_NAMED_PET_HEAL_LEPER  12
#define RECORD_NAMED_PET_COMPACT     13
#define RECORD_NAMED_PET_LOSE_PARENT 14

#define MAX_MANE 16
#define MAX_MONSPELLS 96
#define MONSPELL_TYPE_BOLT 1
#define MONSPELL_TYPE_BALL 2
#define MONSPELL_TYPE_BREATH 3
#define MONSPELL_TYPE_SUMMON 4
#define MONSPELL_TYPE_OTHER 5

#define EATER_EXT 32
#define EATER_CHARGE 0x10000L
#define EATER_ROD_CHARGE 0x10L

#define MAX_KUBI 20

#define DETECT_RAD_DEFAULT 30
#define DETECT_RAD_MAP     30
#define DETECT_RAD_ALL     255

/* Monster Spells */
/*:::X^[̖@@[jO\ȈꗗH*/
///mod131231 Ƃ肠V̂ǉĂ
#define MS_SHRIEK         0
#define MS_DANMAKU        1
#define MS_DISPEL         2
#define MS_ROCKET         3
#define MS_SHOOT          4
#define MS_BR_HOLY        5
#define MS_BR_HELL        6
#define MS_BR_AQUA        7
#define MS_BR_ACID        8
#define MS_BR_ELEC        9
#define MS_BR_FIRE        10
#define MS_BR_COLD        11
#define MS_BR_POIS        12
#define MS_BR_NETHER      13
#define MS_BR_LITE        14
#define MS_BR_DARK        15
#define MS_WAVEMOTION     16
#define MS_BR_SOUND       17
#define MS_BR_CHAOS       18
#define MS_BR_DISEN       19
#define MS_BR_NEXUS       20
#define MS_BR_TIME        21
#define MS_BR_INERTIA     22
#define MS_BR_GRAVITY     23
#define MS_BR_SHARDS      24
#define MS_BR_PLASMA      25
#define MS_BA_FORCE       26
#define MS_BR_MANA        27
#define MS_SPECIAL2       28
#define MS_BR_NUKE        29
#define MS_BALL_CHAOS     30
#define MS_BR_DISI        31
#define MS_BALL_ACID      32
#define MS_BALL_ELEC      33
#define MS_BALL_FIRE      34
#define MS_BALL_COLD      35
#define MS_BALL_POIS      36
#define MS_BALL_NETHER    37
#define MS_BALL_WATER     38
#define MS_BALL_MANA      39
#define MS_BALL_DARK      40
#define MS_DRAIN_MANA     41
#define MS_MIND_BLAST     42
#define MS_BRAIN_SMASH    43
#define MS_CAUSE_1        44
#define MS_CAUSE_2        45
#define MS_CAUSE_3        46
#define MS_CAUSE_4        47
#define MS_BOLT_ACID      48
#define MS_BOLT_ELEC      49
#define MS_BOLT_FIRE      50
#define MS_BOLT_COLD      51
#define MS_STARBURST      52
#define MS_BOLT_NETHER    53
#define MS_BOLT_WATER     54
#define MS_BOLT_MANA      55
#define MS_BOLT_PLASMA    56
#define MS_BOLT_ICE       57
#define MS_MAGIC_MISSILE  58
#define MS_SCARE          59
#define MS_BLIND          60
#define MS_CONF           61
#define MS_SLOW           62
#define MS_SLEEP          63
#define MS_SPEED          64
#define MS_HAND_DOOM      65
#define MS_HEAL           66
#define MS_INVULNER       67
#define MS_BLINK          68
#define MS_TELEPORT       69
#define MS_WORLD          70
#define MS_SPECIAL        71
#define MS_TELE_TO        72
#define MS_TELE_AWAY      73
#define MS_TELE_LEVEL     74
#define MS_PSY_SPEAR      75
#define MS_DARKNESS       76
#define MS_MAKE_TRAP      77
#define MS_FORGET         78
#define MS_COSMIC_HORROR  79
#define MS_S_KIN          80
#define MS_S_CYBER        81
#define MS_S_MONSTER      82
#define MS_S_MONSTERS     83
#define MS_S_ANT          84
#define MS_S_SPIDER       85
#define MS_S_HOUND        86
#define MS_S_HYDRA        87
#define MS_S_ANGEL        88
#define MS_S_DEMON        89
#define MS_S_UNDEAD       90
#define MS_S_DRAGON       91
#define MS_S_HI_UNDEAD    92
#define MS_S_HI_DRAGON    93
#define MS_S_AMBERITE     94
#define MS_S_UNIQUE       95

///mon X^[r_infołID ɃvO珈̈ȊO͏ĂȂ
#define MON_FAIRY			1
#define MON_YASE_CAT		2
#define MON_MAGGOT			8
#define MON_FLOWER_FAIRY	10
//#define MON_BEGGAR        12
//#define MON_LEPER         13
#define MON_FAIRY_MAID	  14
#define MON_D_FAIRY			16
#define MON_FAIRY_EX		17
#define MON_TSUKUMO_1		18
#define MON_TSUKUMO_2		19
//#define MON_LION_HEART    19
//#define MON_GHB           39
#define MON_ZOMBIE_FAIRY	15
#define MON_G_W_CENTIPEDE	24
#define MON_WHITEMOUSE		27
#define MON_SWARM			38
#define MON_NOV_PRIEST    45
#define MON_TSUKUMO_3		52
#define MON_GRIP          53
#define MON_WOLF          54
#define MON_FANG          55
#define MON_G_FROG          56
#define MON_YAMANEKO		62
#define MON_LOUSE         69
#define MON_PIRANHA       70
#define MON_COPPER_COINS  85
#define MON_WHITE_RAT  86

#define MON_NOV_PALADIN   97
#define MON_GREEN_G       100
#define MON_NOV_PRIEST_G  109
#define MON_RAT_THING		115
#define MON_SILVER_COINS  117
#define MON_G_SLUG			120
#define MON_D_ELF         122
#define MON_MANES         128
#define MON_LOST_SOUL     133
#define MON_ROBIN_HOOD    138
#define MON_NOV_PALADIN_G 147
#define MON_PHANTOM_W     152
#define MON_GIANT_GREY_RAT	156
#define MON_NODEPPOU	  159
#define MON_KILLER_BEE		174
#define MON_D_ELF_MAGE    178
#define MON_YOUKAI_CAT		180
#define MON_D_ELF_WARRIOR 182
#define MON_BLUE_HORROR   189
#define MON_HOHGOBLIN		194
#define MON_GOLD_COINS    195
#define MON_BLACK_PANTHER	198
#define MON_VORPAL_BUNNY  205
#define MON_GOLFIMBUL		215
#define MON_KAPPA		224
#define MON_PRIEST        225
#define MON_D_ELF_PRIEST  226
#define MON_TIGER         230
#define MON_YAMAWARO 239
#define MON_DRUID         241
#define MON_PINK_HORROR   242
#define MON_HILL_GIANT    255
#define MON_MAGIC_MUSHROOM  267
#define MON_WERERAT       270
#define MON_MI_GO		274
#define MON_TARANTULA		275
#define MON_UMBER_HULK    283
#define MON_ORC_CAPTAIN   285
#define MON_BERSERKER     293
#define MON_IMP           296
#define MON_SHAGRAT       314
#define MON_GORBAG        315
#define MON_KAPPA_ENGINEER	320
#define MON_STONE_GIANT   321
#define MON_LIZARD_KING   332
#define MON_WYVERN        334
#define MON_G_EAGLE			335
#define MON_SABRE_TIGER   339
#define MON_D_ELF_LORD    348
#define MON_FIRE_VOR      354
#define MON_WATER_VOR     355
#define MON_ARCH_VILE     357
#define MON_COLD_VOR      358
#define MON_ENERGY_VOR    359
#define MON_KILLER_STAG		366
#define MON_IRON_GOLEM    367
#define MON_JADE_MONK     370
#define MON_D_ELF_WARLOCK 375
#define MON_HAGEN         383
#define MON_MENELDOR      384
#define MON_PHANTOM_B     385
#define MON_V_BAT			391
#define MON_C_CRAWLER     395
#define MON_XICLOTLAN     396
#define MON_D_ELF_DRUID   400
#define MON_TROLL_PRIEST  403
#define MON_GWAIHIR       410
#define MON_ANGEL         417
#define MON_ENENRA		 423
#define MON_TZEENTCH_FLAMER			425
#define MON_COLBRAN       435
#define MON_SPIRIT_NAGA   436
#define MON_GACHAPIN      441
#define MON_DEEP_ONE	  452
#define MON_BASILISK      453
#define MON_ARCHANGEL     456
#define MON_MITHRIL_GOLEM 464
#define MON_SKEL_TYRANNO  466
#define MON_THORONDOR     468
#define MON_SHADOW_DRAKE  471
#define MON_GHOST         477
#define MON_OGRE_SHAMAN   479
#define MON_GHOUL_KING    483
#define MON_NINJA         485
#define MON_BICLOPS       490
#define MON_IVORY_MONK    492
#define MON_LOG_MASTER    498
#define MON_ETHER_DRAKE   504
#define MON_GOEMON        505
#define MON_CHERUB        511
#define MON_WATER_ELEM    512
#define MON_JURT          517
#define MON_LICH          518
#define MON_BLOODLETTER   523
#define MON_HALFLING_S    539
#define MON_GRAV_HOUND    540
#define MON_REVENANT      555
#define MON_RAAL          557
#define MON_COLOSSUS      558
#define MON_NIGHTBLADE    564
#define MON_ELDER_THING   569
#define MON_CRYPT_THING   577
#define	MON_FLYING_POLYP	580
#define MON_KOAKUMA     587
#define MON_PLASMA_VOR    588
#define MON_TIME_VOR      589
#define MON_M_MH_DRAGON   593
#define MON_MANDOR        598
#define MON_SHIM_VOR      600
#define MON_SERAPH        605
#define MON_NIGHTGAUNT	  608
#define MON_BARON_HELL    609
#define MON_KAVLAX        616
#define MON_CHTHONIAN	  619
#define MON_ETTIN         621
#define MON_NIGHTMARE     622

#define MON_VAMPIRE_LORD  623
#define MON_JUBJUB        640
#define MON_G_C_DRAKE     646
#define MON_CLUB_DEMON    648
#define MON_F_ANGEL       652
#define MON_D_ELF_SORC    657
#define MON_MASTER_LICH   658
#define MON_BYAKHEE   659

#define MON_HAKUROU_TENGU	660

#define MON_ARCHON        661
#define MON_UND_BEHOLDER  664
#define MON_IRON_LICH     666
#define MON_JACK_SHADOWS  670
#define MON_SPAWN_SHUB	677
#define	MON_COLOUR_OUTOFSPACE	678
#define MON_LLOIGOR       682
#define MON_SHOGGOTH		685
#define MON_DREADMASTER   690
#define MON_DROLEM        691
#define MON_DAWN          693
#define MON_NAZGUL        696
#define MON_SMAUG         697
#define MON_STORMBRINGER  698
#define MON_ULTRA_PALADIN 699
#define MON_G_TITAN       702
#define MON_S_TYRANNO     705
#define MON_FAFNER        712
#define MON_G_BALROG      720
#define MON_TIME_HOUND    725
#define MON_PLASMA_HOUND  726
#define MON_BULLGATES     732
#define MON_SANTACLAUS    733
#define MON_LORD_CHAOS    737
#define MON_KHAMUL			738
#define MON_TINDALOS      739
#define MON_DEMILICH      742
#define MON_NIGHTCRAWLER  744
#define MON_CHAOS_VOR     751
#define MON_THURINGWETHIL 755
#define MON_AETHER_VOR    752
#define MON_FUNDIN        762
#define MON_DWORKIN       763
#define MON_ANCALAGON		766
#define MON_NIGHTWALKER   768
#define MON_RAPHAEL       769
#define MON_SARUMAN       771
#define MON_GANDALF       772
#define MON_BRAND         773
#define MON_SHADOWLORD    774
#define MON_ARCHLICH      776
#define MON_JABBERWOCK    778
#define MON_CHAOS_HOUND   779
#define MON_ULT_BEHOLDER  781
#define MON_SHAMBLER      786
#define MON_BLEYS         789
#define MON_FIONA         791
#define MON_SKY_DRAKE     793
#define MON_JULIAN        794
#define MON_BLACK_REAVER  798
#define MON_CAINE         799
#define MON_GERARD        807
#define MON_UNGOLIANT     808
#define MON_ATLACH_NACHA  809
#define MON_Y_GOLONAC     810
#define MON_AETHER_HOUND  811
#define MON_WARP_DEMON    812
#define MON_ERIC          813
#define MON_UNMAKER       815
#define MON_CYBER         816
#define MON_MOUTH_OF_SAURON	818
#define MON_KLING         819
#define MON_CORWIN        820
#define MON_BENEDICT		824
#define MON_ANGMAR        825

#define MON_KARASU_TENGU  827

#define MON_CANTORAS      830
#define MON_GODZILLA      832
#define MON_SPAWN_CTH     836
#define MON_SURTUR        837
#define MON_TARRASQUE     838
#define MON_LUNGORTHIN    839
#define MON_DRAUGLUIN		840
#define MON_CYBER_KING    843
#define MON_YOG_SOTHOTH		845
#define MON_WYRM_POWER    847
#define MON_NODENS        849
#define MON_CARCHAROTH	850
#define MON_NYARLATHOTEP	851
#define MON_AZATHOTH	  852

#define MON_JORMUNGAND    854
#define MON_DESTROYER     855
#define MON_GOTHMOG       856
#define MON_G_CTHULHU     857
#define MON_SAURON        858
#define MON_UNICORN_ORD   859
#define MON_OBERON        860
#define MON_MORGOTH       861
#define MON_SERPENT       862
#define MON_ONE_RING      864
#define MON_CAAWS         866
#define MON_CULVERIN      867
#define MON_EBONY_MONK    870
#define MON_HAGURE        871
#define MON_OROCHI        872
#define MON_ECHIZEN       873
#define MON_SPECT_WYRM    874
#define MON_DIO           878
#define MON_OHMU          879
#define MON_WONG          880
#define MON_G_TENGU			883
#define MON_D_ELF_SHADE   886
#define MON_MANA_HOUND    887
#define MON_VENOM_WYRM    890
#define MON_TROLL_KING    894
#define MON_BAZOOKER      896
#define MON_SHARD_VOR     897
#define MON_ELF_LORD      900
#define MON_MASTER_MYS    916
#define MON_G_MASTER_MYS  917
#define MON_IE            921
#define MON_TSUCHINOKO    926
#define MON_MARIO		927
#define MON_GCWADL        929
#define MON_LOCKE_CLONE   930
#define MON_CALDARM       931
#define MON_BANORLUPART   932
#define MON_BANOR         933
#define MON_LUPART        934
#define MON_KENSHIROU     936
#define MON_W_KNIGHT      938
#define MON_HOARMURATH	939
#define MON_BONEDRAGON    941
#define MON_PLANETAR      942
#define MON_SOLAR         943
#define MON_BIKETAL       945
#define MON_RICH          948
#define MON_IKETA         949
#define MON_HAMMERBROTHER 950
#define MON_B_DEATH_SWORD 953
#define MON_YASE_HORSE    955
#define MON_HORSE         956
#define MON_BOTEI         963
#define MON_KAGE          964
#define MON_JAIAN         967
#define MON_BELD          973
#define MON_THAT_BAT      975
//#define MON_SHUTEN        979
#define S_SHINREI_B	979
#define S_SHINREI_P	984
#define MON_NEKOMATA		986
#define MON_FENGHUANG     988
#define MON_KIRIN         989
#define MON_BAHAMUT       1000
//#define MON_SUKE          1001
//#define MON_KAKU          1002
#define MON_GHOST_Q       1003
#define MON_PIP           1004
#define MON_G_COCKROACH		1007
#define MON_A_GOLD        1010
#define MON_A_SILVER      1011
#define MON_ROLENTO       1013
#define MON_RAOU          1018
#define S_SHINREI_G	1021
#define MON_NAPPA		1022
#define MON_SHURYUUDAN    1023
#define MON_WAHHA         1031
//#define MON_DEBBY         1032
#define S_SHINREI_W	1032
#define MON_KNI_TEMPLAR   1037
#define MON_PALADIN       1038
#define MON_C_SHINREI     1040
#define MON_D_SHINREI     1041
#define MON_TOPAZ_MONK    1047
#define MON_KRONOS			1051
#define MON_M_MINDCRAFTER 1056
#define MON_ELDER_VAMPIRE 1058
//#define MON_NOBORTA       1059
#define MON_RAIZYU    1060
#define MON_BARNEY        1061
#define MON_GROO          1062
#define MON_LOUSY         1063
#define MON_WYRM_SPACE    1064
#define MON_JIZOTAKO      1065
#define MON_YOUKAI_RABBIT 1067
#define MON_YOUKAI_RABBIT2 1083
#define MON_CHARGE_MAN	1081
#define MON_JURAL	1082

#define MON_G_USAGI		1083
#define MON_G_MUKADE	1088
///mod140107 ǉX^[
#define MON_RUMIA		1089
#define MON_CIRNO		1090
#define MON_MEIRIN		1091
#define MON_PATCHOULI	1092
#define MON_SAKUYA      1093
#define MON_REMY		1094
#define MON_F_SCARLET   1095
#define MON_LETTY   1096
#define MON_CHEN		1097
#define MON_ALICE   1098
#define MON_LUNASA		1099
#define MON_MERLIN		1100
#define MON_LYRICA		1101
#define MON_YOUMU		1102
#define MON_YUYUKO		1103
#define MON_RAN			1104
#define MON_YUKARI		1105
#define MON_WRIGGLE		1106
#define MON_MYSTIA		1107
#define MON_KEINE		1108
#define MON_TEWI		1109
#define MON_UDONGE		1110
#define MON_EIRIN		1111
#define MON_KAGUYA		1112
#define MON_MOKOU		1113
#define MON_SHIZUHA		1114
#define MON_MINORIKO	1115
#define MON_HINA		1116
#define MON_NITORI		1117
#define MON_MOMIZI		1118

#define MON_SHAMEIMARU	1119
#define MON_SANAE		1120
#define MON_KANAKO		1121
#define MON_SUWAKO		1122
#define MON_LILY_WHITE	1123
#define MON_KISUME		1124
#define MON_YAMAME		1125
#define MON_PARSEE		1126
#define MON_YUGI		1127
#define MON_SATORI		1128
#define MON_ORIN		1129
#define MON_UTSUHO		1130
#define MON_KOISHI		1131
#define MON_NAZRIN		1132
#define MON_KOGASA		1133
#define MON_ICHIRIN		1134
#define MON_MURASA		1135
#define MON_SHOU		1136
#define MON_BYAKUREN	1137
#define MON_NUE			1138
#define MON_KYOUKO		1139
#define MON_YOSHIKA		1140
#define MON_SEIGA		1141
#define MON_TOZIKO		1142
#define MON_FUTO		1143
#define MON_MIKO		1144

#define MON_WAKASAGI	1145
#define MON_SEKIBANKI	1146
#define MON_KAGEROU		1147
#define MON_BENBEN		1148
#define MON_YATSUHASHI	1149
#define MON_SEIJA		1150
#define MON_SHINMYOUMARU	1151
#define MON_RAIKO	1152
#define MON_KASEN	1153
#define MON_SUIKA	1154
#define MON_MINI_SUIKA	1155
#define MON_IKU	1156
#define MON_TENSHI	1157
#define MON_KOKORO		1158
#define MON_MEDICINE	1159
#define MON_YUUKA		1160
#define MON_KOMACHI		1161
#define MON_EIKI		1162

#define MON_ALICE_DOLL	1164

#define MON_HATATE		1163

#define MON_LESSER_O_G  1174
#define MON_FLUTIST     1175

#define MON_CHAOS_BLADE 1177
#define MON_OMEGA		1179
#define MON_MICHAEL		1180
#define MON_GREATER_DEMON		1183
#define MON_OURYU			1185
#define MON_REIKI			1186

#define MON_LIB_GOLEM	1187
#define MON_LIB_GOLEM2	1188
#define MON_DEATH_1		1191
#define MON_DEATH_2		1192
#define MON_DEATH_3		1193

#define MON_SENNIN1	1194
#define MON_SENNIN2	1195
#define MON_TENNIN	1196
#define MON_HANA_TENGU	1197
#define MON_BOU_REI	1198
#define MON_G_ONRYOU	1199
#define MON_ONRYOU	1200



#define MON_MOZGUS	1202
#define MON_MOZGUS2	1203
#define MON_KIZINTYOU	1206
#define MON_CHUPACABRA 1207

#define MON_SIGN_R	1208
#define MON_SIGN_B	1209
#define MON_SIGN_W	1210
#define MON_SIGN_L	1211



#define MON_MAGIC_MUSHROOM_RED		1213
#define MON_MAGIC_MUSHROOM_BLUE		1214
#define MON_MAGIC_MUSHROOM_BLACK	1215
#define MON_MAGIC_MUSHROOM_WHITE	1216
#define MON_MAGIC_MUSHROOM_GREEN	1217
#define MON_MAGIC_MUSHROOM_GAUDY	1218
#define MON_MAGIC_MUSHROOM_GRAY		1219
#define MON_MAGIC_MUSHROOM_CLEAR	1220

#define MON_F_SCARLET_4   1221
#define MON_TATARI	1222
#define MON_CIRNO_ICE		1223
#define MON_SEIJA_D		1224
#define MON_HELL_KAPPA		1225
#define MON_REIMU			1226
#define MON_MARISA			1227
#define MON_TANUKI		1228
#define MON_O_TANUKI		1229

#define MON_MAMIZOU		1230
#define MON_CHAMELEON	1231	//dς₷邽߂ɃJIɂĂ

#define MON_TSUKUMO_WEAPON1	1232
#define MON_TSUKUMO_WEAPON5	1236
///mod140719 _j[N
#define MON_RANDOM_UNIQUE_1	1237
#define MON_RANDOM_UNIQUE_2	1238
#define MON_RANDOM_UNIQUE_3	1239
#define IS_RANDOM_UNIQUE_IDX(A) ((A) >= MON_RANDOM_UNIQUE_1 && (A) <= MON_RANDOM_UNIQUE_3)

#define MON_YOUKAI_MOUSE	1240
#define MON_SIGN_S	1241
#define MON_PHILOSOPHER_STONE	1242
#define MON_BANKI_HEAD_1		1243
#define MON_BANKI_HEAD_2		1244
#define MON_HASHIBIROKOU		1245
#define MON_KOMODO_DRAGON		1246
#define MON_G_BOU_REI		1247
#define MON_ZYARYUU			1251
#define MON_INFANTDRAGON	1252
#define MON_GYOKUTO		1253
#define MON_MOKELE			1254
#define MON_TUTUGAMUSHI		1255
#define MON_YUUTEN			1256
#define MON_HAKUSEN		1257
#define MON_TAMA			1259
#define MON_KAPPA_OKURI		1260
#define MON_NINJA_SLAYER	1261
#define MON_TEST			1263
#define MON_HELL_KARASU		1264
#define MON_KANAME			1265
#define	MON_GREEN_EYED		1266
#define MON_SUMIREKO		1267
#define MON_3FAIRIES		1268
#define MON_GETTOMECA		1269
#define MON_MANFACE_DOG		1270
#define MON_BAMBOO_FAIRY	1272
#define MON_SEIRAN			1273
#define MON_RINGO			1274
#define MON_DOREMY			1275
#define MON_SAGUME			1276
#define MON_CLOWNPIECE		1277
#define MON_JUNKO			1278
#define MON_HECATIA1		1279
#define MON_HECATIA2		1280
#define MON_HECATIA3		1281
#define MON_HELL_FAIRY		1282
#define MON_NIGHTMARE_F		1285
#define MON_EAGLE_RABBIT	1286
#define MON_EXTRA_FIELD		1287 //ϐgp̈@_ƂɎgĂ̂ő̂ƂɎgȂ悤
#define MON_SAIBAIMAN		1288
#define MON_PANTHER			1290
#define MON_ASHIURI			1291

#define MON_MASTER_KAGUYA	1293
#define MON_PORTRAIT		1294
#define MON_HASSYAKUSAMA	1295
#define MON_MOON_SENTINEL	1296
#define MON_YORIHIME		1297
#define MON_TOYOHIME		1298
#define MON_REISEN2			1299
#define MON_SAGUME_MINE		1300

#define MON_KUNEKUNE		1302
#define MON_GUNNER_OF_CORWIN		1303
#define MON_ITEM_CARRIER	1304
#define MON_CLEANING_BOT	1305
#define MON_YOUR_BOAT		1306
#define MON_LARVA			1310
#define MON_NEMUNO			1311
#define MON_AUNN			1312
#define MON_NARUMI			1313
#define MON_SATONO			1314
#define MON_MAI				1315
#define MON_OKINA			1316
#define MON_BULLET_GOLEM	1317
#define MON_KOSUZU			1318
#define MON_JYOON			1319
#define MON_SHION_1			1320
#define MON_SHION_2			1321
#define MON_SUMIREKO_2		1322 //idx1267̃Rs[Bqˎ҃tOȂZpBidx̂܂ܓZɏoɂ̓ZtɈâŃRs[B
#define MON_EEL				1323

/* Maximum "Nazguls" number */
#define MAX_NAZGUL_NUM 5

#define DO_AUTOPICK       0x01 /*:::E*/
#define DO_AUTODESTROY    0x02 /*:::*/
#define DO_DISPLAY        0x04
#define DONT_AUTOPICK     0x08 /*:::u*/
#define ITEM_DISPLAY      0x10
#define DO_QUERY_AUTOPICK 0x20 /*:::mFďE*/


#define MAGIC_GLOVE_REDUCE_MANA 0x0001
#define MAGIC_FAIL_5PERCENT     0x0002
#define MAGIC_GAIN_EXP          0x0004

#define VIRTUE_LARGE 1
#define VIRTUE_SMALL 2

#define SPELL_DD_S 27
#define SPELL_DD_T 13
#define SPELL_SW   22
#define SPELL_KABE 20

#define KNOW_STAT   0x01
#define KNOW_HPRATE 0x02

/*
 * Music songs
 */
///mod150824 V̐EƂ̉̂Ɣ̂+100ĎgȂ
#define MUSIC_NONE              0
#define MUSIC_SLOW              101
#define MUSIC_BLESS             102
#define MUSIC_STUN              103
#define MUSIC_L_LIFE            104
#define MUSIC_FEAR              105
#define MUSIC_HERO              106
#define MUSIC_MIND              107
#define MUSIC_STEALTH           108
#define MUSIC_ID                109
#define MUSIC_CONF              110
#define MUSIC_SOUND             111
#define MUSIC_CHARM             112
#define MUSIC_WALL              113
#define MUSIC_RESIST            114
#define MUSIC_SPEED             115
#define MUSIC_DISPEL            116
#define MUSIC_SARUMAN           117
#define MUSIC_QUAKE             118
#define MUSIC_STASIS            119
#define MUSIC_SHERO             120
#define MUSIC_H_LIFE            121
#define MUSIC_INVULN            122
#define MUSIC_PSI               123

#define MUSIC_DETECT            201

///mod140817 ̊֌WɋVlȊO̐E֏
#define music_singing(X) ((CHECK_MUSIC_CLASS) && (p_ptr->magic_num1[0] == (X)))
#define music_singing_any() ((CHECK_MUSIC_CLASS) && p_ptr->magic_num1[0])
//#define music_singing(X) ((p_ptr->pclass == CLASS_BARD) && (p_ptr->magic_num1[0] == (X)))
//#define music_singing_any() ((p_ptr->pclass == CLASS_BARD) && p_ptr->magic_num1[0])

#define HISSATSU_NONE   0
#define HISSATSU_2      1
#define HISSATSU_3WAY   2
#define HISSATSU_SUTEMI 3
#define HISSATSU_FIRE   4
#define HISSATSU_COLD   5
#define HISSATSU_POISON 6
#define HISSATSU_ELEC   7
#define HISSATSU_NYUSIN 8
#define HISSATSU_FUKI   9
#define HISSATSU_MAJIN  10
#define HISSATSU_BOOMER 11
#define HISSATSU_DRAIN  12
#define HISSATSU_SEKIRYUKA 13
#define HISSATSU_OTAKEBI 14
#define HISSATSU_SHOUGE 15
#define HISSATSU_CONF   16
#define HISSATSU_ISSEN  17
#define HISSATSU_KYUSHO 18
#define HISSATSU_DOUBLE 19
#define HISSATSU_HYAKU  20
#define HISSATSU_MINEUCHI 21
#define HISSATSU_MEKIKI 22
#define HISSATSU_ZANMA  23
#define HISSATSU_UNDEAD 24
#define HISSATSU_HAGAN  25
#define HISSATSU_QUAKE  26
#define HISSATSU_COUNTER 27
#define HISSATSU_HARAI  28
#define HISSATSU_3DAN   29
#define HISSATSU_100NIN 30

#define HISSATSU_KAPPA  40

#define HISSATSU_LONGARM  41
#define HISSATSU_EXCLAW  42
#define HISSATSU_ATTACK_ONCE  43
#define HISSATSU_EIGOU  44
#define HISSATSU_SHINMYOU	45 //jۂ̊GHD
#define HISSATSU_NO_AURA	46 //I[󂯂ȂU
#define HISSATSU_UNZAN		47 //_CN[P
#define HISSATSU_SOULSCULPTURE	48 //\EXJv`A
#define HISSATSU_DOUBLESCORE	49 //فX_uXRA
#define HISSATSU_YOSHIKA		50 //F@ȂȂElS
#define HISSATSU_GION			51 //_l̓{
#define HISSATSU_IAI    100

/*
 *  Special essence id for Weapon smith
 */
#define MIN_SPECIAL_ESSENCE 200

#define ESSENCE_ATTACK        (MIN_SPECIAL_ESSENCE + 0)
#define ESSENCE_AC            (MIN_SPECIAL_ESSENCE + 1)
#define ESSENCE_TMP_RES_ACID  (MIN_SPECIAL_ESSENCE + 2)
#define ESSENCE_TMP_RES_ELEC  (MIN_SPECIAL_ESSENCE + 3)
#define ESSENCE_TMP_RES_FIRE  (MIN_SPECIAL_ESSENCE + 4)
#define ESSENCE_TMP_RES_COLD  (MIN_SPECIAL_ESSENCE + 5)
#define ESSENCE_SH_FIRE       (MIN_SPECIAL_ESSENCE + 6)
#define ESSENCE_SH_ELEC       (MIN_SPECIAL_ESSENCE + 7)
#define ESSENCE_SH_COLD       (MIN_SPECIAL_ESSENCE + 8)
#define ESSENCE_RESISTANCE    (MIN_SPECIAL_ESSENCE + 9)
#define ESSENCE_SUSTAIN       (MIN_SPECIAL_ESSENCE + 10)
#define ESSENCE_SLAY_GLOVE    (MIN_SPECIAL_ESSENCE + 11)

#define SPECIAL_ESSENCE_ONI		254 //Cɕt
#define SPECIAL_ESSENCE_OTHER	255 //tr_g̗dA̖Ƃi

#define DUNGEON_MODE_NONE       0
#define DUNGEON_MODE_AND        1
#define DUNGEON_MODE_NAND       2
#define DUNGEON_MODE_OR         3
#define DUNGEON_MODE_NOR        4

/*** Dungeon type flags -- DG ***/
#define DF1_WINNER              0x00000001L/*:::҂ɂȂȂƓoȂ*/
#define DF1_MAZE                0x00000002L/*:::{*/
#define DF1_SMALLEST            0x00000004L/*:::ɏ}bv*/
#define DF1_BEGINNER            0x00000008L/*:::S҃_W@܂ς̂oȂ@C[NA*/
#define DF1_BIG                 0x00000010L/*:::ɑ傫}bv*/
#define DF1_NO_DOORS            0x00000020L/*:::hAȂ@XAR*/
#define DF1_WATER_RIVER         0x00000040L/*:::̐삪邱Ƃ*/
#define DF1_LAVA_RIVER          0x00000080L/*:::n̐삪邱Ƃ*/
#define DF1_CURTAIN             0x00000100L/*:::J[e邱Ƃ@SA*/
#define DF1_GLASS_DOOR          0x00000200L/*:::hAKX@KX̏̂*/
#define DF1_CAVE                0x00000400L/*:::n`AۂHڍוs@AȂ*/
#define DF1_CAVERN              0x00000800L/*:::ۂn`邱ƂH*/
#define DF1_ARCADE              0x00001000L/*:::_Wɒ邱ƂHŜ*/


///mod150906 ̐Epɒǉ
#define DF1_DREAM_WORLD         0x00002000L 
#define DF1_XXX14               0x00004000L
#define DF1_XXX15               0x00008000L
#define DF1_FORGET              0x00010000L/*:::n`oȂ@{̂*/
#define DF1_LAKE_WATER          0x00020000L
#define DF1_LAKE_LAVA           0x00040000L
#define DF1_LAKE_RUBBLE         0x00080000L/*:::₾炯̒n`o邱Ƃ*/
#define DF1_LAKE_TREE           0x00100000L
#define DF1_NO_VAULT            0x00200000L/*:::vaultoȂ*/
#define DF1_ARENA               0x00400000L/*:::A[in`o邱Ƃ*/
#define DF1_DESTROY             0x00800000L/*:::jn`o邱Ƃ*/
#define DF1_GLASS_ROOM          0x01000000L/*:::KX̕o邱ƂEEH*/
#define DF1_NO_CAVE             0x02000000L/*:::AۂoȂ@*/
#define DF1_NO_MAGIC            0x04000000L/*:::@̓A*/
#define DF1_NO_MELEE            0x08000000L/*:::U̓A*/
#define DF1_CHAMELEON           0x10000000L/*:::JIoȂ*/
#define DF1_DARKNESS            0x20000000L/*:::m͈͂*/
#define DF1_XXX30               0x40000000L
#define DF1_XXX31               0x80000000L

#define DF1_LAKE_MASK (DF1_LAKE_WATER | DF1_LAKE_LAVA | DF1_LAKE_RUBBLE | DF1_LAKE_TREE)


/*:::_WIDɉƂ*/
#define DUNGEON_ANGBAND		 1
#define DUNGEON_TAISHI		 2
#define DUNGEON_FOREST		 3
#define DUNGEON_GENBU		 4
#define DUNGEON_KOUMA		 5
#define DUNGEON_ZIGOKUDANI   6
#define DUNGEON_MUEN		 7
#define DUNGEON_EX_HELL		 8
#define DUNGEON_NO_MAGIC     9
#define DUNGEON_NO_MELEE    10
#define DUNGEON_DRAGON      11
#define DUNGEON_CHAOS       12
#define DUNGEON_DREAM_WORLD 13


#define DUNGEON_FEAT_PROB_NUM 3


/*
 * Flags for change floor mode
 */
#define CFM_UP        	 0x0001  /* Move up */
#define CFM_DOWN      	 0x0002  /* Move down */
#define CFM_LONG_STAIRS  0x0004  /* Randomly occurred long stairs/shaft */
#define CFM_XXX  	 0x0008  /* XXX */
#define CFM_SHAFT     	 0x0010  /* Shaft */
#define CFM_RAND_PLACE   0x0020  /* Arrive at random grid */
#define CFM_RAND_CONNECT 0x0040  /* Connect with random stairs */
/*:::ʂ̊Ki~AA[i⓬Z̏ôƂɂTRUE*/
#define CFM_SAVE_FLOORS  0x0080  /* Save floors */
#define CFM_NO_RETURN    0x0100  /* Flee from random quest etc... */
/*:::nォ_Wւ̋AҎAnォ_Wւ̊Ki~肽ƂAϗeƂTRUE*/
#define CFM_FIRST_FLOOR  0x0200  /* Create exit from the dungeon */


/*
 * Flags for save/load temporal saved floor file
 */
#define SLF_SECOND     	 0x0001  /* Called from another save/load function */
#define SLF_NO_KILL      0x0002  /* Don't kill temporal files */


/*
 * Flags for wr_item()/rd_item()
 */
#define SAVE_ITEM_PVAL         0x00000001
#define SAVE_ITEM_DISCOUNT     0x00000002
#define SAVE_ITEM_NUMBER       0x00000004
#define SAVE_ITEM_NAME1        0x00000008
#define SAVE_ITEM_NAME2        0x00000010
#define SAVE_ITEM_TIMEOUT      0x00000020
#define SAVE_ITEM_TO_H         0x00000040
#define SAVE_ITEM_TO_D         0x00000080
#define SAVE_ITEM_TO_A         0x00000100
#define SAVE_ITEM_AC           0x00000200
#define SAVE_ITEM_DD           0x00000400
#define SAVE_ITEM_DS           0x00000800
#define SAVE_ITEM_IDENT        0x00001000
#define SAVE_ITEM_MARKED       0x00002000
#define SAVE_ITEM_ART_FLAGS0   0x00004000
#define SAVE_ITEM_ART_FLAGS1   0x00008000
#define SAVE_ITEM_ART_FLAGS2   0x00010000
#define SAVE_ITEM_ART_FLAGS3   0x00020000
#define SAVE_ITEM_CURSE_FLAGS  0x00040000
#define SAVE_ITEM_HELD_M_IDX   0x00080000
#define SAVE_ITEM_XTRA1        0x00100000
#define SAVE_ITEM_XTRA2        0x00200000
#define SAVE_ITEM_XTRA3        0x00400000
#define SAVE_ITEM_XTRA4        0x00800000
#define SAVE_ITEM_XTRA5        0x01000000
#define SAVE_ITEM_FEELING      0x02000000
#define SAVE_ITEM_INSCRIPTION  0x04000000
#define SAVE_ITEM_ART_NAME     0x08000000
#define SAVE_ITEM_SS_INFO      0x10000000 //v1.1.25 XRAT[op


/*
 * Flags for wr_monster()/rd_monster()
 */
#define SAVE_MON_AP_R_IDX     0x00000001
#define SAVE_MON_SUB_ALIGN    0x00000002
#define SAVE_MON_CSLEEP       0x00000004
#define SAVE_MON_FAST         0x00000008
#define SAVE_MON_SLOW         0x00000010
#define SAVE_MON_STUNNED      0x00000020
#define SAVE_MON_CONFUSED     0x00000040
#define SAVE_MON_MONFEAR      0x00000080
#define SAVE_MON_TARGET_Y     0x00000100
#define SAVE_MON_TARGET_X     0x00000200
#define SAVE_MON_INVULNER     0x00000400
#define SAVE_MON_SMART        0x00000800
#define SAVE_MON_EXP          0x00001000
#define SAVE_MON_MFLAG2       0x00002000
#define SAVE_MON_NICKNAME     0x00004000
#define SAVE_MON_PARENT       0x00008000

#define SAVE_MON_MFLAG        0x00010000


/*
 * Constant for kinds of mimic
 */
#define MIMIC_NONE       0
#define MIMIC_DEMON      1
#define MIMIC_DEMON_LORD 2
#define MIMIC_VAMPIRE    3
#define MIMIC_GIGANTIC  4
#define MIMIC_BEAST		5
#define MIMIC_SLIME		6
#define MIMIC_MARISA	7
#define MIMIC_MIST		8
#define MIMIC_DRAGON	9
#define MIMIC_CAT	10
#define MIMIC_NUE		11
#define MIMIC_SHINMYOU	12
#define MIMIC_METAMORPHOSE_NORMAL	13
#define MIMIC_METAMORPHOSE_MONST	14 //ƊƖ@gȂ
#define MIMIC_METAMORPHOSE_GIGANTIC	15
#define MIMIC_KOSUZU_GHOST	16
#define MIMIC_KOSUZU_HYAKKI	17
#define MIMIC_GOD_OF_NEW_WORLD	18


#define MIMIC_FLAGS choice
#define MIMIC_IS_NONLIVING	0x00000001
#define MIMIC_IS_DEMON		0x00000002
#define MIMIC_IS_UNDEAD		0x00000004
#define MIMIC_IS_GIGANTIC	0x00000008	//ɓȂAŔ΂ȂȂ
#define MIMIC_NO_WIELD		0x00000010  //ϐgɑύXłȂ
#define MIMIC_ONLY_MELEE	0x00000020 //ˌƓƔłȂ ꕔ̋ZgȂ
#define MIMIC_NO_CAST		0x00000040 //mR}h̖@gȂ
#define MIMIC_NO_RIDING		0x00000080 //ϐg͋Rs
#define MIMIC_NO_EXATACK	0x00000100 //ψٕʂȂǂ̒ǉUoȂ
#define MIMIC_NO_QUAFF		0x00000200 //߂Ȃ
#define MIMIC_NO_MAGICITEM	0x00000400 //ƊgȂ

/*:::푰AƈvAϐgłȂꍇ*/
#define prace_is_(A) (!p_ptr->mimic_form && (p_ptr->prace == A))

/* Sub-alignment flags for neutral monsters */
#define SUB_ALIGN_NEUTRAL 0x0000
#define SUB_ALIGN_EVIL    0x0001
#define SUB_ALIGN_GOOD    0x0002

/* Temporary flags macro */
///class ^̂܂ވꎞʔ
#define IS_FAST() (p_ptr->fast || music_singing(MUSIC_SPEED) || music_singing(MUSIC_SHERO) || (p_ptr->kamioroshi & KAMIOROSHI_SUMIYOSHI) || music_singing(MUSIC_NEW_RAIKO_PRISTINE))
#define IS_INVULN() (p_ptr->invuln || music_singing(MUSIC_INVULN) || (p_ptr->special_defense & MUSOU_TENSEI) || SUPER_SHION)
#define IS_HERO() (p_ptr->hero || music_singing(MUSIC_HERO) || music_singing(MUSIC_SHERO) || music_singing(MUSIC_NEW_RAIKO_PRISTINE) || p_ptr->alcohol >= DRANK_1)
#define IS_BLESSED() (p_ptr->blessed || music_singing(MUSIC_BLESS) || hex_spelling(HEX_BLESS))
//v1.1.48 ɂ̑ϐ̂Ƃfdϐ𓾂邱Ƃɂ
#define IS_OPPOSE_ACID() (p_ptr->oppose_acid || p_ptr->ult_res || SUPER_SHION || music_singing(MUSIC_RESIST) || music_singing(MUSIC_NEW_LYRICA_SOLO) || (p_ptr->special_defense & KATA_MUSOU) || (IS_METAMORPHOSIS && r_info[MON_EXTRA_FIELD].flagsr & RFR_IM_ACID))
#define IS_OPPOSE_ELEC() (p_ptr->oppose_elec || p_ptr->ult_res || SUPER_SHION || music_singing(MUSIC_RESIST) || music_singing(MUSIC_NEW_LYRICA_SOLO)  || (p_ptr->special_defense & KATA_MUSOU) || (IS_METAMORPHOSIS && r_info[MON_EXTRA_FIELD].flagsr & RFR_IM_ELEC))
#define IS_OPPOSE_FIRE() (p_ptr->oppose_fire || p_ptr->ult_res || SUPER_SHION || music_singing(MUSIC_RESIST) || music_singing(MUSIC_NEW_LYRICA_SOLO)  || (p_ptr->special_defense & KATA_MUSOU) || (IS_METAMORPHOSIS && r_info[MON_EXTRA_FIELD].flagsr & RFR_IM_FIRE))
#define IS_OPPOSE_COLD() (p_ptr->oppose_cold || p_ptr->ult_res || SUPER_SHION || music_singing(MUSIC_RESIST) || music_singing(MUSIC_NEW_LYRICA_SOLO)  || (p_ptr->special_defense & KATA_MUSOU) || (IS_METAMORPHOSIS && r_info[MON_EXTRA_FIELD].flagsr & RFR_IM_COLD))
#define IS_OPPOSE_POIS() (p_ptr->oppose_pois || p_ptr->ult_res || SUPER_SHION || music_singing(MUSIC_RESIST) || music_singing(MUSIC_NEW_LYRICA_SOLO)  || (p_ptr->special_defense & KATA_MUSOU) || (IS_METAMORPHOSIS && r_info[MON_EXTRA_FIELD].flagsr & RFR_IM_POIS))
#define IS_TIM_ESP() (p_ptr->tim_esp || music_singing(MUSIC_MIND) || ((p_ptr->pclass == CLASS_SNIPER) && p_ptr->concent >= CONCENT_TELE_THRESHOLD))
///spell ꎞB
#define IS_TIM_STEALTH() (p_ptr->tim_stealth || music_singing(MUSIC_STEALTH))

/* Multishadow effects is determined by turn */
#define CHECK_MULTISHADOW() (p_ptr->multishadow && (turn & 1))

/* Is "teleport level" ineffective to this target? */
/*
#define TELE_LEVEL_IS_INEFF(TARGET) \
	(p_ptr->inside_arena || p_ptr->inside_battle || \
	 (p_ptr->inside_quest && !random_quest_number(dun_level)) || \
	 (((TARGET) <= 0) && (quest_number(dun_level) || (dun_level >= d_info[dungeon_type].maxdepth)) && \
	  (dun_level >= 1) && ironman_downward))
 */

///mod160224 e|x菈ύX GNXgNGXgɃe|x͎g
#define TELE_LEVEL_IS_INEFF(TARGET) \
	(p_ptr->inside_arena || p_ptr->inside_battle || \
	 (p_ptr->inside_quest && !random_quest_number(dun_level)) || \
	 (((TARGET) <= 0) && (dun_level >= d_info[dungeon_type].maxdepth) && \
	  (dun_level >= 1) && ironman_downward))


/*
 * Max numbers of macro trigger names
 */
#define MAX_MACRO_MOD 12
#define MAX_MACRO_TRIG 200

/* Max size of screen dump buffer */
//v1.1.28 e4{ɂĂ݂
#define SCREEN_BUF_SIZE (65536 * 4)


/*
 * Special key code used for inkey_special()
 */
#define SKEY_MOD_MASK     0x0f00
#define SKEY_MOD_SHIFT    0x0100
#define SKEY_MOD_CONTROL  0x0200

#define SKEY_MASK         0xf000
#define SKEY_DOWN   	  0xf001
#define SKEY_LEFT   	  0xf002
#define SKEY_RIGHT  	  0xf003
#define SKEY_UP     	  0xf004
#define SKEY_PGUP   	  0xf005
#define SKEY_PGDOWN 	  0xf006
#define SKEY_TOP    	  0xf007
#define SKEY_BOTTOM 	  0xf008

/*
 * Bit flags for move_player_effect()
 */
#define MPE_STAYING       0x00000001 /*:::ȂƂH*/
#define MPE_FORGET_FLOW   0x00000002 /*:::H*/
#define MPE_HANDLE_STUFF  0x00000004
#define MPE_ENERGY_USE    0x00000008
#define MPE_DONT_PICKUP   0x00000010
#define MPE_DO_PICKUP     0x00000020
#define MPE_BREAK_TRAP    0x00000040
#define MPE_DONT_SWAP_MON 0x00000080


#define MTIMED_CSLEEP   0 /* Monster is sleeping */
#define MTIMED_FAST     1 /* Monster is temporarily fast */
#define MTIMED_SLOW     2 /* Monster is temporarily slow */
#define MTIMED_STUNNED  3 /* Monster is stunned */
#define MTIMED_CONFUSED 4 /* Monster is confused */
#define MTIMED_MONFEAR  5 /* Monster is afraid */
#define MTIMED_INVULNER 6 /* Monster is temporarily invulnerable */

#define MAX_MTIMED      7

#define MON_CSLEEP(M_PTR)   ((M_PTR)->mtimed[MTIMED_CSLEEP])
#define MON_FAST(M_PTR)     ((M_PTR)->mtimed[MTIMED_FAST])
#define MON_SLOW(M_PTR)     ((M_PTR)->mtimed[MTIMED_SLOW])
#define MON_STUNNED(M_PTR)  ((M_PTR)->mtimed[MTIMED_STUNNED])
#define MON_CONFUSED(M_PTR) ((M_PTR)->mtimed[MTIMED_CONFUSED])
#define MON_MONFEAR(M_PTR)  ((M_PTR)->mtimed[MTIMED_MONFEAR])
#define MON_INVULNER(M_PTR) ((M_PTR)->mtimed[MTIMED_INVULNER])

/*
 * Bit flags for screen_object()
 */
#define SCROBJ_FAKE_OBJECT  0x00000001
#define SCROBJ_FORCE_DETAIL 0x00000002

/*
 * For travel command (auto run)
 */
#define TRAVEL

/* Sniper */
#define SP_NONE          0
#define SP_LITE          1
#define SP_AWAY          2
#define SP_FIRE          3
#define SP_KILL_WALL     4
#define SP_COLD          5
#define SP_KILL_TRAP     6
#define SP_ELEC          7
#define SP_PIERCE        8
#define SP_RUSH          9
#define SP_DOUBLE        10
#define SP_EXPLODE       11
#define SP_EVILNESS      12
#define SP_HOLYNESS      13
#define SP_FINAL         14
#define SP_NEEDLE        15

#define CONCENT_RADAR_THRESHOLD 2
#define CONCENT_TELE_THRESHOLD  5

/* Hex */
///pend p@Ƃ肠

//#define hex_spelling_any() \
//	((p_ptr->realm1 == REALM_HEX) && (p_ptr->magic_num1[0]))
//#define hex_spelling(X) \
//	((p_ptr->realm1 == REALM_HEX) && (p_ptr->magic_num1[0] & (1L << (X))))
#define hex_spelling_any() (0)
#define hex_spelling(X) (0)



/*:::ԖXy}XȂǎwKς̐E̔*/
#define REALM_SPELLMASTER (cp_ptr->realm_aptitude[0] == 2)
///mod141116 p_ptr->concentgE̔
//v1.1.14 ˕Pǉ
#define CLASS_USE_CONCENT	(p_ptr->pclass == CLASS_SNIPER || p_ptr->pclass == CLASS_SOLDIER || p_ptr->pclass == CLASS_KISUME || p_ptr->pclass == CLASS_YUGI || p_ptr->pclass == CLASS_SANAE || p_ptr->pclass == CLASS_MEIRIN || p_ptr->pclass == CLASS_YATSUHASHI || p_ptr->pclass == CLASS_BENBEN || p_ptr->pclass == CLASS_RAIKO || p_ptr->pclass == CLASS_YORIHIME)



/* 1st book */
#define HEX_BLESS             0
#define HEX_CURE_LIGHT        1
#define HEX_DEMON_AURA        2
#define HEX_STINKING_MIST     3
#define HEX_XTRA_MIGHT        4
#define HEX_CURSE_WEAPON      5
#define HEX_DETECT_EVIL       6
#define HEX_PATIENCE          7
/* 2nd book */
#define HEX_ICE_ARMOR         8
#define HEX_CURE_SERIOUS      9
#define HEX_INHAIL           10
#define HEX_VAMP_MIST        11
#define HEX_RUNESWORD        12
#define HEX_CONFUSION        13
#define HEX_BUILDING         14
#define HEX_ANTI_TELE        15
/* 3rd book */
#define HEX_SHOCK_CLOAK      16
#define HEX_CURE_CRITICAL    17
#define HEX_RECHARGE         18
#define HEX_RAISE_DEAD       19
#define HEX_CURSE_ARMOUR     20
#define HEX_SHADOW_CLOAK     21
#define HEX_PAIN_TO_MANA     22
#define HEX_EYE_FOR_EYE      23
/* 4th book */
#define HEX_ANTI_MULTI       24
#define HEX_RESTORE          25
#define HEX_DRAIN_CURSE      26
#define HEX_VAMP_BLADE       27
#define HEX_STUN_MONSTERS    28
#define HEX_SHADOW_MOVE      29
#define HEX_ANTI_MAGIC       30
#define HEX_REVENGE          31

/*
  Language selection macro
*/
#ifdef JP
#define _(JAPANESE,ENGLISH) (JAPANESE)
#else
#define _(JAPANESE,ENGLISH) (ENGLISH)
#endif


///mod131226 skill Z\ƕZ\ol̓֘A

#define SKILL_EXP_MAX		21
#define SKILL_MARTIALARTS	0
#define SKILL_SHIELD		1
#define SKILL_RIDING		2
#define SKILL_2WEAPONS		3
#define SKILL_THROWING		4
#define SKILL_WEAPON_SHIFT	13
#define SKILL_LEV_TICK		160


///mod140104 p[^ƕ\LύX
//Aꎞ\͏
#define STAT_MAX_MAX 30
//\͏
#define STAT_ADD_MAX 40
//ꎞʍ\͏
#define STAT_HYPERMAX 50


#define MELEE_FIND_DEFAULT	0
#define MELEE_FIND_NOHAND   1
#define MELEE_FIND_LONGARM  2
#define MELEE_FIND_EX_CLAW	3
#define MELEE_FIND_SNEAKING_KILL	4
#define MELEE_FIND_SUMIREKO_DISTANT	5

/*:::fU*/
//Fꕪޕӂ50ނ܂
#define MELEE_MODE_PUNCH1		1	//{@Pɉ
#define MELEE_MODE_KICK1		2	//R
#define MELEE_MODE_BITE			3	//ݕt
#define MELEE_MODE_CLAW			4	//~
#define MELEE_MODE_SHIELD		5   //nxƂ

#define MELEE_MODE_PUNCH2		6	//@iK߂̂Ƃ
#define MELEE_MODE_KICK2		7	//R@iK߂̂Ƃ
#define MELEE_MODE_MA			8	//iƐp

#define MELEE_MODE_FISH_TAIL	20	//lAlψٗp@З
#define MELEE_MODE_PUNCH_ONI	21	//Spp`
#define MELEE_MODE_HEADBUTT		22  //˂@Γψَ
#define MELEE_MODE_HORNS		23  //p
#define MELEE_MODE_BIGHORN		24  //Ȋp
#define MELEE_MODE_BIGTAIL		25  //傫ȐK
#define MELEE_MODE_GIGA_PUNCH	26  //剻̉
#define MELEE_MODE_GIGA_KICK	27  //剻̏R
#define MELEE_MODE_ULTIMATE 	28  //ɐ̐p
#define MELEE_MODE_LONGARM  	29  //͓̒ʔwȂǉui
#define MELEE_MODE_DRILL		30	//H߃h@ߋp
#define MELEE_MODE_KASEN		31	//ؐp
#define MELEE_MODE_VAMP		  	32  //zS̊i܂ɏ@z
#define MELEE_MODE_PUNCH_NINJA	33	//jWpp`
#define MELEE_MODE_KICK_NINJA	34	//jWpLbN
#define MELEE_MODE_BEAST		35	//bϐgp
#define MELEE_MODE_EX_CLAW		36	//܋p
#define MELEE_MODE_SLIME		37	//XCϐgp
#define MELEE_MODE_ATAGO		38	//l̉
#define MELEE_MODE_KOISHI		39	//p
#define MELEE_MODE_MIST			40	//ωp
#define MELEE_MODE_DRAGON		41	//hSωp
#define MELEE_MODE_CIRNO		42	//`mp
#define MELEE_MODE_YOSHIKA		43	//FELV[
#define MELEE_MODE_LIGHTSPEED	44	//ړ@
#define MELEE_MODE_MEDI			45 //fBXp
#define MELEE_MODE_MIND			46 //\͎Ґp
#define MELEE_MODE_YUYUKO		47 //HXq(̂)
#define MELEE_MODE_TOZIKO		48 //j(dU)
#define MELEE_MODE_KISUME1		49 //LXp@xƂ5
#define MELEE_MODE_KISUME2		50
#define MELEE_MODE_KISUME3		51
#define MELEE_MODE_KISUME4		52
#define MELEE_MODE_KISUME5		53
#define MELEE_MODE_MIKO			54 //_q
#define MELEE_MODE_KOKORO		55 //
#define MELEE_MODE_NINJA		56 //E
#define MELEE_MODE_CHEN			57 //(ĂȂ)
#define	MELEE_MODE_MURASA1		58 //1 dUȂ
#define	MELEE_MODE_MURASA2		59 //2 荞ݍUȂǁ@[̎̂
#define MELEE_MODE_REIMU1		60 //얲1 g̓IU
#define MELEE_MODE_REIMU2		61 //얲2 EAzʂȂǁ@NłȂƏoȂ
#define MELEE_MODE_D_LORD		62 //ωp
#define MELEE_MODE_REMY_HAND	63 //~A3
#define MELEE_MODE_REMY_KICK	64
#define MELEE_MODE_REMY_OTHER	65
#define MELEE_MODE_NITORI		66 //ɂƂp
#define MELEE_MODE_HIZIRI		67 //@
#define MELEE_MODE_NUE			68 //ʂ(ϐg)
#define MELEE_MODE_UTSUHO		69 //
#define MELEE_MODE_SUWAKO		70 //zKq
#define MELEE_MODE_RAN			71 //
#define MELEE_MODE_TENSHI		72 //Vq
#define MELEE_MODE_MEIRIN		73 //
#define MELEE_MODE_SHINMYOU2	74 //j2
#define MELEE_MODE_SUMIREKO		75 //俎q
#define MELEE_MODE_ICHIRIN		76 //
#define MELEE_MODE_ICHIRIN2		77 //2
#define MELEE_MODE_MOKOU		78 //g
#define MELEE_MODE_KANAKO		79 //_ގq
#define MELEE_MODE_FUTO			80 //zs
#define MELEE_MODE_MARISA		81 //
#define MELEE_MODE_BENBEN		82 //فX_uXRAgp
#define MELEE_MODE_HINA			83 //
#define MELEE_MODE_3_FAIRIES	84 //O
#define MELEE_MODE_RAIKO		85 //
#define MELEE_MODE_MAMIZOU		86 //}~]E
#define MELEE_MODE_YUKARI		87 //
#define	MELEE_MODE_GUN_HANDGUN	88		//ieBbNKAeA}OiAie
#define MELEE_MODE_GUN_LONGBARREL	89	//eAUeeA}XPbgeAe
#define MELEE_MODE_GUN_BAYONET	90	//e
#define MELEE_MODE_GUN_LAUNCHER	91	//P
#define MELEE_MODE_GUN_TWOHAND	92 //񒚌e
#define MELEE_MODE_UDONGE		93 //ǂ
#define MELEE_MODE_ORIN			94 //
#define MELEE_MODE_SNEAKING		95 //m̃obNX^bup
#define MELEE_MODE_HYAKKI		96 //SSsG̋S
#define MELEE_MODE_DOREMY		97 //h~[
#define MELEE_MODE_JYOON_1		98 //1 DŌ
#define MELEE_MODE_JYOON_2		99 //2 UŌ
#define MELEE_MODE_SUPER_SHION	100 //X[p[nR_̎



/*:::ǉʕ*/
#define MELEE_STUN				1	//NO
#define MELEE_STUN2				2	//NO2
#define MELEE_STUN3				3	//NO3


#define MELEE_ELEC				10	//H߃hȂ XC+ϐ̂ȂGɞNO
#define MELEE_KASEN				11	//ؐ̕с@AfbhAXC
#define MELEE_VAMP				12 //z
#define MELEE_MELT				13 //n z+_
#define MELEE_SLOW				14 //
#define MELEE_ATAGO				15 //͂ȉΉU
#define MELEE_FIRE				16 //ΉU
#define MELEE_COLD				17 //CU
#define MELEE_POIS				18 //
#define MELEE_SINK				19 //vU@HɓGꌂœ|@їp
#define MELEE_SLAY_EVIL			20 //AfbhEEdɃ_[W2.5{
#define MELEE_NUE				21 //E|t^
#define MELEE_WATER				22 //U@ANOϐ̂ȂGNOƂ_̓GɃXC
#define MELEE_NEKOGURUMA		23 //ӂ̔Lԁ@LԂ̒g̏dʂdʂƞNOlɂȂ
#define MELEE_SLEEP				24 //h~[p@_Wu̐EvŃ_CX{AłȂƂU񐔃[vIɑ𖰂点锻


#define TIM_GENERAL_MAX			5	//p_ptr->tim_general[]̗vf@ύX̓Z[uf[^̌݊ȂȂ

///mod140307 Փxݒ
#define DIFFICULTY_EASY		0
#define DIFFICULTY_NORMAL	1
#define DIFFICULTY_HARD		2
#define DIFFICULTY_LUNATIC	3
#define DIFFICULTY_EXTRA	4

#define EXTRA_MODE	(difficulty == DIFFICULTY_EXTRA)

///mod140308 ˌ푕 shootable()Ŏg
//0:ˌ𑕔ĂȂiˌsj
//1:ˌ킪diˌsj
//2:eЎŎĂA܂͎ˌĂiˌsj
//3:ˌɉߐڕ𑕔ĂidyieBj
//4:ˌɉAjȂǂ𑕔Ă(yyieBj
//5:ˌ𗼎(CxgEjőĂiyieBȂj
#define SHOOT_NO_WEAPON		0
#define SHOOT_HEAVY_WEAPON	1
#define SHOOT_UNSUITABLE	2
#define SHOOT_HIGH_PENALTY	3
#define SHOOT_LOW_PENALTY	4
#define SHOOT_NO_PENALTY	5
#define SHOOT_GUN_ONLY		-1


#define RIDING_STOP		4000 //j𗣂nɓȂȂ
#define RIDING_PERFECT	7200 //j𗣂ĂĂn𑀂

/*:::Xԍ*/
#define TOWN_HITOZATO	1
#define TOWN_TENGU	2
#define TOWN_CHITEI	3
#define TOWN_KOUMA	4
#define TOWN_HAKUREI	5
#define TOWN_KAPPA	6
#define TOWN_EIENTEI	7
#define TOWN_KOURIN	8
#define TOWN_MYOURENJI	9
#define TOWN_KIRISAME 10
#define TOWN_UG		11 //pmف@nA[P[hBM̓Xԍ
#define TOWN_MORIYA	12	//v1.1.32 _

/*:::Dx*/
/* v1.1.19 臒lύX
#define DRANK_0  0
#define DRANK_1  1500
#define DRANK_2  3000
#define DRANK_3  7000
#define DRANK_4  10000
*/
#define DRANK_0  0
#define DRANK_1  500
#define DRANK_2  3000
#define DRANK_3  8000
#define DRANK_4  15000

/*:::jח̈_~낵*/	
#define KAMIOROSHI_AMATO		0x00000001
#define KAMIOROSHI_ISHIKORIDOME	0x00000002
#define KAMIOROSHI_IZUNA		0x00000004
#define KAMIOROSHI_IZUNOME		0x00000008
#define KAMIOROSHI_SUMIYOSHI	0x00000010
#define KAMIOROSHI_ATAGO		0x00000020
#define KAMIOROSHI_AMENOUZUME	0x00000040
#define KAMIOROSHI_AMATERASU	0x00000080
//v1.1.14 ǉ
#define KAMIOROSHI_YAOYOROZU	0x00000100
#define KAMIOROSHI_GION			0x00000200
#define KAMIOROSHI_KANAYAMAHIKO		0x00000400
#define KAMIOROSHI_HONOIKAZUTI		0x00000800
#define KAMIOROSHI_AMATSUMIKABOSHI	0x00001000


/*:::̔̓샂[h@*/
#define		D_DOOR_NORMAL	1
#define 	D_DOOR_SHADOW	2 //Í̈uẽQ[gvɂ鎟̔@sȂs悪邢QƈړȂ
#define 	D_DOOR_DRAGON	3 //hSϐg bZ[WႢsyieBȂ
#define 	D_DOOR_MIST		4 //ϐg@sȂEړłs{@Qƃ_e|
#define		D_DOOR_MACHINE	5 //@B̃e|[^[@܂ɕǂ̒ɏo
#define		D_DOOR_MURASA	6 //т̃VJ[S[Xg@sȂn`ɂoȂ
#define		D_DOOR_MINI		7 //sȂ͈3ȓ̂
#define		D_DOOR_MOKOU	8 //gp[XgoCtFjbNX
#define		D_DOOR_FUTO		9 //̋
#define		D_DOOR_DREAM	10 //h[GNXvX
#define		D_DOOR_YUKARI	11 //zz
#define		D_DOOR_PATTERN	12 //p^[vault tÂǂɂłs
#define		D_DOOR_TOYOHIME	13 //LP̎̔@\
#define		D_DOOR_CHOSEN_DIST	14 //dimension_door_distanceŋwł
#define		D_DOOR_BACKDOOR	15 //˂̍e|[g

/*:::ǉCxgő吔@FύXƃZ[ut@Č݊ȂȂ*/
///mod150919 v1.0.74ȍ~AINVEN_ADD_MAX1024ɕύXB͑₷Ȃ݊Ȃ
#define 	INVEN_ADD_MAX	24

/*:::ɓȃACeۑ̈pӂBǉCxgƈႢdʌvZȂBeXbg̎g͑SČ܂ĂB*/
#define INVEN_SPECIAL_MAX	18
#define INVEN_SPECIAL_SLOT_KOGASA_SMITH	0 //Pb
#define INVEN_SPECIAL_ITEM_SLOT_START	1 //Extra[hpACeJ[hXbg
#define INVEN_SPECIAL_ITEM_SLOT_END		16 //16̈mۂĂ̂Ƃ8܂łgȂ
#define INVEN_SPECIAL_SLOT_ORIN_DELIVER 17 //ӂ̃ACezT[rX


/*:::b̔x*/
#define ASTHMA_1	2000 //@s㏸
#define ASTHMA_2	4000 //Bቺ
#define ASTHMA_3	7000 //Ƃǂs
#define ASTHMA_4	10000 //ϋv-4

/*:::̊֌WVCfbNX 0͉̂ĂȂ*/
#define MUSIC_NEW_MYSTIA_YAZYAKU		1 //~XeBA@鐝̉
#define MUSIC_NEW_MYSTIA_MYSTERIOUS		2 //~XeBA@~XeAX\O
#define MUSIC_NEW_MYSTIA_CHORUSMASTER	3 //~XeBA@^钆̃R[X}X^[
#define MUSIC_NEW_KYOUKO_NENBUTSU		4 //q@O
#define MUSIC_NEW_KYOUKO_SCREAM			5 //q@vC}XN[
#define MUSIC_NEW_LUNASA_SOLO			6 //iTE\Cu
#define MUSIC_NEW_MERLIN_SOLO			7 //Enbs[Cu
#define MUSIC_NEW_LYRICA_SOLO			8 //JE\Cu
#define MUSIC_NEW_TSUKUMO_HEIKE			9 //فX@Ƃ̑剅
#define MUSIC_NEW_TSUKUMO_STORM			10 //فX@̃ATu
#define MUSIC_NEW_TSUKUMO_SCOREWEB		11 //فX@XRAEFu
#define MUSIC_NEW_TSUKUMO_DOUBLESCORE	12 //فX@_uXRA
#define MUSIC_NEW_TSUKUMO_NORIGOTO		13 //@Vً̏
#define MUSIC_NEW_TSUKUMO_JINKIN		14 //@lՂƂɖS
#define MUSIC_NEW_TSUKUMO_ECHO			15 //@GR[`Fo[
#define MUSIC_NEW_TSUKUMO_ECHO2			16 //@̎c
#define MUSIC_NEW_RAIKO_AYANOTUDUMI		17 //ۃAmcd~
#define MUSIC_NEW_RAIKO_DENDEN			18 //ۓ{̃ff
#define MUSIC_NEW_RAIKO_PRISTINE		19 //ۃvXeBr[g
#define MUSIC_NEW_MYSTIA_HUMAN_CAGE		20 //~XeBA@q[}P[W



/*:::X^[@̐*/

#define MAX_MONSPELLS2 128

///mod141115 [zCg̃Q[I[o[܂ł̓
#define LILY_LIMIT 30


/*:::얲̐肢p p_ptr->today_monɊi[*/
#define FORTUNETELLER_TREASURE	1
#define FORTUNETELLER_TROPHY	2
#define FORTUNETELLER_GOODLUCK	3
#define FORTUNETELLER_BADLUCK	4

/*:::ǐ_l֘A*/
#define	DBIAS_COSMOS		0 //x
#define	DBIAS_WARLIKE		1 //Dx
#define	DBIAS_REPUTATION	2 //x
#define MAX_DEITY_TABLE_ENTRY	80


/*:::̔*/
#define FULL_MOON	((turn % (TURNS_PER_TICK * TOWN_DAWN) >= 50000) && (turn / (TURNS_PER_TICK * TOWN_DAWN) % 30 + 16 == 30))

/*::: 얲֌W*/
#define OSAISEN_MAX (99999999L)
//NGXgBΑKvZ
#define QUEST_OSAISEN(LEV) ((LEV) * (LEV) * (20 + adj_general[p_ptr->stat_ind[A_CHR]]) / 2)

///mod150215 cp
#define CONCENT_SOMA	1
#define CONCENT_KANA	2
#define CONCENT_SUWA	3

///mod150219 p
#define MARISA_POWER_FIRE	0
#define MARISA_POWER_COLD	1
#define MARISA_POWER_ELEC	2
#define MARISA_POWER_LITE	3
#define MARISA_POWER_DARK	4
#define MARISA_POWER_ILLU	5
#define MARISA_POWER_STAR	6
#define MARISA_POWER_SUPER	7
#define MARISA_POWER_MAX	(99999L)

#define NITORI_ENERGY_MAX	999


///mod150314 dǉvf
#define FAIRY_TYPE_MAX	56
#define CHECK_FAIRY_TYPE	((p_ptr->prace == RACE_FAIRY )? p_ptr->race_multipur_val[0] : 0)

///mod150401 
//וsvcgp magic_num1/2[]̓Y@96O͖Ɏg
#define	SEIJA_ITEM_START	97
#define	SEIJA_ITEM_HIRARI	97
#define	SEIJA_ITEM_SUKIMA	98
#define	SEIJA_ITEM_DECOY	99
#define	SEIJA_ITEM_BOMB		100
#define	SEIJA_ITEM_CAMERA	101
#define	SEIJA_ITEM_ONMYOU	102
#define	SEIJA_ITEM_KODUCHI	103
#define	SEIJA_ITEM_JIZO		104
#define	SEIJA_ITEM_CHOCHIN	105
#define	SEIJA_ITEM_END		105


///mod150502 zKqp
#define SUWAKO_POINT_MAX	99999

///mod150503 ̃Q[I[o[܂ł̓
#define RAN_LIMIT 7

///mod150614 ZύX
#define BATTLE_MON_LIST_MAX	20
#define BATTLE_MON_RANDOM_TEAM_NAME_NUM	38
#define BATTLE_MON_SPECIAL_TEAM_NUM	50
#define BATTLE_MON_TICKS	300

///mod150712 _ގq
//p_ptr->magic_num2[0,1]{Xœ|tOɎgB
#define	KANAKO_BEAT_0_HIZIRIN	0x01
#define	KANAKO_BEAT_0_MIMIMI	0x02
#define	KANAKO_BEAT_0_REIMU		0x04
#define	KANAKO_BEAT_0_CTHULHU	0x08
#define	KANAKO_BEAT_0_OBERON	0x10
#define	KANAKO_BEAT_0_AZAT		0x20
#define	KANAKO_BEAT_0_MORGOTH	0x40
#define	KANAKO_BEAT_0_J			0x80

///mod150805 AX
#define	INVEN_DOLL_SHANHAI	0
#define	INVEN_DOLL_HORAI	1
#define	INVEN_DOLL_RUSSIA	2
#define	INVEN_DOLL_LONDON	3
#define	INVEN_DOLL_ORLEANS	4
#define	INVEN_DOLL_KYOTO	5
#define	INVEN_DOLL_GOLIATH	6
#define	INVEN_DOLL_NUM_MAX	7



///mod150811 
#define MARISA_MAX_MAGIC_KIND	28 //鎩얂@̎ށ@marisa_magic_table[]̗vf
#define MARISA_CARRY_MAGIC_NUM	16 //Ă鎩얂@̐
#define MARISA_HOME_CARRY_SHIFT 40
#define CMM_MODE_CHECK		0 //@I[`̓샂[h
#define CMM_MODE_MAKE		1
#define CMM_MODE_CARRY		2
#define CMM_MODE_CAST		3

///mod150910 NEs[X
#define CLOWNPIECE_MAX_HP	30000

//X^[ւ̕ϐg
#define IS_METAMORPHOSIS	(p_ptr->tim_mimic && (p_ptr->special_defense & SD_METAMORPHOSIS))


#define	HINA_YAKU_LIMIT1	(1000 + p_ptr->lev * 100)
#define	HINA_YAKU_LIMIT2	(2000 + p_ptr->lev * 200)
#define	HINA_YAKU_LIMIT3	(2500 + p_ptr->lev * 350)
#define	HINA_YAKU_MAX		(5000 + p_ptr->lev * 500)



#define SAKUYA_WORLD (p_ptr->pclass == CLASS_SAKUYA && (p_ptr->special_defense & SD_SAKUYA_WORLD))

#define KAGUYA_QUEST_MAX	5


/*:::EX_Wp̌̐@f_infoŃ^OuBUILDING_EX?vƂĈ*/
#define	BLDG_EX_NUM		4
#define EX_BUILDINGS_HISTORY_MAX	6 //Extra[h_Wo𐔁@ςƃZ[uf[^݊ȂȂ̂Œ
#define EX_BUILDINGS_PARAM_MAX	6	//Extra[h_Wp[^zvf@̃tA@ςƃZ[uf[^݊ȂȂ̂Œ

#define	BLDG_EX_STORE_GENERAL	1	
#define	BLDG_EX_STORE_ARMOURY	2	
#define	BLDG_EX_STORE_WEAPON	3	
#define	BLDG_EX_STORE_TEMPLE	4	
#define	BLDG_EX_STORE_ALCHEMIST	5	
#define	BLDG_EX_STORE_MAGIC	6		
#define	BLDG_EX_STORE_BLACK	7		
#define	BLDG_EX_STORE_BOOK	8		

#define BLDG_EX_REIMU		9 //AÁAΑK
#define BLDG_EX_KOGASA		10 //틭
#define BLDG_EX_UG_GUILDS	11 //Mh
#define BLDG_EX_PATCHOULI	12 //[UA*Ӓ*
#define BLDG_EX_MYSTIA		13 //H
#define BLDG_EX_EIRIN		14 //ÁAˑRψَ
#define BLDG_EX_SMITH		15 //bAC
#define BLDG_EX_FLAN		16 //t̒n
#define BLDG_EX_UDONGE		17 //ǂ񂰂̍s
#define BLDG_EX_AKISISTERS	18 //Hỏ

#define BLDG_EX_IKUCHI		19 //LmR̐L
#define BLDG_EX_CHAOS_BLADE	20 //̌̕
#define BLDG_EX_ABANDONED	21 //pH[ɑ
#define BLDG_EX_SUKIMA		22 //Êقс@
#define BLDG_EX_SUWAKO		23 //J[hɓ@܂M
#define BLDG_EX_HINA		24 //l`l̔(Aol)
#define BLDG_EX_KOURIN		25 //V@*Ӓ*Ai
#define BLDG_EX_SHINREIBYOU 26 //__o [UAACe]
#define BLDG_EX_PRINT_TENGU 27 //V̈
#define BLDG_EX_GRASSROOTS  28 //̍dlbg[ÑLv
#define BLDG_EX_ORIN		29 //ӂ̑z
#define BLDG_EX_ORC			30 //I[Ň
#define BLDG_EX_MARISA		31 //J@Xo
#define BLDG_EX_NAZRIN		32 //ӒAn}
#define BLDG_EX_OKINA		33 //_ȉN
#define BLDG_EX_MORIYA		34 //A\͉񕜁A_lEƈē
#define BLDG_EX_PUFFBALL	35 //IjtXx̐ꏊ
#define BLDG_EX_LARVA		36 //o̕ʑ

#define BLDG_EX_MAX			37 //Ō̌ԍ+1

#define CAST_MONSPELL_EXTRA_KYOUKO_YAMABIKO -1 


//eACe̎ˌ̎
#define	GUN_FIRE_MODE_DEFAULT	0	//ˌ
#define	GUN_FIRE_MODE_BOLT		1	//{g
#define	GUN_FIRE_MODE_BALL		2	//{[
#define	GUN_FIRE_MODE_BEAM		3	//r[
#define	GUN_FIRE_MODE_ROCKET	4	//Pbg
#define	GUN_FIRE_MODE_BREATH	5	//uX
#define	GUN_FIRE_MODE_SPARK		6	//^r[
#define GUN_FIRE_MODE_MADAN		7	//e̎ˎp
#define GUN_FIRE_MODE_BLAST		8	//fire_blast NUKp
#define GUN_FIRE_MODE_VLADIMIR	9	//nRl2p
#define GUN_FIRE_MODE_JUMP		10 //fire_ball_jump ̂Ƃ됴p

//fR}ĥƂegǂ̔莮
#define CHECK_USE_GUN ((inventory[INVEN_RARM].tval == TV_GUN || inventory[INVEN_LARM].tval == TV_GUN) && !(mimic_info[p_ptr->mimic_form].MIMIC_FLAGS & MIMIC_ONLY_MELEE || p_ptr->clawextend || check_invalidate_inventory(INVEN_RARM) || check_invalidate_inventory(INVEN_LARM)))

//̃_SCt[GXɂƉuۗL
#define CHECK_RINGO_IMMUNE(TYP) (p_ptr->pclass == CLASS_RINGO && p_ptr->tim_general[1] && p_ptr->magic_num1[3] == (TYP))


//O[oϐspecial_shooting_modeɎg
//v1.1.21 rbgtOłȂʂ̐lɕύX
#define	SSM_SEIRAN1	1	//1	fire_ball_jump()ɂȂ
#define	SSM_SEIRAN2	2	//2	GZAEFC
#define	SSM_SEIRAN3	3	//3	xǂɔ
#define	SSM_SEIRAN4	4	//4 Seˌ
#define	SSM_SEIRAN5	5	//5 Ǌђʎ󑮐r[

#define SSM_CONFUSE	6	//ˌ

#define SSM_RAPID_FIRE	8	//sbht@CAƃieBbN_u


#define SSM_CHANGE_AMMO_START 11
#define SSM_FIRE		11	//@̒eہFΉe
#define SSM_COLD		12	//@̒eہFXe
#define SSM_ELEC		13	//@̒eہFde
#define SSM_ACID		14	//@̒eہFne
#define SSM_LIGHT		15	//Me
#define SSM_VAMPIRIC	16	//ze
#define SSM_SONICWAVE	17	//Ռe
#define SSM_GRAV		18	//d͒e

#define SSM_POIS		31
#define SSM_SLAY_ANIMAL	32
#define SSM_SLAY_NONLIV	33
#define SSM_SLAY_EVIL	34
#define SSM_SLAY_HUMAN	35
#define SSM_SLAY_FLYER	36
#define SSM_SILVER		37
#define SSM_HEAVY		38
#define SSM_BREATH		39
#define SSM_ICE			40
#define SSM_SLAY_DRAGON	41
#define SSM_SLAY_DEITY	42
#define SSM_NIGHTMARE	43
#define SSM_HOLY		44
#define SSM_RED			45
#define SSM_DIAMOND		46
#define SSM_METEOR		47
#define SSM_HIHIIROKANE	48
#define SSM_CHANGE_AMMO_END 48




#define HECATE_BODY_OTHER	0	//wJ[eBAيE
#define HECATE_BODY_EARTH	1	//wJ[eBAn
#define HECATE_BODY_MOON	2	//wJ[eBA
#define hecatia_body_is_(A) (p_ptr->pclass == CLASS_HECATIA && p_ptr->magic_num2[0] == (A)) //wJ[eBȂ̂̃`FbNp
#define HECATE_SEIKAKU_CHOOSE 10	//wJ[eBȂ̂̐iIł悤ɂȂuʂ̐iv̐



//uȂZvgprh𔻒
//:𑝂₷Ƃ̓XRAT[õZ[ut@Cǂݎ胋[`ɎKv
#define USE_NAMELESS_ARTS (p_ptr->pclass == CLASS_JUNKO || is_special_seikaku(SEIKAKU_SPECIAL_SUMIREKO))

//ϗpZݒtO1

#define JKF1_ATTACK_BOLT	1	//{gU
#define JKF1_ATTACK_BALL	2	//{[U
#define JKF1_ATTACK_BEAM	3	//r[U
#define JKF1_ATTACK_ROCKET	4	//PbgU
#define JKF1_ATTACK_BREATH	5	//uXU
#define JKF1_ATTACK_SPARK	6	//^[U[U
#define JKF1_ATTACK_AROUND	7	//S{[U
#define JKF1_ATTACK_SIGHT	8	//EU
#define JKF1_ATTACK_FLOOR	9	//tAU
#define JKF1_FOOD			10	//󕠏[

#define JKF1_HEAL1			11	//()
#define JKF1_HEAL2			12	//()
#define JKF1_DETECT_MON		13	//X^[m
#define JKF1_DETECT_TRAPS	14	//㩊m
#define JKF1_DETECT_OBJ		15	//ACem
#define JKF1_ENLIGHT		16	//[
#define JKF1_RESTORE		17	//\́Aol
#define JKF1_TELEPO			18	//e|
#define JKF1_D_DOOR			19	//̔
#define	JKF1_WHIRL_WIND		20	//S͕U
#define	JKF1_RUSH_ATTACK	21	//g
#define	JKF1_MULTI_HIT		22	//AU
#define JKF1_CURE_ALL		23	//
#define JKF1_RESTORE_NEXUS	24	//񕜁{ψَ{Ԉُ펡
#define JKF1_REMOVE_CURSE	25	//
#define JKF1_VANISH_BEAM	26  //{gE[U[
#define JKF1_EXPLOSION_DEF	27	//{[EPbgy
#define JKF1_BREATH_DEF		28  //uXy
#define JKF1_DESTRUCT_DEF	29  //*j*j~
#define JKF1_ABSORB_MAGIC	30	//@z
#define JKF1_KILL_WALL		31	//ǖxړ
#define JKF1_MASTER_MAGITEM 32	//͎gp

#define JKF1_MUSCLE_UP		33	//rϋ
#define JKF1_MENTAL_UP		34	//m
#define JKF1_INVULNER		35	//G
#define JKF1_SPEED			36	//ꎞ
#define JKF1_RES_MAGIC		37	//@h㏸
#define JKF1_SHIELD			38	//AC+50
#define JKF1_MAGICDEF		39	//@̊Z
#define JKF1_S_STEALTH		40	//ꎞB
#define JKF1_PASS_WALL		41	//ǔ
#define JKF1_DUSTROBE		42	//jЃI[
#define JKF1_RES_ELEM		43	//Ggϐ
#define JKF1_ULTI_RES		44	//ɂ̑ϐ
#define JKF1_ADD_ESSENCE1 	45	//ւ̗͂ȂǕt^
#define JKF1_ADD_ESSENCE2	46	//ւ̑ϐt^
#define JKF1_IDENTIFY		47	//Ӓ
#define JKF1_DESTROY		48	//*j*
#define JKF1_SILENT_FLOOR	49	//tAÎ
#define JKF1_MASS_GENO		50	//ӖE
#define JKF1_CALL_CHAOS		51	//׏
#define JKF1_TELE_AWAY_ALL	52	//Ee|AEFC
#define JKF1_DEATH_RAY		53	//Ě
#define JKF1_MOSES			54	//EuCvU
#define JKF1_STASIS			55	//E
#define JKF1_DISTURB_SUMMON	56	//jQ
#define JKF1_ALTER_REALITY	57	//ϗe
#define JKF1_CALL_METEOR	58	//Q

#define JKF1_SELF_LIGHT		59	//
#define JKF1_MASTER_MELEE	60  //U񐔂▽ȂǏ㏸
#define JKF1_EARTHQUAKES	61  //nk
#define JKF1_DISARM			62  //ӂ̃gbv
#define JKF1_LUCKY			63  //K^
#define JKF1_MAX			63 //Zp\̂▼̌胊Xg̗vfɎg



//ϗpZݒtO2
#define JKF2_START		80 	//tOJn
#define JKF2_ACID		80	//_
#define JKF2_ELEC		81
#define JKF2_FIRE		82
#define JKF2_COLD		83
#define JKF2_POIS		84
#define JKF2_LITE		85
#define JKF2_DARK		86
#define JKF2_SHARDS		87
#define JKF2_WATER		88
#define JKF2_SOUND		89
#define JKF2_NUKE		90
#define JKF2_MANA		91
#define JKF2_METEOR		92
#define JKF2_CHAOS		93
#define JKF2_NETHER		94
#define JKF2_DISENCHANT	95
#define JKF2_TIME		96
#define JKF2_DISTORTION	97
#define JKF2_HOLY		98
#define JKF2_HELL		99
#define JKF2_DISINTEGRATE	100
#define JKF2_WIND		101
#define JKF2_STEAM		102
#define JKF2_MAKE_WALL	103
#define JKF2_MAKE_DOOR	104
#define JKF2_MAKE_TREE	105
#define JKF2_END		105
//p_ptr->magic_num2[]ɑΉ̂ōől107

#define JUNKO_ARTS_COUNT (2 + (p_ptr->lev + 1) / 7)
#define JUNKO_ARTS_COUNT_MAX	9

//ϗpZp[^Qƃ}N
#define JUNKO_ARTS_PARAM(NUM,VAL) (p_ptr->magic_num1[(NUM)*11+(VAL)])

#define JKAP_JKF1	0
#define JKAP_GF		1
#define JKAP_COST	2
#define JKAP_RAD	3
#define JKAP_BASE	4
#define JKAP_DICE	5
#define JKAP_SIDES	6
#define JKAP_COUNT_NUM	7
#define JKAP_QUARK_IDX	8
#define JKAP_XTRA_VAL1	9
#define JKAP_XTRA_VAL2	10

//v1.1.21
/*:::mpZ֘A*/
#define SOLDIER_SKILL_SHOOT			0		//ˌZ\
#define SOLDIER_SKILL_COMBAT		1		//ߐڋZ\
#define SOLDIER_SKILL_ENGINEER		2		//HZ\
#define SOLDIER_SKILL_MAGICBULLET	3		//eZ\
#define SOLDIER_SKILL_ARRAY_MAX		4	//̋Z\
#define SOLDIER_SKILL_NUM_MAX		9	//eZ\ɂXL̐


//ˌZ\
#define	SS_S_CURBING_SHOT		1//
#define	SS_S_HAWK_EYE			2//
#define	SS_S_HEAD_SHOT			3//
#define	SS_S_QUICK_DRAW			4//
#define	SS_S_MAINTENANCE		5//
#define	SS_S_RAPID_FIRE			6//
#define	SS_S_WEAPON_MASTERY		7//
#define	SS_S_INTERCEPTOR		8//
#define	SS_S_ONE_MAN_ARMY		9//

//ߐڋZ\
#define	SS_C_KNIFE_MASTERY		1//
#define	SS_C_MUSCLE				2//
#define	SS_C_CLOSE_RANGE_SHOT	3//
#define	SS_C_HIT_AND_AWAY		4//
#define	SS_C_SCAVENGER			5//
#define	SS_C_SNEAKING			6//
#define	SS_C_RESIST				7//
#define	SS_C_ADRENALIN_CONTROL	8//
#define	SS_C_LETHAL_WEAPON		9//

//HZ\
#define	SS_E_SRH_DIS_PLUS		1//
#define	SS_E_DETECTING			2//
#define	SS_E_BARRICADE			3//
#define	SS_E_PORTAL				4//
#define	SS_E_SET_BOMB			5//
#define	SS_E_MANA_PLUS			6//
#define	SS_E_MEGA_CRASH			7//
#define	SS_E_POWERUP_BOMB		8//
#define	SS_E_DETONATOR			9//

//eZ\
#define	SS_M_SCAN_MONSTER		1
#define	SS_M_ELEM_BULLET		2
#define	SS_M_MAGITEM			3
#define	SS_M_CONCEALMENT		4
#define	SS_M_HIGH_BULLET		5
#define	SS_M_CONCENT			6
#define	SS_M_MATERIAL_BULLET	7
#define	SS_M_NOCTO_VISION		8
#define	SS_M_DER_FREISCHUTZ		9

//NeBJvZ邽߂̃tO
#define GUN_CRIT_HEAD			0x00000001	//wbhVbg
#define GUN_CRIT_CONCENT		0x00000002	//_W
#define GUN_CRIT_CLOSE			0x00000004	//ߐڎˌ
#define GUN_CRIT_TRIGGERHAPPY	0x00000008  //gK[nbs[
#define GUN_CRIT_NIGHT			0x00000010	//Z\
#define GUN_CRIT_CONCEAL		0x00000020  //Z\
#define GUN_CRIT_SPECIALBULLET	0x00000040  //eeύX
#define GUN_CRIT_MAGICBULLET	0x00000080  //e̎ˎ

#define GUN_CRIT_DEV_2			0x10000000	//l2Ŋ
#define GUN_CRIT_DEV_3			0x20000000	//l3Ŋ
#define GUN_CRIT_DEV_5			0x40000000	//l5Ŋ






#define HAVE_SOLDIER_SKILL(ARR,NUM) ((p_ptr->pclass == CLASS_SOLDIER) && (p_ptr->magic_num2[(ARR)] >= (NUM)))
//v1.1.22 mZ\@n`(zSȊO)ƐXn`
#define CHECK_CONCEALMENT (HAVE_SOLDIER_SKILL(SOLDIER_SKILL_MAGICBULLET,SS_M_CONCEALMENT) && ( cave_have_flag_bold(py,px,FF_WATER) && !prace_is_(RACE_VAMPIRE) || cave_have_flag_bold(py,px,FF_TREE)))

#define SCORE_SERVER_STR_LEN	40

//v1.1.35 lm꒣ɂ邩ǂ̔
#define IS_NEMUNO_IN_SANCTUARY	(p_ptr->pclass == CLASS_NEMUNO && (cave[py][px].cave_xtra_flag & CAVE_XTRA_FLAG_NEMUNO))

#define CAVE_XTRA_FLAG_NEMUNO	0x00000001	//lm̓꒣

//v1.1.37 |_ ϐgĂȂ̓ꏈp
#define IS_VULN_FEAR (p_ptr->pclass == CLASS_KOSUZU && !p_ptr->mimic_form)

//v1.1.46 ̎w֑
#define JYOON_INVEN2_NUM	8

//v1.1.48 ߈˒ǂ̔
#define SHION_POSSESSING	(p_ptr->pclass == CLASS_SHION && p_ptr->tim_mimic && p_ptr->mimic_form >= MIMIC_METAMORPHOSE_NORMAL && p_ptr->mimic_form <= MIMIC_METAMORPHOSE_GIGANTIC && (p_ptr->special_flags & SPF_IGNORE_METAMOR_TIME))
//̃X[p[nR_[h
#define SUPER_SHION		(p_ptr->pclass == CLASS_SHION && p_ptr->tim_general[0])

//X[p[nR_ɕϐg\ȃ^[ (Oϐg12Ԍoߖ+1^[AOϐg|ꂽ߈˂X^[̗݌vol50000Ƃ+1^[)
#define CALC_SUPER_SHION_TURNS ( (turn - p_ptr->magic_num1[0]) / 50000 + p_ptr->magic_num1[1] / 50000)

//X[p[nR_ԂJ|tO
#define IS_SHION_TRUE_LOSER (p_ptr->pclass == CLASS_SHION && p_ptr->magic_num2[0])
//unRʁv̂Ɏgp_ptr->magic_num1[1]̒l
#define SHION_BINBOUDAMA	25000

//v1.1.51 VA[iu̐Eɒ킷()vp

//oĂ郂X^[̍ő吔 Z[uf[^ɉêŕύX
#define	NIGHTMARE_DIARY_MONSTER_MAX	5	
//s閲̐ẼXe[W
#define	NIGHTMARE_DIARY_STAGE_LEV_MAX	8
//̐ẼXe[WGg
#define NIGHTMARE_GEN_MAP_TABLE_SIZE	46

//̐Eɂ邩ǂ̔Bh~[̓Zp[^ɉeBVA[i̐EɊ܂ނ̂Ƃ
#define IN_DREAM_WORLD ( dungeon_type == DUNGEON_DREAM_WORLD || p_ptr->inside_arena)



