/* File: tables.c */

/*
 * Copyright (c) 1997 Ben Harrison, James E. Wilson, Robert A. Koeneke
 *
 * This software may be copied and distributed for educational, research,
 * and not for profit purposes provided that this copyright and statement
 * are included in all such copies.  Other copyrights may also apply.
 */

/* Purpose: Angband Tables */

#include "angband.h"




/*
 * Global array for looping through the "keypad directions"
 */
const s16b ddd[9] =
{ 2, 8, 6, 4, 3, 1, 9, 7, 5 };

/*
 * Global arrays for converting "keypad direction" into offsets
 */
/*:::L[͂̐Wړɕϊ\*/
const s16b ddx[10] =
{ 0, -1, 0, 1, -1, 0, 1, -1, 0, 1 };

const s16b ddy[10] =
{ 0, 1, 1, 1, 0, 0, 0, -1, -1, -1 };

/*
 * Global arrays for optimizing "ddx[ddd[i]]" and "ddy[ddd[i]]"
 */
const s16b ddx_ddd[9] =
{ 0, 0, 1, -1, 1, -1, 1, -1, 0 };

const s16b ddy_ddd[9] =
{ 1, -1, 0, 0, 1, 1, -1, -1, 0 };


/*
 * Circular keypad direction array
 */
const s16b cdd[8] =
{ 2, 3, 6, 9, 8, 7, 4, 1 };

/*
 * Global arrays for optimizing "ddx[cdd[i]]" and "ddy[cdd[i]]"
 */
const s16b ddx_cdd[8] =
{ 0, 1, 1, 1, 0, -1, -1, -1 };

const s16b ddy_cdd[8] =
{ 1, 1, 0, -1, -1, -1, 0, 1 };



/*
 * Global array for converting numbers to uppercase hecidecimal digit
 * This array can also be used to convert a number to an octal digit
 */
const char hexsym[16] =
{
	'0', '1', '2', '3', '4', '5', '6', '7',
	'8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
};


/*
 * Global array for converting numbers to a logical list symbol
 */
///mod151213 ԉʎqO񂪓ȂȂ̂łƑ₵
const char listsym[] =
{
	'0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
	'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
	'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
	'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
	'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
	'!', '"','$','%','&','(',')','=','-',
	'\0'
};


/*
 * Encode the screen colors
 */
const cptr color_char = "dwsorgbuDWvyRGBU";


/*
 * Stat Table (INT/WIS) -- Number of half-spells per level
 */
const byte adj_mag_study[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	1	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	2	/* 12 */,
	2	/* 13 */,
	2	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	2	/* 18/00-18/09 */,
	2	/* 18/10-18/19 */,
	2	/* 18/20-18/29 */,
	2	/* 18/30-18/39 */,
	2	/* 18/40-18/49 */,
	3	/* 18/50-18/59 */,
	3	/* 18/60-18/69 */,
	3	/* 18/70-18/79 */,
	3	/* 18/80-18/89 */,
	4	/* 18/90-18/99 */,
	4	/* 18/100-18/109 */,
	4	/* 18/110-18/119 */,
	5	/* 18/120-18/129 */,
	5	/* 18/130-18/139 */,
	5	/* 18/140-18/149 */,
	5	/* 18/150-18/159 */,
	5	/* 18/160-18/169 */,
	5	/* 18/170-18/179 */,
	5	/* 18/180-18/189 */,
	5	/* 18/190-18/199 */,
	5	/* 18/200-18/209 */,
	6	/* 18/210-18/219 */,
	6	/* 18/220+ */
	,6,6,6,6,6,6,6,6,6,6 ///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (INT/WIS) -- extra 1/4-mana-points per level
 */
const byte adj_mag_mana[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	1       /* 8 */,
	2       /* 9 */,
	3       /* 10 */,
	4       /* 11 */,
	5       /* 12 */,
	5       /* 13 */,
	6       /* 14 */,
	7       /* 15 */,
	8       /* 16 */,
	9       /* 17 */,
	10      /* 18/00-18/09 */,
	11      /* 18/10-18/19 */,
	11      /* 18/20-18/29 */,
	12      /* 18/30-18/39 */,
	12      /* 18/40-18/49 */,
	13      /* 18/50-18/59 */,
	14      /* 18/60-18/69 */,
	15      /* 18/70-18/79 */,
	16      /* 18/80-18/89 */,
	17      /* 18/90-18/99 */,
	18      /* 18/100-18/109 */,
	19      /* 18/110-18/119 */,
	20      /* 18/120-18/129 */,
	21      /* 18/130-18/139 */,
	22      /* 18/140-18/149 */,
	23      /* 18/150-18/159 */,
	24      /* 18/160-18/169 */,
	25      /* 18/170-18/179 */,
	26      /* 18/180-18/189 */,
	27      /* 18/190-18/199 */,
	28      /* 18/200-18/209 */,
	29      /* 18/210-18/219 */,
	30      /* 18/220+ */
	,31,32,33,34,35,36,37,38,39,40 ///mod140325 p[^ύX
};


/*
 * Stat Table (INT/WIS) -- Minimum failure rate (percentage)
 */
/*:::x̖@ŒᎸs*/
const byte adj_mag_fail[] =
{
	99      /* 3 */,
	99      /* 4 */,
	99      /* 5 */,
	99      /* 6 */,
	99      /* 7 */,
	50      /* 8 */,
	30      /* 9 */,
	20      /* 10 */,
	15      /* 11 */,
	12      /* 12 */,
	11      /* 13 */,
	10      /* 14 */,
	9       /* 15 */,
	8       /* 16 */,
	7       /* 17 */,
	6       /* 18/00-18/09 */,
	6       /* 18/10-18/19 */,
	5       /* 18/20-18/29 */,
	5       /* 18/30-18/39 */,
	5       /* 18/40-18/49 */,
	4       /* 18/50-18/59 */,
	4       /* 18/60-18/69 */,
	4       /* 18/70-18/79 */,
	4       /* 18/80-18/89 */,
	3       /* 18/90-18/99 */,
	3       /* 18/100-18/109 */,
	2       /* 18/110-18/119 */,
	2       /* 18/120-18/129 */,
	2       /* 18/130-18/139 */,
	2       /* 18/140-18/149 */,
	1       /* 18/150-18/159 */,
	1       /* 18/160-18/169 */,
	1       /* 18/170-18/179 */,
	1       /* 18/180-18/189 */,
	1       /* 18/190-18/199 */,
	0       /* 18/200-18/209 */,
	0       /* 18/210-18/219 */,
	0       /* 18/220+ */
	,0,0,0,0,0,0,0,0,0,0///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (INT/WIS) -- Various things
 */
const byte adj_mag_stat[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	1       /* 8 */,
	1       /* 9 */,
	1       /* 10 */,
	1       /* 11 */,
	1       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	2       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	3       /* 18/00-18/09 */,
	3       /* 18/10-18/19 */,
	3       /* 18/20-18/29 */,
	3       /* 18/30-18/39 */,
	3       /* 18/40-18/49 */,
	4       /* 18/50-18/59 */,
	4       /* 18/60-18/69 */,
	5       /* 18/70-18/79 */,
	6       /* 18/80-18/89 */,
	7       /* 18/90-18/99 */,
	8       /* 18/100-18/109 */,
	9       /* 18/110-18/119 */,
	10      /* 18/120-18/129 */,
	11      /* 18/130-18/139 */,
	12      /* 18/140-18/149 */,
	13      /* 18/150-18/159 */,
	14      /* 18/160-18/169 */,
	15      /* 18/170-18/179 */,
	16      /* 18/180-18/189 */,
	17      /* 18/190-18/199 */,
	18      /* 18/200-18/209 */,
	19      /* 18/210-18/219 */,
	20      /* 18/220+ */
	,21,22,23,24,25,26,27,28,29,30///mod140104 p[^ύX
};


/*
 * Stat Table (CHR) -- payment percentages
 */
const byte adj_chr_gold[] =
{
	130     /* 3 */,
	125     /* 4 */,
	122     /* 5 */,
	120     /* 6 */,
	118     /* 7 */,
	116     /* 8 */,
	114     /* 9 */,
	112     /* 10 */,
	110     /* 11 */,
	108     /* 12 */,
	106     /* 13 */,
	104     /* 14 */,
	103     /* 15 */,
	102     /* 16 */,
	101     /* 17 */,
	100     /* 18/00-18/09 */,
	99      /* 18/10-18/19 */,
	98      /* 18/20-18/29 */,
	97      /* 18/30-18/39 */,
	96      /* 18/40-18/49 */,
	95      /* 18/50-18/59 */,
	94      /* 18/60-18/69 */,
	93      /* 18/70-18/79 */,
	92      /* 18/80-18/89 */,
	91      /* 18/90-18/99 */,
	90      /* 18/100-18/109 */,
	89      /* 18/110-18/119 */,
	88      /* 18/120-18/129 */,
	87      /* 18/130-18/139 */,
	86      /* 18/140-18/149 */,
	85      /* 18/150-18/159 */,
	84      /* 18/160-18/169 */,
	83      /* 18/170-18/179 */,
	82      /* 18/180-18/189 */,
	81      /* 18/190-18/199 */,
	80      /* 18/200-18/209 */,
	79      /* 18/210-18/219 */,
	78      /* 18/220+ */
	,77,76,75,74,73,72,71,70,69,68///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (INT) -- Magic devices
 */
const byte adj_int_dev[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	1       /* 8 */,
	1       /* 9 */,
	1       /* 10 */,
	1       /* 11 */,
	1       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	2       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	3       /* 18/00-18/09 */,
	3       /* 18/10-18/19 */,
	4       /* 18/20-18/29 */,
	4       /* 18/30-18/39 */,
	5       /* 18/40-18/49 */,
	5       /* 18/50-18/59 */,
	6       /* 18/60-18/69 */,
	6       /* 18/70-18/79 */,
	7       /* 18/80-18/89 */,
	7       /* 18/90-18/99 */,
	8       /* 18/100-18/109 */,
	9       /* 18/110-18/119 */,
	10      /* 18/120-18/129 */,
	11      /* 18/130-18/139 */,
	12      /* 18/140-18/149 */,
	13      /* 18/150-18/159 */,
	14      /* 18/160-18/169 */,
	15      /* 18/170-18/179 */,
	16      /* 18/180-18/189 */,
	17      /* 18/190-18/199 */,
	18      /* 18/200-18/209 */,
	19      /* 18/210-18/219 */,
	20      /* 18/220+ */
	,21,22,23,24,25,26,27,28,29,30///mod140325 p[^ύX
};


/*
 * Stat Table (WIS) -- Saving throw
 */
const byte adj_wis_sav[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	1       /* 8 */,
	1       /* 9 */,
	1       /* 10 */,
	1       /* 11 */,
	1       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	2       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	3       /* 18/00-18/09 */,
	3       /* 18/10-18/19 */,
	3       /* 18/20-18/29 */,
	3       /* 18/30-18/39 */,
	3       /* 18/40-18/49 */,
	4       /* 18/50-18/59 */,
	4       /* 18/60-18/69 */,
	5       /* 18/70-18/79 */,
	5       /* 18/80-18/89 */,
	6       /* 18/90-18/99 */,
	7       /* 18/100-18/109 */,
	8       /* 18/110-18/119 */,
	9       /* 18/120-18/129 */,
	10      /* 18/130-18/139 */,
	11      /* 18/140-18/149 */,
	12      /* 18/150-18/159 */,
	13      /* 18/160-18/169 */,
	14      /* 18/170-18/179 */,
	15      /* 18/180-18/189 */,
	16      /* 18/190-18/199 */,
	17      /* 18/200-18/209 */,
	18      /* 18/210-18/219 */,
	19      /* 18/220+ */
	,20,22,24,26,28,30,32,34,37,40///mod140325 p[^ύX
};


/*
 * Stat Table (DEX) -- disarming
 */
const byte adj_dex_dis[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	0       /* 8 */,
	0       /* 9 */,
	0       /* 10 */,
	0       /* 11 */,
	0       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	1       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	4       /* 18/00-18/09 */,
	4       /* 18/10-18/19 */,
	4       /* 18/20-18/29 */,
	4       /* 18/30-18/39 */,
	5       /* 18/40-18/49 */,
	5       /* 18/50-18/59 */,
	5       /* 18/60-18/69 */,
	6       /* 18/70-18/79 */,
	6       /* 18/80-18/89 */,
	7       /* 18/90-18/99 */,
	8       /* 18/100-18/109 */,
	8       /* 18/110-18/119 */,
	8       /* 18/120-18/129 */,
	8       /* 18/130-18/139 */,
	8       /* 18/140-18/149 */,
	9       /* 18/150-18/159 */,
	9       /* 18/160-18/169 */,
	9       /* 18/170-18/179 */,
	9       /* 18/180-18/189 */,
	9       /* 18/190-18/199 */,
	10      /* 18/200-18/209 */,
	10      /* 18/210-18/219 */,
	10      /* 18/220+ */
	,11,11,12,12,13,14,15,16,18,20///mod140325 p[^ύX
};


/*
 * Stat Table (INT) -- disarming
 */
const byte adj_int_dis[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	1       /* 8 */,
	1       /* 9 */,
	1       /* 10 */,
	1       /* 11 */,
	1       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	2       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	3       /* 18/00-18/09 */,
	3       /* 18/10-18/19 */,
	3       /* 18/20-18/29 */,
	4       /* 18/30-18/39 */,
	4       /* 18/40-18/49 */,
	5       /* 18/50-18/59 */,
	6       /* 18/60-18/69 */,
	7       /* 18/70-18/79 */,
	8       /* 18/80-18/89 */,
	9       /* 18/90-18/99 */,
	10      /* 18/100-18/109 */,
	10      /* 18/110-18/119 */,
	11      /* 18/120-18/129 */,
	12      /* 18/130-18/139 */,
	13      /* 18/140-18/149 */,
	14      /* 18/150-18/159 */,
	15      /* 18/160-18/169 */,
	16      /* 18/170-18/179 */,
	17      /* 18/180-18/189 */,
	18      /* 18/190-18/199 */,
	19      /* 18/200-18/209 */,
	19      /* 18/210-18/219 */,
	20      /* 18/220+ */
	,21,22,23,24,25,27,29,31,33,35///mod140325 p[^ύX
};


/*
 * Stat Table (DEX) -- bonus to ac (plus 128)
 */
const byte adj_dex_ta[] =
{
	128 + -4    /*  3 */,
	128 + -3    /*  4 */,
	128 + -2    /*  5 */,
	128 + -1    /*  6 */,
	128 + 0     /*  7 */,
	128 + 0     /*  8 */,
	128 + 0     /*  9 */,
	128 + 0     /* 10 */,
	128 + 0     /* 11 */,
	128 + 0     /* 12 */,
	128 + 0     /* 13 */,
	128 + 0     /* 14 */,
	128 + 1     /* 15 */,
	128 + 1     /* 16 */,
	128 + 1     /* 17 */,
	128 + 2     /* 18/00-18/09 */,
	128 + 2     /* 18/10-18/19 */,
	128 + 2     /* 18/20-18/29 */,
	128 + 2     /* 18/30-18/39 */,
	128 + 2     /* 18/40-18/49 */,
	128 + 3     /* 18/50-18/59 */,
	128 + 3     /* 18/60-18/69 */,
	128 + 3     /* 18/70-18/79 */,
	128 + 4     /* 18/80-18/89 */,
	128 + 5     /* 18/90-18/99 */,
	128 + 6     /* 18/100-18/109 */,
	128 + 7     /* 18/110-18/119 */,
	128 + 8     /* 18/120-18/129 */,
	128 + 9     /* 18/130-18/139 */,
	128 + 9     /* 18/140-18/149 */,
	128 + 10    /* 18/150-18/159 */,
	128 + 11    /* 18/160-18/169 */,
	128 + 12    /* 18/170-18/179 */,
	128 + 13    /* 18/180-18/189 */,
	128 + 14    /* 18/190-18/199 */,
	128 + 15    /* 18/200-18/209 */,
	128 + 15    /* 18/210-18/219 */,
	128 + 16    /* 18/220+ */
	,128 + 17,128 + 18,128 + 20,128 + 22,128 + 24,128 + 27,128 + 30,128 + 33,128 + 36,128 + 40
	///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (STR) -- bonus to dam (plus 128)
 */
const byte adj_str_td[] =
{
	128 + -2    /*  3 */,
	128 + -2    /*  4 */,
	128 + -1    /*  5 */,
	128 + -1    /*  6 */,
	128 + 0     /*  7 */,
	128 + 0     /*  8 */,
	128 + 0     /*  9 */,
	128 + 0     /* 10 */,
	128 + 0     /* 11 */,
	128 + 0     /* 12 */,
	128 + 0     /* 13 */,
	128 + 0     /* 14 */,
	128 + 0     /* 15 */,
	128 + 1     /* 16 */,
	128 + 2     /* 17 */,
	128 + 2     /* 18/00-18/09 */,
	128 + 2     /* 18/10-18/19 */,
	128 + 3     /* 18/20-18/29 */,
	128 + 3     /* 18/30-18/39 */,
	128 + 3     /* 18/40-18/49 */,
	128 + 3     /* 18/50-18/59 */,
	128 + 3     /* 18/60-18/69 */,
	128 + 4     /* 18/70-18/79 */,
	128 + 5     /* 18/80-18/89 */,
	128 + 5     /* 18/90-18/99 */,
	128 + 6     /* 18/100-18/109 */,
	128 + 7     /* 18/110-18/119 */,
	128 + 8     /* 18/120-18/129 */,
	128 + 9     /* 18/130-18/139 */,
	128 + 10    /* 18/140-18/149 */,
	128 + 11    /* 18/150-18/159 */,
	128 + 12    /* 18/160-18/169 */,
	128 + 13    /* 18/170-18/179 */,
	128 + 14    /* 18/180-18/189 */,
	128 + 15    /* 18/190-18/199 */,
	128 + 16    /* 18/200-18/209 */,
	128 + 18    /* 18/210-18/219 */,
	128 + 20    /* 18/220+ */
	,128 + 22,128 + 24,128 + 26,128 + 28,128 + 30,128 + 32,128 + 34,128 + 36,128 + 38,128 + 40
	///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (DEX) -- bonus to hit (plus 128)
 */
const byte adj_dex_th[] =
{
	128 + -3        /* 3 */,
	128 + -2        /* 4 */,
	128 + -2        /* 5 */,
	128 + -1        /* 6 */,
	128 + -1        /* 7 */,
	128 + 0 /* 8 */,
	128 + 0 /* 9 */,
	128 + 0 /* 10 */,
	128 + 0 /* 11 */,
	128 + 0 /* 12 */,
	128 + 0 /* 13 */,
	128 + 0 /* 14 */,
	128 + 0 /* 15 */,
	128 + 1 /* 16 */,
	128 + 2 /* 17 */,
	128 + 3 /* 18/00-18/09 */,
	128 + 3 /* 18/10-18/19 */,
	128 + 3 /* 18/20-18/29 */,
	128 + 3 /* 18/30-18/39 */,
	128 + 3 /* 18/40-18/49 */,
	128 + 4 /* 18/50-18/59 */,
	128 + 4 /* 18/60-18/69 */,
	128 + 4 /* 18/70-18/79 */,
	128 + 4 /* 18/80-18/89 */,
	128 + 5 /* 18/90-18/99 */,
	128 + 6 /* 18/100-18/109 */,
	128 + 7 /* 18/110-18/119 */,
	128 + 8 /* 18/120-18/129 */,
	128 + 9 /* 18/130-18/139 */,
	128 + 9 /* 18/140-18/149 */,
	128 + 10        /* 18/150-18/159 */,
	128 + 11        /* 18/160-18/169 */,
	128 + 12        /* 18/170-18/179 */,
	128 + 13        /* 18/180-18/189 */,
	128 + 14        /* 18/190-18/199 */,
	128 + 15        /* 18/200-18/209 */,
	128 + 15        /* 18/210-18/219 */,
	128 + 16        /* 18/220+ */
	,128 + 17,128 + 18,128 + 20,128 + 22,128 + 24,128 + 27,128 + 30,128 + 33,128 + 36,128 + 40
	///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (STR) -- bonus to hit (plus 128)
 */
const byte adj_str_th[] =
{
	128 + -3        /* 3 */,
	128 + -2        /* 4 */,
	128 + -1        /* 5 */,
	128 + -1        /* 6 */,
	128 + 0 /* 7 */,
	128 + 0 /* 8 */,
	128 + 0 /* 9 */,
	128 + 0 /* 10 */,
	128 + 0 /* 11 */,
	128 + 0 /* 12 */,
	128 + 0 /* 13 */,
	128 + 0 /* 14 */,
	128 + 0 /* 15 */,
	128 + 0 /* 16 */,
	128 + 0 /* 17 */,
	128 + 1 /* 18/00-18/09 */,
	128 + 1 /* 18/10-18/19 */,
	128 + 1 /* 18/20-18/29 */,
	128 + 1 /* 18/30-18/39 */,
	128 + 1 /* 18/40-18/49 */,
	128 + 1 /* 18/50-18/59 */,
	128 + 1 /* 18/60-18/69 */,
	128 + 2 /* 18/70-18/79 */,
	128 + 3 /* 18/80-18/89 */,
	128 + 4 /* 18/90-18/99 */,
	128 + 5 /* 18/100-18/109 */,
	128 + 6 /* 18/110-18/119 */,
	128 + 7 /* 18/120-18/129 */,
	128 + 8 /* 18/130-18/139 */,
	128 + 9 /* 18/140-18/149 */,
	128 + 10        /* 18/150-18/159 */,
	128 + 11        /* 18/160-18/169 */,
	128 + 12        /* 18/170-18/179 */,
	128 + 13        /* 18/180-18/189 */,
	128 + 14        /* 18/190-18/199 */,
	128 + 15        /* 18/200-18/209 */,
	128 + 15        /* 18/210-18/219 */,
	128 + 16        /* 18/220+ */
	,128 + 17,128 + 18,128 + 20,128 + 22,128 + 24,128 + 27,128 + 30,128 + 33,128 + 36,128 + 40
	///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (STR) -- weight limit in deca-pounds
 */
const byte adj_str_wgt[] =
{
	10      /* 3 */,
	11      /* 4 */,
	12      /* 5 */,
	13      /* 6 */,
	14      /* 7 */,
	15      /* 8 */,
	16      /* 9 */,
	17      /* 10 */,
	18      /* 11 */,
	19      /* 12 */,
	20      /* 13 */,
	21      /* 14 */,
	22      /* 15 */,
	23      /* 16 */,
	24      /* 17 */,
	25      /* 18/00-18/09 */,
	26      /* 18/10-18/19 */,
	27      /* 18/20-18/29 */,
	28      /* 18/30-18/39 */,
	29      /* 18/40-18/49 */,
	30      /* 18/50-18/59 */,
	31      /* 18/60-18/69 */,
	31      /* 18/70-18/79 */,
	32      /* 18/80-18/89 */,
	32      /* 18/90-18/99 */,
	33      /* 18/100-18/109 */,
	33      /* 18/110-18/119 */,
	34      /* 18/120-18/129 */,
	34      /* 18/130-18/139 */,
	35      /* 18/140-18/149 */,
	35      /* 18/150-18/159 */,
	36      /* 18/160-18/169 */,
	36      /* 18/170-18/179 */,
	37      /* 18/180-18/189 */,
	37      /* 18/190-18/199 */,
	38      /* 18/200-18/209 */,
	38      /* 18/210-18/219 */,
	39      /* 18/220+ */
	,40,42,44,47,50,54,58,63,69,75///mod140325 p[^ύX
};


/*
 * Stat Table (STR) -- weapon weight limit in pounds
 */
/*:::^ɂȂȂdʁ@Ȃ{@k_info[].weight/10ɑΉ*/
///mod160503 ƒ
const byte adj_str_hold[] =
{
	4       /* 3 */,
	5       /* 4 */,
	6       /* 5 */,
	7       /* 6 */,
	8       /* 7 */,
	9       /* 8 */,
	10      /* 9 */,
	11      /* 10 */,
	12      /* 11 */,
	13      /* 12 */,
	14      /* 13 */,
	15      /* 14 */,
	16      /* 15 */,
	17      /* 16 */,
	18      /* 17 */,
	19      /* 18/00-18/09 */,
	20      /* 18/10-18/19 */,
	21      /* 18/20-18/29 */,
	22      /* 18/30-18/39 */,
	23      /* 18/40-18/49 */,
	24      /* 18/50-18/59 */,
	25      /* 18/60-18/69 */,
	26      /* 18/70-18/79 */,
	27      /* 18/80-18/89 */,
	28      /* 18/90-18/99 */,
	30      /* 18/100-18/109 */,
	32      /* 18/110-18/119 */,
	34      /* 18/120-18/129 */,
	36      /* 18/130-18/139 */,
	38      /* 18/140-18/149 */,
	40      /* 18/150-18/159 */,
	43      /* 18/160-18/169 */,
	46      /* 18/170-18/179 */,
	49      /* 18/180-18/189 */,
	52      /* 18/190-18/199 */,
	55     /* 18/200-18/209 */,
	60     /* 18/210-18/219 */,
	65     /* 18/220+ */
	,70,75,80,85,90,96,102,108,114,120///mod140325 S̓Iɂ〈 r͂ŋmƂa(wgt2000)𗼎ŐU悤ɐݒ肷
};

/*
 * Stat Table (STR) -- digging value
 */
const byte adj_str_dig[] =
{
	0       /* 3 */,
	0       /* 4 */,
	1       /* 5 */,
	2       /* 6 */,
	3       /* 7 */,
	4       /* 8 */,
	4       /* 9 */,
	5       /* 10 */,
	5       /* 11 */,
	6       /* 12 */,
	6       /* 13 */,
	7       /* 14 */,
	7       /* 15 */,
	8       /* 16 */,
	8       /* 17 */,
	9       /* 18/00-18/09 */,
	10      /* 18/10-18/19 */,
	12      /* 18/20-18/29 */,
	15      /* 18/30-18/39 */,
	20      /* 18/40-18/49 */,
	25      /* 18/50-18/59 */,
	30      /* 18/60-18/69 */,
	35      /* 18/70-18/79 */,
	40      /* 18/80-18/89 */,
	45      /* 18/90-18/99 */,
	50      /* 18/100-18/109 */,
	55      /* 18/110-18/119 */,
	60      /* 18/120-18/129 */,
	65      /* 18/130-18/139 */,
	70      /* 18/140-18/149 */,
	75      /* 18/150-18/159 */,
	80      /* 18/160-18/169 */,
	85      /* 18/170-18/179 */,
	90      /* 18/180-18/189 */,
	95      /* 18/190-18/199 */,
	100     /* 18/200-18/209 */,
	100     /* 18/210-18/219 */,
	100     /* 18/220+ */
	,105,110,115,120,125,130,135,140,145,150///mod140325 p[^ύX
};


/*
 * Stat Table (STR) -- help index into the "blow" table
 */
///mod140907 255𒴂̂bytełȂs16bɂ
const s16b adj_str_blow[] =
{
	3       /* 3 */,
	4       /* 4 */,
	5       /* 5 */,
	6       /* 6 */,
	7       /* 7 */,
	8       /* 8 */,
	9       /* 9 */,
	10      /* 10 */,
	11      /* 11 */,
	12      /* 12 */,
	13      /* 13 */,
	14      /* 14 */,
	15      /* 15 */,
	16      /* 16 */,
	17      /* 17 */,
	20 /* 18/00-18/09 */,
	30 /* 18/10-18/19 */,
	40 /* 18/20-18/29 */,
	50 /* 18/30-18/39 */,
	60 /* 18/40-18/49 */,
	70 /* 18/50-18/59 */,
	80 /* 18/60-18/69 */,
	90 /* 18/70-18/79 */,
	100 /* 18/80-18/89 */,
	110 /* 18/90-18/99 */,
	120 /* 18/100-18/109 */,
	130 /* 18/110-18/119 */,
	140 /* 18/120-18/129 */,
	150 /* 18/130-18/139 */,
	160 /* 18/140-18/149 */,
	170 /* 18/150-18/159 */,
	180 /* 18/160-18/169 */,
	190 /* 18/170-18/179 */,
	200 /* 18/180-18/189 */,
	210 /* 18/190-18/199 */,
	220 /* 18/200-18/209 */,
	230 /* 18/210-18/219 */,
	240 /* 18/220+ */
	,250,260,270,280,300,320,340,360,380,400//mod140325 p[^ύX byte^Ȃ̂łȏ㑝₹Ȃ
};


/*
 * Stat Table (DEX) -- index into the "blow" table
 */
const byte adj_dex_blow[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	0       /* 8 */,
	0       /* 9 */,
	1       /* 10 */,
	1       /* 11 */,
	1       /* 12 */,
	1       /* 13 */,
	1       /* 14 */,
	2       /* 15 */,
	2       /* 16 */,
	2       /* 17 */,
	2       /* 18/00-18/09 */,
	3       /* 18/10-18/19 */,
	3       /* 18/20-18/29 */,
	3       /* 18/30-18/39 */,
	4       /* 18/40-18/49 */,
	4       /* 18/50-18/59 */,
	5       /* 18/60-18/69 */,
	5       /* 18/70-18/79 */,
	6       /* 18/80-18/89 */,
	6       /* 18/90-18/99 */,
	7       /* 18/100-18/109 */,
	7       /* 18/110-18/119 */,
	8       /* 18/120-18/129 */,
	8       /* 18/130-18/139 */,
	9      /* 18/140-18/149 */,
	9      /* 18/150-18/159 */,
	10      /* 18/160-18/169 */,
	10      /* 18/170-18/179 */,
	11      /* 18/180-18/189 */,
	11      /* 18/190-18/199 */,
	12      /* 18/200-18/209 */,
	12      /* 18/210-18/219 */,
	13      /* 18/220+ */
	,13,13,13,13,13,13,13,13,13,13///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (DEX) -- chance of avoiding "theft" and "falling"
 */
const byte adj_dex_safe[] =
{
	0       /* 3 */,
	1       /* 4 */,
	2       /* 5 */,
	3       /* 6 */,
	4       /* 7 */,
	5       /* 8 */,
	5       /* 9 */,
	6       /* 10 */,
	6       /* 11 */,
	7       /* 12 */,
	7       /* 13 */,
	8       /* 14 */,
	8       /* 15 */,
	9       /* 16 */,
	9       /* 17 */,
	10      /* 18/00-18/09 */,
	10      /* 18/10-18/19 */,
	15      /* 18/20-18/29 */,
	15      /* 18/30-18/39 */,
	20      /* 18/40-18/49 */,
	25      /* 18/50-18/59 */,
	30      /* 18/60-18/69 */,
	35      /* 18/70-18/79 */,
	40      /* 18/80-18/89 */,
	45      /* 18/90-18/99 */,
	50      /* 18/100-18/109 */,
	60      /* 18/110-18/119 */,
	70      /* 18/120-18/129 */,
	80      /* 18/130-18/139 */,
	90      /* 18/140-18/149 */,
	100     /* 18/150-18/159 */,
	100     /* 18/160-18/169 */,
	100     /* 18/170-18/179 */,
	100     /* 18/180-18/189 */,
	100     /* 18/190-18/199 */,
	100     /* 18/200-18/209 */,
	100     /* 18/210-18/219 */,
	100     /* 18/220+ */
	,100,100,100,100,100,100,100,100,100,100///mod140104 p[^ƕ\LύX
};


/*
 * Stat Table (CON) -- base regeneration rate
 */
const byte adj_con_fix[] =
{
	0       /* 3 */,
	0       /* 4 */,
	0       /* 5 */,
	0       /* 6 */,
	0       /* 7 */,
	0       /* 8 */,
	0       /* 9 */,
	0       /* 10 */,
	0       /* 11 */,
	0       /* 12 */,
	0       /* 13 */,
	1       /* 14 */,
	1       /* 15 */,
	1       /* 16 */,
	1       /* 17 */,
	2       /* 18/00-18/09 */,
	2       /* 18/10-18/19 */,
	2       /* 18/20-18/29 */,
	2       /* 18/30-18/39 */,
	2       /* 18/40-18/49 */,
	3       /* 18/50-18/59 */,
	3       /* 18/60-18/69 */,
	3       /* 18/70-18/79 */,
	3       /* 18/80-18/89 */,
	3       /* 18/90-18/99 */,
	4       /* 18/100-18/109 */,
	4       /* 18/110-18/119 */,
	5       /* 18/120-18/129 */,
	6       /* 18/130-18/139 */,
	6       /* 18/140-18/149 */,
	7       /* 18/150-18/159 */,
	7       /* 18/160-18/169 */,
	8       /* 18/170-18/179 */,
	8       /* 18/180-18/189 */,
	8       /* 18/190-18/199 */,
	9       /* 18/200-18/209 */,
	9       /* 18/210-18/219 */,
	9       /* 18/220+ */
	,10,10,10,11,11,12,12,13,14,15///mod140325 p[^ύX
};


/*
 * Stat Table (CON) -- extra 1/4-hitpoints per level (plus 128)
 */
const byte adj_con_mhp[] =
{
	128 + -8        /* 3 */,
	128 + -6        /* 4 */,
	128 + -4        /* 5 */,
	128 + -2        /* 6 */,
	128 + -1 /* 7 */,
	128 + 0 /* 8 */,
	128 + 0 /* 9 */,
	128 + 0 /* 10 */,
	128 + 0 /* 11 */,
	128 + 0 /* 12 */,
	128 + 0 /* 13 */,
	128 + 1 /* 14 */,
	128 + 1 /* 15 */,
	128 + 2 /* 16 */,
	128 + 3 /* 17 */,
	128 + 4 /* 18/00-18/09 */,
	128 + 5 /* 18/10-18/19 */,
	128 + 6 /* 18/20-18/29 */,
	128 + 7 /* 18/30-18/39 */,
	128 + 8 /* 18/40-18/49 */,
	128 + 9 /* 18/50-18/59 */,
	128 + 10  /* 18/60-18/69 */,
	128 + 11 /* 18/70-18/79 */,
	128 + 12 /* 18/80-18/89 */,
	128 + 14 /* 18/90-18/99 */,
	128 + 17         /* 18/100-18/109 */,
	128 + 20        /* 18/110-18/119 */,
	128 + 23        /* 18/120-18/129 */,
	128 + 26        /* 18/130-18/139 */,
	128 + 29        /* 18/140-18/149 */,
	128 + 32        /* 18/150-18/159 */,
	128 + 35        /* 18/160-18/169 */,
	128 + 38        /* 18/170-18/179 */,
	128 + 40        /* 18/180-18/189 */,
	128 + 42        /* 18/190-18/199 */,
	128 + 44        /* 18/200-18/209 */,
	128 + 46        /* 18/210-18/219 */,
	128 + 48        /* 18/220+ */
	,128+51,128+54,128+58,128+62,128+67,128+72,128+78,128+84,128+90,128+96///mod140325 p[^ύX
};


/*
 * Stat Table (CHR) -- charm
 */
const byte adj_chr_chm[] =
{
	0       /* 3 */,
	0       /* 4 */,
	1       /* 5 */,
	2       /* 6 */,
	3       /* 7 */,
	4       /* 8 */,
	4       /* 9 */,
	5       /* 10 */,
	5       /* 11 */,
	6       /* 12 */,
	6       /* 13 */,
	7       /* 14 */,
	7       /* 15 */,
	8       /* 16 */,
	8       /* 17 */,
	9       /* 18/00-18/09 */,
	10      /* 18/10-18/19 */,
	12      /* 18/20-18/29 */,
	15      /* 18/30-18/39 */,
	18      /* 18/40-18/49 */,
	21      /* 18/50-18/59 */,
	24      /* 18/60-18/69 */,
	28      /* 18/70-18/79 */,
	32      /* 18/80-18/89 */,
	36      /* 18/90-18/99 */,
	39      /* 18/100-18/109 */,
	42      /* 18/110-18/119 */,
	45      /* 18/120-18/129 */,
	49      /* 18/130-18/139 */,
	53      /* 18/140-18/149 */,
	57      /* 18/150-18/159 */,
	61      /* 18/160-18/169 */,
	65      /* 18/170-18/179 */,
	69      /* 18/180-18/189 */,
	73      /* 18/190-18/199 */,
	77      /* 18/200-18/209 */,
	81      /* 18/210-18/219 */,
	85      /* 18/220+ */
	,90,95,101,107,113,120,127,134,142,150///mod140325 p[^ύX
};


/*
 * This table is used to help calculate the number of blows the player can
 * make in a single round of attacks (one player turn) with a normal weapon.
 *
 * This number ranges from a single blow/round for weak players to up to six
 * blows/round for powerful warriors.
 *
 * Note that certain artifacts and ego-items give "bonus" blows/round.
 *
 * First, from the player class, we extract some values:
 *
 * Warrior       num = 6; mul = 5; div = MAX(70, weapon_weight);
 * Berserker     num = 6; mul = 7; div = MAX(70, weapon_weight);
 * Mage          num = 3; mul = 2; div = MAX(100, weapon_weight);
 * Priest        num = 5; mul = 3; div = MAX(100, weapon_weight);
 * Mindcrafter   num = 5; mul = 3; div = MAX(100, weapon_weight);
 * Rogue         num = 5; mul = 3; div = MAX(40, weapon_weight);
 * Ranger        num = 5; mul = 4; div = MAX(70, weapon_weight);
 * Paladin       num = 5; mul = 4; div = MAX(70, weapon_weight);
 * Weaponsmith   num = 5; mul = 5; div = MAX(150, weapon_weight);
 * Warrior-Mage  num = 5; mul = 3; div = MAX(70, weapon_weight);
 * Chaos Warrior num = 5; mul = 4; div = MAX(70, weapon_weight);
 * Monk          num = 5; mul = 3; div = MAX(60, weapon_weight);
 * Tourist       num = 4; mul = 3; div = MAX(100, weapon_weight);
 * Imitator      num = 5; mul = 4; div = MAX(70, weapon_weight);
 * Beastmaster   num = 5; mul = 3; div = MAX(70, weapon_weight);
 * Cavalry(Ride) num = 5; mul = 4; div = MAX(70, weapon_weight);
 * Cavalry(Walk) num = 5; mul = 3; div = MAX(100, weapon_weight);
 * Sorcerer      num = 1; mul = 1; div = MAX(1, weapon_weight);
 * Archer        num = 4; mul = 2; div = MAX(70, weapon_weight);
 * Magic eater   num = 4; mul = 2; div = MAX(70, weapon_weight);
 * ForceTrainer  num = 4; mul = 2; div = MAX(60, weapon_weight);
 * Mirror Master num = 3; mul = 3; div = MAX(100, weapon_weight);
 * Ninja         num = 4; mul = 1; div = MAX(20, weapon_weight);
 *
 * To get "P", we look up the relevant "adj_str_blow[]" (see above),
 * multiply it by "mul", and then divide it by "div".
 * Increase P by 1 if you wield a weapon two-handed.
 * Decrease P by 1 if you are a Ninja.
 *
 * To get "D", we look up the relevant "adj_dex_blow[]" (see above),
 *
 * The player gets "blows_table[P][D]" blows/round, as shown below,
 * up to a maximum of "num" blows/round, plus any "bonus" blows/round.
 */
///mod40315 őU񐔂67
const byte blows_table[12][12] =
{
	/* P/D */
	/*      0,   1,   2,   3,   4,   5,   6,   7,   8,   9,  10,  11+ */
	/*      3   10   15  /10  /40  /60  /80 /100 /120 /140 /160 /180  */
/* 0 */{	1,   1,   1,   1,   1,   2,   2,   2,   2,   3,   3,   4 },
/* 1 */{	1,   1,   1,   2,   2,   2,   3,   3,   3,   4,   4,   4 },
/* 2 */{	1,   1,   2,   2,   3,   3,   4,   4,   4,   5,   5,   5 },
/* 3 */{	1,   1,   2,   3,   3,   4,   4,   4,   5,   5,   5,   5 },
/* 4 */{	1,   1,   2,   3,   3,   4,   4,   5,   5,   5,   5,   5 },
/* 5 */{	1,   1,   2,   3,   4,   4,   4,   5,   5,   5,   5,   6 },
/* 6 */{	1,   1,   2,   3,   4,   4,   4,   5,   5,   5,   5,   6 },
/* 7 */{	1,   2,   2,   3,   4,   4,   4,   5,   5,   5,   5,   6 },
/* 8 */{	1,   2,   3,   3,   4,   4,   4,   5,   5,   5,   6,   6 },
/* 9 */{	1,   2,   3,   4,   4,   4,   5,   5,   5,   6,   6,   7 },
/* 10*/{	2,   2,   3,   4,   4,   4,   5,   5,   6,   6,   7,   7 },
/*11+*/{	2,   2,   3,   4,   4,   4,   5,   5,   6,   7,   7,   7 },

};

///item mon A[ĩX^[ƏiTVAL,SVAL
const arena_type arena_info[MAX_ARENA_MONS + 2] =
{
	{ MON_IMP,       TV_AMULET, SV_AMULET_RESIST_ELEC           },
	{ MON_IMP,    TV_FOOD,   SV_FOOD_SLIMEMOLD          },
	{ MON_IMP,           TV_POTION, SV_POTION_SPEED               },
	{ MON_NOV_PRIEST,    0,         0                             },
	{ MON_IMP,   TV_POTION, SV_POTION_CURING              },
	{ MON_SABRE_TIGER,   TV_WAND,   SV_WAND_STONE_TO_MUD          },
	{ MON_LIZARD_KING,   TV_WAND,   SV_WAND_TELEPORT_AWAY         },
	{ MON_WYVERN,        TV_POTION, SV_POTION_HEALING             },
	{ MON_ARCH_VILE,     TV_POTION, SV_POTION_RESISTANCE          },
	{ MON_ELF_LORD   ,   TV_POTION, SV_POTION_ENLIGHTENMENT       },
	{ MON_GHOUL_KING,    TV_MUSHROOM,   SV_MUSHROOM_RESTORING             },
	{ MON_COLBRAN,       TV_RING,   SV_RING_ELEC                  },
	{ MON_BICLOPS,       TV_WAND,   SV_WAND_ACID_BALL             },
	{ MON_M_MINDCRAFTER, TV_POTION, SV_POTION_SELF_KNOWLEDGE      },
	{ MON_GROO,          TV_SCROLL, SV_SCROLL_ACQUIREMENT         },
	{ MON_RAAL,          TV_SCROLL, SV_SCROLL_STAR_DESTRUCTION    },
	{ MON_DREADMASTER,   TV_WAND,   SV_WAND_DRAIN_LIFE            },
	{ MON_ULTRA_PALADIN, TV_STAFF,  SV_STAFF_DISPEL_EVIL          },
	{ MON_BARNEY,        TV_RING,   SV_RING_RES_CHAOS             },
	{ MON_TROLL_KING,    TV_SCROLL, SV_SCROLL_MASS_GENOCIDE       },
	{ MON_BARON_HELL,    TV_POTION, SV_POTION_AUGMENTATION        },
	{ MON_F_ANGEL,       TV_SCROLL, SV_SCROLL_RUNE_OF_PROTECTION  },
	{ MON_G_C_DRAKE,     TV_WAND,   SV_WAND_DRAGON_FIRE           },
	{ MON_IRON_LICH,     TV_STAFF,  SV_STAFF_DESTRUCTION          },
	{ MON_DROLEM,        TV_POTION, SV_POTION_STAR_HEALING        },
	{ MON_G_TITAN,       TV_WAND,   SV_WAND_GENOCIDE              },
	{ MON_G_BALROG,      TV_POTION, SV_POTION_EXPERIENCE          },
	{ MON_ELDER_VAMPIRE, TV_RING,   SV_RING_SUSTAIN               },
	{ MON_NIGHTWALKER,   TV_WAND,   SV_WAND_STRIKING              },
	{ MON_S_TYRANNO,     TV_SCROLL, SV_SCROLL_STAR_ACQUIREMENT    },
	{ MON_G_MASTER_MYS,  TV_ROD,    SV_ROD_IDENTIFY               },
	{ MON_LORD_CHAOS,    TV_POTION, SV_POTION_LIFE                },
	{ MON_SHADOWLORD,    TV_POTION, SV_POTION_STAR_ENLIGHTENMENT  },
	{ MON_ULT_BEHOLDER,  TV_AMULET, SV_AMULET_REFLECTION          },
	{ MON_JABBERWOCK,    TV_ROD,    SV_ROD_HEALING                },
	{ MON_LOCKE_CLONE,   TV_WAND,   SV_WAND_DISINTEGRATE          },
	{ MON_WYRM_SPACE,    TV_ROD,    SV_ROD_RESTORATION            },
	{ MON_SHAMBLER,      TV_SCROLL, SV_SCROLL_STAR_ACQUIREMENT    },
	{ MON_BLACK_REAVER,  TV_RING,   SV_RING_LORDLY                },
	{ MON_FENGHUANG,     TV_STAFF,  SV_STAFF_THE_MAGI             },
	{ MON_WYRM_POWER,    TV_SCROLL, SV_SCROLL_ARTIFACT            },
	{ 0,                 0,         0                             }, /* Victory prizing */
	{ MON_HAGURE,        TV_SCROLL, SV_SCROLL_ARTIFACT            },
};



///bldg131222 VXꗗ
const cptr new_store_name[][MAX_STORES] = {
	{"","","","","","","","","",""},//_~[
	{"GݓX","hX","X","X/","X","@X","","_","ވ","GgX"},//l
	{"GݓX","hX","X","X/","X","@X","KN^s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","}","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},
	{"nGݓX","nhX","nX","nX/","nX","n@X","ubN}[Pbg","_","nX","GgX"}
};

///bldg131222 VI[i[ꗗ
const cptr new_store_owner_name[][MAX_STORES] = {
	{"","","","","","","","","",""},//_~[
	{"GݓX","hX","̒b艮","m","","@X","X","_","{@","GgX"},//l
	{"GݓX","hX","X","X/","V̏","@X","X","_","X","GgX"},//V̗
	{"GݓX","hX","X","X/","n̏","@X","D_sX","_","X","GgX"},//nsX
	{"GݓX","hX","X","X/","X","@X","D_s","_","","GgX"},//gفiX̂݁j
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},//_ЁiXȂj
	{"͓X","͓̕","͓̋","X/","͓̏","@X","͓","_","X","GgX"},//͓̃oU[
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},//iiXȂj
	{"GݓX","hX","X","X/","X","@X","X߁@V","_","X","GgX"},//iBM̂)
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},//@(XȂ)
	{"GݓX","hX","X","X/","X","@X","D_s","_","X","GgX"},//J@X(XȂ)
	{"h[","ChDA","AR[q","zAX","E[@^","AhitF","J","_","","GgX"}//n@pmق̊XԍȂ̂Œ
};
/*
 * Store owners (exactly four "possible" owners per store, chosen randomly)
 * { name, purse, max greed, min greed, haggle_per, tolerance, race, unused }
 *
 * Lifted extra shopkeepers from CthAngband (don't you just love open source
 * development? ;-)). Since this gave less than 32 unique names for some
 * shops, those have their first x names copied to reach 32.
 *
 * For the weapon and armour shops, several owners have a limit of 5k.
 *
 * I want to do 50k owners, but the purse is currently s16b. Perhaps
 * we should just store 1/10th of the purse?
 */

///del140105 owner_type owners[][]푰ύXʓ|Ȃ̂őS




/*
 * This table allows quick conversion from "speed" to "energy"
 * The basic function WAS ((S>=110) ? (S-110) : (100 / (120-S)))
 * Note that table access is *much* quicker than computation.
 *
 * Note that the table has been changed at high speeds.  From
 * "Slow (-40)" to "Fast (+30)" is pretty much unchanged, but
 * at speeds above "Fast (+30)", one approaches an asymptotic
 * effective limit of 50 energy per turn.  This means that it
 * is relatively easy to reach "Fast (+30)" and get about 40
 * energy per turn, but then speed becomes very "expensive",
 * and you must get all the way to "Fast (+50)" to reach the
 * point of getting 45 energy per turn.  After that point,
 * furthur increases in speed are more or less pointless,
 * except to balance out heavy inventory.
 *
 * Note that currently the fastest monster is "Fast (+30)".
 *
 * It should be possible to lower the energy threshhold from
 * 100 units to 50 units, though this may interact badly with
 * the (compiled out) small random energy boost code.  It may
 * also tend to cause more "clumping" at high speeds.
 */
const byte extract_energy[200] =
{
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* S-50 */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* S-40 */     2,  2,  2,  2,  2,  2,  2,  2,  2,  2,
	/* S-30 */     2,  2,  2,  2,  2,  2,  2,  3,  3,  3,
	/* S-20 */     3,  3,  3,  3,  3,  4,  4,  4,  4,  4,
	/* S-10 */     5,  5,  5,  5,  6,  6,  7,  7,  8,  9,
	/* Norm */    10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
	/* F+10 */    20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
	/* F+20 */    30, 31, 32, 33, 34, 35, 36, 36, 37, 37,
	/* F+30 */    38, 38, 39, 39, 40, 40, 40, 41, 41, 41,
	/* F+40 */    42, 42, 42, 43, 43, 43, 44, 44, 44, 44,
	/* F+50 */    45, 45, 45, 45, 45, 46, 46, 46, 46, 46,
	/* F+60 */    47, 47, 47, 47, 47, 48, 48, 48, 48, 48,
	/* F+70 */    49, 49, 49, 49, 49, 49, 49, 49, 49, 49,
	/* Fast */    49, 49, 49, 49, 49, 49, 49, 49, 49, 49,
};




/*
 * Base experience levels, may be adjusted up for race and/or class
 */
//v1.1.43 oX̂߂Ƀx20`40ӂȂ
#if 0
const s32b player_exp[PY_MAX_LEVEL] =
{
	10,
	25,
	45,
	70,
	100,
	140,
	200,
	280,
	380,/*10*/
	500,
	650,
	850,
	1100,
	1400,
	1800,
	2300,
	2900,
	3600,
	4400,/*20*/
	5400,
	6800,
	8400,
	10200,
	12500,
	17500,
	25000,
	35000L,
	50000L,
	75000L,/*30*/
	100000L,
	150000L,
	200000L,
	275000L,
	350000L,
	450000L,
	550000L,
	700000L,
	850000L,
	1000000L,/*40*/
	1250000L,
	1500000L,
	1800000L,
	2100000L,
	2400000L,
	2700000L,
	3000000L,
	3500000L,
	4000000L,
	4500000L,/*50*/
	5000000L
};
#endif

const s32b player_exp[PY_MAX_LEVEL] =
{
	10,
	25,
	45,
	70,
	100,
	140,
	200,
	280,
	380,/*10*/
	500,
	650,
	850,
	1100,
	1400,
	1800,
	2300,
	2900,
	3600,
	4400,/*20*/
	5400,
	6600,
	8000,
	9800,
	12000,
	15000,
	18500,
	23000L,
	29000L,
	38000L,/*30*/
	50000L,
	80000L,
	120000L,
	170000L,
	230000L,
	300000L,
	400000L,
	520000L,
	660000L,
	820000L,/*40*/
	1000000L,
	1200000L,
	1450000L,
	1750000L,
	2100000L,
	2500000L,
	3000000L,
	3500000L,
	4000000L,
	4500000L,/*50*/
	5000000L
};


const s32b player_exp_a[PY_MAX_LEVEL] =
{
	20,
	50,
	100,
	170,
	280,
	430,
	650,
	950,
	1400,/*10*/
	1850,
	2300,
	2900,
	3600,
	4400,
	5400,
	6800,
	8400,
	10400,
	12500,/*20*/
	17500,
	25000,
	35000,
	50000L,
	75000L,
	100000L,
	150000L,
	200000L,
	275000L,
	350000L,/*30*/
	450000L,
	550000L,
	650000L,
	800000L,
	950000L,
	1100000L,
	1250000L,
	1400000L,
	1550000L,
	1700000L,/*40*/
	1900000L,
	2100000L,
	2300000L,
	2550000L,
	2800000L,
	3050000L,
	3300000L,
	3700000L,
	4100000L,
	4500000L,/*50*/
	5000000L
};


/*
 * Player Sexes
 *
 *      Title,
 *      Winner
 */
const player_sex sex_info[MAX_SEXES] =
{
	{
#ifdef JP
		"",
		"NC[",
#endif
		"Female",
		"Queen"
	},
	{
#ifdef JP
		"j",
		"LO",
#endif
		"Male",
		"King"
	}
};


/*
 * Player Races
 *
 *      Title,
 *      {STR,INT,WIS,DEX,CON,CHR},
 *:::   r_dis, r_dev, r_sav, r_stl, r_srh, r_GRAZE, r_thn, r_thb,
 *      hitdie, exp base,
 *      Age (Base, Mod),
 *      Male (Hgt, Wgt),
 *      Female (Hgt, Wgt)
 *      infra,
 *      class-choices
 *:::   realm{fA\At^AA_AAjׁARAϗeAÍAA}
 *:::   XRA{@{100
 *:::	Flag AIsAϗê݁Aj[N̂
 */
const player_race race_info[MAX_RACES] =
{
	{
#ifdef JP
		"l",
#endif
		"Human",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		10,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		///mod140105 푰ύXijbǉ		

		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE,//FLAG
		'p',(RF3_HUMAN),

	},
	{
#ifdef JP
		"d",
#endif
		"Youkai",

		{ 2,  -2,  -3,  0, 2, -2 },
		-3,  -5,  0, 0, 10,  3, 10, -5,
		11,  125,
		24, 16,
		66,  6, 130, 15,
		62,  6, 100, 10,
		3,
		0xFFFFFFF,
		///mod140105 푰ύXijbǉ		

		{0,4,4,4,4,2,2,1,3,7,7,6,6, 5, 5, 5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'y',(RF3_KWAI),

	},
	{
#ifdef JP
		"d",
#endif
		"Half-Youkai",

		{ 1, 0, -1, 0, 1, -1 },
		0, -1, 1, 0, 10, 1, 3, 0,
		10,  120,
		75, 75,
		60,  4, 100,  6,
		54,  4, 80,  6,
		0,
		0xFFFFFFF,
		{0,5,5,5,5,4,4,4,4,5,5,5,5,5,5,5},//realm
		90,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG

		,'p',(RF3_HUMAN | RF3_KWAI),
	},
	{
#ifdef JP
		"l",
#endif
		"Sennin",

		{ -1, 2, 3, 0, 0, 2 },
		2, 10, 8, 1, 15, 5, 0, -10,
		10, 150,
		21, 12,
		36,  3, 60,  3,
		33,  3, 50,  3,
		2,
		0xFFFFFFF,
		{0,6,6,6,5,9,9,8,9,4,6,5,4,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_HUMAN),
	},
	{
#ifdef JP
		"Vl",
#endif
		"Tennin",

		{  2, 3, 3, 2, 3, 3 },
		0,  12, 12, 0, 15, 5, 10, 10,
		12,  185,
		35, 15,
		48,  3, 150, 10,
		46,  3, 120, 10,
		2,
		0xFFFFFFF,

		{0,6,7,6,5,9,9,9,7,0,0,0,2,5,5,5},//realm
		60,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_HUMAN),
	},
	{
#ifdef JP
		"d",
#endif
		"Fairy",

		{ -4,-4, -4, -2, -3, -2 },
		-5, -5, 10, 5, 10, 5, -20, -10,
		7,  150,
		35, 15,
		48,  3, 150, 10,
		46,  3, 120, 10,
		2,
		0xFFFFFFF,

		{0,3,1,1,1,2,6,1,7,1,1,1,1,5,5,5},//realm
		200,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'F',(RF3_FAIRY),
	},


	{
#ifdef JP
		"͓",
#endif
		"kappa",

		{  0, 1, -3,  2,  1, -1 },
		20, -4, 3, 2, 13, 2, 5, 10,
		11,  110,
		11,  4,
		66,  1, 150,  5,
		62,  1, 120,  5,
		0,
		0xFFFFFFF,
		{0,3,2,2,2,3,2,1,5,7,6,5,5,5,5,5},//realm
		95,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'K',(RF3_KWAI),
	},
	{
#ifdef JP
		"@g",
#endif
		"Magician",

		{ -2, 4, 3, -1, -1, 0 },
		5, 15, 10, 1, 15, -2, -10, -10,
		8,  130,
		20, 10,
		96, 10, 250, 50,
		84,  8, 225, 40,
		5,
		0xFFFFFFF,
		{0,9,9,9,9,7,6,6,7,7,7,8,8,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_DEMIHUMAN),
	},
	{
#ifdef JP
		"V",
#endif
		"Karasu-Tengu",

		{  1,  2, 0,  4,  2, 0 },
		5,  7, 6, 2, 15, 25, 10, 10,
		11,  140,
		50, 50,
		82, 5, 190, 20,
		78,  6, 180, 15,
		0,
		0xFFFFFFF,
		{0,4,5,4,3,5,3,2,8,6,7,6,5,5,5,5},//realm
		70,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'t',(RF3_KWAI),
	},
	{
#ifdef JP
		"TV",
#endif
		"Hakurou-Tengu",

		{  3,  -2,  -2, 2, 3, -2 },
		8, -3, 0, 2, 20, 12, 15, 5,
		12,  135,
		100, 30,
		90, 10, 190, 20,
		82, 10, 180, 15,
		8,
		0xFFFFFFF,
		{0,2,3,1,1,1,2,1,4,5,5,4,4,5,5,5},//realm
		85,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'t',(RF3_KWAI),
	},
	{
#ifdef JP
		"S",
#endif
		"Oni",

		{ 7, -3, 1, 1, 4, 0 },
		-10, 5, 0, -3, 7, -10, 30, 0,
		18, 165,
		14, 8,
		82, 5, 200, 20,
		78,  6, 190, 15,
		0,
		0xFFFFFFF,
		{0,5,5,5,5,5,4,2,3,5,7,5,6,5,5,5},//realm
		60,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'P',(RF3_KWAI),
	},
	{
#ifdef JP
		"_",
#endif
		"Death",

		{ 2, 1, 2, -1, 2, -3 },
		-3, 8, 25, 3, 10, -5, 15, -10,
		12,  160,
		40, 10,
		92, 10, 255, 60,
		80,  8, 235, 60,
		8,
		0xFFFFFFF,
		{0,5,5,5,5,3,0,2,2,4,7,9,6,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'W',(RF3_KWAI),
	},
	{
#ifdef JP
		"bl",
#endif
		"Warbeast",

		{ 1, -1, -2, 2, 2, -2 },
		-2, -3, -3, 2, 14, 15, 10, -5,
		11, 140,
		30, 10,
		100,10, 255, 65,
		80, 10, 240, 64,
		10,
		0xFFFFFFF,
		{0,4,4,4,3,3,4,2,6,8,5,6,5,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'h',(RF3_KWAI | RF3_ANIMAL),
	},
	{
#ifdef JP
		"tr_",
#endif
		"Tsukumo",

		{ -1, -1, -1, 0, 1, -1},
		15, 16, 8, 1, 12, 0, 0, -5,
		9, 120,
		50, 24,
		92, 10, 255, 60,
		80,  8, 235, 60,
		2,
		0xFFFFFFF,

		{0,3,4,7,3,5,3,3,3,7,5,5,5,5,5,5},//realm
		85,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'y',(RF3_KWAI | RF3_NONLIVING),
	},
	{
#ifdef JP
		"dl`",
#endif
		"Youkai-Doll",

		{ 1, -1, -2, 0, 1, 0},
		0, 5, -5, 2, 8, 0, 5, 5,
		11, 200,
		100,30,
		111, 11, 255, 86,
		99, 11, 250, 86,
		0,
		0xFFFFFFF,
		{0,5,3,7,4,4,2,4,3,6,5,6,5,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'g',(RF3_KWAI | RF3_NONLIVING),
	},

	{
#ifdef JP
		"ʓe",
#endif
		"gyokuto",

		{ 0, 0, -1, 2, 1, 1},
		8, 8, 8, 2, 12, 12, 5, 15,
		10, 150,
		14, 3,
		50,  3, 90,  6,
		50,  3, 75,  3,
		7,
		0xFFFFFFF,
		{0,4,4,4,3,5,5,4,3,4,2,2,4,5,5,5},//realm
		85,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'h',(RF3_KWAI | RF3_ANIMAL),
	},
	{
#ifdef JP
		"d",
#endif
		"Youko",

		{ -1, 3, 3, 2, 0, 1 },
		2, 10, 16, 3, 14, 7, -10, -10,
		9, 170,
		20, 3,
		60,  3, 80,  4,
		54,  3, 70,  4,
		7,
		0xFFFFFFF,

		{0,7,8,7,7,7,5,5,7,9,7,7,7,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'f',(RF3_KWAI | RF3_ANIMAL),
	},
	{
#ifdef JP
		"R",
#endif
		"Yamawaro",

		{ 1, 0, -3, 1, 2, -1 },
		15, -6, 0, 2, 15, 4, 15, 10,
		11, 125,
		11,  3,
		60,  1, 130,  5,
		55,  1, 100,  5,
		0,
		0xFFFFFFF,
		{0,3,2,2,2,3,2,1,5,7,6,5,5,5,5,5},//realm
		90,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'K',(RF3_KWAI),
	},
	{
#ifdef JP
		"K",
#endif
		"Bake-danuki",

		{ 1, 1, 1, -1, 1, -1 },
		2, 2, 3, 4, 10, 2, 7, 0,
		11, 140,
		40, 12,
		43,  3, 92,  6,
		40,  3, 78,  3,
		5,
		0xFFFFFFF,
		{0,5,4,4,5,3,4,2,5,8,6,5,7,5,5,5},//realm
		80,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'h',(RF3_KWAI | RF3_ANIMAL),
	},
	{
#ifdef JP
		"l",
#endif
		"Ningyo",

		{ 0, 0, 0, 1, 1, 1 },
		0, 7, 7, 2, 12, 0, 0, -5,
		10, 110,
		75, 75,
		60,  4, 100,  6,
		54,  4, 80,  6,
		0,
		0xFFFFFFF,
		{0,6,6,7,5,5,5,3,4,8,6,7,6,5,5,5},//realm
		90,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'h',(RF3_KWAI),
	},
	{
#ifdef JP
		"ztSu",
#endif
		"Hofgoblin",

		{ -1, -1, -2, 1, 2, -4 },
		7, 5, 3, 2, 12, 4, 5, 5,
		8, 110,
		75, 33,
		76,  1, 160,  5,
		72,  1, 130,  5,
		4,
		0xFFFFFFF,
		{0,5,5,5,5,3,3,2,4,5,5,5,5,5,5,5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'o',(RF3_KWAI),
	},
	{
#ifdef JP
		"",
#endif
		"Nyudo",

		{ 3, -1, -2, -3, 3, -1 },
		-4, -3, 0, 2, 12, 0, 20, 0,
		13, 150,
		100, 25,
		68,  6, 142, 15,
		63,  6, 112, 10,
		0,
		0xFFFFFFF,
		{0,2,3,2,2,2,1,1,3,8,4,4,3,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'P',(RF3_KWAI),
	},
	{
#ifdef JP
		"",
#endif
		"Imp",

		{ -1, 2, -2, 1, 0, -2 },
		5, 10, 10, 2, 12, 3, 0, 0,
		9, 130,
		13,  4,
		68,  1, 150,  5,
		64,  1, 120,  5,
		6,
		0xFFFFFFF,
		{0,8,7,9,7,3,2,0,2,7,9,7,8,5,5,5},//realm
		80,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'u',(RF3_DEMON),
	},
	{
#ifdef JP
		"S[",
#endif
		"Golem",

		{ 4, -5, -5, -3, 5, -2 },
		-10, -10, 20, -2, 7, -10, 20, 0,
		14, 160,
		1, 100,
		66,  1, 200,  6,
		62,  1, 180,  6,
		0,
		0xFFFFFFF,
		{0,6,2,6,3,2,1,1,1,5,4,4,3,5,5,5},//realm
		80,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'g',(RF3_NONLIVING),
	},
	{
#ifdef JP
		"l",
#endif
		"Kobito",

		{ -5, 0, 0, 0, -4, 0 },
		20, 12, 0, 20, 30, 50, -20, -5,
		5, 50,
		100, 35,
		72,  6, 50, 5,
		66,  4, 50, 5,
		0,
		0xFFFFFFF,
		{0,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_HUMAN),
	},
	{
#ifdef JP
		"LV[",
#endif
		"Zombie",

		{ 2, -4, -3, -2, 3, -3 },
		-5, -6, 5, 2, 8, -5, 10, -5,
		12, 150,
		100, 30,
		72, 6, 100, 25,
		66, 4, 100, 20,
		0,
		0xFFFFFFF,
		{0,3,2,3,2,1,1,1,1,3,3,8,3,5,5,5},//realm
		80,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'z',(RF3_UNDEAD),
	},
	{
#ifdef JP
		"zS",
#endif
		"Vampire",

		{ 4, 2, 1, 2, 7, 2 },
		-2, 6, 10, 3, 11, 5, 20, 0,
		16, 175,
		100, 30,
		72,  6, 180, 25,
		66,  4, 150, 20,
		10,
		0xFFFFFFF,
		{0,7,7,7,7,1,0,0,1,8,8,9,6,5,5,5},//realm
		65,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'V',(RF3_UNDEAD | RF3_DEMON),
	},
	{
#ifdef JP
		"H",
#endif
		"Spectre",

		{ -3, 0, 0, -1, -2, -2 },
		3, 7, 5, 4, 11, 0, -10, -15,
		7, 170,
		100, 30,
		72, 6, 100, 25,
		66, 4, 100, 20,
		8,
		0xFFFFFFF,
		{0,5,5,5,5,1,0,1,1,5,7,9,5,5,5,5},//realm
		50,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'G',(RF3_UNDEAD),
	},
	{
#ifdef JP
		"ǐ_l",
#endif
		"Stray-god",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		11,  150,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5 ,5,5,5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'S',(RF3_DEITY),
	},


	{
#ifdef JP
		"d",  
#endif
		"Daiyoukai",

		{ 4, 3, 1, 2, 4, 2 },
		2, 10, 20, 1, 18, 5, 15, 5,
		13, 200,
		14, 6,
		65,  6, 150, 20,
		61,  6, 120, 15,
		8,
		0xFFFFFFF,
		{0,7,6,6,7,4,3,0,3,7,9,6,7,5,5,5},//realm
		60,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'Y',(RF3_KWAI),
	},


	{
		"l_",
		"Demigod",

		{  1,  1,  1,  1,  1,  1 },
		0,  3,  3,  0,  13,  0,  3,  3,
		11,  125,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5},//realm
		75,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_HUMAN | RF3_DEITY),
	},

	{
		"̖",
		"Lunarian",

		{  -2, 7, 5, 2, 1, 2 },
		10,  15, 12, 3, 20, 5, -30, 15,
		11, 190,
		35, 15,
		48,  3, 150, 10,
		46,  3, 120, 10,
		0,
		0xFFFFFFF,

		{0,8,8,8,8,9,2,9,2,4,0,0,4,5,5,5},//realm
		70,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(RF3_DEMIHUMAN | RF3_DEITY),
	},
/*:::I\Ȏ푰͂܂ŁBgɂ͐FXpb`[NKvB*/

	{
#ifdef JP
		"jW",
		"Ninja",
#else
		"Balrog",
#endif

		{  4,  2,  2,  7,  4,  -5 },
		20,  10, 10,  10, 20, 20, 20, 20,
		15,  150,
		255, 255,
		100,10, 255, 65,
		80, 10, 240, 64,
		10,
		0xFFFFFFF,

		{0,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5},//realm
		20,//scoremul
		FALSE,TRUE,TRUE,FALSE//FLAG
		,'p',(RF3_DEMIHUMAN),
	},
	{
#ifdef JP
		"l",
#endif
		"Half-Ghost",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		10,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		///mod140105 푰ύXijbǉ		

		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,TRUE//FLAG
		,'p',(RF3_HUMAN | RF3_UNDEAD),
	},
	{
#ifdef JP
		"l(lԑ)",
#endif
		"Greater-Lilliput",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		10,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,//scoremul
		FALSE,FALSE,FALSE,TRUE//FLAG
		,'p',(RF3_HUMAN),
	},
	{
#ifdef JP
		"b`",
#endif
		"Lich",

		{ -4,  6,  5,  -3,  3,  -5},
		6, 24, 30,  3, 20,  -8, -35, -25,
		11,  200,
		14,  6,
		48,  6, 150, 25,
		44,  4, 130, 20,
		5,
		0xFFFFFFF,
		{0,8,8,8,8,0,0,0,0,9,9,9,9,5,5,5},//realm
		33,//scoremul
		FALSE,TRUE,TRUE,FALSE//FLAG
		,'L',(RF3_UNDEAD),
	},
	{
#ifdef JP
		"ɐ",
#endif
		"Ultimate-thing",

		{ 6, 6, 5, 5, 7, 3 },
		8, 10, 15, 4, 20, 15, 25, 25,
		20, 250,
		1, 100,
		72, 12, 240, 64,
		66, 12, 220, 64,
		10,
		0xFFFFFFF,
		{0,8,8,8,8,8,8,8,8,9,8,8,8,8,8,5},//realm
		10,//scoremul
		FALSE,TRUE,FALSE,FALSE//FLAG
		,'H',(0L),
	},
	{
#ifdef JP
		"_i",
#endif
		"Deity",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  10,  10,
		12,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 5},
		100,//scoremul
		FALSE,FALSE,FALSE,TRUE//FLAG
		,'S',(RF3_DEITY),
	},
	{
		"q",
		"Highschoolgirl",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		10,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,//scoremul
		FALSE,FALSE,FALSE,TRUE//FLAG
		,'p',(RF3_HUMAN),
	},
	{
		"Hl",
		"Hourai",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  0,  0,
		10,  100,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,//scoremul
		FALSE,FALSE,FALSE,TRUE//FLAG
		,'p',(RF3_DEMIHUMAN),
	},
	{
		"@n",
		"Magic-jizo",

		{  0,  1,  2,  -2,  1,  1 },
		-8,  6,  16,  2,  3,  0, -6, -6,
		12,  130,
		14,  6,
		72,  6, 180, 25,
		66,  4, 150, 20,
		0,
		0xFFFFFFF,
		{ 0, 7, 8, 8, 7, 8, 8, 7, 7, 3, 2, 3, 2, 5, 5, 5},
		75,//scoremul
		FALSE,TRUE,FALSE,FALSE//FLAG
		,'g',(RF3_NONLIVING),
	},

};


/*
 * Player Classes
 *
 *      Title,
 *      {STR,INT,WIS,DEX,CON,CHR},
 *      c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *      x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *      HD, Exp, pet_upkeep_div
 */
const player_class class_info[MAX_CLASS] =
{
	{
#ifdef JP
		"m",
		"m",
#endif
		"Warrior",

		{ 4, -2, -2, 2, 2, -1},
		25, 18, 31, 1,  14, 40, 70, 55,
		9, 7,  10, 0,  0,  12,  30, 30,
		9,  0, 60

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,5,70,
		{4,5,3,5,4,0,0,0,0,0
		,4,5,4,5,5,5,5,5,4,4
		,2}
		,100,0,5,1,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},

	{
#ifdef JP
		"CW",
		"CW",
#endif
		"Mage",

		{-3, 3, 1, 0, -2, 1},
		30, 40, 40, 3,  21, 20, 34, 20,
		12,  15, 13,  0,  3,  7,  6, 7,
		0, 30, 30

		,{3,5,5,5,5,5,5,5,5,5,5,5,5,0,0,5}
		,A_INT
		,3,2,100,
		{1,1,1,1,3,0,0,0,0,0
		,3,2,1,2,3,1,1,1,1,1
		,2}
		,85,1,1,5,
		TRUE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"_",
		"ޏ",
#endif
		"Priest",

		{0, 1, 3, -1, 0, 2},
		25, 35, 50, 2, 18, 25, 40, 40,
		7,  11, 15, 0,  1,  9, 13, 12,
		4, 65, 40

		,{3,0,0,0,0,4,5,5,4,4,5,5,4,0,0,0}
		,A_INT
		,5,3,100,
		{3,2,1,1,2,0,0,0,0,0
		,3,2,3,4,4,1,2,2,3,1
		,1}
		,80,4,2,4,
		TRUE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"T",
		"T",
#endif
		"Explorer",

		{ 1, 1, -2, 2, 1, 0},
		45, 37, 36, 4, 40, 45, 48, 43,
		15, 12, 10, 1,  7, 15, 16, 18,
		4, 20, 55

		,{1,2,2,2,2,2,2,2,2,2,2,2,2,0,0,2}
		,A_INT
		,5,3,40,
		{3,2,2,4,4,0,0,0,0,0
		,5,3,3,2,2,2,1,1,2,4
		,3}
		,85,2,4,4,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"W[",
		"W[",
#endif
		"Ranger",

		{ 2, 0, -1, 3, 1, -1},
		30, 23, 36, 3, 35, 60, 60, 72,
		10,  9, 10, 2,  5, 18, 21, 32,
		5, 30, 40

		,{1,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0}
		,A_INT
		,5,4,70,
		{3,2,4,3,4,0,0,0,0,0
		,5,4,3,3,3,5,3,3,5,3
		,3}
		,70,2,3,2,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"",
		"",
#endif
		"Paladin",

		{ 1, -2, 2, -1, 2, 3},
		16, 20, 37, 1, 18, 35, 68, 40,
		 7,  10, 14, 0,  2, 10, 24, 15,
		8, 45, 40

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,5,70,
		{2,5,4,3,2,0,0,0,0,0
		,3,5,4,3,3,3,5,4,2,2
		,1}
		,75,0,4,3,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"t",
		"t",
#endif
		"Teacher",

		{ 0, 2, 0, 1, 0, 1},
		30, 35, 36, 2, 20, 40, 45, 45,
		 9, 10, 10, 0,  1, 10, 15, 15,
		3, 25, 45

		,{3,4,4,4,4,4,4,4,4,4,4,4,4,0,0,4}
		,A_INT
		,5,3,70,
		{3,3,3,3,3,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,3}
		,80,3,3,3,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"",
		"Ch",
#endif
		"Maid",

		{ 0, 1, 1, 1, 1, 1},
		40, 30, 36, 3, 25, 40, 63, 50,
		12, 12, 12, 0,  3, 12, 22, 18,
		3, 25, 50

		,{1,3,3,3,3,3,3,3,3,3,3,3,3,0,0,3}
		,A_INT
		,5,4,60,
		{3,4,1,4,4,0,0,0,0,0
		,4,4,4,4,4,4,4,4,2,2
		,2}
		,85,1,4,4,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
		"i",
		"i",
		"Martial-artist",
		{ 2, -2, 1, 3, 1, 1},
		20, 18, 26, 2, 22, 45, 55, 30,
		10,  7, 14,  1,  3,  15, 28, 12,
		4, 20, 80

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,2,90,
		{5,1,1,1,3,0,0,0,0,0
		,2,1,1,1,4,1,1,1,1,1
		,1}
		,75,1,2,1,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},

	{
#ifdef JP
		"\͎",
		"\͎",
#endif
		"Mindcrafter",

		{0, -1, 3, 1, 0, 2},   /* note: spell stat is Wis */
		30, 33, 38, 3,  24, 16, 50, 45,
		12, 11, 12, 0,   4,  0, 18, 18,
		3, 20, 30

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_WIS
		,5,3,100,
		{4,2,1,1,4,0,0,0,0,0
		,4,4,2,3,3,3,3,3,2,2
		,1}
		,60,0,4,4,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"nC=CW",
		"nC=CW",
#endif
		"High-Mage",

		{-4, 4, 2, -1, -2, 0},
		30, 40, 40, 3, 18, 18, 34, 20,
		7,  18, 13, 0,  2,  6,  6, 7,
		0, 10, 25

		,{1,6,6,6,6,6,6,6,6,6,6,6,6,0,0,6}
		,A_INT
		,3,2,100,
		{1,1,1,1,2,0,0,0,0,0
		,3,2,1,2,3,1,1,1,1,1
		,1}
		,90,1,1,5,
		TRUE,FALSE,FALSE
		,TRUE
		,5
	},

	{
#ifdef JP
		"ʂ̏Zl",
		"ʂ̏Zl",
#endif
		"Civilian",
		{ 0, 0, 0, 0, 0, 0},
		25, 20, 30, 3, 20, 24, 43, 25,
		12,  9,  9, 0,  2,  8, 12, 10,
		3, 0, 80

		,{1,2,2,2,2,2,2,2,2,2,2,2,2,0,0,2}
		,A_INT
		,4,3,100,
		{3,3,3,3,3,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,3}
		,150,3,2,1,
		FALSE,FALSE,FALSE
		,TRUE
		,2
	},

	{
#ifdef JP
		"C",
		"C",
#endif
		"Monk",
		{ 1, 0, 2, 1, 1, 0},
		25, 30, 36, 2, 24, 36, 60, 40,
		7,  10, 15, 0,  2,  15, 18, 16,
		4, 25, 55

		,{1,0,0,0,0,4,4,4,4,4,0,4,0,0,0,0}
		,A_INT
		,5,4,80,
		{5,1,2,1,3,0,0,0,0,0
		,3,2,4,2,5,2,2,2,2,1
		,1}
		,75,2,3,3,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"@m",
		"@m",
#endif
		"Magic-Knight",
		{ 1, 2, 0, 1, 0, 1},
		28, 40, 34, 2, 17, 24, 50, 33,
		9,  12, 11 ,0, 1,   7, 16, 10,
		4, 45, 50

		//ǉlb
		,{1,4,4,4,4,0,0,0,0,0,4,0,4,0,0,0}
		,A_INT
		,5,4,80,
		{2,3,2,4,2,0,0,0,0,0
		,4,5,4,1,1,1,1,1,1,1
		,1}
		,75,4,3,3,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"()",
		"()",
#endif
		"Dark-Knight",//@mƏC҂̂قɈÍRmĂ̂悤ƎvĂ肵

		{-5, 6, -2, 2, 0, -2},
		30, 48, 75, 2,  12, 22,  0, 0,
		 7, 18, 13, 0,  0,  0,  0, 0,
		4, 60, 25

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,5,70,
		{4,4,4,4,4,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,3}
		,100,5,3,3,
		FALSE,TRUE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"ˎ",
		"ˎ",
#endif
		"Archer",

		{ 2, -1, -2, 3, 1, 0},
		40, 24, 35, 3,  30, 35, 45, 85,
		13, 10, 10, 0,  3,  10, 15, 40,
		4, 10, 60

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,80,
		{2,1,1,1,4,0,0,0,0,0
		,3,3,2,2,2,2,2,2,5,5
		,4}
		,85,0,4,2,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},

	{
		"g",
		"g",
		"Magic-Eater",

		{-1, 3, 1, 1, -2, 0},
		30, 45, 36, 3,  22, 16, 45, 35,
		10, 22, 10, 0,  2,  0, 12, 10,
		2, 30, 50
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,2,90,
		{1,2,1,1,3,0,0,0,0,0
		,3,2,2,2,3,2,2,2,2,1
		,3}
		,80,0,2,5,
		TRUE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"GWjA",
		"GWjA",
#endif
		"Engineer",
		{1, 3, -3, 2, 0, 0},
		40, 15, 20,  2, 25, 20, 47, 55,
		20,  6,   8,  0,  4,   8, 16, 24,
		2, 20, 80

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,90,
		{3,3,1,1,4,0,0,0,0,0
		,4,2,2,4,3,2,2,2,2,4
		,4}
		,82,0,4,1,
		FALSE,FALSE,FALSE
		,TRUE
		,2
	},

	{
#ifdef JP
		"i",
		"i",
#endif
		"Librarian",

		{ 1, 2, -1, 1, 1, 0},
		20, 34, 34, 3, 16, 20, 55, 25,
		7,  11, 11, 0,   2, 10,  17, 11,
		4, 30, 60

		//ǉlb
		,{2,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0}
		,A_INT
		,5,3,80,
		{2,3,2,2,3,0,0,0,0,0
		,4,4,3,4,2,2,1,1,2,3
		,2}
		,90,3,4,4,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},

	{
#ifdef JP
		"p",
		"p",
#endif
		"Samurai",

		{ 3, -2, 1, 2, 1, 0},
		25, 18, 32, 2,  16, 6, 70, 40,
		12, 7,  10, 0,  1,  0,  23, 18,
		6,  30, 60

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0}
		,A_INT
		,5,4,70,
		{2,1,3,5,4,0,0,0,0,0
		,4,5,5,2,4,2,3,3,4,2
		,1}
		,90,0,5,1,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},


	{
		"m",
		"m",
		"Soldier",
		{2, 1, -1, 2, 2, -3},
		32, 20, 20,  4, 28, 27, 55, 60,
		14,  8,  8,  0,  4, 10, 20, 25,
		4, 50, 120

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,2,100,
		{4,1,1,4,4,0,0,0,0,0
		,5,3,3,3,2,2,1,1,2,4
		,5}
		,80,0,3,1,
		FALSE,FALSE,FALSE
		,TRUE
		,2
	},


	{
		"t",
		"t",
		"Chemist",

		{-1, 4, 0, 1, 0, 2},
		37, 32, 32, 4, 36, 25, 47, 52,
		11, 12, 10, 0,  5,  8, 18, 20,
		3, 50, 60

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0}
		,A_INT
		,4,2,80,
		{3,2,1,1,4,0,0,0,0,0
		,4,2,2,3,3,2,2,1,2,3
		,2}
		,100,3,3,4,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"R",
		"R",
#endif
		"Cavalry",
		{ 2, -2, -2, 2, 2, 0},
		20, 18, 32, 1,  16, 35, 60, 66,
		10,  7, 10, 0,  0,  10, 22, 26,
		5, 20, 35

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{1,4,5,3,2,0,0,0,0,0
		,2,4,3,4,4,3,5,5,4,3
		,2}
		,90,0,5,1,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},
/*
	{
#ifdef JP
		"m",
		"m",
#endif
		"Berserker",

		{ 8, -20, -20, 4, 4, -5},
		-100, -1000, -200, -100,  -100, -100, 120, -2000,
		0, 0,  0, 0,  0,  0,  50, 0,
		11,  60, 255

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,5,70,
		{4,4,4,4,4,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,3}
		,100,0,3,3,
		FALSE,TRUE,FALSE
		,TRUE
		,1
	},
*/

	{
#ifdef JP
		"tr_g",
		"tr_g",
#endif
		"Tsukumo-master",

		{1, 2, -1, 1, 1, -2},
		40, 36, 35, 2, 24, 25, 50, 45,
		13, 14, 12, 0,  3,  3, 18, 15,
		4, 35, 25

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,70,
		{2,2,2,2,5,0,0,0,0,0
		,4,3,3,4,3,4,3,3,1,2
		,1}
		,80,0,5,5,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},		
		
	{			
#ifdef JP				
		"Ó",		
		"Ó",		
#endif				
		"Secondhand-dealer",	
				
		{1, 2, 0, 1, 0, -1},		
		40, 30, 30, 3, 35, 25, 48, 45,	
		12, 12, 10, 0,  6,  8, 17, 18,
		4, 35, 70		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,4,100,
		{1,3,2,3,3,0,0,0,0,0		
		,3,3,3,3,3,3,3,3,3,4		
		,3}		
		,85,0,5,5,
		FALSE,FALSE,FALSE
		,TRUE
		,2
	},

	{
#ifdef JP
		"t",
		"t",
#endif
		"Jeweler",

		{ -1, 2, 1, 2, -2, 2},
		30, 40, 36, 2, 24, 16, 48,30,
		10, 17, 12, 0,  3,   3, 16,10,
		2, 50, 45

		//ǉlb
		,{1,5,5,5,5,5,5,5,5,5,5,5,5,0,0,5}
		,A_INT
		,4,2,80,
		{1,2,1,1,3,0,0,0,0,0
		,4,3,2,3,2,2,2,2,2,2
		,1}
		,80,2,4,5,
		FALSE,FALSE,FALSE
		,TRUE
		,4
	},
	{
#ifdef JP
		"E",
		"E",
#endif
		"Ninja",

		{ 0, 1, 0, 3, 0, -2},
		45, 27, 27, 5, 33, 48, 55,63,
		15, 12, 10, 2,  6, 16, 24,18,
		2,  45, 90

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,1,50,
		{5,1,1,4,5,0,0,0,0,0
		,5,2,3,2,1,1,1,1,3,3
		,1}
		,80,0,4,4,
		FALSE,FALSE,FALSE
		,TRUE
		,3
	},

	{
#ifdef JP
		"()",
		"()",
#endif
		"Secondhand-dealer",

		{ 2, -1, -1, 2, 1, 0},
		25, 24, 28, 5, 32, 18, 35,  72,
		12, 10, 10, 0,  0,  0, 12,  28,
		2, 20, 40

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,5,70,
		{4,4,4,4,4,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,3}
		,100,0,3,3,
		FALSE,TRUE,FALSE
		,TRUE
		,2
	},

	{
#ifdef JP
		"Ol",
		"Ol",
#endif
		"Outsider",

		{ -3, -3, -3, -3, -3, -3},
		10, 10, 10, 1, 10, 10, 30, 30,
		10, 10, 10, 1,  1, 10, 12, 12,
		1, 30, 90

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,2,120,
		{2,2,2,2,2,0,0,0,0,0
		,2,2,2,2,2,2,2,2,2,2
		,2}
		,300,0,1,1,
		FALSE,FALSE,FALSE
		,TRUE
		,1
	},

		{			
#ifdef JP				
		"ł̗d",		
		"ł̗d",		
#endif				
		"Rumia",		
				
		{1, -1, -1, -1, 0, -1},		
		20,  7, 25, 2, 8, 20, 50, 20,		
		 5, 10, 12, 2, 1,  5, 15, 10,		
		3, 10, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,2,70,		
		{4,1,1,3,2,0,0,0,0,0		
		,4,3,2,3,2,2,1,1,1,1		
		,1}		
		,150,0,2,1,		
		FALSE,FALSE,TRUE		
		,TRUE
		,2
	},

	{			
#ifdef JP				
		"l̒t",		
		"l̒t",		
#endif				
		"Youmu",		
				
		{2, -2, 0, 3, 3, 2},		
		25, 20, 32, 2,20, 40, 60, 45,		
		 8, 13, 13, 1, 1, 18, 24, 15,		
		5, 50, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0}		
		,A_INT
		,5,4,70,		
		{2,1,1,5,3,0,0,0,0,0		
		,4,4,5,2,2,1,1,1,2,1		
		,1}	
		,55,0,4,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},

	{			
#ifdef JP				
		"K^̑fe",		
		"K^̑fe",		
#endif				
		"Tewi",		
				
		{-2, 3, 2, 0, -1, 4},
		36, 22, 36, 3, 32, 42, 40, 40,
		12, 11, 12, 1,  5, 15, 15, 12,
		2, 30, 30
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}			
		,A_INT
		,4,2,100,		
		{1,1,1,1,2,0,0,0,0,0		
		,3,2,2,4,4,3,2,2,2,1		
		,1}		
		,90,0,2,2,		
		FALSE,FALSE,TRUE
		,FALSE
		,2
	},	



	{			
#ifdef JP				
		"Č̓e",		
		"Č̓e",		
#endif				
		"Udonge",		
				
		{2, 3, -1, 0, 2, 0},
		36, 27, 40, 2, 30, 40, 52, 60,
		12, 12, 16, 3,  4, 14, 22, 30,
		5, 40, 50
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,70,		
		{4,3,1,3,3,0,0,0,0,0		
		,4,4,4,3,3,3,4,4,3,4		
		,5}		
		,64,0,4,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{			
#ifdef JP				
		"̈",		
		"̈",		
#endif				
		"Iku",		
				
		{0, 3, 3, 2, 0, 3},		
		25, 36, 40, 3, 30, 45, 52, 36,		
		14, 12, 15, 0,  4, 18, 18, 18,		
		4, 30, 50		
				
		,{1,4,4,3,3,3,3,3,4,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,80,		
		{4,3,3,3,3,0,0,0,0,0		
		,3,3,3,3,3,3,3,3,3,3		
		,3}		
		,65,2,5,5,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{			
#ifdef JP				
		"Or̐ēl",		
		"Or̐ēl",		
#endif				
		"Komachi",		
				
		{0, 0, -2, 3, 2, 2},		
		20, 30, 50, 1, 28, 25, 60, 35,		
		 9, 12, 18, 0,  3, 10, 27, 20,		
		6, 0, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,5,90,		
		{2,2,3,2,4,0,0,0,0,0		
		,2,2,2,2,5,3,4,5,1,1		
		,1}		
		,60,0,3,3,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{			
#ifdef JP				
		"ȖYP",		
		"ȖYP",		
#endif				
		"Kogasa",		
				
		{2, 0, -1, 0, 1, 2},		
		25, 30, 36, 1, 25, 25, 45, 10,		
		10, 10, 12, 0,  2,  5, 16,  1,		
		4, 0, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,100,		
		{1,2,1,1,1,0,0,0,0,0		
		,1,1,1,1,5,1,1,1,1,1		
		,1}		
		,135,0,5,5,		
		FALSE,FALSE,TRUE		
		,TRUE
		,2
	},	

	{			
#ifdef JP				
		"ИrLp̐l",		
		"ИrLp̐l",		
#endif				
		"Kasen",		
				
		{6, 0, 0, 2, 6, 2},		
		23, 40, 45, 4, 22, 30, 72, 35,		
		12, 16, 18, 0,  1, 12, 25, 12,		
		7, 60, 20		
		
		,{1,0,0,0,5,5,5,0,5,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,70,		
		{5,1,5,1,3,0,0,0,0,0		
		,3,2,2,5,4,3,2,2,2,2		
		,1}		
		,40,5,3,4,		
		TRUE,FALSE,TRUE		
		,FALSE
		,4
	},	
	{			
#ifdef JP				
		"ȕSSs",		
		"ȕSSs",		
#endif				
		"Suika",		
				
		{2, 2, 1, 2, 2, 2},		
		16, 20, 36, 1, 18, 24, 80, 50,		
		16, 10, 14, 0,  4, 12, 32, 24,		
		10, 30, 30		
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,9,50,		
		{5,1,1,1,4,0,0,0,0,0		
		,2,1,2,4,1,3,1,2,1,1		
		,1}		
		,50,0,2,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	


	{			
#ifdef JP				
		"ʂ̍pt",		
		"ʂ̍pt",		
#endif				
		"Marisa",		
				
		{-1, 4, 4, 5, 1, 4},		
		40, 47, 32, 5, 45, 50, 50, 50,		
		15, 16, 12, 0,  8, 30, 18, 18,		
		4, 0, 30	
		
		,{3,5,5,5,5,5,5,5,5,5,5,5,5,0,0,5}	
		,A_INT
		,4,3,100,	
		{4,3,4,1,3,0,0,0,0,0		
		,3,2,2,2,4,2,2,3,2,2		
		,4}
		,10,3,1,5,		
		TRUE,TRUE,TRUE		
		,FALSE
		,5
	},

	{			
#ifdef JP				
		"Wɐސl",		
		"Wɐސl",		
#endif				
		"Wakasagi",		
				
		{ -2, 0, 1, 1, -1, 1},		
		20, 24, 32, 4, 30, 25, 44, 55,		
		 9, 12, 16, 1,  4,  8, 12, 16,		
		2, 0, 50		
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,3,100,		
		{3,3,1,1,4,0,0,0,0,0		
		,3,3,2,3,3,1,4,1,3,3		
		,1}		
		,150,0,2,2,		
		FALSE,FALSE,TRUE		
		,TRUE
		,2
	},		
	{			
#ifdef JP				
		"̓",		
		"̓",		
#endif				
		"Koishi",		
				
		{ -2, -7, -3, 3, 1, 2},		
		 1, 16, 75,  0,  1, 80, 30,  1,		
		 1, 10, 15,  5,  0,  0, 30,  1,		
		2, 60, 200		
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,3,4,100,		
		{4,2,1,5,1,0,0,0,0,0		
		,3,2,2,2,2,2,2,2,1,1		
		,1}		
		,25,0,1,1,		
		FALSE,FALSE,TRUE		
		,FALSE
		,4
	},	
	{			
#ifdef JP				
		"[V",		
		"[V",		
#endif				
		"Momizi",		
				
		{ 1, 3, 0, 1, 0, 0},		
		36, 21, 32, 2, 60, 45, 54, 50,		
		12,  9, 10, 0, 10, 12, 18, 20,		
		3, 30, 50		
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,80,		
		{3,5,1,1,3,0,0,0,0,0		
		,4,5,4,3,3,3,3,3,4,4		
		,2}		
		,95,0,4,1,		
		FALSE,FALSE,TRUE		
		,FALSE
		,2
	},	

	{			
#ifdef JP				
		"ǔ̎א",		
		"ǔ̎א",		
#endif				
		"Seiga",		
				
		{ -1, 3, -1, 2, 1, -3},		
		24, 40, 40, 3, 32, 30, 36, 36,		
		15, 15, 15, 0,  3, 12,  8,  8,		
		1, 40, 50
		
		,{3,4,4,5,4,3,4,2,2,2,5,5,5,0,0,0}		
		,A_INT
		,3,2,100,		
		{1,1,1,1,3,0,0,0,0,0		
		,3,2,1,1,4,1,1,1,1,1		
		,2}		
		,50,2,2,5,		
		TRUE,FALSE,TRUE		
		,FALSE
		,4
	},
	{			
#ifdef JP				
		"X̗d",		
		"X̗d",		
#endif				
		"Cirno",		
				
		{ 3, 1, 2, 3, 3, 3},		
		10, 14, 30, 1, 12, 25, 40, 18,		
		 2,  9, 12, 0,  1,  8, 23,  9,		
		5, -20, 50
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,2,100,		
		{4,2,1,2,3,0,0,0,0,0		
		,3,4,2,3,2,2,2,2,1,1		
		,1}		
		,75,0,1,1,		
		FALSE,FALSE,TRUE		
		,TRUE
		,4
	},	
	{			
#ifdef JP				
		"n̗։",		
		"n̗։",		
#endif				
		"Orin",		
		
		{ 1, 4, 3, 1, 1, -3},
		30, 30, 36, 4, 32, 55, 55, 36,		
		12, 13, 15, 1,  4, 20,  20,  8,		
		4, 45, 30
		
		,{1,0,0,0,0,0,0,0,0,3,4,5,4,0,0,0}
		,A_INT
		,4,3,90,		
		{4,2,1,1,3,0,0,0,0,0		
		,3,2,2,3,3,2,2,2,1,1		
		,2}		
		,70,3,3,3,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},

	{			
#ifdef JP				
		"l̖",		
		"l̖",		
#endif				
		"Shinmyoumaru",		
				
		{1, 0, 3, 2, 1, 3},		
		36, 48, 32, 3, 32, 45, 55, 32,		
		12, 24, 12, 1,  3, 16, 20, 16,		
		5, 20, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,6,3,100,		
		{3,3,4,2,4,0,0,0,0,0		
		,5,5,5,4,3,2,3,3,3,3		
		,2}		
		,27,0,5,5,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{			
#ifdef JP				
		"_EU[̏ȑ叫",	
		"_EU[̏ȑ叫",		
#endif				
		"Nazrin",		
				
		{ -2, 3, 3, 0, -2, 1},
		40, 40, 38, 3, 40, 36, 37, 40,		
		14, 14, 12, 1,  8, 11, 12, 10,		
		2, 25, 40	
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,5,100,	
		{1,2,2,2,3,0,0,0,0,0		
		,3,3,2,2,4,2,3,2,2,3		
		,2}		
		,165,0,4,4,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{
#ifdef JP
		"~̖Yꕨ",
		"~̖Yꕨ",
#endif
		"Letty",
		{ -1, 1, 2, -2, 0, 1},
		25, 20, 30, 4, 15, 20, 45, 30,
		12, 10, 10, 1,  1,  7,  15, 15,
		2, 20, 50

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,2,100,
		{2,3,1,1,2,0,0,0,0,0
		,3,3,2,3,3,2,3,2,2,2
		,1}
		,125,0,2,3,
		FALSE,FALSE,TRUE
		,TRUE
		,4
	},
	{
#ifdef JP
		"Ȏ",
		"Ȏ",
#endif
		"Yoshika",
		{ 1, 2, 1, 0, 2, 2},
		10, 14, 30, 3,  8, 20, 65, 10,
		 6,   6,  8, 0,  0,  4,  20,  5,
		10, 30, 50

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,5,70,
		{4,3,1,1,1,0,0,0,0,0
		,2,2,1,4,3,4,1,3,1,1
		,1}
		,75,0,1,1,
		FALSE,FALSE,TRUE
		,FALSE
		,2
	},

	{
#ifdef JP
		"Ȃ}",
		"Ȃ}",
#endif
		"Patchouli",
		{ -2, 5, 3, -2, -4, 1},
		15, 30, 35, 4, 20, 10, 15, 10,
		10, 18, 15, 0,  3,  2,   5,  5,
		0, 40, 15

		//ǉlb
		,{2,5,5,5,5,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,1,100,
		{1,1,1,1,2,0,0,0,0,0
		,2,1,1,1,2,1,1,1,1,1
		,1}
		,70,1,1,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	{
#ifdef JP
		"`̌zu",
		"`̌zu",
#endif
		"Aya",
		{ 1, 1, 2, 5, 2, 1},
		25, 26, 32, 3, 30, 30, 55, 40,
		15, 13, 12, 0,  5, 15, 22, 12,
		4, 90, 50

		//ǉlb
		,{1,0,0,0,0,3,0,0,4,0,0,0,0,0,0,0}
		,A_INT
		,6,3,60,
		{4,1,1,3,3,0,0,0,0,0
		,5,4,5,2,4,2,4,4,1,1
		,1}
		,55,1,4,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{			
#ifdef JP				
		"낭̉",		
		"낭̉",		
#endif				
		"Sekibanki",		
				
		{0, 1, 0, 1, 1, 1},		
		23, 20, 22, 3, 22, 30, 50, 40,		
		12, 11, 15, 0,  2, 10, 18, 16,		
		3, 15, 50
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,3,90,		
		{3,4,4,2,3,0,0,0,0,0		
		,3,4,2,3,2,3,4,4,2,4		
		,3}
		,115,0,3,2,		
		FALSE,FALSE,TRUE		
		,TRUE
		,2
	},	
	{			
#ifdef JP				
		"鐝̉",
		"鐝̉",	
#endif				
		"Mystia",		
				
		{-1, -2, 0, 2, 0, 3},		
		26, 20, 32, 5, 24, 32, 45, 15,		
		12,  9, 10, 1,  3, 10, 21, 10,		
		3, 25, 40
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,2,90,		
		{4,2,1,1,2,0,0,0,0,0		
		,4,3,3,2,2,2,4,3,1,2		
		,1}
		,120,0,2,2,		
		FALSE,FALSE,TRUE		
		,TRUE
		,4
	},
	{			
#ifdef JP				
		"̖",		
		"̖",		
#endif				
		"Flandre",		
		{5, 3, -8, 1, 3, 0},		
		1,  1, 60, 1,  10, 32, 72, 20,		
		1, 16, 12, 0,  0, 10, 26, 20,		
		7, 35, 100
		,{1,4,0,0,0,0,0,0,0,0,4,0,4,0,0,0}
		,A_INT
		,6,6,80,
		{3,1,1,4,1,0,0,0,0,0		
		,2,5,2,4,5,4,3,3,3,1		
		,1}
		,35,4,2,2,		
		TRUE,FALSE,TRUE		
		,FALSE
		,4
	},
	{			
#ifdef JP				
		"V̒q",		
		"V̒q",		
#endif				
		"Shou",		
				
		{3, 2, 5, -1, 2, 5},		
		20, 30, 38, 2, 24, 24, 16, 16,		
		10, 12, 16, 0,  2, 12, 40, 30,		
		6, 40, 30	
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,5,100,		
		{4,3,4,4,4,0,0,0,0,0		
		,3,4,4,3,4,3,5,4,3,2		
		,1}
		,65,0,4,3,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},
	{
#ifdef JP
		"ȃXC[g|CY",
		"ȃXC[g|CY",
#endif
		"Medicine",
		{ 0, 1, 1, 1, 0, 1},
		21, 24, 30, 4, 16, 20, 40, 40,
		12, 12, 11, 0,  1,  4,  21, 18,
		3, 30, 50
		,{1,4,4,4,4,0,0,0,0,4,4,4,4,0,0,0}
		,A_INT
		,4,2,100,
		{3,3,1,3,3,0,0,0,0,0
		,3,3,3,3,3,3,3,3,3,3
		,2}
		,85,2,4,4,
		FALSE,FALSE,TRUE
		,TRUE
		,4
	},

	{			
#ifdef JP				
		"̖S",		
		"̖S",		
#endif				
		"Yuyuko",		
				
		{ 4, 4, 3, 2, 3, 5},		
		22, 45, 45, 5, 35, 30, 55, 40,		
		10, 16, 18, 1,  3, 10, 24, 16,		
		5, 50, 20
		
		,{1,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0}		
		,A_INT
		,5,3,90,	
		{4,3,3,3,3,0,0,0,0,0	
		,4,3,4,2,3,2,4,4,3,2		
		,1}		
		,35,3,3,5,		
		TRUE,FALSE,TRUE		
		,FALSE
		,5
	},
	{			
		"ꋯޏ",		
		"ꋯޏ",		
		"Satori",	
				
		{ -2, 6, 6, 0, -2, -4},
		16, 30, 36, 4, 23, 40, 37, 45,		
		12, 12, 12, 0,  1, 12, 12,  20,	
		3, 25, 20
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,3,3,100,	
		{1,2,2,1,2,0,0,0,0,0
		,3,2,2,2,2,2,2,2,2,2
		,1}
		,80,2,3,3,	
		FALSE,FALSE,TRUE	
		,FALSE
		,5
	},
	{			
#ifdef JP				
		"ǌo郄}rR",
		"ǌo郄}rR",	
#endif				
		"Kyouko",		
				
		{-1, 0, 2, -1, -1, 1},		
		24, 20, 28, 2, 18, 24, 43, 15,		
		10, 11, 10, 0,  2,  8, 18, 10,		
		3, 10, 60
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,2,80,		
		{2,2,1,1,3,0,0,0,0,0		
		,2,2,2,3,4,2,3,3,1,2		
		,1}
		,120,0,2,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},
	{			
#ifdef JP				
		"_̖̖S",
		"_̖̖S",	
#endif				
		"Toziko",
				
		{2, 1, 0, 1, 2, 0},
		20, 22, 30, 3, 18, 36, 45, 50,
		10, 12, 11, 0,  1, 15, 16, 23,
		3, 30, 60
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,3,100,
		{4,2,1,1,3,0,0,0,0,0
		,3,3,3,2,2,2,2,2,4,3
		,1}	
		,115,1,3,2,	
		FALSE,FALSE,TRUE	
		,FALSE
		,4
	},
	{			
#ifdef JP				
		"t^ԗd",
		"t^ԗd",	
#endif				
		"Lilywhite",
				
		{3, 3, 3, 3, 3, 3},
		20, 21, 35, 1, 21, 26, 50, 20,
		 5,  12, 12, 0, 2,  12, 20, 10,
		3, 0, 80
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,2,80,	
		{1,1,1,2,1,0,0,0,0,0
		,2,2,2,2,2,2,2,2,1,1	
		,1}	
		,120,1,2,2,	
		FALSE,FALSE,TRUE	
		,TRUE
		,4
	},

	{
#ifdef JP				
		"ׂ˂̉",		
		"ׂ˂̉",		
#endif				
		"Kisume",		
				
		{ -1, -1, 1, -2, 2, -2},	
		18, 20, 28, 5, 20, 25, 60, 48,		
		10,  9, 11, 1,  3, 10, 25, 24,		
		3, 15, 70	
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,3,80,
		{4,3,1,1,4,0,0,0,0,0
		,1,2,2,4,2,4,2,2,1,2
		,1}
		,180,0,4,1,	
		FALSE,FALSE,TRUE	
		,TRUE
		,2
	},	

	{
		"ǂ̔OʋL",
		"ǂ̔OʋL",
		"Hatate",

		{ 0, 2, 1, -1, 1, 1},
		24, 32, 30, 3, 27, 25, 50, 68,
		11, 12, 10, 1,  4, 12, 20, 27,
		4, 40, 75

		,{1,0,4,0,0,0,3,0,0,0,3,0,0,0,0,0}
		,A_INT
		,4,2,90,
		{2,2,1,1,4,0,0,0,0,0
		,3,2,3,1,2,1,3,2,3,4
		,4}
		,68,3,3,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},

	{
#ifdef JP
		"m",
		"m",
#endif
		"Miko",
		{ 3, 5, 5, 2, 2, 5},
		30, 48, 40, 4, 32, 36, 55, 48,
		18, 22, 18, 0,  5,  18, 25, 21,
		5, 30, 25

		//ǉlb
		,{2,0,0,0,0,5,5,5,5,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{4,3,4,4,4,0,0,0,0,0
		,4,5,5,4,4,4,4,4,4,3
		,3}
		,16,2,5,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},

	{			
#ifdef JP				
		"\Lȃ|[J[tFCX",		
		"\Lȃ|[J[tFCX",		
#endif				
		"Kokoro",		
				
		{2, 3, 3, 2, 2, 3},
		26, 36, 32, 3, 24, 30, 58, 45,
		13, 16, 13, 0,  3, 12, 25, 20,
		5, 55, 60
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,4,70,	
		{4,2,1,1,3,0,0,0,0,0
		,3,3,4,3,3,3,4,5,3,3	
		,2}
		,40,0,4,5,	
		FALSE,FALSE,TRUE	
		,FALSE
		,4
	},	
	{			
		"ł忂",
		"ł忂",
		"Wriggle",		
				
		{ -1, -2, -1, 0, 1, 1},
		24, 20, 32, 3, 27, 30, 43, 36,		
		12, 10, 12, 0,  3,   8, 16, 14,		
		2, 30, 30	
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}	
		,A_INT
		,4,2,100,
		{4,2,2,2,2,0,0,0,0,0	
		,3,3,2,2,2,2,3,3,2,2	
		,1}
		,160,0,2,1,		
		FALSE,FALSE,TRUE		
		,TRUE
		,3
	},
	{
#ifdef JP
		"lG̃t[}X^[",
		"lG̃t[}X^[",
#endif
		"Yuuka",

		{ 3, 2, 2, 1, 3, 3},
		33, 30, 36, 4,  30, 30, 75, 45,
		11, 13, 14, 0,  4,  10,  32, 16,
		9, 140, 40

		,{1,5,0,0,0,0,0,0,5,0,0,0,5,0,0,0}
		,A_INT
		,6,3,70,
		{3,2,2,2,3,0,0,0,0,0
		,3,3,3,3,4,3,4,4,2,1
		,1}
		,35,0,4,4,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{			
#ifdef JP				
		"̍L",		
		"̍L",		
#endif				
		"Chen",
				
		{1, 2, 1, 3, 1, 2},
		20, 24, 30, 4, 18, 36, 55, 20,
		10, 12, 11, 1, 3,  15, 24, 10,
		3, 10, 50	
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}	
		,A_INT
		,4,3,80,		
		{4,1,1,2,2,0,0,0,0,0	
		,4,2,2,2,2,2,2,2,1,1		
		,1}	
		,140,1,2,3,	
		FALSE,FALSE,TRUE	
		,FALSE
		,2
	},
	{			
#ifdef JP				
		"̂̔O",	
		"̂̔O",		
#endif				
		"Minamitsu",		
				
		{ 1, 1, 3, 1, 0, -2},
		36, 30, 38, 4, 20, 32, 50, 40,	
		13, 12, 11, 0,  3, 10, 20, 10,		
		5, 25, 40
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,5,100,	
		{4,1,1,1,4,0,0,0,0,0		
		,2,2,2,4,4,2,2,2,2,2	
		,1}		
		,65,0,3,3,	
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},
	{			
#ifdef JP				
		"mƗj̔b",	
		"mƗj̔b",		
#endif				
		"Keine",		
				
		{ -2, 6, 4, -2, 0, 4},
		32, 36, 30, 2, 27, 26, 55, 45,	
		16, 14, 13, 0,  4, 10, 24, 15,		
		5, 45, 40
		
		,{1,0,0,0,0,5,5,5,5,4,0,0,0,0,0,0}	
		,A_INT
		,5,3,80,	
		{3,3,2,2,3,0,0,0,0,0		
		,3,4,4,3,3,2,2,2,2,2	
		,2}		
		,75,4,4,4,	
		FALSE,FALSE,TRUE		
		,FALSE
		,4
	},

	{			
		"̛ޏ",		
		"̛ޏ",		
		"Reimu",		
				
		{0, 0, 0, 0, 0, 0},		
		25, 30, 27, 2, 25, 65, 50, 50,		
		12, 12, 12, 0,  5, 25, 20, 20,		
		6, 30, 40	
				
		,{1,0,0,0,0,4,4,5,4,0,0,0,0,0,0,0}	
		,A_INT
		,4,4,80,	
		{4,4,4,4,5,0,0,0,0,0		
		,4,4,4,4,5,4,4,4,4,4		
		,4}		
		,10,1,4,4,	
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},

	{			
#ifdef JP				
		"͗_",		
		"͗_",		
#endif				
		"Yugi",		
				
		{4, 1, 2, -1, 3, 1},		
		10, 24, 29, 1, 16, 20, 90, 40,		
		10, 10, 11, 0,  2, 12, 30, 18,		
		7, 35, 55		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,9,50,		
		{4,1,1,1,2,0,0,0,0,0		
		,2,2,2,3,3,3,2,2,1,1		
		,1}		
		,75,0,3,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},
	{			
		"|т̃[K[",
		"|т̃[K[",
		"Kagerou",	
				
		{1, 0, 0, 1, 1, 1},	
		25, 20, 30, 4,20, 40, 55, 30,		
		 8, 12, 12, 0, 3, 18, 24, 12,		
		4, 20, 50
				
		,{1,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0}	
		,A_INT
		,5,3,80,	
		{4,1,1,3,2,0,0,0,0,0
		,3,2,2,2,2,2,2,2,1,1	
		,1}
		,100,0,1,3,
		FALSE,FALSE,TRUE	
		,TRUE
		,3
	},
	{			
		"₵ƏȈے",		
		"₵ƏȈے",		
		"Shizuha",		
				
		{2, -1, 0, 2, -1, -2},		
		24, 22, 27, 3,16, 20, 50, 20,		
		12, 12, 12, 0, 3,  5, 22, 10,		
		2, 0, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,2,70,		
		{4,1,1,1,2,0,0,0,0,0		
		,2,2,2,3,2,3,1,1,1,1		
		,1}		
		,200,0,2,1,	
		FALSE,FALSE,TRUE		
		,FALSE
		,2
	},


	{
		"J镗̐l",
		"J镗̐l",
		"Sanae",

		{-1, 1, 3, -1, -1, 2},
		26, 32, 32, 3, 21, 25, 43, 38,
		12, 12, 16, 0,  2,  9, 16, 12,
		3, 40, 50

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,90,
		{3,2,1,1,3,0,0,0,0,0
		,3,2,2,3,4,2,2,2,1,1
		,2}
		,85,1,2,4,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"LƖ̏ے",
		"LƖ̏ے",
		"Minoriko",
		{ 0, 0, 2, -1, 0, 1},
		22, 24, 32, 2, 20, 23, 45, 25,
		10, 12, 10, 0,  3,  7, 12, 10,
		2, 25, 60

		,{1,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0}
		,A_INT
		,3,2,100,
		{1,2,2,2,3,0,0,0,0,0
		,2,2,2,3,2,2,2,3,1,1
		,1}
		,160,3,2,2,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{			
		"iɍgc",
		"iɍgc",	
		"Remilia",
				
		{3, 2, 2, 3, 3, 3},
		36, 45, 40, 4, 36, 36, 80, 60,
		12, 12, 12, 1,  5, 15, 30, 27,
		8, 80, 30
				
		,{1,4,5,4,4,0,0,0,0,4,5,4,4,0,0,0}
		,A_INT
		,6,5,70,
		{5,2,2,2,5,0,0,0,0,0
		,4,4,4,4,4,4,5,5,3,3	
		,1}
		,25,1,3,2,	
		FALSE,FALSE,TRUE	
		,FALSE
		,4
	},
	{
		"de",
		"de",
		"Nitori",
		{1, 1, 1, 2, 0, 1},
		55, 21, 27, 3, 23, 20, 50, 60,
		32,  9, 10, 0,  2,  8, 22, 24,
		4, 50, 80

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,80,
		{4,3,1,1,3,0,0,0,0,0
		,2,1,1,4,3,2,1,1,1,4
		,5}
		,67,0,4,2,
		FALSE,FALSE,TRUE
		,FALSE
		,2
	},
	{
		"󂳂ꂽ喂@g",
		"󂳂ꂽ喂@g",
		"Byakuren",
		{ -1, 3, 7, -1, -2, 6},
		27, 45, 36, 2, 21, 30, 40, 40,
		16, 18, 15, 0,  4, 12, 15, 18,
		0, 70, 30

		,{1,5,5,5,5,5,5,0,5,0,5,0,0,0,0,0}
		,A_INT
		,5,3,100,
		{5,3,2,2,4,0,0,0,0,0
		,2,4,3,3,4,3,3,3,2,2
		,1}
		,30,3,3,5,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{
#ifdef JP
		"y_̒_",
		"y_̒_",
#endif
		"Suwako",
		{ 1, 4, 7, 2, 3, 2},
		30, 40, 40, 3, 28, 30, 50, 45,
		18, 18, 18, 1,  5, 12, 18, 16,
		6, 120, 20

		//ǉlb
		,{2,0,0,0,0,0,0,0,0,5,5,5,5,0,0,0}
		,A_INT
		,5,3,100,
		{4,1,1,2,3,0,0,0,0,0
		,4,3,4,3,3,2,3,3,2,2
		,1}
		,20,1,3,5,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},

	{
#ifdef JP
		"mFzs",
		"mFzs",
#endif
		"Nue",
		{ 0, 2, 0, 1, 0, 0},
		27, 34, 32, 5, 24, 27, 55, 45,
		16, 16, 12, 1,  3, 18, 27, 15,
		5, 40, 40

		//ǉlb
		,{1,0,0,0,0,0,0,0,0,5,5,5,5,0,0,0}
		,A_INT
		,5,4,80,
		{4,2,2,2,3,0,0,0,0,0
		,3,3,3,3,3,4,5,4,1,1
		,1}
		,40,3,3,5,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{	
		"tP̂܂̂Ⴍ",
		"tP̂܂̂Ⴍ",
		"Seija",	
		{-3, 5, 5, 2, -2, -7},		
		32, 48, 25, 5, 28, 32, 35, 50,		
		18, 20,  8, 1,  5, 10,  12, 25,		
		0, 35, 80
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,2,120,		
		{1,1,1,1,3,0,0,0,0,0		
		,2,1,1,2,1,1,1,1,1,2		
		,2}
		,125,0,5,5,
		TRUE,FALSE,TRUE		
		,FALSE
		,3
	},
	{
		"MYސ_̉",
		"MYސ_̉",
		"Utsuho",
		{ 2, -3, 1, 0, 4, 2},
		14, 15, 36, 1, 15, 18, 55, 45,
		10, 10, 16, 0,  1,   6, 24, 16,
		7, 50, 90
		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{4,1,1,1,1,0,0,0,0,0
		,1,1,1,3,3,1,1,1,1,1
		,4}
		,25,0,1,1,
		FALSE,FALSE,TRUE
		,FALSE
		,5
	},
	{			
		"ÂA̖邢",		
		"ÂA̖邢",		
		"Yamame",		
				
		{1, -1, 0, 1, 0, -2},		
		32, 20, 25, 4, 28, 20, 45, 20,		
		10,  8, 12, 1, 1,  5, 18, 10,		
		3, 20, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,3,80,		
		{3,2,1,2,2,0,0,0,0,0		
		,3,2,2,3,2,3,2,2,1,1		
		,1}		
		,120,0,2,2,		
		FALSE,FALSE,TRUE		
		,TRUE
		,3
	},
	{
		"ܗd̎",
		"ܗd̎",
		"Ran",
		{4, 4, 4, 4, 4, 4},
		30, 36, 40, 4, 32, 40, 60, 60,
		10, 15, 12, 0,  3,  12, 20, 20,
		7, 30, 25

		,{3,4,4,4,4,4,4,4,4,4,4,4,4,0,0,0}
		,A_INT
		,5,4,70,
		{4,4,4,4,4,0,0,0,0,0
		,4,4,4,4,4,4,4,4,4,4
		,4}
		,65,4,4,4,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"y̍ōٔ",
		"y̍ōٔ",
		"Yamaxanadu",
		{ 2, 5, 9, 1, 5, 3},
		20, 38, 45, 2, 32, 20, 45, 40,
		12, 15, 20, 0,  9,  7,  16, 18,
		7, 100, 30

		,{1,0,0,0,0,4,4,4,4,0,0,0,0,0,0,0}
		,A_INT
		,4,3,100,
		{1,2,1,1,2,0,0,0,0,0
		,3,3,3,3,3,3,3,3,1,1
		,1}
		,18,0,5,5,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"zzV̖",
		"zzV̖",
		"Tenshi",
		{ 1, 0, 0, 1, 1, -1},
		25, 32, 36, 1, 20, 24, 45, 40,
		8,  12, 13 ,0, 2,   7, 26, 15,
		5, 30, 40

		//ǉlb
		,{1,0,0,0,0,4,4,4,4,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{4,2,2,2,2,0,0,0,0,0
		,4,5,4,3,3,3,2,2,2,2
		,2}
		,45,3,2,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"ؐl",
		"ؐl",
		"Meirin",
		{ 1, -1, 2, 2, 2, 1},
		22, 22, 30, 3, 24, 32, 55, 47,
		6,  11, 12, 0,  2,  12, 23, 17,
		6, 30, 65

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,4,80,
		{5,3,1,1,4,0,0,0,0,0
		,3,3,3,3,4,3,3,3,2,1
		,1}
		,65,0,3,3,
		FALSE,FALSE,TRUE
		,FALSE
		,3
	},
	{
		"nk̉̎iS",
		"nk̉̎iS",
		"Parsee",

		{ 0, 1, 2, 0, -1, -2},
		20, 24, 28, 2, 16, 20, 45, 30,
		12, 10,  9, 0,  4,   5,  15, 15,
		1, 20, 70

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,2,90,
		{2,1,1,2,2,0,0,0,0,0
		,3,3,3,3,3,3,2,2,2,2
		,1}
		,110,0,2,2,
		FALSE,FALSE,TRUE
		,TRUE
		,3
	},
	{			
#ifdef JP				
		"l̖",		
		"l̖",		
#endif				
		"Shinmyoumaru2",		
				
		{1, 0, 3, 2, 1, 3},		
		36, 48, 32, 3, 32, 45, 55, 32,		
		12, 24, 12, 1,  3, 16, 20, 16,		
		5, 30, 50		
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,6,3,100,		
		{4,1,4,2,4,0,0,0,0,0		
		,5,5,5,4,3,2,3,3,3,3		
		,1}		
		,67,0,5,5,	
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	

	{
		"镕y",
		"镕y",
		"Sumireko",

		{-2, 3, 3, 1, -1, 2},
		30, 20, 35, 4, 28, 16, 45, 55,
		12, 15, 11, 0,  5,  0, 22, 24,
		3, 40, 60

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,1,100,
		{4,2,2,1,5,0,0,0,0,0
		,2,1,1,2,2,2,2,2,1,2
		,3}
		,40,0,2,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"ꂵ",
		"ꂵ",
		"Ichirin",
		{ -1, 3, 5, 0, 0, 3},
		25, 26, 30, 1, 24, 36, 70, 24,
		7,  12, 11, 0,  2,  15, 16, 10,
		3, 65, 70

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,3,2,80,
		{4,1,1,1,2,0,0,0,0,0
		,1,1,1,2,2,1,1,1,1,1
		,1}
		,67,2,2,3,
		FALSE,FALSE,TRUE
		,FALSE
		,3
	},

	{			
		"H̐ľ`",		
		"H̐ľ`",	
		"Mokou",
		{-1, 1, 3, 1, -2, 0},
		39, 36, 30, 3, 30, 35, 64, 55,	
		11, 10, 10, 0,  2, 12, 18, 18,	
		0, 180, 70
		,{1,4,4,4,4,4,4,4,4,0,4,4,4,0,0,0}		
		,A_INT
		,5,1,100,	
		{4,4,4,4,4,0,0,0,0,0		
		,4,4,4,4,4,4,4,4,4,4
		,1}		
		,100,2,4,4,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{
		"Rƌ΂̌",
		"Rƌ΂̌",
		"Kanako",
		{ 1, 0, 2, -1, 2, 1},
		24, 25, 36, 2, 20, 24, 40, 40,
		10, 10, 12 ,0,  2,   7, 15, 12,
		3, 120, 20

		,{1,0,0,0,0,4,4,4,4,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{4,3,3,3,4,0,0,0,0,0
		,3,4,4,5,5,3,4,4,3,2
		,1}
		,20,4,4,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},

	{			
		"Ñ{̛",		
		"Ñ{̛",		
		"Futo",		
				
		{ -1, 2, 0, 2, -1, 1},		
		22, 34, 30, 1, 20, 24, 48, 56,		
		15, 12, 14, 1,  5,  8,  18,  22,		
		3, 30, 55
	
		,{1,3,3,0,0,3,0,0,4,0,0,0,0,0,0,0}	
		,A_INT
		,3,2,100,	
		{4,1,2,2,4,0,0,0,0,0	
		,2,2,2,2,2,1,1,1,4,3	
		,1}		
		,80,1,1,4,		
		TRUE,FALSE,TRUE		
		,FALSE
		,4
	},
	{
		"P̌",
		"P̌",
		"Sunnymilk",
		{ 2, 2, 1, 1, 1, 1},
		25, 20, 28, 0, 20, 24, 45, 25,
		9,  9,  8, 1,  2,  8, 16, 10,
		4, 10, 80

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,100,
		{3,3,1,1,2,0,0,0,0,0
		,2,3,2,3,3,3,2,2,1,1
		,1}
		,110,0,1,2,
		FALSE,FALSE,TRUE
		,TRUE
		,2
	},
	{
		"ÂȂ錎̌",
		"ÂȂ錎̌",
		"Lunarchild",
		{ 0, 3, 1, -2, 0, 1},
		20, 22, 30, 2, 30, 24, 40, 25,
		7,  11,  12, 1,  4,  8, 15, 10,
		3, 30, 60

		,{1,2,2,0,0,0,2,0,2,0,2,0,0,0,0,0}
		,A_INT
		,4,2,100,
		{1,2,1,1,1,0,0,0,0,0
		,3,2,2,2,1,1,2,1,1,2
		,1}
		,100,3,2,3,
		FALSE,FALSE,TRUE
		,TRUE
		,4
	},

	{
		"~蒍̌",
		"~蒍̌",
		"Starsaphire",
		{ 0, 2, 1, 2, -1, 1},
		28, 24, 30, 5, 23, 24, 37, 40,
		15, 12, 10, 0,  3,  8, 12, 16,
		2, 20, 70

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,1,100,
		{1,1,1,2,3,0,0,0,0,0
		,2,2,2,2,1,1,2,2,2,3
		,1}
		,120,0,3,2,
		FALSE,FALSE,TRUE
		,TRUE
		,3
	},
	{			
#ifdef JP				
		"F̐l`",		
		"F̐l`",		
#endif				
		"Alice",		
				
		{-1, 2, 1, 5, -1, 2},
		40, 42, 28, 3, 27, 18, 50, 20,		
		16, 15, 12, 0,  3, 10, 21, 10,		
		4, 70, 20	
				
		,{1,4,4,4,4,0,0,0,0,0,4,4,0,0,0,0}	
		,A_INT
		,1,1,100,	
		{2,1,1,1,4,0,0,0,0,0	
		,4,4,4,4,4,4,4,4,1,1		
		,1}		
		,65,1,4,5,		
		TRUE,FALSE,TRUE		
		,TRUE
		,4
	},

	{			
		"샔@CIXg",
		"샔@CIXg",	
		"Lunasa",
				
		{2, 4, 3, 2, 2, 3},
		20, 24, 32, 3, 18, 30, 47, 40,
		10, 12, 12, 0,  1, 12, 16, 16,
		3, 20, 40
				
		,{3,4,4,4,4,0,0,0,0,0,4,4,4,0,0,0}
		,A_INT
		,4,2,100,
		{2,2,2,2,2,0,0,0,0,0
		,3,3,2,2,4,3,4,2,2,2
		,1}	
		,100,2,3,3,	
		FALSE,FALSE,TRUE	
		,TRUE
		,4
	},
	{			
		"gyb^[",
		"gyb^[",	
		"Merlin",
				
		{3, 0, 2, 2, 4, 4},
		12, 20, 28, 1, 16, 32, 60, 36,
		10, 10, 10, 0,  0, 13, 27, 15,
		3, 20, 80 //HD7ɕ␳
				
		,{3,4,4,4,4,0,0,0,0,0,4,4,4,0,0,0}
		,A_INT
		,5,3,80,
		{4,2,1,1,2,0,0,0,0,0
		,3,3,2,4,4,4,3,3,1,1
		,1}	
		,100,0,1,1,	
		FALSE,FALSE,TRUE	
		,TRUE
		,4
	},
	{			
		"L[{[fBXg",
		"L[{[fBXg",	
		"Lyrica",
				
		{2, 3, 1, 5, 2, 3},
		30, 28, 30, 3, 24, 38, 50, 50,
		18, 15, 11, 1,  4, 15, 23, 20,
		3, 20, 50 
				
		,{3,4,4,4,4,0,0,0,0,0,4,4,4,0,0,0}
		,A_INT
		,5,2,100,
		{3,3,3,4,4,0,0,0,0,0
		,5,4,4,4,4,4,4,4,4,4
		,3}	
		,100,0,4,4,	
		FALSE,FALSE,TRUE	
		,TRUE
		,4
	},

	{			
		"n̗d",
		"n̗d",	
		"Clownpiece",
				
		{10, 0, 10, 10, 10, 10},
		30, 30, 36, 1, 24, 38, 65, 50,
		18, 15, 15, 0,  4, 15, 30, 20,
		1, 0, 20 
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,2,100,
		{2,1,1,1,2,0,0,0,0,0
		,3,3,2,4,4,3,3,4,1,1
		,1}	
		,75,0,1,3,	
		FALSE,FALSE,TRUE	
		,FALSE
		,3
	},
	{			
		"̎xz",		
		"̎xz",		
		"Doremy",	
				
		{ -2, 5, 6, 1, -1, 2},
		24, 32, 36, 5, 27, 40, 48, 40,		
		15, 16, 13, 0,  2, 12, 18, 14,	
		3, 50, 30
		
		,{1,4,4,4,5,0,0,0,0,4,4,4,4,0,0,0}	
		,A_INT
		,4,3,100,	
		{3,2,3,1,3,0,0,0,0,0
		,3,3,2,3,3,2,2,2,1,2
		,1}
		,45,2,3,4,	
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	{	
		"Âтi̕tr_",
		"Âтi̕tr_",
		"Benben",
		
		{ 1, 3, 2, -1, 0, 1},
		23, 28, 31, 2, 21, 32, 48, 36,	
		12, 16, 12, 0,  2,  10, 20,  8,	
		5, 20, 70
		
		,{1,5,4,4,4,3,3,3,4,4,5,5,4,0,0,0}
		,A_INT
		,4,3,90,	
		{4,2,1,1,2,0,0,0,0,0		
		,4,3,4,4,3,2,2,2,3,1		
		,2}		
		,67,3,4,3,		
		FALSE,FALSE,TRUE		
		,TRUE
		,4
	},

	{	
		"ÂтՂ̕tr_",
		"ÂтՂ̕tr_",
		"Yatsuhashi",
		
		{ 0, 4, 2, 0, -1, 1},
		28, 32, 31, 4, 24, 32, 42, 36,		
		15, 15, 12, 0,  3,  10, 14,  8,		
		2, 20, 70
		
		,{3,5,5,5,5,4,4,3,4,4,5,5,5,0,0,0}
		,A_INT
		,3,2,90,
		{2,1,1,1,2,0,0,0,0,0		
		,4,2,3,2,2,2,1,1,1,1		
		,2}		
		,67,3,4,4,		
		FALSE,FALSE,TRUE		
		,TRUE
		,4
	},

	{			
		"_",		
		"_",		
		"Hina",	
				
		{-1, 1, 3, -2, 2, -16},
		24, 24, 36, 6, 23, 10, 47, 20,
		16, 12, 16, 0, 3,  5, 18, 10,		
		5, 80, 100	
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,3,2,70,		
		{3,1,1,1,1,0,0,0,0,0	
		,3,2,2,3,2,2,2,4,1,1	
		,1}
		,125,0,4,4,	
		FALSE,FALSE,TRUE
		,FALSE
		,3
	},
	{
		"gق̃Ch",
		"gق̃Ch",
		"Sakuya",

		{ 0, 4, 2, 3, 2, 3},
		45, 25, 30, 5, 28, 40, 55, 64,
		16, 14, 11, 0,  6, 12, 24, 24,
		4, 75, 30

		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,6,2,70,
		{4,1,1,5,5,0,0,0,0,0
		,5,4,3,2,2,2,2,2,2,2
		,2}
		,38,1,4,4,
		FALSE,FALSE,TRUE
		,FALSE
		,4
	},
	{
		"̎Od",
		"̎Od",
		"Three-fairies",
		{ 3, 2, 1, 0, 2, 3},
		25, 24, 31, 2, 25, 24, 50, 45,
		9,  11, 10, 1,  5,  8, 20, 18,
		6, 90, 60

		,{1,2,2,0,0,0,2,0,2,0,2,0,0,0,0,0}
		,A_INT
		,4,4,100,
		{3,2,2,1,2,0,0,0,0,0
		,3,3,2,3,3,3,3,3,2,2
		,1}
		,50,1,2,3,
		FALSE,FALSE,TRUE
		,TRUE
		,4
	},
	{			
		"̃p[JbVjXg",
		"̃p[JbVjXg",	
		"Raiko",
				
		{4, 4, 2, 3, 3, 2},
		35, 36, 32, 2, 30, 30, 55, 40,
		14, 13, 12, 0,  3, 12, 27, 18,
		8, 40, 50
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,4,80,
		{4,1,1,5,3,0,0,0,0,0
		,4,3,3,5,5,4,3,4,2,2
		,3}
		,24,3,4,4,
		FALSE,FALSE,TRUE	
		,TRUE
		,4
	},

	
	{
		"K\ω",		
		"K\ω",		
		"Mamizou",		
				
		{ 2, 4, 4, 2, 3, 3},	
		36, 35, 32, 5, 32, 25, 55, 48,		
		15, 14, 12, 0,  4, 10, 21, 21,		
		6, 100, 20	
		
		,{1,0,0,0,0,0,0,0,0,5,5,5,5,0,0,0}
		,A_INT
		,5,2,80,
		{4,3,4,2,4,0,0,0,0,0
		,3,3,4,4,3,3,3,3,3,2
		,2}
		,30,0,4,5,	
		TRUE,FALSE,TRUE	
		,TRUE
		,5
	},	
	{
		"_B̎",
		"_B̎",
		"Yukari",
		{ 0, 4, 4, 1, 2, 3},
		27, 38, 36, 5, 30, 27, 50, 45,
		16, 16, 14, 1,  4, 18, 18, 15,
		7, 80, 30

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,5,2,80,
		{4,3,2,2,4,0,0,0,0,0
		,3,3,3,4,4,3,3,4,3,3
		,3}
		,14,3,4,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	{			
		"kF̃C[OB",	
		"kF̃C[OB",		
		"Ringo",		
				
		{ -1, 4, 2, -1, -1, 1},
		48, 27, 30, 4, 32, 28, 50, 50,		
		20, 12, 10, 0,  5, 10, 22, 22,		
		3, 10, 40
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,3,70,	
		{4,2,2,2,3,0,0,0,0,0		
		,4,3,3,3,3,2,3,3,2,3		
		,4}		
		,75,0,4,4,		
		FALSE,FALSE,TRUE		
		,FALSE
		,4
	},	
	{			
		"KF̃C[OB",
		"KF̃C[OB",	
		"Seiran",
		{ 1, 0, -1, 2, 1, -1},
		40, 20, 28, 3, 28, 28, 48, 60,		
		15, 10, 10, 0,  3, 12, 20, 27,		
		4, 25, 75	
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,5,4,70,	
		{3,2,1,1,3,0,0,0,0,0		
		,3,3,2,4,3,3,2,3,2,4		
		,5}
		,110,0,4,2,
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	
	{			
		"̓]",		
		"̓]",	
		"Eirin",
		{3, 9, 8, 4, 5, 4},
		45, 48, 45, 5, 40, 35, 60, 85,	
		16, 20, 16, 0,  5, 12, 24, 30,	
		7, 60, 15
		,{2,5,5,5,5,5,5,5,5,5,5,5,5,0,5,0}
		,A_INT
		,5,4,80,
		{3,4,4,4,4,0,0,0,0,0	
		,4,4,4,4,4,4,4,4,5,4
		,4}
		,50,2,5,5,
		TRUE,FALSE,TRUE		
		,FALSE
		,5
	},
	{
		"iƐ{k̍ߐl",
		"iƐ{k̍ߐl",
		"Kaguya",
		{2, 2, 3, -2, 0, 9},
		24, 40, 36, 2, 27, 20, 45, 45,
		8, 20, 12, 0,  2, 6, 16, 16,
		5, 100, 30
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,1,100,
		{1,2,2,2,4,0,0,0,0,0
		,2,2,2,3,3,2,3,3,3,2
		,2}		
		,100,1,4,5,
		FALSE,FALSE,TRUE		
		,FALSE
		,4
	},
	{
		"Ђ炷_",
		"Ђ炷_",
		"Sagume",
		{ 0, 3, 2, -2, -1, 2},
		23, 48, 30, 5, 27, 30, 16, 45,
		13, 18, 12, 0,  4, 12, 8, 18,
		0, 30, 20

		//ǉlb
		,{1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6}
		,A_INT
		,3,1,100,
		{1,3,1,1,3,0,0,0,0,0
		,1,1,1,1,1,1,1,1,2,2
		,3}
		,50,1,4,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	///v1.1.12
	{			
//H
		"̖hq",		
		"̖hq",		
		"Reisen2",		
				
		{0, 1, -1, 2, 0, -1},
		22, 20, 27, 3, 24, 30, 45, 50,
		11, 10, 10, 0,  2, 10, 16, 21,
		4, 20, 50
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,2,80,		
		{2,2,1,2,3,0,0,0,0,0		
		,3,2,2,4,3,3,3,2,2,3		
		,4}	
		,142,0,2,2,		
		FALSE,FALSE,TRUE		
		,FALSE
		,2
	},	
	///v1.1.13
	{
		"CƎRq̕P",
		"CƎRq̕P",
		"Toyohime",

		{ 0, 4, 3, 0, 1, 3},
		28, 40, 32, 5,  32, 30, 45, 45,
		10, 18, 11, 0,   4, 10, 16, 18,
		4, 70, 3

		,{3,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0}
		,A_INT
		,3,1,70,
		{2,2,1,1,3,0,0,0,0,0
		,2,2,2,2,2,2,2,2,2,2
		,2}
		,16,0,3,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	//v1.1.14
	{
		"_̈˂߂̕P",
		"_̈˂߂̕P",
		"Yorihime",
		{ 2, 4, 2, 2, 2, 1},
		33, 36, 33, 3,  30, 30, 80, 45,
		11, 15, 12, 0,   3, 10, 27, 18,
		7, 70, 30

		,{1,0,0,0,0,4,4,5,4,0,0,0,0,0,0,0}
		,A_INT
		,6,2,70,
		{4,3,3,3,3,0,0,0,0,0
		,4,4,5,3,3,3,3,3,3,3
		,4}
		,16,0,5,4,
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	//v1.1.15
	{
		"(̑)",
		"(̑)",
		"Junko",
		{ 2, 6, 9, 1, 4, 2},
		80, 32, 60, 2, 15, 30, 45, 45,
		30, 16, 20, 0,  2, 12, 24, 24,
		7, 120, 20

		//ǉlb
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
		,A_INT
		,4,3,100,
		{3,1,1,3,2,0,0,0,0,0
		,3,3,3,3,3,3,3,3,2,2
		,1}
		,18,1,4,4,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	{
		"n̏_",
		"n̏_",
		"Hecatia",
		{ 1, 9, 9, 2, 3, 4},
		30, 50, 50, 3, 27, 24, 48, 50,
		23, 20, 18, 0,  5, 12, 23, 23,
		7, 120, 20

		//ǉlb
		,{2,5,5,5,5,5,5,5,5,5,5,5,5,0,0,0}
		,A_INT
		,5,2,100,
		{3,3,3,3,3,0,0,0,0,0
		,3,3,2,4,4,2,2,2,3,3
		,1}
		,6,3,4,5,
		TRUE,FALSE,TRUE
		,FALSE
		,5
	},
	///v1.1.33
	{			
		"̊ւ𒴂RW",		
		"̊ւ𒴂RW",		
		"Nemuno",		
				
		{0, 2, 2, 1, 0, 1},
		20, 20, 27, 2, 28, 26, 50, 48,
		10, 11, 10, 0,  4, 10, 16, 18,
		3, 30, 40
				
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}		
		,A_INT
		,4,4,80,		
		{3,2,1,2,3,0,0,0,0,0		
		,4,3,4,4,4,5,2,2,2,2		
		,1}	
		,80,0,4,4,		
		FALSE,TRUE,TRUE		
		,FALSE
		,3
	},	
	//v1.1.33
	{			
		"_ɐS_b",		
		"_ɐS_b",		
		"Aunn",		
				
		{1, 2, 4, -1, 1, 2},
		18, 22, 36, 5, 32, 26, 55, 45,
		10, 12, 12, 0,  5, 10, 22, 16,
		6, 35, 60
				
		,{1,0,0,0,0,2,2,2,2,0,0,0,0,0,0,0}		
		,A_INT
		,4,3,80,		
		{4,3,1,2,3,0,0,0,0,0		
		,3,2,2,3,3,2,2,2,2,2		
		,1}	
		,80,0,2,3,		
		FALSE,FALSE,TRUE		
		,FALSE
		,3
	},	

	//v1.1.34
	{			
		"XŐ瑂@n",		
		"XŐ瑂@n",		
		"Narumi",	
				
		{ -2, 2, 3, -1, 0, 1},
		21, 27, 32, 1, 26, 25, 36, 30,		
		10, 12, 15, 0,  3,  7, 12, 10,	
		2, 50, 40
		
		,{3,5,5,5,5,5,6,5,5,0,0,0,0,0,0,0}	
		,A_INT
		,3,2,100,	
		{1,2,1,1,1,0,0,0,0,0
		,1,1,2,3,4,1,1,1,1,1
		,1}
		,80,3,4,5,	
		TRUE,FALSE,TRUE
		,FALSE
		,4
	},
	//@
	{			
		"Ǌ̃rutBA",		
		"Ǌ̃rutBA",		
		"Kosuzu",	
				
		{ -2, 1, 0, 0, -1, 2},
		16, 10, 20, 3, 27, 20, 30, 24,		
		 5, 16, 10, 0,  4,  7, 15, 12,	
		2, 20, 50
		
		,{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}	
		,A_INT
		,3,1,100,	
		{1,2,1,1,1,0,0,0,0,0
		,2,1,1,2,3,1,1,2,1,1
		,1}
		,200,3,1,4,	
		FALSE,FALSE,TRUE
		,FALSE
		,2
	},
	{
		"_ɋ߂Â̗d",
		"_ɋ߂Â̗d",
		"Eternitylarva",
		{ -2, -2, -1, -1, 0, 0 },
		12, 10, 20, 0, 15, 16, 20, 20,
		16, 14, 14, 1,  5, 12, 20, 20,
		2, -50, 60

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,3,1,100,
			{ 2,1,1,1,3,0,0,0,0,0
			,3,2,2,2,2,2,2,2,2,2
			,1 }
			,135,0,1,2,
			FALSE,FALSE,TRUE
			,TRUE
			,2
	},

	{
		"댯obN_T[",
		"댯obN_T[",
		"Mai",

		{ 1, 0, 0, 0, 1, 1 },
		23, 27, 30, 1, 25, 40, 50, 45,
		15, 12, 12, 0,  3, 12, 25, 15,
		3, 55, 25

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,4,2,100,
			{ 2,2,1,1,1,0,0,0,0,0
			,2,2,2,2,4,2,5,4,1,1
			,1 }
			,70,2,4,3,
			FALSE,FALSE,TRUE
			,FALSE
			,3
	},
	{
		"댯obN_T[",
		"댯obN_T[",
		"Satono",

		{ 0, 1, 1, 0, 0, 1 },
		23, 40, 30, 4, 25, 40, 45, 45,
		15, 12, 12, 0,  3, 12, 15, 15,
		3, 55, 25

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,3,2,100,
			{ 2,2,1,1,1,0,0,0,0,0
			,3,2,2,2,2,3,2,3,1,1
			,1 }
			,70,2,4,3,
			FALSE,FALSE,TRUE
			,FALSE
			,4
	},
	{
		"CȂn̗d",
		"CȂn̗d",
		"VFS_Clownpiece",

		{ 4, 1, 1, 4, 4, 1},
		16, 20, 32, 3, 20, 32, 45, 40,
		10, 12, 12, 0,  2, 10, 20, 16,
		5, 0, 70

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,4,2,100,
			{ 2,1,1,1,2,0,0,0,0,0
			,3,3,2,4,4,3,3,4,1,1
			,1 }
			,75,0,1,3,
			FALSE,FALSE,TRUE
			,TRUE
			,3
	},

	{
#ifdef JP				
		"ŋň̑oq̖",
		"ŋň̑oq̖",
#endif				
		"Jyoon",

		{ 3, 2, -1, 2, 2, -4 },
		32, 27, 40, 3, 32, 40, 60, 45,
		12, 12, 15, 0,  5, 14, 25, 18,
		6, 45, 40

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,4,2,70,
			{ 5,1,1,1,4,0,0,0,0,0
			,2,2,2,3,2,2,2,2,2,2
			,2 }
			,35,0,4,4,
			FALSE,FALSE,TRUE
			,FALSE
			,3
	},
	{
#ifdef JP				
		"ŋň̑oq̎o",
		"ŋň̑oq̎o",
#endif				
		"Shion",

		{ 0, 0, 0, 0, 0, -9 },
		10, 22, 44, 1, 10, 20, 45, 45,
		10, 10, 18, 1,  1, 10, 15, 15,
		2, 80, 90

		,{ 1,0,3,0,0,3,0,0,0,3,3,3,3,0,0,0 }
			,A_INT
			,3,1,70,
			{ 3,2,1,1,3,0,0,0,0,0
			,2,2,2,2,2,2,2,2,2,2
			,2 }
			,160,0,4,4,
			FALSE,FALSE,TRUE
			,FALSE
			,5
	},
	{
#ifdef JP				
		"ɂ̐Δ_",
		"ɂ̐Δ_",
#endif				
		"Okina",

		{ 2, 3, -1, 0, 2, 0 },
		36, 27, 40, 2, 30, 40, 52, 60,
		12, 12, 16, 3,  4, 14, 22, 30,
		5, 40, 50

		,{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 }
			,A_INT
			,5,4,70,
			{ 4,3,1,3,3,0,0,0,0,0
			,4,4,4,3,3,3,4,4,3,4
			,5 }
			,64,0,4,2,
			TRUE,FALSE,TRUE
			,FALSE
			,3
	},




};

///seikaku
const player_seikaku seikaku_info[MAX_SEIKAKU] =
{
	{
#ifdef JP
		"ɂ߂ĕ",
		"ɂ߂ĕ",
#endif
		"Ordinary",
		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  0,  0,  0,  0,
		0, 1
		,FALSE
	},

	{
#ifdef JP
		"͎",
		"͎",
#endif
		"Mighty",
		{  2,  -2,  -1,  0,  1,  0 },
		-5,  -5,  -3,  -1,  -2,  -2,  10,  0,
		1, 0
		,FALSE
	},

	{
#ifdef JP
		"؂҂",
		"",
#endif
		"Shrewd",
		{  -2,  2,  1,  0,  -1,  0 },
		3,  8,  2,  0,  3,  5,  -8,  -5,
		-1, 0
		,FALSE
	},

	{
#ifdef JP
		"̂񂫂",
		"̂񂫂",
#endif
		"Pious",
		{  0,  -1,  2,  -1,  1,  1 },
		-5,  2,  6,  -1,  0,  -2,  -3,  -6,
		0, 0
		,FALSE
	},

	{
#ifdef JP
		"΂",
		"΂",
#endif
		"Nimble",
		{  -1,  1,  -1,  2,  -1,  -1 },
		7,  2,  -1,  1,  5,  5,  0,  10,
		0, 0
		,FALSE
	},

	{
#ifdef JP
		"m炸",
		"Ă",
#endif
		"Fearless",
		{  2,  1,  1,  -1,  -1,  0 },
		-5,  5,  -2,  0,  2,  -2,  10,  10,
		-1, 0
		,FALSE
	},

	{
#ifdef JP
		"gK[nbs[",
		"gK[nbs[",
#endif
		"Combat",
		{  0,  4,  4,  2,  -4,  5 },
		-10,  10, -10,  -3,  -5,  10,  5, 50,
		-3, 0
		,FALSE
	},

	{
#ifdef JP
		"_fB",
		"n",
#endif
		"Elegant",
		{ -1,  1,  0,  1,  -1,  3 },
		3,  3, 0, -1, 3, 3, -5, 5,
		0, 0
		,FALSE
	},

	{
#ifdef JP
		"Lm{[[",
		"Lm{[[",
#endif
		"Cannon-Baller",
		{  1,  1,  1,  1,  1,  3 },
		10,  5,  3,  0,  4,  2,  10,  10,
		0, 0
		,FALSE
	},

	{
#ifdef JP
		"bL[}",
		"bL[K[",
#endif
		"Lucky",
		{  -2,  -2,  -2,  -2,  -2,  2 },
		10,  7,  3,  2, 10,  8,  15,  15,
		0, 1
		,FALSE
	},

	{
#ifdef JP
		"܂Â悢",
		"܂Â悢",
#endif
		"Patient",
		{  -1,  -1,  1,  -2,  2,  0 },
		-5,  -3,  3,  1,  0,  -3,  -6,  -6,
		1, 0
		,FALSE
	},


	{
#ifdef JP
		"",
		"",
#endif
		"Munchkin",
		{ 10,  10,  10,  10,  10,  10 },
		 20, 40, 30, 10, 40, 40,  80, 80,
		 15, 1
		,FALSE
	},
	//v1.1.32 ɂ̓`ḿuĂvȂǂ̓Ȑiݒ肷B
	//p_ptr->pseikakuSEIKAKU_SPECIAL(12)̂ƂAap_ptrɑ΂seikaku_info[]łȂseikaku_special_info[]ւ̃|C^B
	{
		"[ꐫi]",
		"[ꐫi]",
		"Collector",
		{ 0, 0, 0, 0, 0, 0 },
		3, 3, -3, -1, 3, 0, 0, 0,
		0, 1
		,TRUE
	},

	{
		"C",
		"C",
		"Berserk",
		{ 5, -5, -5, 5, 5, -5 },
		-50, -50, -50, -10, -50, 10, 150, 0,
		10, 0
		,FALSE
	},


};



/*:::@ɂꎞI푰ϗep푰e[u*/
///mod140325 ϐ_~[lǉ@剻ǉ
const player_race mimic_info[] =
{
	{
#ifdef JP
		"[W`]",
#endif
		"Default",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  0,  10,  0,  0,
		10,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x000000, //̐lMIMIC_FLAGƂĎgĂ炵
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[]",
#endif
		"[Demon]",

		{  5,  3,  2,  3,  4,  -6 },
		-5,  18, 20, -2,  3,  10, 40, 20,
		//v1.1.32 HD1215
		15,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		5,
		0x000003,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[]",
#endif
		"[Demon lord]",

		{  20,  20,  20,  20,  20,  20 },
		20,  20, 25, -2,  3,  10, 70, 40,
		//v1.1.32 HD1418
		18,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		20,
		0x000003,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[zS]",
#endif
		"[Vampire]",

		{ 4, 4, 1, 1, 2, 3 },
		6, 12, 8, 6, 2, 12, 30, 20,
		//v1.1.32 HD1115
		15,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		5,
		0x000005,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[剻]",
#endif
		"[Greater]",

		{ 20, 0, 0, -5, 20, 0 },
		-30, 0, 20, -20, -10, -20, 70, 0,
		36,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x0004D8,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[bω]",
#endif
		"[Beast]",

		{ 10, -10, -10, 10, 10, -10 },
		-80, -50, 10, 3, 10, 20, 50, -20,
		27,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		20,
		0x0004F8,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[XC]",
#endif
		"[Slime]",

		{ 0, -15, -15, 0, 20, -10 },
		30, -50, 30, 10, -20, -20, 30, -30,
		20,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x0005F0,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[H]",
#endif
		"[Marisa]",

		{ 0, 0, 0, 0, 0, 0 },
		10, 5, 5, 0, 10, 10, 0, 0,
		10,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x000080,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},

	{
#ifdef JP
		"[ω]",
#endif
		"[Mist]",

		{ -5, 0, 0, -2, -2, -2 },
		30, -10,  0, 15, -5, 20, -30, -15,
		7,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x000080,//RȊOȂ
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[ω]",
#endif
		"[Dragon]",

		{ 20, 5, 5, 5, 20,  0 },
		-50, -50, 30, -10, -10, 10, 70, -20,
		0,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		25,
		0x0006F8,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
#ifdef JP
		"[L`]",
#endif
		"[Cat]",

		{ -3, -2, -2, 5, -2,  2 },
		-20, -20, 0, 15, 10, 20, 10, -30,
		7,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		10,
		0x0005F0,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},

	{
		"[̕s]",
		"[Undefined]",

		{ 8, 3, 1, 6, 8, 2 },
		2, 10, 30, 3, 18, 10, 60, 20,
		20,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		20,
		0x000000,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	{
		"[^]",
		"Kobito",

		{ -5, 0, 0, 0, -4, 0 },
		20, 12, 0, 30, 30, 50, -20, -5,
		5, 50,
		100, 35,
		72,  6, 50, 5,
		66,  4, 50, 5,
		0,
		0x000000,
		{0,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5},//realm
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(0L),
	},
	//ϐg1 ˌAAAύXARAǉUs
	{
		"[ϐg(l^)]",
		"Metamorpho1",

		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  0,  10,  0,  0,
		10,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x0001B0, 
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	//ϐg2 1ɉ@Ɩs
	{
		"[ϐg()]",
		"Metamorpho2",

		{  0, -4, -2,  0,  0,  -3 },
		-10, -10,  0,  0, -5,  10,  0,  0,
		10,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x0005F0, 
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	//ϐg3 2ɉ剻tOt^
	{
		"[ϐg()]",
		"Metamorpho3",

		{ 10, -2, 0,  0,  5, -5 },
		-30, -30,  0,  0,  -10,  10,  0,  0,
		10,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		0,
		0x0005F8, 
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},

	{
#ifdef JP
		"[̉]",
#endif
		"[Ghost]",

		{ 2, 2, 2, 2, 2, 7 },
		6, 12, 8, 5, 10, 12, 20, 20,
		12,  0,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		7,
		0x000005,
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},
	//RAǉUs
	{
		"[G̎׋S]",
		"Hyakki",

		{  6,  0,  0,  6,  6,  -20 },
		0, 10, 30, -10, 0,  10, 50, 30,
		18,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		7,
		0x000182, 
		{ 0, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5},
		100,
		FALSE,FALSE,FALSE,FALSE
		,'p',(0L),
	},

	{
		"[VE̐_H]",
		"Deity",

		{ 0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  10,  0,  10,  10,
		12,  100,
		0,  0,
		0,  0, 0, 0,
		0,  0, 0, 0,
		8,
		0x000000,
		{ 0, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 5 },
		100,//scoremul
		FALSE,FALSE,FALSE,FALSE//FLAG
		,'p',(0L),
	},


};


//@̓e
//ԍ͎i(Ԗ)pŁAcheck_book_realm()̂Ƃ3ڈȍ~ǂ߂Ȃ

magic_type spell_base_info[MAX_MAGIC][32][6] =
{
	{
	/*:::f1*/
	{{ 3,  2,22,  0},{ 7,  2,25,  5},{ 5,  2,25,  5},{ 3,  2,23,  5},{ 1,  1,20,  5},{ 1,  1,15,  5},},//}WbN~TC
	{{ 4,  3,25,  0},{ 8,  4,27,  5},{ 6,  3,27,  5},{ 3,  3,25,  5},{ 2,  3,22,  5},{ 1,  1,18,  5},},//M
	{{ 8,  6,30,  0},{11,  9,30,  5},{ 8,  8,30,  5},{ 5,  5,30,  5},{ 4,  3,25,  5},{ 3,  3,20,  5},},//T_[E{g
	{{10,  8,35,  0},{12, 12,35,  6},{10, 10,35,  6},{ 6,  6,34,  6},{ 5,  4,30,  6},{ 4,  3,25,  6},},//ACXE{g
	{{13, 10,40,  0},{99,  0, 0,  0},{12, 11,40,  8},{ 9,  7,37,  8},{ 7,  5,35,  8},{ 6,  4,30,  8},},//AVbhE{g
	{{15, 12,45,  0},{18, 18,45, 10},{15, 13,45, 10},{12,  9,43, 10},{ 9,  7,40, 10},{ 8,  6,35, 10},},//t@CAE{g
	{{18, 16,45,  0},{20, 20,48, 20},{18, 17,48, 20},{15, 12,48, 20},{12, 10,40, 20},{11,  8,35, 20},},//V
	{{22, 20,50,  0},{24, 22,50, 40},{22, 20,50, 40},{19, 18,50, 40},{16, 15,43, 40},{13, 10,38, 40},},//xՒf
	/*:::f2*/
	{{19, 12,40,  0},{20, 18,45, 20},{18, 15,45, 20},{16, 12,40, 20},{12, 11,37, 20},{11,  9,32, 20},},//ϓd
	{{22, 12,40,  0},{22, 18,45, 20},{20, 15,45, 20},{18, 12,40, 20},{13, 11,37, 20},{12,  9,32, 20},},//ώ_
	{{27, 20,55,  0},{99,  0, 0,  0},{25, 23,58, 50},{21, 19,55, 50},{16, 16,65, 50},{14, 13,60, 50},},//EBhJb^[
	{{30, 27,60,  0},{28, 32,65, 60},{26, 29,60, 60},{24, 26,60, 60},{18, 20,55, 60},{16, 18,45, 60},},//gl
	{{32, 18,55,  0},{32, 24,55, 60},{28, 21,55, 60},{26, 18,50, 60},{20, 14,45, 60},{18, 12,40, 60},},//T_[E{[
	{{34, 21,55,  0},{34, 27,60, 65},{30, 24,60, 65},{28, 20,55, 65},{22, 16,50, 65},{20, 14,45, 65},},//ACXE{[
	{{36, 22,60,  0},{99,  0, 0,  0},{32, 25,65, 70},{30, 21,60, 70},{24, 18,55, 70},{22, 16,50, 70},},//AVbhE{[
	{{40, 25,70,  0},{40, 32,75, 80},{37, 28,75, 80},{35, 24,70, 80},{28, 22,65, 80},{25, 20,60, 80},},//t@CAE{[
	/*:::f3*/
	{{99,  0, 0,  0},{99,  0, 0,  0},{26, 32,75, 80},{23, 28,70, 80},{20, 25,65, 80},{18, 21,60, 80},},//̊Z
	{{99,  0, 0,  0},{33, 36,60,100},{29, 33,50,100},{25, 29,45,100},{23, 25,40,100},{20, 22,30,100},},//Ƃ
	{{99,  0, 0,  0},{36, 41,75,100},{32, 38,70,100},{28, 36,65,100},{25, 32,55,100},{23, 27,40,100},},//G^
	{{99,  0, 0,  0},{99,  0, 0,  0},{35, 36,70,120},{30, 35,65,120},{27, 30,60,120},{25, 25,50,120},},//fϐ
	{{99,  0, 0,  0},{38, 40,70,100},{35, 35,65,100},{32, 31,60,100},{30, 27,55,100},{28, 24,50,100},},//X̑
	{{99,  0, 0,  0},{99,  0, 0,  0},{38, 48,75,120},{35, 45,70,120},{33, 40,65,120},{30, 34,60,120},},//_̉J
	{{99,  0, 0,  0},{44, 45,85,140},{42, 39,80,140},{40, 36,75,140},{36, 32,70,140},{32, 25,65,140},},//̗
	{{99,  0, 0,  0},{46, 48,75,180},{45, 40,70,180},{42, 35,65,180},{40, 30,60,180},{37, 26,50,180},},//̘r
	/*:::f4*/
	{{99,  0, 0,  0},{35, 30,80, 75},{30, 25,70, 75},{24, 21,55, 75},{20, 18,50, 75},{16, 15,40, 75},},//͏
	{{99,  0, 0,  0},{99,  0, 0,  0},{37, 32,80,120},{32, 28,75,120},{28, 25,70,120},{25, 23,60,120},},//q
	{{99,  0, 0,  0},{48, 70,85,150},{45, 60,80,150},{40, 55,70,150},{36, 50,60,150},{33, 43,55,150},},//Εǐ
	{{99,  0, 0,  0},{50, 80,90,150},{47, 75,88,150},{43, 67,85,150},{40, 60,80,150},{37, 55,75,150},},//Ηx
	{{99,  0, 0,  0},{99,  0, 0,  0},{50,100,95,180},{46, 90,90,180},{43, 75,85,180},{40, 68,80,180},},//Ag~bNC
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{48, 50,99,250},{45, 40,99,250},{41, 35,85,250},},//GNT[
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{49,145,85,200},{46,130,80,200},{43,115,70,200},},//lfƉu
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{50, 92,95,250},{48, 84,90,250},{45, 75,72,250},},//G[eXgCN
	},
	{	
	/*:::\1*/
	{{ 3,  3,25,  0},{ 7,  3,25,  5},{ 5,  2,25,  5},{ 3,  2,20,  5},{ 1,  1,20,  5},{ 1,  1,20,  5},},//zTm
	{{ 4,  5,25,  0},{ 8,  6,25,  5},{ 6,  4,25,  5},{ 4,  3,20,  5},{ 1,  2,20,  5},{ 1,  1,20,  5},},//gbvm
	{{ 5,  8,25,  0},{10,  8,35,  5},{ 7,  6,30,  5},{ 5,  5,25,  5},{ 2,  3,20,  5},{ 1,  2,20,  5},},//X^[m
	{{ 8, 10,35,  0},{11, 10,40,  8},{ 9,  8,35,  8},{ 7,  7,30,  8},{ 3,  5,30,  8},{ 3,  4,25,  8},},//|
	{{11, 12,25,  0},{13, 12,30, 10},{10, 10,25, 10},{ 8,  9,20, 10},{ 5,  7,20, 10},{ 4,  6,20, 10},},//hAEKim
	{{16, 18,30,  0},{15, 18,35, 12},{12, 16,30, 12},{10, 14,25, 12},{ 6, 10,20, 12},{ 5,  9,20, 12},},//ACem
	{{20, 18,40,  0},{16, 20,45, 18},{14, 17,40, 18},{12, 15,40, 18},{ 9, 12,35, 18},{ 7, 10,30, 18},},//|̃rW
	{{22, 18,40,  0},{19, 19,40, 20},{17, 17,35, 20},{15, 15,35, 20},{12, 12,30, 20},{10, 10,25, 20},},//Ӓ
	/*:::\2*/
	{{25, 16,55,  0},{18, 21,55, 25},{15, 19,55, 25},{13, 17,50, 25},{10, 14,45, 25},{ 8, 12,40, 25},},//ӊm
	{{27, 20,50,  0},{20, 26,50, 25},{18, 23,45, 25},{16, 20,40, 25},{13, 15,35, 25},{10, 13,30, 25},},//
	{{30, 27,60,  0},{24, 36,55, 45},{21, 32,55, 45},{18, 28,50, 45},{16, 24,45, 45},{14, 20,40, 45},},//̋P
	{{32, 25,80,  0},{28, 34,80, 35},{26, 30,80, 35},{24, 27,80, 35},{20, 23,70, 35},{17, 20,60, 35},},//_
	{{33, 20,50,  0},{30, 18,50, 45},{28, 16,50, 45},{26, 14,45, 45},{23, 12,40, 45},{20, 10,35, 45},},//o
	{{35, 45,50,  0},{33, 43,50, 55},{30, 40,50, 55},{28, 35,45, 55},{25, 32,40, 55},{23, 30,35, 55},},//Cm
	{{39, 25,70,  0},{36, 29,75, 35},{33, 27,70, 35},{30, 24,65, 35},{27, 21,60, 35},{25, 18,50, 35},},//jł̃rW
	{{44, 28,70,  0},{39, 36,70, 65},{37, 30,70, 65},{35, 27,65, 65},{31, 24,60, 65},{27, 21,55, 65},},//Sm
	/*:::\3*/
	{{99,  1,20,  5},{32, 50,50, 60},{30, 45,45, 60},{26, 40,40, 60},{23, 30,30, 60},{20, 27,26, 60},},//^bg肢
	{{99,  1,20,  5},{99, 0,  0,  0},{32, 60,50, 70},{30, 55,45, 70},{27, 50,40, 70},{24, 44,33, 70},},//ʂȋGm
	{{99,  1,20,  5},{38, 41,60, 70},{35, 38,60, 70},{32, 35,60, 70},{30, 30,55, 70},{26, 25,47, 70},},//*Ӓ*
	{{99,  1,20,  5},{40, 35,80, 85},{38, 33,75, 85},{36, 30,70, 85},{33, 25,60, 85},{30, 20,54, 85},},//ȕ
	{{99,  1,20,  5},{42, 40,75, 90},{39, 35,75, 90},{37, 32,70, 90},{35, 28,65, 90},{32, 25,59, 90},},//JIXϐ
	{{99,  1,20,  5},{99,  0, 0,  0},{43, 47,75,100},{40, 41,70,100},{38, 36,60,100},{35, 32,54,100},},//*X^[m*
	{{99,  1,20,  5},{99,  0, 0,  0},{46, 65,85,125},{44, 57,80,125},{41, 50,70,125},{38, 45,65,125},},//\m
	{{99,  1,20,  5},{50, 95,95,175},{48, 90,95,175},{46, 85,90,175},{43, 72,80,175},{40, 64,72,175},},//`̕im
	/*:::\4*/
	{{99,  1,20,  5},{34, 40,70, 75},{32, 37,70, 70},{29, 32,65, 70},{27, 27,60, 70},{24, 24,55, 70},},//qC̓
	{{99,  1,20,  5},{45, 72,90, 90},{42, 60,85, 90},{38, 52,80, 90},{33, 45,75, 90},{30, 38,65, 90},},//*痢*
	{{99,  1,20,  5},{48, 43,90,100},{45, 40,90,100},{40, 35,90,100},{38, 30,85,100},{35, 27,80,100},},//ʍ
	{{99,  1,20,  5},{99,  1,20,  5},{99,  0, 0,  0},{43, 32,65,120},{40, 27,50,120},{36, 24,45,120},},//VhEVtg
	{{99,  1,20,  5},{99,  1,20,  5},{47, 90,90,160},{45, 80,85,160},{42, 72,75,160},{40, 64,65,160},},//jł̐鍐
	{{99,  1,20,  5},{99,  1,20,  5},{50, 86,85,200},{47, 77,85,200},{45, 65,80,200},{43, 58,70,200},},//K^̃JjY
	{{99,  1,20,  5},{99,  1,20,  5},{99,  0, 0,  0},{50, 85,90,230},{47, 76,85,230},{45, 67,80,230},},//ʏC
	{{99,  1,20,  5},{99,  1,20,  5},{99,  0, 0,  0},{50,150,99,250},{49,120,99,250},{46,105,75,250},},//AJVbNR[h
	},
	{
	/*:::t^1*/
	{{ 3,  3,25,  0},{ 7,  4,30,  5},{ 5,  3,30,  5},{ 3,  3,25,  5},{ 1,  2,20,  5},{ 1,  2,20,  5},},//@̎{@
	{{ 6,  4,35,  0},{ 9,  6,40,  5},{ 6,  5,40,  5},{ 4,  4,35,  5},{ 1,  3,30,  5},{ 1,  2,25,  5},},//@̜W@
	{{ 9,  6,30,  0},{10,  9,35,  5},{ 7,  7,35,  5},{ 5,  5,30,  5},{ 3,  3,25,  5},{ 2,  2,20,  5},},//񕜗͋
	{{12,  7,35,  0},{12, 10,40,  8},{ 9,  8,40,  8},{ 7,  7,35,  8},{ 5,  5,30,  8},{ 4,  4,25,  8},},//gbv/hAj
	{{15, 11,40,  0},{99,  1,20, 10},{12, 12,45, 10},{ 9, 10,40, 10},{ 7,  8,35, 10},{ 6,  7,30, 10},},//͋@
	{{18, 15,35,  0},{15, 20,40, 15},{13, 17,40, 15},{10, 14,35, 15},{ 8, 12,30, 15},{ 7, 10,25, 15},},//󕠏[@
	{{20, 13,55,  0},{18, 18,60, 20},{15, 16,60, 20},{12, 12,55, 20},{10, 10,50, 20},{ 8,  8,45, 20},},//ϔMϊ@
	{{24, 20,60,  0},{21, 22,65, 20},{18, 20,65, 20},{15, 17,60, 20},{13, 15,55, 20},{10, 12,50, 20},},//ؗ͑@
	/*:::t^2*/
	{{24, 24,60,  0},{18, 30,60, 25},{16, 27,60, 25},{14, 24,58, 25},{12, 21,55, 25},{10, 18,50, 25},},//@wݒu@
	{{30, 12,45,  0},{20, 18,50, 20},{18, 15,45, 20},{16, 12,45, 20},{14, 10,40, 20},{12,  9,35, 20},},//ϓd@
	{{30, 12,45,  0},{20, 18,50, 20},{18, 15,45, 20},{16, 12,45, 20},{14, 10,40, 20},{12,  9,35, 20},},//ώ_
	{{35, 25,55,  0},{24, 30,70, 35},{21, 27,60, 35},{18, 24,55, 35},{16, 20,50, 35},{14, 18,45, 35},},//m
	{{38, 22,75,  0},{27, 30,90, 50},{25, 26,80, 50},{22, 23,75, 50},{18, 18,70, 50},{16, 16,65, 50},},//͏[U
	{{42, 26,65,  0},{99,  1,20,  5},{30, 30,70, 40},{26, 27,65, 40},{22, 24,60, 40},{20, 22,55, 40},},//Ӌ}@
	{{45, 74,85,  0},{36, 90,90, 80},{33, 80,90, 80},{30, 72,85, 80},{25, 60,80, 80},{23, 54,70, 80},},//틭@
	{{45, 79,85,  0},{36,100,90, 80},{33, 88,90, 80},{30, 80,85, 80},{25, 70,80, 80},{23, 72,70, 80},},//h
	/*:::t^3*/
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{24, 60,85, 60},{22, 51,80, 60},{20, 43,75, 60},},//S[쐬
	{{99,  1,20,  5},{34, 30,67, 85},{31, 25,63, 85},{28, 21,60, 85},{25, 18,55, 85},{23, 15,50, 85},},//畆d
	{{99,  1,20,  5},{36, 36,80, 85},{32, 30,77, 85},{30, 27,75, 85},{27, 24,70, 85},{25, 20,65, 85},},//Sϐ@
	{{99,  1,20,  5},{99,  1,20,  5},{35, 25,80,120},{32, 23,80,120},{30, 20,75,120},{27, 18,70,120},},//g̉@
	{{99,  1,20,  5},{39, 30,20,  5},{37, 26,70, 85},{35, 24,65, 85},{32, 21,60, 85},{30, 16,55, 85},},//̃[
	{{99,  1,20,  5},{45, 48,65, 95},{43, 45,60, 95},{39, 41,55, 95},{36, 38,50, 95},{33, 32,45, 95},},//SȂm
	{{99,  1,20,  5},{48, 76,85,125},{45, 70,80,125},{43, 66,75,125},{40, 60,70,125},{37, 58,65,125},},//@
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{45, 74,85,200},{43, 68,80,200},{39, 60,75,200},},//@̊Z
	/*:::t^4*/
	{{99,  1,20,  0},{28, 28,60, 55},{26, 25,55, 55},{24, 23,55, 55},{20, 20,50, 55},{18, 18,45, 55},},//
	{{99,  1,20,  5},{99,  1,20,  5},{35, 72,90,100},{30, 64,85,100},{25, 55,80,100},{23, 48,75,100},},//򓁍쐬
	{{99,  1,20,  5},{42, 52,90,100},{38, 45,90,100},{35, 40,85,100},{32, 32,80,100},{30, 27,75,100},},//͉
	{{99,  1,20,  5},{45,100,90,150},{43, 95,88,150},{40, 90,85,150},{37, 85,80,150},{35, 78,75,150},},//̋Z
	{{99,  1,20,  5},{48, 94,95,180},{45, 85,95,180},{42, 77,95,180},{40, 72,90,180},{38, 66,85,180},},//ւ̖Ɖu
	{{99,  1,20,  5},{50,100,95,  5},{48, 90,95,  5},{45, 85,95,200},{43, 77,90,200},{40, 70,85,200},},//j
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{47, 45,85,220},{45, 37,80,220},{42, 30,75,220},},//*͏[U*
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{50,180,99,240},{48,150,95,240},{45,125,90,240},},//l
	},

	{
	/*:::1*/
	{{ 3,  3,20,  0},{ 7,  3,25,  5},{ 5,  3,25,  5},{ 3,  2,23,  5},{ 1,  2,20,  5},{ 1,  1,18,  5},},//֏
	{{ 5,  3,25,  0},{ 8,  4,32,  5},{ 6,  4,30,  5},{ 4,  3,28,  5},{ 2,  2,25,  5},{ 1,  1,22,  5},},//V[gEe|[g
	{{ 8,  6,30,  0},{10,  8,40,  5},{ 8,  7,40,  5},{ 6,  6,35,  5},{ 4,  5,30,  5},{ 3,  3,25,  5},},//
	{{10,  6,40,  0},{11,  7,50, 10},{10,  6,46, 10},{ 8,  6,43, 10},{ 6,  5,40, 10},{ 4,  3,35, 10},},//T}eA
	{{14, 12,35,  0},{14, 13,45, 15},{12, 12,40, 15},{10, 11,35, 15},{ 8, 10,30, 15},{ 7,  9,25, 15},},//d
	{{15, 14,35,  0},{16, 16,40, 20},{14, 15,35, 20},{12, 14,33, 20},{10, 12,30, 20},{ 9, 10,25, 20},},//e|[g
	{{17, 17,40,  0},{20, 23,50, 25},{17, 20,45, 25},{15, 18,40, 25},{13, 16,35, 25},{11, 14,30, 25},},//
	{{20, 16,70,  0},{22, 24,70, 30},{18, 21,67, 30},{16, 17,65, 30},{15, 14,63, 30},{13, 12,60, 30},},//ACee|[g
	/*:::2*/
	{{23, 14,45,  0},{24, 20,50, 40},{20, 18,47, 40},{18, 16,43, 40},{16, 13,40, 40},{15, 10,35, 40},},//e|[gEAEFC
	{{27, 23,50,  0},{30, 28,55, 45},{26, 26,52, 45},{23, 24,48, 45},{20, 21,45, 45},{18, 18,40, 45},},//X^[̏
	{{32, 27,45,  0},{31, 35,55, 40},{27, 32,48, 40},{25, 28,43, 40},{22, 25,40, 40},{20, 20,35, 40},},//e|[gEx
	{{35, 33,50,  0},{35, 42,60, 50},{32, 38,55, 50},{28, 35,50, 50},{25, 30,45, 50},{23, 27,40, 50},},//
	{{38, 28,60,  0},{99,  1,20,  0},{33, 41,65, 70},{30, 38,60, 70},{27, 35,55, 70},{25, 32,50, 70},},//]w
	{{41, 32,55,  0},{38, 40,65, 80},{36, 36,60, 80},{32, 32,55, 80},{30, 30,50, 80},{28, 27,45, 80},},//G^
	{{44, 37,35,  0},{41, 32,40, 70},{38, 30,36, 70},{36, 28,33, 70},{34, 26,30, 70},{31, 22,27, 70},},//bďW
	{{48, 34,55,  0},{99,  1,20,  0},{43, 40,60, 90},{39, 37,55, 90},{36, 32,50, 90},{32, 27,45, 90},},//̔
	/*:::3*/
	{{99,  1,20,  5},{30, 55,60, 50},{27, 50,57, 50},{24, 45,53, 50},{20, 40,50, 50},{18, 35,47, 50},},//^EEe|[g
	{{99,  1,20,  5},{99,  1,20,  5},{35, 55,95, 65},{30, 50,90, 65},{26, 45,85, 65},{24, 42,80, 65},},//[t@[nEh
	{{99,  1,20,  5},{99,  1,20,  5},{37, 42,77, 80},{32, 38,73, 80},{29, 35,70, 80},{27, 30,66, 80},},//ʒu
	{{99,  1,20,  5},{40, 45,80,100},{38, 42,75,100},{34, 40,70,100},{32, 38,65,100},{29, 35,60,100},},//_i
	{{99,  1,20,  5},{43, 48,65, 70},{40, 43,57, 70},{36, 40,53, 70},{34, 36,50, 70},{30, 32,45, 70},},//_We|[g
	{{99,  1,20,  5},{46, 50,45, 85},{42, 40,38, 85},{38, 35,35, 85},{36, 30,30, 85},{32, 25,27, 85},},//hS
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{40, 40,55, 90},{38, 36,50, 90},{35, 31,45, 90},},//W
	{{99,  1,20,  5},{49, 72,99,120},{45, 68,97,120},{42, 64,93,120},{40, 60,90,120},{38, 54,86,120},},//X^[
	/*:::4*/
	{{99,  1,20,  5},{99,  1,20,  5},{35, 38,70, 90},{27, 32,64, 90},{24, 30,60, 90},{22, 27,55, 90},},//ϐ
	{{99,  1,20,  5},{40, 47,78,100},{35, 44,73,100},{32, 40,69,100},{30, 36,65,100},{26, 32,60,100},},//*e|[gEAEFC*
	{{99,  1,20,  5},{99,  1,20,  5},{42, 56,80,120},{40, 50,75,120},{38, 45,70,120},{35, 40,65,120},},//dԏ
	{{99,  1,20,  5},{50,100,75,180},{47, 90,70,180},{44, 82,65,180},{42, 75,60,180},{40, 70,55,180},},//ʈ
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  0},{45, 50,90,150},{43, 45,85,150},{41, 40,80,150},},//ҏp
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  0},{48,140,99,200},{45,130,95,200},{44,115,90,200},},//TCo[f[
	{{99,  1,20,  5},{99,  1,20,  5},{50, 90,70,200},{50, 75,55,200},{48, 70,50,200},{46, 64,45,200},},//ÑhS
	{{99,  1,20,  5},{50,100,20,250},{50, 95,20,250},{50, 84,20,250},{50, 77,20,250},{49, 70,20,250},},//J
	},
	{
	/*:::_1*/
	{{ 3,  1,20,  0},{ 7,  3,30,  5},{ 5,  2,25,  5},{ 3,  2,23,  5},{ 1,  1,20,  5},{ 1,  1,20,  5},},//V
	{{ 5,  2,30,  0},{ 7,  4,40,  5},{ 6,  3,36,  5},{ 4,  3,34,  5},{ 1,  2,30,  5},{ 1,  1,25,  5},},//X^[m
	{{ 8,  3,25,  0},{ 8,  5,35, 10},{ 7,  4,32, 10},{ 5,  3,28, 10},{ 2,  2,25, 10},{ 1,  1,20, 10},},//V[gEe|[g
	{{10,  4,25,  0},{ 9,  6,40,  5},{ 8,  5,35,  5},{ 6,  4,30,  5},{ 3,  3,25,  5},{ 2,  2,20,  5},},//
	{{12,  4,25,  0},{11,  8,40, 10},{10,  6,35, 10},{ 8,  5,30, 10},{ 4,  4,25, 10},{ 2,  2,20, 10},},//Öp
	{{16,  8,30,  0},{12, 10,40, 15},{11,  9,35, 15},{ 9,  8,33, 15},{ 5,  7,30, 15},{ 4,  6,25, 15},},//e|[g
	{{20, 10,50,  0},{14, 60,60, 25},{12, 13,58, 25},{10, 12,55, 25},{ 7, 10,50, 25},{ 6,  8,40, 25},},//n`m
	{{24, 22,70,  0},{16, 35,90, 30},{14, 30,85, 30},{12, 25,80, 30},{ 9, 20,70, 30},{ 8, 15,60, 30},},//͏[U
	/*:::_2*/
	{{28, 16,50,  0},{19, 25,60, 30},{16, 21,57, 30},{14, 18,54, 30},{10, 15,50, 30},{ 9, 12,45, 30},},//ʓV̏p
	{{30, 16,45,  0},{21, 23,50, 35},{18, 20,46, 35},{16, 18,43, 35},{12, 16,40, 35},{11, 13,35, 35},},//Ӓ
	{{32, 15,45,  0},{99,  1,20, 35},{20, 18,50, 35},{18, 16,45, 35},{15, 14,40, 35},{13, 12,35, 35},},//e|[gEX^[
	{{34, 18,55,  0},{26, 27,60, 40},{23, 23,57, 40},{20, 19,55, 40},{18, 16,50, 40},{16, 14,45, 40},},//Sŋp
	{{36, 20,63,  0},{30, 29,70, 45},{27, 25,66, 45},{24, 22,63, 45},{20, 19,60, 45},{18, 16,55, 45},},//g̉
	{{38, 72,80,  0},{33, 90,90, 55},{30, 85,86, 55},{27, 80,83, 55},{24, 70,80, 55},{21, 60,75, 55},},//
	{{42, 22,70,  0},{36, 33,80, 80},{35, 28,75, 80},{33, 25,70, 80},{30, 20,65, 80},{27, 18,60, 80},},//Sm
	{{45, 75,70,  0},{99,  1,20,  5},{42, 80,80,120},{39, 76,75,120},{36, 70,70,120},{32, 65,60,120},},//_i
	/*:::_3*/
	{{99,  1,20,  5},{99,  1,20,  5},{20, 25,50, 40},{18, 20,45, 40},{15, 16,40, 40},{13, 12,35, 40},},//Ŕj
	{{99,  1,20,  5},{30, 80,60, 50},{27, 75,50, 50},{24, 70,45, 50},{20, 60,40, 50},{18, 50,35, 50},},//򉍂̏p
	{{99,  1,20,  5},{99,  1,20,  5},{30, 26,70, 55},{27, 23,65, 55},{24, 20,60, 55},{22, 18,55, 55},},//p
	{{99,  1,20,  5},{38, 40,85,  5},{35, 36,83, 70},{33, 34,80, 70},{30, 30,75, 70},{28, 27,70, 70},},//*Ӓ*
	{{99,  1,20,  5},{43, 50,80, 80},{38, 43,70, 80},{36, 40,65, 80},{32, 36,60, 80},{30, 30,55, 80},},//Ȍp
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1, 0,  0},{40, 64,85,110},{36, 60,80,110},{32, 55,75,110},},//ǔ
	{{99,  1,20,  5},{46, 36,80,100},{44, 33,70,100},{42, 28,65,100},{38, 25,60,100},{35, 23,55,100},},//A
	{{99,  1,20,  5},{99,  1,20,  5},{48, 48,90,120},{45, 42,85,120},{42, 36,80,120},{38, 32,75,120},},//̔@
	/*:::_4*/
	{{99,  1,20,  5},{30, 40,80, 75},{26, 38,80, 75},{24, 35,75, 75},{22, 30,70, 75},{20, 24,65, 75},},//~_X̎
	{{99,  1,20,  5},{35, 50,80, 85},{30, 48,77, 85},{27, 45,73, 85},{24, 40,70, 85},{22, 36,65, 85},},//CzՒf
	{{99,  1,20,  5},{99,  1,20,  5},{34, 32,68, 95},{31, 28,64, 95},{28, 24,60, 95},{25, 21,55, 95},},//͏
	{{99,  1,20,  5},{99,  1,20,  5},{43, 60,95,140},{40, 50,90,140},{35, 40,80,140},{32, 35,75,140},},//痢
	{{99,  1,20,  5},{47, 48,90,165},{45, 42,86,165},{42, 48,83,165},{40, 45,80,165},{36, 40,75,165},},//Ԃ
	{{99,  1,20,  5},{50, 72,80,175},{46, 63,80,175},{44, 57,75,175},{42, 50,70,175},{40, 43,65,175},},//p̏p
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{47, 80,90,220},{45, 70,85,220},{43, 66,80,220},},//̋
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{50,120,95,250},{48,100,90,250},{45, 90,85,250},},//S_ω
	},
	{
	/*:::1*/
	{{ 3,  2,25,  0},{ 7,  3,30,  5},{ 5,  2,28,  5},{ 3,  2,25,  5},{ 1,  1,20,  5},{ 1,  1,18,  5},},//y̎
	{{ 5,  4,40,  0},{99,  5,50,  5},{ 6,  4,45,  5},{ 5,  3,40,  5},{ 3,  2,35,  5},{ 2,  2,30,  5},},//j
	{{ 7,  7,40,  0},{10,  8,45, 10},{ 8,  7,43, 10},{ 6,  6,40, 10},{ 4,  5,35, 10},{ 3,  4,30, 10},},//
	{{ 9,  7,40,  0},{12,  9,45, 10},{ 9,  8,43, 10},{ 7,  7,40, 10},{ 5,  5,35, 10},{ 4,  4,30, 10},},//̏
	{{12,  9,40,  0},{15, 11,45, 20},{11, 10,40, 20},{ 9,  8,35, 20},{ 7,  7,30, 20},{ 6,  5,25, 20},},//̊m
	{{15, 12,45,  0},{18, 15,55, 20},{13, 14,50, 20},{11, 12,45, 20},{ 9, 10,40, 20},{ 8,  8,35, 20},},//񕜗͋
	{{18, 18,55,  0},{99,  1,65, 25},{16, 20,60, 25},{14, 17,55, 25},{12, 15,50, 25},{10, 13,45, 25},},//󕠏[
	{{21, 20,45,  0},{21, 25,55, 30},{18, 23,50, 30},{16, 20,45, 30},{14, 18,40, 30},{12, 16,35, 30},},//
	/*:::2*/
	{{24, 18,50,  0},{25, 25,60, 30},{20, 20,50, 30},{18, 18,48, 30},{16, 16,45, 30},{14, 14,40, 30},},//
	{{27, 24,55,  0},{99,  1,20,  5},{24, 26,57, 35},{21, 22,53, 35},{18, 20,50, 35},{16, 18,45, 35},},//ϔMϊ
	{{30, 20,45,  0},{30, 26,52, 40},{27, 23,48, 40},{23, 20,45, 40},{20, 16,40, 40},{18, 14,35, 40},},//^[Afbh
	{{34, 22,55,  0},{32, 29,60, 40},{27, 26,58, 40},{24, 23,55, 40},{22, 20,50, 40},{20, 18,45, 40},},//ϒn
	{{38, 24,55,  0},{99,  1,20,  5},{30, 26,58, 45},{28, 24,55, 45},{25, 20,50, 45},{23, 18,45, 45},},//ϓ
	{{42, 28,75,  0},{35, 33,80, 40},{32, 30,75, 40},{30, 27,73, 40},{28, 25,70, 40},{25, 23,65, 40},},//ӎ
	{{45, 32,60,  0},{40, 42,70, 60},{36, 38,65, 60},{33, 35,60, 60},{30, 30,55, 60},{27, 27,50, 60},},//̗͉
	{{48, 48,85,  0},{47, 53,90, 80},{42, 50,86, 80},{38, 48,83, 80},{35, 45,80, 80},{32, 40,75, 80},},//E̖
	/*:::3*/
	{{99,  1,20,  5},{99,  1,20,  5},{29, 38,80, 50},{26, 34,75, 50},{23, 30,70, 50},{20, 27,65, 50},},//_
	{{99,  1,20,  5},{33, 40,80, 70},{30, 35,77, 70},{27, 30,73, 70},{25, 27,70, 70},{23, 24,65, 70},},//̋
	{{99,  1,20,  5},{38, 55,75, 85},{34, 50,70, 85},{30, 45,65, 85},{27, 40,60, 85},{25, 36,55, 85},},//**
	{{99,  1,20,  5},{99,  1,20,  5},{35, 44,80, 80},{32, 40,75, 80},{30, 35,70, 80},{27, 32,65, 80},},//fBXy
	{{99,  1,20,  5},{42, 45,75, 70},{39, 40,75, 70},{36, 36,70, 70},{33, 30,65, 70},{30, 25,60, 70},},//Ҏ
	{{99,  1,20,  5},{44, 50,85, 80},{41, 40,80, 80},{39, 37,78, 80},{36, 35,75, 80},{33, 30,70, 80},},//ύ
	{{99,  1,20,  5},{99,  1,20,  5},{46, 72,75,100},{44, 68,72,100},{41, 65,70,100},{39, 60,65,100},},//*ӎ*
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  0},{46, 59,78,120},{43, 55,75,120},{41, 50,70,120},},//_h
	/*:::4*/
	{{99,  1,20,  5},{99,  1,20,  5},{38, 50,95,115},{33, 43,90,115},{30, 40,85,115},{27, 35,80,115},},//ANeBuq[
	{{99,  1,20,  5},{42, 70,90,120},{40, 65,88,120},{36, 59,84,120},{34, 55,80,120},{31, 51,75,120},},//Afbh
	{{99,  1,20,  5},{45,100,90,150},{42, 94,85,150},{38, 87,78,150},{36, 80,75,150},{33, 73,70,150},},//S
	{{99,  1,20,  5},{99,  1,20,  5},{45,105,90,120},{42, 96,88,120},{40, 90,85,120},{36, 82,75,120},},//CtXg[
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,110},{46, 75,84,110},{44, 70,80,110},{40, 64,75,110},},//^EE
	{{99,  1,20,  5},{50, 70,95,180},{49, 65,90,180},{47, 60,85,180},{45, 50,80,180},{42, 43,75,180},},//*̗͉*
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,230},{49, 88,93,230},{48, 80,90,230},{45, 70,85,230},},//V
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,250},{50,108,83,250},{50,100,80,250},{47, 85,75,250},},//ɂ̑ϐ
	},
	{
	/*:::j1*/
	{{ 3,  1,20,  0},{ 7,  2,30,  5},{ 5,  2,27,  5},{ 3,  2,25,  5},{ 1,  1,20,  5},{ 1,  1,20,  5},},//̂܂Ȃ
	{{ 5,  2,20,  0},{ 8,  5,33,  5},{ 6,  4,30,  5},{ 4,  3,25,  5},{ 2,  2,20,  5},{ 1,  1,20,  5},},//א͊m
	{{ 8,  4,30,  0},{10,  6,45, 10},{ 7,  5,40, 10},{ 5,  4,35, 10},{ 3,  3,30, 10},{ 2,  2,25, 10},},//j
	{{11,  8,30,  0},{12, 12,40, 10},{ 8, 10,35, 10},{ 6,  8,30, 10},{ 3,  6,25, 10},{ 2,  4,22, 10},},//̂܂ȂD
	{{14,  7,40,  0},{13, 10,48, 15},{10,  9,45, 15},{ 7,  8,40, 15},{ 6,  7,35, 15},{ 5,  6,32, 15},},//̎F
	{{17,  9,30,  0},{14, 15,40, 20},{11, 12,35, 20},{ 9, 10,30, 20},{ 8,  8,25, 20},{ 7,  7,22, 20},},//mCg
	{{20, 11,43,  0},{99,  1,55, 30},{14, 14,50, 30},{11, 12,45, 30},{10, 10,40, 30},{ 9,  8,37, 30},},//X^[_Xg
	{{23, 19,58,  0},{20, 25,70, 40},{16, 23,65, 40},{13, 20,60, 40},{12, 18,55, 40},{10, 16,50, 40},},//
	/*:::j2*/
	{{26, 17,50,  0},{99,  1,20, 50},{99,  1,20, 50},{17, 23,50, 50},{15, 20,45, 50},{13, 17,40, 50},},//
	{{29, 13,45,  0},{22, 16,50, 50},{20, 14,45, 50},{18, 13,43, 50},{16, 12,40, 50},{15, 11,36, 50},},//Ј
	{{32, 15,52,  0},{99,  1,20, 60},{24, 18,60, 60},{20, 16,55, 60},{18, 14,50, 60},{16, 13,45, 60},},//Ȃ
	{{35, 20,63,  0},{30, 30,70, 80},{26, 25,68, 80},{24, 22,64, 80},{21, 19,60, 80},{18, 17,55, 80},},//ޖ̎
	{{38, 12,32,  0},{33, 16,40, 80},{30, 13,36, 80},{27, 12,33, 80},{24, 10,30, 80},{22,  9,27, 80},},//
	{{40, 32,64,  0},{36, 45,80, 90},{32, 40,70, 90},{29, 35,65, 90},{27, 30,60, 90},{24, 27,55, 90},},//fBXy
	{{43, 34,85,  0},{42, 45,90,100},{38, 39,88,100},{35, 36,83,100},{33, 32,80,100},{30, 28,75,100},},//ق̗
	{{46, 38,85,  0},{99,  1,20,125},{99,  1,20,125},{43, 40,85,125},{40, 35,80,125},{36, 32,75,125},},//Ȃ䌾t
	/*:::j3*/
	{{99,  1,20,  5},{24, 23,60, 50},{22, 20,56, 50},{20, 17,53, 50},{18, 14,50, 50},{16, 13,45, 50},},//
	{{99,  1,20,  5},{99,  1,20,  5},{29, 27,67, 60},{27, 24,64, 60},{24, 20,60, 60},{22, 18,55, 60},},//ώ׈E
	{{99,  1,20,  5},{36, 30,64, 75},{32, 27,60, 75},{30, 25,55, 75},{27, 23,50, 75},{25, 20,45, 75},},//jׂ̈
	{{99,  1,20,  5},{38, 50,95,100},{35, 45,90,100},{33, 40,85,100},{30, 35,80,100},{28, 33,75,100},},//**
	{{99,  1,20,  5},{99,  1,20,  5},{38, 28,67, 80},{35, 25,64, 80},{32, 20,60, 80},{30, 18,55, 80},},//ȂI[
	{{99,  1,20,  5},{43, 38,80, 80},{40, 35,78, 80},{37, 32,73, 80},{34, 30,70, 80},{32, 27,65, 80},},//Ȃ
	{{99,  1,20,  5},{99,  1,20,  5},{42, 40,80,100},{40, 36,75,100},{37, 30,70,100},{35, 27,65,100},},//׈Ǖ
	{{99,  1,20,  5},{99,  1,20,  5},{45, 50,80,120},{42, 48,75,120},{40, 45,70,120},{37, 40,65,120},},//X^[o[Xg
	/*:::j4*/
	{{99,  1,20,  5},{40, 46,80,100},{37, 40,75,100},{34, 36,70,100},{30, 32,60,100},{27, 30,55,100},},//VΖʖ~
	{{99,  1,20,  5},{45, 80,80,120},{40, 72,75,120},{38, 63,70,120},{35, 50,65,120},{33, 43,60,120},},//΋ÉW~
	{{99,  1,20,  5},{47, 75,86,150},{43, 70,83,150},{40, 64,80,150},{38, 57,75,150},{35, 50,70,150},},//эj~
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,160},{42, 76,74,160},{40, 70,70,160},{38, 64,65,160},},//ɓ\~
	{{99,  1,20,  5},{99,  1,20,  5},{46, 77,94,170},{44, 72,90,170},{42, 65,85,170},{40, 58,80,170},},//ZgO_~
	{{99,  1,20,  5},{50, 90,90,180},{48, 82,86,180},{46, 77,83,180},{44, 70,80,180},{42, 64,70,180},},//~
	{{99,  1,20,  5},{99,  1,20,  5},{50,100,88,200},{48, 98,84,200},{46, 90,80,200},{43, 85,75,200},},//VF󔄖~
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,250},{50,120,95,250},{48,108,90,250},{46,100,80,250},},//VƑ_~
	},
	{
	/*:::R1*/
	{{ 3,  4,20,  0},{ 7,  5,25,  5},{ 5,  4,25,  5},{ 3,  3,20,  5},{ 1,  2,20,  5},{ 1,  2,20,  5},},//X^[m
	{{ 5,  3,25,  0},{ 8,  5,28,  5},{ 5,  4,25,  5},{ 4,  3,25,  5},{ 1,  2,20,  5},{ 1,  1,15,  5},},//d
	{{ 8,  5,25,  0},{ 9,  7,33,  8},{ 6,  6,30,  8},{ 5,  5,25,  8},{ 3,  4,20,  8},{ 2,  3,18,  8},},//㩂Ɣm@
	{{10,  7,30,  0},{10,  9,35, 10},{ 8,  8,30, 10},{ 6,  7,30, 10},{ 5,  6,25, 10},{ 4,  5,20, 10},},//HƐ
	{{12,  6,30,  0},{12,  9,35, 15},{ 9,  7,30, 15},{ 7,  6,30, 15},{ 6,  5,25, 15},{ 5,  4,20, 15},},//̌
	{{15, 10,35,  0},{14, 12,40, 20},{11, 11,38, 20},{ 9, 10,35, 20},{ 8,  9,30, 20},{ 7,  8,25, 20},},//炵
	{{18, 10,40,  0},{16, 13,45, 30},{13, 11,40, 30},{12, 10,40, 30},{10,  8,35, 30},{ 9,  7,30, 30},},//ւ̑ϐ
	{{20,  8,35,  0},{18, 10,40, 20},{16,  9,35, 20},{15,  8,35, 20},{12,  6,30, 20},{10,  5,25, 20},},//ƓŎ
	/*:::R2*/
	{{23,  9,40,  0},{19, 12,40, 30},{17, 10,40, 30},{15,  8,40, 30},{12,  7,35, 30},{10,  5,30, 30},},//Ηn
	{{26, 18,50,  0},{24, 25,50, 40},{20, 22,50, 40},{18, 18,50, 40},{16, 15,45, 40},{12, 13,40, 40},},//ϐ
	{{28, 12,45,  0},{25, 15,50, 35},{23, 13,45, 35},{21, 12,45, 35},{18, 10,40, 35},{15,  9,35, 35},},//z
	{{32, 30,55,  0},{26, 40,70, 40},{24, 35,65, 40},{22, 32,60, 35},{19, 28,55, 35},{16, 24,50, 35},},//
	{{34, 21,55,  0},{99,  1,20,  5},{27, 24,60, 40},{25, 22,55, 40},{22, 18,50, 40},{19, 15,45, 40},},//R̊o
	{{40, 28,55,  0},{35, 35,65, 55},{32, 32,60, 55},{29, 28,55, 55},{25, 25,50, 55},{22, 23,45, 55},},//
	{{45, 35,65,  0},{99,  1,20,  5},{38, 38,70, 60},{35, 35,65, 60},{30, 32,60, 60},{27, 28,55, 60},},//򑐎
	{{48, 40,75,  0},{43, 48,80, 80},{41, 45,75, 80},{39, 40,75, 80},{36, 35,70, 80},{32, 30,65, 80},},//
	/*:::R3*/
	{{99,  1,20,  5},{99,  1,20,  5},{21, 25,60, 55},{17, 22,55, 55},{15, 18,55, 55},{12, 16,50, 55},},//Ή
	{{99,  1,20,  5},{30, 30,55, 50},{27, 27,55, 50},{23, 25,50, 50},{20, 22,50, 50},{18, 18,45, 50},},//VI
	{{99,  1,20,  5},{36, 35,80, 60},{32, 32,70, 60},{28, 28,65, 60},{26, 24,65, 60},{23, 20,60, 60},},//^Eϐ
	{{99,  1,20,  5},{99,  1,20,  5},{37, 40,75, 75},{34, 34,75, 75},{31, 30,70, 75},{28, 26,65, 75},},//Xёn
	{{99,  1,20,  5},{42, 40,85, 80},{39, 36,80, 80},{35, 32,80, 80},{33, 26,75, 80},{30, 20,70, 80},},//hg
	{{99,  1,20,  5},{45, 50,95, 90},{43, 44,90, 90},{39, 40,90, 90},{36, 35,85, 90},{33, 32,80, 90},},//
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{43, 50,90,110},{40, 45,85,110},{36, 42,80,110},},//΂̕
	{{99,  1,20,  5},{49, 53,85,100},{47, 48,85,100},{45, 43,85,100},{42, 40,80,100},{38, 36,75,100},},//
	/*:::R4*/
	{{99,  1,20,  5},{35, 35,60, 60},{30, 30,55, 60},{27, 28,50, 60},{24, 25,50, 60},{20, 23,40, 60},},//d
	{{99,  1,20,  5},{40, 40,60, 80},{38, 36,55, 80},{35, 30,55, 80},{32, 26,50, 80},{28, 24,40, 80},},//nk
	{{99,  1,20,  5},{43, 53,70,100},{40, 50,65,100},{37, 45,65,100},{35, 38,60,100},{32, 32,55,100},},//
	{{99,  1,20,  5},{48, 85,20,150},{43, 78,90,150},{40, 72,90,150},{38, 65,85,150},{36, 58,80,150},},//̐n
	{{99,  1,20,  5},{99,  1,20,  5},{46, 40,80,120},{43, 36,85,120},{41, 32,80,120},{38, 27,76,120},},//z
	{{99,  1,20,  5},{99,  1,20,  5},{48, 75,85,120},{45, 70,80,120},{43, 64,80,120},{41, 57,75,120},},//
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{48,195,95,250},{46,180,95,250},{43,160,90,250},},//b
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{50,100,90,200},{47, 90,85,200},{44, 84,80,200},},//Vϒnف@
	},



	{
	/*:::ϗe1*/
	{{ 4,  2,20,  0},{ 7,  4,30,  5},{ 5,  3,25,  5},{ 3,  3,23,  5},{ 1,  2,20,  5},{ 1,  1,20,  5},},//
	{{ 6,  5,30,  0},{ 8,  9,40,  5},{ 6,  8,36,  5},{ 4,  7,33,  5},{ 3,  5,30,  5},{ 1,  3,25,  5},},//ؓ
	{{ 8,  5,25,  0},{ 9,  7,35,  5},{ 7,  6,32,  5},{ 6,  5,28,  5},{ 4,  4,25,  5},{ 3,  3,22,  5},},//b̎
	{{10,  8,35,  0},{10, 10,50, 10},{ 9,  9,45, 10},{ 8,  8,40, 10},{ 6,  7,35, 10},{ 5,  6,32, 10},},//͓
	{{14, 14,40,  0},{13, 21,50, 10},{11, 19,50, 10},{10, 15,45, 10},{ 8, 13,40, 10},{ 7, 10,36, 10},},//畆ϗe
	{{16, 12,40,  0},{99,  1,20, 15},{13, 13,48, 15},{12, 11,44, 15},{10, 10,40, 15},{ 8,  9,36, 15},},//̖ѐj
	{{18, 14,30,  0},{99,  1,40, 20},{14, 15,38, 20},{13, 14,35, 20},{12, 12,30, 20},{ 9, 10,27, 20},},//
	{{21, 18,35,  0},{18, 20,43, 30},{16, 19,40, 30},{15, 17,38, 30},{14, 16,35, 30},{12, 14,32, 30},},//
	/*:::ϗe2*/
	{{24, 22,45,  0},{21, 30,55, 35},{19, 25,53, 35},{17, 23,50, 35},{15, 20,45, 35},{14, 18,40, 35},},//zϗe
	{{27, 16,45,  0},{24, 24,50, 30},{22, 20,48, 30},{20, 18,45, 30},{18, 16,40, 30},{16, 14,35, 30},},//ڂr[@
	{{30, 23,50,  0},{28, 30,55, 40},{26, 26,53, 40},{24, 24,50, 40},{21, 21,45, 40},{18, 20,40, 40},},//hA@
	{{33, 28,45,  0},{32, 35,50, 50},{28, 30,45, 50},{26, 28,43, 50},{23, 26,40, 50},{20, 24,37, 50},},//Đ@
	{{37, 38,60,  0},{36, 50,72, 70},{30, 48,68, 70},{28, 43,65, 70},{26, 40,63, 70},{23, 36,55, 70},},//܋
	{{40, 26,50,  0},{99,  1,20, 55},{34, 30,56, 55},{32, 27,53, 55},{30, 24,50, 55},{27, 20,45, 55},},//uX
	{{43, 33,55,  0},{42, 40,65, 60},{38, 38,61, 60},{36, 35,58, 60},{34, 32,55, 60},{32, 28,50, 60},},//Ki
	{{46, 30,60,  0},{99,  1, 0,  0},{39, 32,66, 80},{38, 30,63, 80},{36, 28,60, 80},{33, 25,55, 80},},//Lr
	/*:::ϗe3*/
	{{99,  1,20,  5},{32, 35,60, 65},{28, 33,57, 65},{25, 30,53, 65},{22, 26,50, 65},{20, 22,50, 65},},//XvOtA
	{{99,  1,20,  5},{34, 40,70, 75},{30, 35,68, 75},{27, 33,64, 75},{25, 30,60, 75},{23, 27,55, 75},},//dΉ
	{{99,  1,20,  5},{99,  1,20,  5},{34, 50,80, 95},{31, 45,75, 95},{28, 40,70, 95},{26, 36,65, 95},},//XCω@
	{{99,  1,20,  5},{99,  1,20,  5},{40, 36,70, 75},{35, 33,63, 75},{32, 30,60, 75},{29, 27,55, 75},},//*ؓ* 
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{37, 47,64, 90},{35, 42,60, 90},{32, 37,55, 90},},//̍č\@
	{{99,  1,20,  5},{99,  1,20,  5},{43, 60,75, 90},{40, 56,70, 90},{38, 50,65, 90},{35, 45,60, 90},},//*uX*@
	{{99,  1,20,  5},{46, 65,85,130},{44, 60,80,130},{42, 55,75,130},{40, 50,70,130},{37, 45,65,130},},//bω
	{{99,  1,20,  5},{48, 70,85,105},{47, 64,83,105},{45, 60,80,105},{43, 55,75,105},{41, 49,70,105},},//}O}
	/*:::ϗe4*/
	{{99,  1,20,  5},{37, 80,80,120},{35, 73,75,120},{32, 70,70,120},{28, 65,65,120},{25, 60,60,100},},//ω
	{{99,  1,20,  5},{42, 55,70, 80},{38, 51,66, 80},{35, 48,63, 80},{32, 45,60, 80},{30, 40,55, 80},},//[_[ZX
	{{99,  1,20,  5},{99,  1,20,  5},{42, 60,77,120},{38, 55,73,120},{37, 50,70,120},{34, 43,65,120},},//nʉj@
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,150},{43, 85,75,150},{40, 80,70,150},{38, 75,65,150},},//ω
	{{99,  1,20,  5},{50,180,90,170},{49,170,80,170},{47,160,75,170},{45,150,70,170},{42,140,65,170},},//̕ϗe
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,160},{48, 88,90,160},{46, 80,85,160},{43, 70,80,160},},//̃Pbg
	{{99,  1,20,  5},{99,  1,20,  5},{50,140,99,200},{50,130,95,200},{48,120,90,200},{46,100,85,200},},//hSω@
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,250},{50,225,99,250},{50,200,90,250},{50,180,85,250},},//] 
	},
		
//ϗe͎푰ɂꏈŃx㉺gpۂς悤ɂ悤
	{
	/*:::Í1*/
	{{ 3,  2,20,  0},{ 7,  3,30,  5},{ 5,  2,25,  5},{ 3,  2,22,  5},{ 1,  1,20,  5},{ 1,  1,16,  5},},//}WbN~TC
	{{ 5,  3,20,  0},{ 8,  4,30,  5},{ 6,  3,27,  5},{ 4,  3,24,  5},{ 2,  2,20,  5},{ 1,  1,18,  5},},//ECm
	{{ 8,  4,20,  0},{10,  6,30, 10},{ 8,  5,26, 10},{ 5,  4,23, 10},{ 3,  3,20, 10},{ 2,  2,18, 10},},//̏j
	{{10,  4,25,  0},{11,  6,35, 15},{ 9,  5,33, 15},{ 6,  4,30, 15},{ 4,  3,25, 15},{ 3,  3,22, 15},},//L_
	{{12, 10,45,  0},{12, 12,48, 20},{10, 11,45, 20},{ 8, 10,43, 20},{ 7,  9,40, 20},{ 5,  8,36, 20},},//ψÍ
	{{15,  7,33,  0},{13, 11,40, 25},{12,  9,35, 25},{10,  7,30, 25},{ 8,  6,25, 25},{ 7,  5,20, 25},},//È
	{{18, 13,40,  0},{17, 15,42, 35},{15, 14,40, 35},{12, 12,38, 35},{10, 10,33, 35},{ 9,  9,30, 35},},//Í̖@
	{{21, 16,45,  0},{99, 1,  1,  0},{17, 20,50, 35},{15, 18,48, 35},{11, 14,43, 35},{10, 12,40, 35},},//_
	/*:::Í2*/
	{{25, 18,75,  0},{20, 23,80, 40},{18, 20,75, 40},{16, 18,70, 40},{14, 15,65, 40},{13, 12,60, 40},},//ϓ
	{{28, 32,63,  0},{25, 33,75, 55},{22, 30,70, 55},{20, 28,65, 55},{17, 24,60, 55},{16, 20,55, 55},},//ŉthz
	{{32, 22,52,  0},{99,  1,20,  5},{25, 25,60, 55},{23, 23,55, 55},{20, 20,50, 55},{18, 17,45, 55},},//Ǖ
	{{36, 20,64,  0},{30, 27,75, 70},{27, 24,70, 70},{25, 20,65, 65},{22, 18,60, 65},{20, 16,56, 65},},//Í[U[
	{{40, 27,85,  0},{35, 38,88, 85},{30, 35,85, 85},{27, 30,83, 85},{24, 25,80, 85},{21, 23,75, 85},},//
	{{43, 85,84,  0},{99,  1,20,  5},{32, 90,87,100},{29, 85,84,100},{27, 80,80,100},{25, 70,75,100},},//Őj쐬
	{{46, 28,72,  0},{40, 38,85, 90},{36, 35,80, 90},{32, 30,75, 90},{30, 27,70, 90},{27, 24,65, 90},},//z
	{{50, 40,95,  0},{99,  1,20,  5},{99,  1,20,  0},{42, 40,93,120},{38, 36,90,120},{36, 32,85,120},},//E
	/*:::Í3*/
	{{99,  1,20,  5},{30, 25,75, 55},{28, 21,70, 55},{25, 19,63, 55},{22, 16,60, 55},{20, 14,57, 55},},//iCgA
	{{99,  1,20,  5},{34, 35,80, 75},{30, 30,77, 75},{27, 28,74, 75},{25, 25,70, 75},{23, 23,66, 75},},//
	{{99,  1,20,  5},{36, 38,64, 85},{33, 35,60, 85},{30, 32,54, 85},{27, 30,50, 85},{24, 26,47, 85},},//őf̗
	{{99,  1,20,  5},{99,  1,20,  5},{35, 37,80,100},{32, 34,74,100},{30, 30,70,100},{27, 28,66,100},},//wEX
	{{99,  1,20,  5},{99,  1,20,  5},{41, 60,90,125},{36, 53,85,125},{33, 45,80,125},{30, 40,75,125},},//ω
	{{99,  1,20,  5},{45, 42,75,105},{43, 40,70,105},{39, 38,65,105},{36, 36,60,105},{33, 33,55,105},},//Í̗
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{42, 45,75,120},{39, 40,70,120},{36, 35,65,120},},//^Ez
	{{99,  1,20,  5},{99,  1,20,  5},{47, 55,88,160},{45, 50,84,160},{42, 46,80,160},{40, 42,75,160},},//łƂ̗Za
	/*:::Í4*/
	{{99,  1,20,  5},{99,  1,20,  5},{33, 35,70,100},{31, 32,65,100},{28, 28,60,100},{25, 24,55,100},},//ẽQ[g
	{{99,  1,20,  5},{37, 63,74, 80},{35, 60,70, 80},{30, 55,65, 80},{25, 50,60, 80},{22, 45,55, 80},},//sщ
	{{99,  1,20,  5},{45, 80,90,120},{42, 74,88,120},{40, 68,85,120},{36, 60,80,120},{33, 55,75,120},},//
	{{99,  1,20,  5},{99,  1,20,  5},{44,100,82,150},{42, 95,78,150},{40, 90,70,150},{38, 83,65,150},},//eve[V
	{{99,  1,20,  5},{99,  1,20,  5},{99,  0, 0,  0},{44, 80,85,180},{42, 75,80,180},{39, 69,75,180},},//ӖE
	{{99,  1,20,  5},{50,128,99,200},{48,120,96,200},{46,110,93,200},{44,100,90,200},{41, 93,85,200},},//ʈ
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{48, 94,95,180},{46, 85,90,180},{43, 79,85,180},},//n̍
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{50,120,90,250},{49,100,85,250},{47, 88,80,250},},//ω
	},
	{
	/*:::1*/
	{{ 3,  2,25,  0},{ 7,  4,30,  5},{ 5,  3,25,  5},{ 3,  2,25,  5},{ 1,  2,20,  5},{ 1,  1,16,  5},},//
	{{ 4,  3,25,  0},{ 8,  6,30,  5},{ 6,  5,25,  5},{ 4,  4,25,  5},{ 2,  3,20,  5},{ 1,  2,20,  5},},//m
	{{ 6,  5,30,  0},{ 9,  7,35,  5},{ 7,  6,30,  5},{ 5,  5,25,  5},{ 3,  4,25,  5},{ 2,  3,20,  5},},//AfbhގU
	{{ 8,  5,25,  0},{10,  7,30,  8},{ 8,  6,25,  8},{ 6,  5,25,  8},{ 4,  4,20,  8},{ 3,  3,20,  8},},//Ö
	{{11,  7,30,  0},{12,  8,35, 10},{ 9,  7,30, 10},{ 7,  6,25, 10},{ 5,  5,25, 10},{ 4,  4,20, 10},},//S
	{{14,  8,40,  0},{13, 10,50, 15},{10,  9,45, 15},{ 9,  8,40, 15},{ 7,  6,35, 15},{ 6,  5,30, 15},},//ϒn@
	{{18, 10,45,  0},{14, 11,50, 20},{12, 10,45, 20},{10, 10,40, 20},{ 8,  8,40, 20},{ 7,  7,35, 20},},//XPg
	{{20,  9,35,  0},{16, 14,50, 25},{14, 12,40, 25},{12, 11,35, 25},{10,  8,30, 25},{ 9,  7,25, 25},},//Afbh
	/*:::2*/
	{{22, 13,35,  0},{18, 17,45, 35},{16, 15,40, 35},{14, 13,35, 35},{13, 12,30, 35},{11,  9,27, 35},},//n̖
	{{25, 13,30,  0},{20, 19,40, 30},{18, 16,35, 30},{16, 14,30, 30},{15, 12,30, 30},{13, 10,25, 30},},//쏢
	{{28, 24,45,  0},{25, 32,50, 35},{23, 28,45, 35},{20, 25,43, 35},{18, 20,40, 35},{14, 18,35, 35},},//O
	{{30, 15,55,  0},{27, 20,60, 30},{25, 17,60, 30},{22, 15,55, 30},{20, 12,50, 30},{18, 10,45, 30},},//cvO
	{{34, 20,50,  0},{33, 30,60, 40},{28, 25,55, 40},{25, 21,50, 40},{23, 18,45, 40},{20, 15,40, 40},},//߈
	{{36, 22,60,  0},{36, 35,70, 50},{32, 30,65, 50},{28, 25,60, 50},{25, 20,55, 50},{22, 17,50, 50},},//Afbh̏
	{{42, 21,75,  0},{99,  1,20,  5},{99,  1,20,  5},{30, 18,75, 80},{28, 15,70, 80},{25, 12,60, 80},},//͋z
	{{45, 25,50,  0},{99,  1,20,  5},{42, 40,55, 60},{38, 37,50, 60},{35, 35,50, 60},{32, 30,45, 60},},//gt
	/*:::3*/
	{{99,  1,20,  5},{32, 25,60, 50},{28, 22,57, 50},{25, 20,54, 50},{20, 17,50, 50},{18, 15,47, 50},},//̌
	{{99,  1,20,  5},{99,  1,20,  5},{30, 26,56, 65},{27, 24,53, 65},{24, 20,50, 65},{20, 18,45, 65},},//_
	{{99,  1,20,  5},{36, 48,80, 70},{33, 45,80, 70},{30, 44,75, 70},{27, 40,70, 70},{24, 35,65, 70},},//Afbh
	{{99,  1,20,  5},{99,  1,20,  0},{39, 50,65,100},{35, 40,60,100},{33, 30,55,100},{30, 25,48,100},},//̌
	{{99,  1,20,  5},{99,  1,20,  5},{43, 45,70,120},{38, 42,65,120},{35, 38,60,120},{32, 34,52,120},},//̃I[
	{{99,  1,20,  5},{42, 42,70, 80},{40, 40,68, 80},{38, 37,65, 80},{36, 34,60, 80},{34, 30,50, 80},},//E@w
	{{99,  1,20,  5},{48, 60,85,150},{45, 52,80,150},{40, 48,75,150},{38, 40,70,150},{36, 36,65,150},},//zS
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{45, 80,90,150},{43, 75,85,150},{40, 70,80,150},},//ʃAfbh
	/*:::4*/
	{{99,  1,20,  5},{40, 62,92, 95},{35, 55,90, 95},{32, 51,85, 95},{28, 47,80, 95},{25, 41,73, 95},},//r
	{{99,  1,20,  5},{99,  1,20,  5},{41, 58,70, 85},{38, 53,65, 85},{35, 50,60, 85},{32, 45,55, 85},},//jł̎
	{{99,  1,20,  5},{48, 52,80,105},{45, 48,80,105},{42, 44,76,105},{39, 40,70,105},{37, 35,65,105},},//n̗
	{{99,  1,20,  5},{48, 55,90,120},{46, 50,90,120},{44, 46,85,120},{42, 40,80,120},{40, 37,75,120},},//Q̌_
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{48, 74,85,180},{45, 70,80,180},{42, 65,75,180},},//\EXeB[
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{49,111,95,200},{47,100,90,200},{45, 90,85,200},},//H̉
	{{99,  1,20,  5},{99,  1,20,  5},{50, 96,90,160},{50, 91,84,160},{48, 85,80,160},{47, 80,72,160},},//̎
	{{99,  1,20,  5},{99,  1,20,  5},{99,  1,20,  5},{50,240,99,250},{50,230,95,250},{48,210,80,250},},//҂̔󁨗H̋S_
	},

	{
	/*:::1*/
	{{ 3,  2,22,  0},{ 7,  2,30,  5},{ 5,  2,28,  5},{ 3,  2,23,  5},{ 1,  1,20,  5},{ 1,  1,15,  5},},//}WbN~TC
	{{ 4,  3,25,  0},{ 8,  4,32,  5},{ 6,  3,30,  5},{ 3,  3,25,  5},{ 1,  2,22,  5},{ 1,  1,15,  5},},//gbv/hAj
	{{ 6,  4,30,  0},{11,  9,35,  5},{ 8,  8,35,  5},{ 4,  5,30,  5},{ 2,  2,25,  5},{ 2,  1,15,  5},},//M
	{{ 9,  6,35,  0},{12, 12,45,  6},{ 9, 10,40,  6},{ 6,  6,34,  6},{ 5,  5,30,  6},{ 4,  2,20,  6},},//̎
	{{16, 14,45,  0},{15, 13,60,  8},{12, 11,60,  8},{10,  7,53,  8},{ 9,  6,48,  8},{ 6,  4,40,  8},},//y
	{{23, 18,45,  0},{18, 18,45, 10},{15, 13,50, 10},{15,  9,48, 10},{13,  9,45, 10},{10,  5,35, 10},},//t@CAE{g
	{{26, 24,45,  0},{99,  0, 0,  0},{18, 15,48, 20},{16, 12,48, 20},{14,  9,45, 20},{12,  6,35, 20},},//͂̌
	{{28, 25,50,  0},{24, 22,50, 40},{20, 20,50, 40},{18, 18,42, 40},{15, 10,35, 40},{14,  7,25, 40},},//e|[g
	/*:::2*/
	{{29, 26,60,  0},{22, 18,45, 20},{21, 15,40, 20},{19, 13,30, 20},{17, 11,25, 20},{15,  9,20, 20},},//_[
	{{32, 29,60,  0},{25, 20,45, 20},{23, 18,55, 20},{21, 15,50, 20},{19, 12,45, 20},{17, 10,35, 20},},//JIXE{g
	{{35, 35,70,  0},{99,  0, 0,  0},{26, 20,62, 50},{23, 16,55, 50},{21, 13,45, 50},{19, 11,35, 50},},//\jbNu[
	{{38, 36,70,  0},{99,  0, 0,  0},{27, 22,65, 60},{25, 18,60, 60},{23, 15,50, 60},{21, 12,40, 60},},//jł̖
	{{41, 40,75,  0},{32, 30,55, 60},{28, 24,55, 60},{26, 19,55, 60},{24, 16,50, 60},{22, 13,40, 60},},//t@CA{[
	{{43, 35,65,  0},{34, 30,80, 65},{32, 27,70, 65},{28, 22,65, 65},{25, 18,60, 65},{23, 15,50, 65},},//e|AEFC
	{{46, 38,90,  0},{43, 40,90, 70},{38, 30,90, 70},{33, 25,85, 70},{30, 20,80, 70},{27, 17,70, 70},},//j
	{{49, 60,85,  0},{99,  0, 0,  0},{42, 50,85, 80},{38, 45,85, 80},{35, 40,80, 80},{30, 35,75, 80},},//OX
	/*:::3*/
	{{99,  0, 0,  0},{28, 32,75, 80},{26, 30,70, 80},{23, 27,60, 80},{20, 24,55, 80},{18, 20,50, 80},},//ҕϗe
	{{99,  0, 0,  0},{99,  0, 0,  0},{33, 40,90,100},{30, 37,85,100},{27, 32,80,100},{24, 28,70,100},},//JWA
	{{99,  0, 0,  0},{99,  0, 0,  0},{35, 36,90,120},{32, 30,85,120},{29, 25,80,120},{26, 22,70,120},},//q
	{{99,  0, 0,  0},{38, 40,70,100},{37, 32,90,100},{34, 28,90,100},{30, 25,85,100},{27, 22,75,100},},//ϗe
	{{99,  0, 0,  0},{40, 40,80,100},{38, 35,80,100},{35, 30,75,100},{32, 27,70,100},{29, 24,60,100},},//vY}
	{{99,  0, 0,  0},{48,120,95,140},{45,100,95,140},{40, 90,95,140},{36, 80,90,140},{32, 65,85,140},},//ׂ̐n
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{42, 40,85,120},{40, 36,80,120},{36, 33,70,120},},//}WbNPbg
	{{99,  0, 0,  0},{45, 50,85,180},{45, 45,80,180},{44, 43,75,180},{42, 40,70,180},{38, 36,60,180},},//͏̋
	/*:::4*/
	{{99,  0, 0,  0},{40, 70,95, 75},{36, 60,90, 75},{32, 55,85, 75},{30, 50,85, 75},{26, 45,80, 75},},//ȕϗe
	{{99,  0, 0,  0},{43, 45,90,120},{39, 40,90,120},{36, 35,85,120},{33, 32,80,120},{30, 28,75,120},},//E`()
	{{99,  0, 0,  0},{48, 70,95,150},{44, 65,90,150},{40, 55,90,150},{38, 48,85,150},{35, 43,80,150},},//Ԙc
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{45, 80,90,180},{42, 75,85,180},{39, 60,75,180},},//OX̃uX
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{47, 66,90,150},{45, 58,85,150},{42, 52,75,150},},//̗͂
	{{99,  0, 0,  0},{99,  0, 0,  0},{50,110,90,250},{48,100,90,250},{47, 90,90,250},{44, 75,80,250},},//׏
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{49,110,90,200},{48,100,85,200},{46, 90,75,200},},//
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{50,200,99,250},{50,180,95,250},{48,150,80,250},},//I[vph
	},

};

///mod160706 IJg@p̃f[^
//i͂Ƃ肠O
magic_type occult_spell_base_info[32][6] =
	{
	/*:::p1*/
	{{99,  2,22,  0},{ 8, 14,30,  3},{ 5, 12,26,  3},{ 4, 10,23,  3},{ 2,  8,20,  3},{ 1,  7,15,  3},},//{Y
	{{99,  3,25,  0},{10, 10,30,  5},{ 8,  8,27,  5},{ 6,  7,25,  5},{ 4,  5,22,  5},{ 2,  3,20,  5},},//肳
	{{99,  6,30,  0},{15, 20,40,  8},{12, 18,35,  8},{ 9, 15,33,  8},{ 7, 11,30,  8},{ 5,  8,25,  8},},//s
	{{99,  8,35,  0},{24, 30,50, 20},{20, 25,45, 20},{15, 20,40, 20},{12, 15,35, 20},{10, 12,30, 20},},//ё
	{{99, 10,40,  0},{99,  0, 0,  0},{99,  0, 0,  0},{20, 25,45, 40},{18, 22,42, 40},{16, 18,38, 40},},//uĂx
	{{99, 12,45,  0},{35, 50,60, 50},{30, 40,55, 50},{27, 36,50, 50},{24, 30,45, 50},{22, 24,40, 50},},//gC̉Ԏq
	{{99, 16,45,  0},{40, 30,70, 60},{36, 25,65, 60},{32, 20,55, 60},{28, 16,50, 60},{25, 10,45, 60},},//ԃ}g}g
	{{99, 20,50,  0},{99,  0, 0,  0},{42, 50,75, 80},{38, 43,70, 80},{35, 36,65, 80},{32, 27,60, 80},},//@
	/*:::p2*/
	{{99, 12,40,  0},{15, 20,45,  5},{10, 15,35,  5},{ 7, 10,30,  5},{ 5,  8,27,  5},{ 3,  6,24,  5},},//lʌ
	{{99, 12,40,  0},{20, 27,50, 10},{17, 24,45, 10},{14, 20,44, 10},{11, 15,40, 10},{ 9, 10,32, 10},},//ԏ
	{{99, 20,55,  0},{22, 32,50, 25},{20, 30,48, 25},{18, 25,43, 25},{15, 21,40, 25},{12, 15,35, 25},},//􂯏
	{{99, 27,60,  0},{30, 50,70, 40},{26, 40,65, 40},{23, 36,60, 40},{20, 32,55, 40},{18, 25,50, 40},},//^[{k
	{{99, 18,55,  0},{32, 36,55, 60},{30, 30,52, 60},{27, 27,48, 60},{23, 20,45, 60},{20, 16,40, 60},},//ԒM~
	{{99, 21,55,  0},{35, 40,60, 75},{32, 38,57, 75},{29, 35,53, 75},{26, 30,48, 75},{24, 25,45, 75},},//[̓db
	{{99, 22,60,  0},{99,  0, 0,  0},{40, 80,70, 90},{35, 72,65, 90},{32, 60,60, 90},{30, 50,55, 90},},//ڂ
	{{99, 25,70,  0},{46, 60,85,100},{43, 50,82,100},{40, 48,80,100},{36, 44,75,100},{33, 40,70,100},},//˂(v1.1.19 ̎肩ύX)
	/*:::p3*/
	{{99,  0, 0,  0},{14, 35,60,  7},{12, 32,55,  7},{ 8, 27,50,  7},{ 6, 24,45,  7},{ 4, 20,40,  7},},//UFO
	{{99,  0, 0,  0},{20, 40,55, 10},{16, 32,50, 10},{12, 28,44, 10},{10, 22,40, 10},{ 8, 18,36, 10},},//l̔
	{{99,  0, 0,  0},{99,  0, 0,  0},{30, 45,60, 40},{25, 40,55, 40},{21, 32,50, 40},{18, 27,44, 40},},//lbV[
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{30,  1,90, 70},{27,  1,80, 70},{24,  1,75, 70},},//̎(v1.1.19 OڂɈړ\ύX)
	{{99,  0, 0,  0},{38, 50,70, 80},{36, 45,65, 80},{32, 40,60, 80},{29, 36,55, 80},{26, 32,50, 80},},//gO[}
	{{99,  0, 0,  0},{99,  0, 0,  0},{43, 60,85,100},{40, 50,80,100},{36, 44,70,100},{32, 37,64,100},},//hbyQK[
	{{99,  0, 0,  0},{48, 70,90,120},{46, 65,85,120},{44, 60,83,120},{42, 55,80,120},{39, 47,75,120},},//MIB
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{48, 70,88,160},{45, 65,83,160},{42, 50,80,160},},//ʒ̏P
	/*:::p4*/
	{{99,  0, 0,  0},{24, 35,55, 50},{18, 30,50, 50},{16, 24,45, 50},{13, 20,40, 50},{10, 15,35, 50},},//GC{̖̎ԗ
	{{99,  0, 0,  0},{35, 30,65, 80},{30, 25,60, 80},{25, 20,55, 80},{22, 15,50, 80},{18, 12,35, 80},},//XC}̐o
	{{99,  0, 0,  0},{43, 75,83,100},{40, 70,80,100},{35, 60,75,100},{30, 50,70,100},{27, 40,65,100},},//يEƂ̐ڐG
	{{99,  0, 0,  0},{50, 40,60,100},{42, 35,55,100},{37, 30,50,100},{33, 20,45,100},{30, 18,40,100},},//يEւ̑ގU
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{41,200,90,120},{37,180,80,120},{35,150,75,120},},//̖I𐻑
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{45,128,95,140},{40,100,90,140},{37, 80,85,140},},//CVX̕
	{{99,  0, 0,  0},{99,  0, 0,  0},{50,120,95,160},{47,100,90,160},{44, 80,85,160},{40, 64,80,160},},//_̈
	{{99,  0, 0,  0},{99,  0, 0,  0},{99,  0, 0,  0},{50,120,95,200},{48, 96,90,200},{45, 77,85,200},},//O\g[g̈ꌂ
	};

magic_type hissatsu_info[32] =
{
		{ 1,   12,   0,   0},
		{ 3,   16,   0,   0},
		{ 6,   15,   0,   0},
		{ 9,   18,   0,   0},
		{ 10,   8,   0,   0},
		{ 12,  20,   0,   0},
		{ 14,   7,   0,   0},
		{ 17,  20,   0,   0},

		{ 19,  24,   0,   0},
		{ 22,  27,   0,   0},
		{ 24,  30,   0,   0},
		{ 25,  16,   0,   0},
		{ 27,  15,   0,   0},
		{ 29,  35,   0,   0},
		{ 32,  50,   0,   0},
		{ 35,  43,   0,   0},

		{ 18,  20,   0,   0},
		{ 22,  36,   0,   0},
		{ 24,  24,   0,   0},
		{ 26,  35,   0,   0},
		{ 30,  30,   0,   0},
		{ 32,  51,   0,   0},
		{ 36,  25,   0,   0},
		{ 39,  64,   0,   0},

		{ 26,  20,   0,   0},
		{ 29,  40,   0,   0},
		{ 31,  35,   0,   0},
		{ 36,  68,   0,   0},
		{ 39,  80,   0,   0},
		{ 42, 110,   0,   0},
		{ 45, 120,   0,   0},
		{ 50, 180,   0,   0}
};

///realḿApAp̊e@̃xAMPAsAol
#if 0
const magic_type technic_info[NUM_TECHNIC][32] =
{
	{
		/* Music */
		{ 1,  1,  10,   2},
		{ 2,  1,  10,   2},
		{ 3,  2,  20,   3},
		{ 4,  2,  20,   4},
		{ 5,  2,  20,   6},
		{ 7,  4,  30,   8},
		{ 9,  3,  30,   10},
		{ 10, 2,  30,   12},

		{ 12,  3,   40,   20},
		{ 15, 16,  42,   35},
		{ 17, 18,  40,   25},
		{ 18,  2,  45,   30},
		{ 23,  8,  50,   38},
		{ 28, 30,  50,   41},
		{ 33, 35,  60,   42},
		{ 38, 35,  70,   46},

		{ 10,  4,  20,   13},
		{ 22,  5,  30,   26},
		{ 23,  3,  35,   27},
		{ 26,  28,  37,   29},
		{ 32,  37,  41,   36},
		{ 33,  22,  43,   40},
		{ 37,  35,  46,   42},
		{ 45,  60,  50,   56},

		{ 23,  18,  20,   23},
		{ 30,  30,  30,   26},
		{ 33,  65,  41,   30},
		{ 37,  35,  43,   35},
		{ 40,  30,  46,   50},
		{ 42,  75,  50,   68},
		{ 45,  58,  62,   73},
		{ 49,  48,  70,  200}
	},

	{
		/* Hissatsu */
		{ 1,   15,   0,   0},
		{ 3,   10,   0,   0},
		{ 6,   15,   0,   0},
		{ 9,    8,   0,   0},
		{ 10,  12,   0,   0},
		{ 12,  25,   0,   0},
		{ 14,   7,   0,   0},
		{ 17,  20,   0,   0},

		{ 19,  10,   0,   0},
		{ 22,  20,   0,   0},
		{ 24,  30,   0,   0},
		{ 25,  10,   0,   0},
		{ 27,  15,   0,   0},
		{ 29,  45,   0,   0},
		{ 32,  70,   0,   0},
		{ 35,  50,   0,   0},

		{ 18,  40,   0,   0},
		{ 22,  22,   0,   0},
		{ 24,  30,   0,   0},
		{ 26,  35,   0,   0},
		{ 30,  30,   0,   0},
		{ 32,  60,   0,   0},
		{ 36,  40,   0,   0},
		{ 39,  80,   0,   0},

		{ 26,  20,   0,   0},
		{ 29,  40,   0,   0},
		{ 31,  35,   0,   0},
		{ 36,  80,   0,   0},
		{ 39, 100,   0,   0},
		{ 42, 110,   0,   0},
		{ 45, 130,   0,   0},
		{ 50, 255,   0,   0}
	},

	{
		/* Hex */
		{  1,  2, 20,   2},
		{  1,  2, 20,   2},
		{  3,  2, 30,   3},
		{  5,  3, 30,   4},
		{  7,  3, 40,   6},
		{  8, 10, 60,   8},
		{  9,  3, 30,  10},
		{ 10,  5, 40,  12},

		{ 12,  8, 40,  15},
		{ 12,  9, 35,  15},
		{ 15, 10, 50,  20},
		{ 20, 12, 45,  35},
		{ 25, 15, 50,  50},
		{ 30, 12, 60,  70},
		{ 35, 10, 60,  80},
		{ 40, 16, 70, 100},

		{ 15,  8, 20,  20},
		{ 18, 15, 50,  20},
		{ 22, 10, 65,  35},
		{ 25, 28, 70,  50},
		{ 28, 10, 70,  60},
		{ 30, 20, 60,  60},
		{ 36, 22, 70,  80},
		{ 40, 28, 70, 100},

		{  5,  6, 35,   5},
		{ 22, 24, 70,  40},
		{ 25,  2, 65,  50},
		{ 32, 20, 50,  70},
		{ 35, 35, 70,  80},
		{ 38, 32, 70,  90},
		{ 42, 24, 70, 120},
		{ 46, 45, 80, 200}
	},
};
#endif

/*
 * Zangband uses this array instead of the spell flags table, as there
 * are 5 realms of magic, each with 4 spellbooks and 8 spells per book -- TY
 */
const u32b fake_spell_flags[4]=
{
	0x000000ff,
	0x0000ff00,
	0x00ff0000,
	0xff000000
};

#if 0
///realm class
const s32b realm_choices1[MAX_CLASS] =
{
	(CH_NONE),				/* Warrior */
	(CH_LIFE | CH_SORCERY | CH_NATURE |
	 CH_CHAOS | CH_DEATH | CH_TRUMP |
	 CH_ARCANE | CH_ENCHANT | CH_DAEMON |
	 CH_CRUSADE),                              /* Mage */
	(CH_LIFE | CH_DEATH | CH_DAEMON |
	 CH_CRUSADE),                              /* Priest */
	(CH_SORCERY | CH_DEATH | CH_TRUMP |
	 CH_ARCANE | CH_ENCHANT),               /* Rogue */
	(CH_NATURE),                            /* Ranger */
	(CH_CRUSADE | CH_DEATH),                   /* Paladin */
	(CH_ARCANE),                            /* Warrior-Mage */
	(CH_CHAOS | CH_DAEMON),                 /* Chaos-Warrior */
	(CH_LIFE | CH_NATURE | CH_DEATH |
	 CH_ENCHANT),                           /* Monk */
	(CH_NONE),                              /* Mindcrafter */
	(CH_LIFE | CH_SORCERY | CH_NATURE |
	 CH_CHAOS | CH_DEATH | CH_TRUMP |
	 CH_ARCANE | CH_ENCHANT | CH_DAEMON |
	 CH_CRUSADE | CH_HEX),                  /* High-Mage */
	(CH_ARCANE),                            /* Tourist */
	(CH_NONE),                              /* Imitator */
	(CH_TRUMP),                             /* Beastmaster */
	(CH_NONE),                              /* Sorcerer */
	(CH_NONE),                              /* Archer */
	(CH_NONE),                              /* Magic eater */
	(CH_MUSIC),                             /* Bard */
	(CH_NONE),                              /* Red Mage */
	(CH_HISSATSU),                          /* Samurai */
	(CH_LIFE | CH_NATURE | CH_DEATH |
	 CH_ENCHANT | CH_CRUSADE),                 /* ForceTrainer */
	(CH_NONE),                              /* Blue Mage */
	(CH_NONE),				/* Cavalry */
	(CH_NONE),				/* Berserker */
	(CH_NONE),				/* Weaponsmith */
	(CH_NONE),				/* Mirror-master */
	(CH_NONE),				/* Ninja */
	(CH_NONE),				/* Sniper */
};

///realm class
const s32b realm_choices2[MAX_CLASS] =
{
	(CH_NONE),                              /* Warrior */
	(CH_LIFE | CH_SORCERY | CH_NATURE |
	 CH_CHAOS | CH_DEATH | CH_TRUMP |
	 CH_ARCANE | CH_ENCHANT | CH_DAEMON |
	 CH_CRUSADE),                              /* Mage */
	(CH_LIFE | CH_SORCERY | CH_NATURE |
	 CH_CHAOS | CH_DEATH | CH_TRUMP |
	 CH_ARCANE | CH_ENCHANT | CH_DAEMON |
	 CH_CRUSADE),                              /* Priest */
	(CH_NONE),                              /* Rogue */
	(CH_SORCERY | CH_CHAOS | CH_DEATH |
	 CH_TRUMP | CH_ARCANE | CH_DAEMON),     /* Ranger */
	(CH_NONE),                              /* Paladin */
	(CH_LIFE | CH_NATURE | CH_CHAOS |
	 CH_DEATH | CH_TRUMP | CH_ARCANE |
	 CH_SORCERY | CH_ENCHANT | CH_DAEMON |
	 CH_CRUSADE),                              /* Warrior-Mage */
	(CH_NONE),                              /* Chaos-Warrior */
	(CH_NONE),                              /* Monk */
	(CH_NONE),                              /* Mindcrafter */
	(CH_NONE),                              /* High-Mage */
	(CH_NONE),                              /* Tourist */
	(CH_NONE),                              /* Imitator */
	(CH_NONE),                              /* Beastmanster */
	(CH_NONE),                              /* Sorcerer */
	(CH_NONE),                              /* Archer */
	(CH_NONE),                              /* Magic eater */
	(CH_NONE),                              /* Bard */
	(CH_NONE),                              /* Red Mage */
	(CH_NONE),                              /* Samurai */
	(CH_NONE),                              /* ForceTrainer */
	(CH_NONE),                              /* Blue Mage */
	(CH_NONE),				/* Cavalry */
	(CH_NONE),				/* Berserker */
	(CH_NONE),				/* Weaponsmith */
	(CH_NONE),				/* Mirror-master */
	(CH_NONE),				/* Ninja */
	(CH_NONE),				/* Sniper */
};
#endif

#ifdef JP
const cptr realm_names[TV_BOOK_END+1] =
{
	"_~[",
	"f",
	"\",
	"t^",
	"",
	"_",
	"",
	"j",
	"R",
	"ϗe",
	"Í",
	"",
	"",
	"|",
	"",
	"p",
};
#endif

#ifdef JP
const cptr E_realm_names[TV_BOOK_END+1]
#else
const cptr realm_names[]
#endif
= {
	"none",
	"Element",
	"Foreseeing",
	"Enchant",
	"Summon",
	"Mystic",
	"Life",
	"Punish",
	"Nature",
	"Transform",
	"Darkness",
	"Necromancy",
	"Chaos",
	"Sword",
	"Makedrug",
	"Occult",
};
/*:::@̈於ꗗ@Y*/
/*
#ifdef JP
const cptr realm_names[] =
{
	"@Ȃ",
	"",
	"p",
	"R",
	"JIX",
	"Í",
	"gv",
	"p",
	"",
	"",
	"j",
	"s",
	"s",
	"s",
	"s",
	"s",
	"",
	"|",
	"p",
	"s"
};
#endif

#ifdef JP
const cptr E_realm_names[]
#else
const cptr realm_names[]
#endif
= {
	"none",
	"Life",
	"Sorcery",
	"Nature",
	"Chaos",
	"Death",
	"Trump",
	"Arcane",
	"Craft",
	"Daemon",
	"Crusade",
	"unknown",
	"unknown",
	"unknown",
	"unknown",
	"unknown",
	"Music",
	"Kendo",
	"Hex",
	"unknown"
};
*/

/*
 * Each chest has a certain set of traps, determined by pval
 * Each chest has a "pval" from 1 to the chest level (max 55)
 * If the "pval" is negative then the trap has been disarmed
 * The "pval" of a chest determines the quality of its treasure
 * Note that disarming a trap on a chest also removes the lock.
 */
const int chest_traps[64] =
{
	0,                                      /* 0 == empty */
	(CHEST_POISON),
	(CHEST_LOSE_STR),
	(CHEST_LOSE_CON),
	(CHEST_LOSE_STR),
	(CHEST_LOSE_CON),                       /* 5 == best small wooden */
	0,
	(CHEST_ALARM),
	(CHEST_ALARM),
	(CHEST_LOSE_STR),
	(CHEST_LOSE_CON),
	(CHEST_POISON),
	(CHEST_SCATTER),
	(CHEST_LOSE_STR | CHEST_LOSE_CON),
	(CHEST_LOSE_STR | CHEST_LOSE_CON),
	(CHEST_SUMMON),                 /* 15 == best large wooden */
	0,
	(CHEST_ALARM),
	(CHEST_SCATTER),
	(CHEST_PARALYZE),
	(CHEST_LOSE_STR | CHEST_LOSE_CON),
	(CHEST_SUMMON),
	(CHEST_PARALYZE),
	(CHEST_LOSE_STR),
	(CHEST_LOSE_CON),
	(CHEST_EXPLODE),                        /* 25 == best small iron */
	0,
	(CHEST_E_SUMMON),
	(CHEST_POISON | CHEST_LOSE_CON),
	(CHEST_LOSE_STR | CHEST_LOSE_CON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_BIRD_STORM),
	(CHEST_POISON | CHEST_SUMMON),
	(CHEST_E_SUMMON | CHEST_ALARM),
	(CHEST_EXPLODE),
	(CHEST_EXPLODE | CHEST_SUMMON), /* 35 == best large iron */
	0,
	(CHEST_SUMMON | CHEST_ALARM),
	(CHEST_EXPLODE),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_POISON | CHEST_PARALYZE),
	(CHEST_EXPLODE),
	(CHEST_BIRD_STORM),
	(CHEST_EXPLODE | CHEST_E_SUMMON | CHEST_ALARM),
	(CHEST_H_SUMMON),        /* 45 == best small steel */
	0,
	(CHEST_EXPLODE | CHEST_SUMMON | CHEST_ALARM),
	(CHEST_BIRD_STORM),
	(CHEST_RUNES_OF_EVIL),
	(CHEST_EXPLODE | CHEST_SUMMON | CHEST_ALARM),
	(CHEST_BIRD_STORM | CHEST_ALARM),
	(CHEST_H_SUMMON | CHEST_ALARM),
	(CHEST_RUNES_OF_EVIL),
	(CHEST_H_SUMMON | CHEST_SCATTER | CHEST_ALARM),
	(CHEST_RUNES_OF_EVIL | CHEST_EXPLODE),  /* 55 == best large steel */
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
	(CHEST_EXPLODE | CHEST_SUMMON),
};


/*
 * Class titles for the player.
 *
 * The player gets a new title every five levels, so each class
 * needs only ten titles total.
 */
///del140126 EƂƂ݂̏̍Ȃ̂sgp
#if 0
#ifdef JP
const cptr player_title[MAX_CLASS][PY_MAX_LEVEL / 5] =
{
	/* Warrior */
	{
		"VQ",
		"m",
		"b",
		"ÎQ",
		"m",
		"m",
		"pY",
		"j",
		"",
		"N",
	},

	/* Mage */
	{
				/*"K",*/
		"K",                 /*tAK */
		"pt",               /*\tAyet */
		"pt",
		"pt",
		"t",
		"t",
		"pt",
		"t",
		"CvVV}X",
		"喂t",
	},

	/* Priest */
	{
		"M",                 /*Mk */
		"m",             /*dҁAKmAmA] */
		"nm",
		"E",                 /*E */
		"`t",               /*iՕ]cAC */
		"qt",               /*}̑m */
		"l",               /*iA勳Ai */
		"Վi",                 /*ՎiAi */
		"Վi",               /*ՎiAՎi */
		"c",
	},

	/* Rogues */
	{
		/* "",*/                     /*AVAQ */
		"",
		"ǂ͂",                     /*ǂAAD_ */
		"铐",                         /*A铐AD_ */
		"D",                       /*DAD_ */
		"yet",                     /*kAyetA\t */
		"EV[t",
		"nCV[t",
		"}X^[", /* "}X^[V[t", */
		"ATV",						/* ÎE */
		"", /*"Mh}X^[",*/
	},

	/* Rangers */
	{
		"g",
		"yv",
		"ˌ",                         /*ˌAA@ */
		"l",
		"ǐՎ",
		"擱",
		"T",                       /*JҁAT */
		"앚",
		"앚",
		"앚̑",
	},

	/* Paladins */
	{
		"Em",                 /*FjAlAҁAEȐl */
		"qm",
		"ی",
		"hq",
		"q",
		"Rm",
		"dRm",
		"Rm",
		"㋉Rm",
		"Rmc",
	},

	/* Warrior-Mage */
	{
		"K",
		"k",			/*tAK */
		"lO",
		"ÎQ",
		"pm",
		"pm",
		"p̉pY", /* Mage-Hero */
		"j",
		/* "", */
		"퓬pm",
		"m̎", /* "EBU[h[h", */
	},

	/* Chaos Warrior */
	{
		"VQ",
		"m",
		"b",
		"ÎQ",
		"m",
		"m",
		"ׂ̉pY",
		"ׂ̒j",
		"ׂ̌",
		"ׂ̉",
	},

	/* Monk */
	{
		"",
		"q",
		"q",
		"t͑",
		"t",
		"",
		"l",
		"喼l",
		"",
		"_",
	},

	/* Mindcrafter */
	{
		"K",
		"K",
		"nm",
		"nBm",
		"ّzm",
		"Spm",
		"TCLbN",
		"TCIjbN",
		"\͎",
		"_̎xz", /* "}Ch}X^[", */
	},

	/* High Mage; same as Mage */
	{
				/*"K",*/
		"K",                 /*tAK */
		"pt",               /*\tAyet */
		"pt",
		"pt",
		"t",
		"t",
		"pt",
		"t",
		"CvVV}X",
		"喂t",
	},

	/* Tourist */
	{
		"v[Y",
		"όq",
		"Vs",
		"՗",
		"s",
		"Q", /* "l", */
		"qC",
		"T",
		"`",
		"XyJ[",
	},

	/* Imitator */
	{
		"ꂩ",
		"܂",
		"܂܂",
		"ڂڂ",
		"",
		"܂܂",
		"ȂȂ",
		"",
		"Ƃ",
		"炢",
	},

	/* Beastmaster */
	{
		"Cg",
		"wrg",
		"Ng",
		"Tg",
		"gg",
		"bg",
		"qhg",
		"nEhg",
		"[}Ng",
		"hSg",
	},

	/* Sorcerer; same as Mage */
	{
				/*"K",*/
		"K",                 /*tAK */
		"pt",               /*\tAyet */
		"pt",
		"pt",
		"t",
		"t",
		"pt",
		"t",
		"CvVV}X",
		"喂t",
	},

	/* Archer */
	{
		"VQ",
		"m",
		"b",
		"ÎQ",
		"m",
		"m",
		"pY",
		"j",
		"",
		"̎",
	},

	/* Magic eater */
	{
		"mȂ",
		"",
		"pt",
		"pt",
		"pt",
		"n",
		"Bl",
		"Bl",
		"t",
		"SĂm",
	},

	/* Bard */
	{
		"K",	/*"Apprentice"*/
		"ȉ",	/*"Songsmith"*/
		"Vl",	/*"Bard"*/
		"RpjI",	/*"Companion"*/
		"S̖",	/*"Minstrel"*/
		"GՎt",	/*"Harper"*/
		"`̖a",	/*"Loreweaver"*/
		"_̐\q",	/*"Muse"*/
		"a",	/*"Dreamweaver"*/
		"}X^[",	/*"Master Harper"*/
	},

	/* Red Mage; same as Warrior-Mage */
	{
		"K",
		"k",			/*tAK */
		"lO",
		"ÎQ",
		"pm",
		"pm",
		"p̉pY", /* Mage-Hero */
		"j",
		/* "", */
		"퓬pm",
		"m̎", /* "EBU[h[h", */
	},

	/* Samurai */
	{
		"",
		"q",
		"q",
		"t͑",
		"t",
		"",
		"l",
		"喼l",
		"",
		"_",
	},

	/* ForceTrainer; same as Monk(?) */
	{
		"",
		"q",
		"q",
		"t͑",
		"t",
		"",
		"l",
		"喼l",
		"",
		"_",
	},

	/* Blue Mage; same as Mage */
	{
				/*"K",*/
		"K",                 /*tAK */
		"pt",               /*\tAyet */
		"pt",
		"pt",
		"t",
		"t",
		"pt",
		"t",
		"CvVV}X",
		"喂t",
	},

	/* Cavalry */
	{
		"VQ",
		"m",
		"b",
		"ÎQ",
		"m",
		"m",
		"pY",
		"j",
		"",
		"̎",
	},

	/* Berserker */
	{
		"o[T[J[",
		"o[T[J[",
		"o[T[J[",
		"{̌",
		"{̌",
		"{̌",
		"{̉",
		"{̉",
		"{̉",
		"{̉g",
	},

	/* Weaponsmith */
	{
		"b",
		"Sb",
		"|b",
		"b",
		"b",
		"b",
		"b",
		"b",
		"_b",
		"Sb",
	},

	/* Mirror Master */
	{
		"l",
		"",
		"El",
		"pt",
		"t",
		"̌",
		"̉",
		"̍c",
		"̉g",
		"tm[",
	},
	/* Ninja */
	{
		"P",
		"d",
		"nB",
		"Zg",
		"؂",
		"r",
		"̐n",
		"ł̈ꌂ",
		"ÎE",
		"̒r",
	},

	/* Sniper */
	{
		"VQ",
		"m",
		"b",
		"ÎQ",
		"m",
		"m",
		"pY",
		"j",
		"",
		"̎",
	},
};

#else
const cptr player_title[MAX_CLASS][PY_MAX_LEVEL / 5] =
{
	/* Warrior */
	{
		"Rookie",
		"Soldier",
		"Mercenary",
		"Veteran",
		"Swordsman",
		"Champion",
		"Hero",
		"Baron",
		"Duke",
		"Lord",
	},

	/* Mage */
	{
		"Apprentice",
		"Trickster",
		"Illusionist",
		"Spellbinder",
		"Evoker",
		"Conjurer",
		"Warlock",
		"Sorcerer",
		"Ipsissimus",
		"Archimage",
	},

	/* Priest */
	{
		"Believer",
		"Acolyte",
		"Adept",
		"Curate",
		"Canon",
		"Priest",
		"High Priest",
		"Cardinal",
		"Inquisitor",
		"Pope",
	},

	/* Rogues */
	{
		"Cutpurse",
		"Robber",
		"Burglar",
		"Filcher",
		"Sharper",
		"Low Thief",
		"High Thief",
		"Master Thief",
		"Assassin",
		"Guildmaster",
	},

	/* Rangers */
	{
		"Runner",
		"Strider",
		"Scout",
		"Courser",
		"Tracker",
		"Guide",
		"Pathfinder",
		"Low Ranger",
		"High Ranger",
		"Ranger Lord",
	},

	/* Paladins */
	{
		"Gallant",
		"Keeper",
		"Protector",
		"Defender",
		"Warder",
		"Knight",
		"Guardian",
		"Low Paladin",
		"High Paladin",
		"Paladin Lord",
	},

	/* Warrior-Mage */
	{
		"Novice",
		"Apprentice",
		"Journeyman",
		"Veteran",
		"Enchanter",
		"Champion",
		"Mage-Hero",
		"Baron Mage",
		"Battlemage",
		"Wizard Lord",
	},

	/* Chaos Warrior */
	{
		"Rookie",
		"Soldier",
		"Mercenary",
		"Veteran",
		"Swordsman",
		"Champion",
		"Chaos Hero",
		"Chaos Baron",
		"Chaos Duke",
		"Chaos Lord",
	},

	/* Monk */
	{
		"Initiate",
		"Brother",
		"Disciple",
		"Immaculate",
		"Master",
		"Soft Master",
		"Hard Master",
		"Flower Master",
		"Dragon Master",
		"Grand Master",
	},

	/* Mindcrafter */
	{
		"Trainee",
		"Acolyte",
		"Adept",
		"Immaculate",
		"Contemplator",
		"Mentalist",
		"Psychic",
		"Psionicist",
		"Esper",
		"Mindmaster",
	},

	/* High Mage; same as Mage */
	{
		"Apprentice",
		"Trickster",
		"Illusionist",
		"Spellbinder",
		"Evoker",
		"Conjurer",
		"Warlock",
		"Sorcerer",
		"Ipsissimus",
		"Archimage",
	},

	/* Tourist */
	{
		"Rambler",
		"Sightseer",
		"Excursionist",
		"Peregrinator",
		"Traveler",
		"Journeyer",
		"Voyager",
		"Explorer",
		"Adventurer",
		"Spelunker",
	},

	/* Imitator */
	{
		"Yet",
		"Lacks",
		"Still more",
		"So so",
		"All right",
		"Not bad",
		"Considerable",
		"Go go",
		"Sizable",
		"Great man",
	},

	/* BeastMaster */
	{
		"Newt Master",
		"Snake Master",
		"Spider Master",
		"Wolf Master",
		"Tiger Master",
		"Beetle Master",
		"Hydra Master",
		"Hound Master",
		"Mumak Master",
		"Dragon Master",
	},

	/* Sorcerer */
	{
		"Apprentice",
		"Trickster",
		"Illusionist",
		"Spellbinder",
		"Evoker",
		"Conjurer",
		"Warlock",
		"Sorcerer",
		"Ipsissimus",
		"Archimage",
	},

	/* Archer */
	{
		"Rookie",
		"Soldier",
		"Mercenary",
		"Veteran",
		"Bowman",
		"Champion",
		"Hero",
		"Baron",
		"Duke",
		"Lord",
	},

	/* Magic eater */
	{
		"Apprentice",
		"Beginner",
		"Jagguler",
		"Skilled",
		"Conjurer",
		"Magician",
		"Master",
		"Master",
		"Wizard",
		"Almighty",
	},

	/* Bard */
	{
		"Apprentice",	/*"Apprentice"*/
		"Songsmith",	/*"Songsmith"*/
		"Bard",	/*"Bard"*/
		"Companion",	/*"Companion"*/
		"Minstrel",	/*"Minstrel"*/
		"Harper",	/*"Harper"*/
		"Loreweaver",	/*"Loreweaver"*/
		"Muse",	/*"Muse"*/
		"Dreamweaver",	/*"Dreamweaver"*/
		"Master Harper",	/*"Master Harper"*/
	},

	/* Red Mage */
	{
		"Novice",
		"Apprentice",
		"Journeyman",
		"Veteran",
		"Enchanter",
		"Champion",
		"Mage-Hero",
		"Baron Mage",
		"Battlemage",
		"Wizard Lord",
	},

	/* Samurai */
	{
		"Initiate",
		"Brother",
		"Disciple",
		"Immaculate",
		"Master",
		"Soft Master",
		"Hard Master",
		"Flower Master",
		"Dragon Master",
		"Grand Master",
	},

	/* ForceTrainer */
	{
		"Initiate",
		"Brother",
		"Disciple",
		"Immaculate",
		"Master",
		"Soft Master",
		"Hard Master",
		"Flower Master",
		"Dragon Master",
		"Grand Master",
	},

	/* Blue Mage */
	{
		"Apprentice",
		"Trickster",
		"Illusionist",
		"Spellbinder",
		"Evoker",
		"Conjurer",
		"Warlock",
		"Sorcerer",
		"Ipsissimus",
		"Archimage",
	},

	/* Warrior */
	{
		"Rookie",
		"Soldier",
		"Mercenary",
		"Veteran",
		"Swordsman",
		"Champion",
		"Hero",
		"Baron",
		"Duke",
		"Lord",
	},

	/* Berserker */
	{
		    "Berserker",
		    "Berserker",
		    "Berserker",
		    "Rage Prince",
		    "Rage Prince",
		    "Rage Prince",
		    "Rage King",
		    "Rage King",
		    "Rage King",
		    "God of Rage",
	},

	/* Weaponsmith */
	{
		"Copper smith",
		"Iron smith",
		"Steel smith",
		"Silver smith",
		"Dragon smith",
		"Spirit smith",
		"Magic smith",
		"Soul smith",
		"God smith",
		"AlmightySmith",
	},

	/* Mirror Master */
	{
		"Mirrorstarer",
		"Mirrorcleaner",
		"Mirrormaker",
		"Mirrormagician",
		"Mirror Guru",
		"Mirror Mage",
		"Mirror King",
		"Mirror Emperor",
		"Mirror Avatar",
		"Ruffnor King",
	},

	/* Ninja */
	{
		"Trainee",
		"Myrmidon",
		"Initiate",
		"Knifer",
		"Bladesman",
		"Hashishin",
		"Black Dagger",
		"Shadowstrike",
		"Assassinator",
		"Death Lord",
	},

	/* Sniper */
	{
		"Rookie",
		"Soldier",
		"Mercenary",
		"Veteran",
		"Swordsman",
		"Champion",
		"Hero",
		"Baron",
		"Duke",
		"Lord",
	},
};
#endif
#endif




const monster_power monster_powers[MAX_MONSPELLS] =
{
/* level,  smana,  %fail,  manedam,  %manefail,  use_stat, name */
#ifdef JP
{  1,   1,  10,    0,  15, A_CON,  ""},
{ 10,   4,  35,   89,  40, A_INT,  ""},
{ 40,  35,  85,    0,  40, A_INT,  "͏"},
{ 35,  30,  80,  800,  70, A_STR,  "Pbg"},
{  5,   1,  20,   18,  15, A_DEX,  "ˌ"},
{ 10,   4,  35,   89,  40, A_INT,  ""},
{ 10,   4,  35,   89,  40, A_INT,  ""},
{ 10,   4,  35,   89,  40, A_INT,  ""},
{ 20,  15,  55, 1600,  95, A_CON,  "_̃uX"},
{ 20,  15,  55, 1600,  95, A_CON,  "d̃uX"},
{ 20,  15,  55, 1600,  95, A_CON,  "̃uX"},
{ 20,  15,  55, 1600,  95, A_CON,  "C̃uX"},
{ 20,  15,  55,  800,  95, A_CON,  "ł̃uX"},
{ 20,  15,  70,  550,  95, A_CON,  "ñuX"},
{ 20,  16,  70,  400,  95, A_CON,  "M̃uX"},
{ 20,  16,  70,  400,  95, A_CON,  "Í̃uX"},
{ 20,  20,  70,  450,  95, A_CON,  "̃uX"},
{ 20,  20,  70,  450,  95, A_CON,  "̃uX"},
{ 20,  20,  70,  600,  95, A_CON,  "JIX̃uX"},
{ 20,  16,  70,  500,  95, A_CON,  "򉻂̃uX"},
{ 30,  25,  80,  250,  95, A_CON,  "ʍ̃uX"},
{ 35,  18,  80,  150,  95, A_CON,  "ԋt]̃uX"},
{ 30,  25,  80,  200,  95, A_CON,  "x݂̃uX"},
{ 30,  28,  90,  200,  95, A_CON,  "d͂̃uX"},
{ 20,  15,  70,  500,  95, A_CON,  "jЂ̃uX"},
{ 35,  15,  80,  150,  95, A_CON,  "vY}̃uX"},
{ 30,  18,  70,  200,  95, A_CON,  "tH[X̃uX"},
{ 30,  28,  80,  250,  95, A_CON,  "͂̃uX"},
{ 25,  20,  95,  320,  80, A_INT,  "˔\"},
{ 25,  15,  70,  800,  95, A_CON,  "ːp̃uX"},
{ 30,  32,  85,  400,  80, A_INT,  "OX"},
{ 35,  40,  95,  150,  95, A_CON,  "̃uX"},
{ 18,  13,  55,  630,  80, A_INT,  "AVbhE{["},
{ 14,  10,  45,  316,  60, A_INT,  "T_[E{["},
{ 20,  14,  60,  720,  80, A_INT,  "t@CAE{["},
{ 15,  11,  50,  320,  60, A_INT,  "ACXE{["},
{  5,   3,  40,   48,  20, A_INT,  "L_"},
{ 25,  18,  70,  350,  80, A_INT,  "n"},
{ 30,  22,  75,  350,  80, A_INT,  "EH[^[E{["},
{ 44,  45,  85,  550,  95, A_INT,  "̗͂"},
{ 40,  42,  90,  550,  95, A_INT,  "Í̗"},
{ 10,   5,  50,    0,  25, A_INT,  "͋z"},
{ 25,  10,  60,    0,  30, A_INT,  "_U"},
{ 30,  14,  65,    0,  30, A_INT,  "]U"},
{  3,   1,  25,   24,  20, A_INT,  "y"},
{ 12,   2,  35,   64,  25, A_INT,  "d"},
{ 22,   6,  50,  150,  30, A_INT,  "v"},
{ 32,  10,  70,  225,  35, A_INT,  "E˂"},
{ 13,   7,  40,  178,  40, A_INT,  "AVbhE{g"},
{ 10,   5,  35,  130,  35, A_INT,  "T_[E{g"},
{ 15,   9,  50,  210,  45, A_INT,  "t@CAE{g"},
{ 12,   6,  35,  162,  40, A_INT,  "ACXE{g"},
{ 40,  42,  90,  550,  95, A_INT,  "X^[Eo[Xg"},
{ 25,  17,  60,  255,  60, A_INT,  "n̖"},
{ 25,  20,  65,  250,  60, A_INT,  "EH[^[E{g"},
{ 25,  24,  90,  400,  80, A_INT,  "̖͂"},
{ 25,  20,  80,  216,  60, A_INT,  "vY}E{g"},
{ 25,  16,  60,  186,  60, A_INT,  "Ɋ̖"},
{  3,   1,  25,   12,  20, A_INT,  "}WbNE~TC"},
{  5,   3,  35,    0,  20, A_INT,  "Q"},
{ 10,   5,  40,    0,  20, A_INT,  "Ӗ"},
{ 10,   5,  40,    0,  20, A_INT,  "pjbNEX^["},
{ 10,   5,  40,    0,  20, A_INT,  "XEEX^["},
{ 10,   5,  40,    0,  20, A_INT,  "X[vEX^["},
{ 20,  10,  70,    0,  40, A_INT,  "Xs[h"},
{ 45, 120,  95,    0,  60, A_INT,  "jł̎"},
{ 20,  15,  70,    0,  20, A_WIS,  "̗͉"},
{ 45,  65,  80,    0,  60, A_INT,  "̋"},
{  5,   1,  30,    0,  20, A_INT,  "V[gEe|[g"},
{ 15,   8,  40,    0,  30, A_INT,  "e|[g"},
{ 40, 999,  99,    0,  80, A_INT,  "UE[h"},
{  1,   0,   0,    0,  15, A_INT,  ""},
{ 15,   8,  50,    0,  30, A_INT,  "悹"},
{ 20,  13,  80,    0,  30, A_INT,  "e|[gEAEFC"},
{ 30,  40,  95,    0,  40, A_INT,  "e|[gEx"},
{ 35,  30,  80,  350,  70, A_INT,  "̌"},
{  5,   1,  20,    0,  15, A_INT,  "È"},
{  5,   1,  20,    0,  15, A_DEX,  "gbvn"},
{ 15,   3,  40,    0,  30, A_INT,  "Lr"},
{ 30,  30,  70,    0,  40, A_INT,  "ҕ"},
{ 40,  70,  85,    0,  45, A_INT,  "RĂ"},
{ 45,  90,  90,    0,  50, A_INT,  "TCo[f[̏"},
{ 25,  20,  65,    0,  30, A_INT,  "X^[̏"},
{ 35,  30,  75,    0,  40, A_INT,  "̃X^[̏"},
{ 25,  25,  65,    0,  25, A_INT,  "Ȁ"},
{ 25,  20,  60,    0,  25, A_INT,  "w偂̏"},
{ 35,  26,  75,    0,  40, A_INT,  "nEh̏"},
{ 30,  23,  70,    0,  35, A_INT,  "qh̏"},
{ 40,  50,  85,    0,  40, A_INT,  "Vg̏"},
{ 35,  50,  80,    0,  35, A_INT,  "f[̏"},
{ 30,  30,  75,    0,  35, A_INT,  "Afbh̏"},
{ 39,  70,  80,    0,  40, A_INT,  "hS̏"},
{ 43,  85,  85,    0,  45, A_INT,  "㋉Afbh̏"},
{ 46,  90,  85,    0,  45, A_INT,  "ÑhS̏"},
{ 48, 120,  90,    0,  50, A_INT,  "Ao[̉̏"},
{ 50, 150,  95,    0,  50, A_INT,  "j[NX^[̏"},
#else
{  1,   1,  10,    0,  15, A_CON,  "shriek"},
{ 10,   4,  35,   89,  40, A_INT,  "something"},
{ 40,  35,  85,    0,  40, A_INT,  "dispel-magic"},
{ 35,  30,  80,  800,  70, A_STR,  "rocket"},
{  2,   1,  15,   10,  15, A_DEX,  "arrow"},
{  5,   2,  20,   18,  20, A_DEX,  "arrows"},
{ 12,   3,  25,   30,  25, A_DEX,  "missile"},
{ 16,   4,  30,   42,  30, A_DEX,  "missiles"},
{ 20,  15,  55, 1600,  95, A_CON,  "breath acid"},
{ 20,  15,  55, 1600,  95, A_CON,  "breath lightning"},
{ 20,  15,  55, 1600,  95, A_CON,  "breath fire"},
{ 20,  15,  55, 1600,  95, A_CON,  "breath cold"},
{ 20,  15,  55,  800,  95, A_CON,  "breath poison"},
{ 20,  15,  70,  550,  95, A_CON,  "breath nether"},
{ 20,  16,  70,  400,  95, A_CON,  "breath light"},
{ 20,  16,  70,  400,  95, A_CON,  "breath dark"},
{ 20,  20,  70,  450,  95, A_CON,  "breath confusion"},
{ 20,  20,  70,  450,  95, A_CON,  "breath sound"},
{ 20,  20,  70,  600,  95, A_CON,  "breath chaos"},
{ 20,  16,  70,  500,  95, A_CON,  "breath disenchantment"},
{ 30,  25,  80,  250,  95, A_CON,  "breath nexus"},
{ 35,  18,  80,  150,  95, A_CON,  "breath time"},
{ 30,  25,  80,  200,  95, A_CON,  "breath inertia"},
{ 30,  28,  90,  200,  95, A_CON,  "breath gravity"},
{ 20,  15,  70,  500,  95, A_CON,  "breath shards"},
{ 35,  15,  80,  150,  95, A_CON,  "breath plasma"},
{ 30,  18,  70,  200,  95, A_CON,  "breath force"},
{ 30,  28,  80,  250,  95, A_CON,  "breath mana"},
{ 25,  20,  95,  320,  80, A_INT,  "nuke ball"},
{ 25,  15,  70,  800,  95, A_CON,  "breath nuke"},
{ 30,  32,  85,  400,  80, A_INT,  "raw Logrus"},
{ 35,  40,  95,  150,  95, A_CON,  "breath disintegrate"},
{ 18,  13,  55,  630,  80, A_INT,  "acid ball"},
{ 14,  10,  45,  316,  60, A_INT,  "lightning ball"},
{ 20,  14,  60,  720,  80, A_INT,  "fire ball"},
{ 15,  11,  50,  320,  60, A_INT,  "frost ball"},
{  5,   3,  40,   48,  20, A_INT,  "stinking cloud"},
{ 25,  18,  70,  350,  80, A_INT,  "nether ball"},
{ 30,  22,  75,  350,  80, A_INT,  "water ball"},
{ 44,  45,  85,  550,  95, A_INT,  "mana storm"},
{ 40,  42,  90,  550,  95, A_INT,  "darkness storm"},
{ 10,   5,  50,    0,  25, A_INT,  "drain mana"},
{ 25,  10,  60,    0,  30, A_INT,  "mind blast"},
{ 30,  14,  65,    0,  30, A_INT,  "brain smash"},
{  3,   1,  25,   24,  20, A_INT,  "cause light wounds"},
{ 12,   2,  35,   64,  25, A_INT,  "cause serious wounds"},
{ 22,   6,  50,  150,  30, A_INT,  "cause critical wounds"},
{ 32,  10,  70,  225,  35, A_INT,  "cause mortal wounds"},
{ 13,   7,  40,  178,  40, A_INT,  "acid bolt"},
{ 10,   5,  35,  130,  35, A_INT,  "lightning bolt"},
{ 15,   9,  50,  210,  45, A_INT,  "fire bolt"},
{ 12,   6,  35,  162,  40, A_INT,  "frost bolt"},
{ 40,  42,  90,  550,  95, A_INT,  "starburst"},
{ 25,  17,  60,  255,  60, A_INT,  "nether bolt"},
{ 25,  20,  65,  250,  60, A_INT,  "water bolt"},
{ 25,  24,  90,  400,  80, A_INT,  "mana bolt"},
{ 25,  20,  80,  216,  60, A_INT,  "plasma bolt"},
{ 25,  16,  60,  186,  60, A_INT,  "ice bolt"},
{  3,   1,  25,   12,  20, A_INT,  "magic missile"},
{  5,   3,  35,    0,  20, A_INT,  "scare"},
{ 10,   5,  40,    0,  20, A_INT,  "blind"},
{ 10,   5,  40,    0,  20, A_INT,  "confuse"},
{ 10,   5,  40,    0,  20, A_INT,  "slow"},
{ 10,   5,  40,    0,  20, A_INT,  "sleep"},
{ 20,  10,  70,    0,  40, A_INT,  "speed"},
{ 45, 120,  95,    0,  60, A_INT,  "the Hand of Doom"},
{ 20,  15,  70,    0,  20, A_WIS,  "heal-self"},
{ 45,  65,  80,    0,  60, A_INT,  "make invulnerable"},
{  5,   1,  30,    0,  20, A_INT,  "blink-self"},
{ 15,   8,  40,    0,  30, A_INT,  "teleport-self"},
{ 40, 999,  99,    0,  80, A_INT,  "The world"},
{  1,   0,   0,    0,  15, A_INT,  "something"},
{ 15,   8,  50,    0,  30, A_INT,  "teleport to"},
{ 20,  13,  80,    0,  30, A_INT,  "teleport away"},
{ 30,  40,  95,    0,  40, A_INT,  "teleport level"},
{ 35,  30,  80,  350,  70, A_INT,  "psycho-spear"},
{  5,   1,  20,    0,  15, A_INT,  "create darkness"},
{  5,   1,  20,    0,  15, A_DEX,  "create traps"},
{ 15,   3,  40,    0,  30, A_INT,  "cause amnesia"},
{ 30,  30,  70,    0,  40, A_INT,  "raise dead"},
{ 40,  70,  85,    0,  45, A_INT,  "summon aid"},
{ 45,  90,  90,    0,  50, A_INT,  "summon Cyberdemons"},
{ 25,  20,  65,    0,  30, A_INT,  "summon a monster"},
{ 35,  30,  75,    0,  40, A_INT,  "summon monsters"},
{ 25,  25,  65,    0,  25, A_INT,  "summon ants"},
{ 25,  20,  60,    0,  25, A_INT,  "summon spiders"},
{ 35,  26,  75,    0,  40, A_INT,  "summon hounds"},
{ 30,  23,  70,    0,  35, A_INT,  "summon hydras"},
{ 40,  50,  85,    0,  40, A_INT,  "summon an angel"},
{ 35,  50,  80,    0,  35, A_INT,  "summon a daemon"},
{ 30,  30,  75,    0,  35, A_INT,  "summon an undead"},
{ 39,  70,  80,    0,  40, A_INT,  "summon a dragon"},
{ 43,  85,  85,    0,  45, A_INT,  "summon Greater Undead"},
{ 46,  90,  85,    0,  45, A_INT,  "summon Ancient Dragon"},
{ 48, 120,  90,    0,  50, A_INT,  "summon Lords of Amber"},
{ 50, 150,  95,    0,  50, A_INT,  "summon Unique Monsters"},
#endif

};


const cptr monster_powers_short[MAX_MONSPELLS] = {
#ifdef JP

	"", "", "͏", "Pbg", "ˌ", "", "", "",
	"_", "d", "Ή", "C", "", "n", "M", "Í",
	"", "", "JIX", "", "ʍ", "ԋt]", "x", "d",
	"j", "vY}", "tH[X", "", "˔\", "ːp", "OX", "",

	"_", "d", "Ή", "C", "L_", "n", "EH[^[", "̗͂",
	"Í̗", "͋z", "_U", "]U", "y", "d", "v", "E˂",
	"_", "d", "Ή", "C", "X^[o[Xg", "n̖", "EH[^[", "̖͂",
	"vY}", "Ɋ", "}WbN~TC", "Q", "Ӗ", "", "", "",

	"", "jł̎", "̗͉", "̋", "V[ge|[g", "e|[g", "~߂", "",
	"悹", "e|[gAEFC", "e|[gx", "̌", "È", "gbvn", "Lr", "ҕ",
	"R", "TCo[f[", "X^[", "̃X^[", "a", "w", "nEh", "qh",
	"Vg", "", "Afbh", "hS", "㋉Afbh", "ÑhS", "Ao[̉", "j[N"

#else

	"Shriek", "Something", "Dispel-magic", "Rocket", "Arrow", "Arrows", "Missile", "Missiles",
	"Acid", "Lightning", "Fire", "Cold", "Poison", "Nether", "Light", "Dark",
	"Confusion", "Sound", "Chaos", "Disenchantment", "Nexus", "Time", "Inertia", "Gravity",
	"Shards", "Plasma", "Force", "Mana", "Nuke", "Nuke", "Logrus", "Disintergrate",

	"Acid", "Lightning", "Fire", "Frost", "Stinking Cloud", "Nether", "Water", "Mana storm",
	"Darkness storm", "Drain mana", "Mind blast", "Brain smash", "Cause Light Wound", "Cause Serious Wound", "Cause Critical Wound", "Cause Mortal Wound",
	"Acid", "Lightning", "Fire", "Frost", "Starburst", "Nether", "Water", "Mana",
	"Plasm", "Ice", "Magic missile", "Scare", "Blind", "Confuse", "Slow", "Sleep",

	"Speed", "Hand of doom", "Heal-self", "Invulnerable", "Blink", "Teleport", "The world", "Something",
	"Teleport to", "Teleport away", "Teleport level", "Psycho-spear", "Create darkness", "Create traps", "Amnesia", "Raise dead",
	"Aid", "Cyberdeamons", "A monster", "Monsters", "Ants", "Spiders", "Hounds", "Hydras",
	"Angel", "Daemon", "Undead", "Dragon", "Greater Undead", "Ancient Dragon", "Lords of Amber", "Unique monsters"

#endif
};


/*
 * Hack -- the "basic" color names (see "TERM_xxx")
 */
const cptr color_names[16] =
{
#ifdef JP
	"",
	"",
	"DF",
	"IW",
	"",
	"",
	"",
	"ߐF",
	"DF",
	"DF",
	"",
	"",
	"邢",
	"邢",
	"邢",
	"ߐF",
#else
	"Dark",
	"White",
	"Slate",
	"Orange",
	"Red",
	"Green",
	"Blue",
	"Umber",
	"Light Dark",
	"Light Slate",
	"Violet",
	"Yellow",
	"Light Red",
	"Light Green",
	"Light Blue",
	"Light Umber",
#endif

};


/*
 * Abbreviations of healthy stats
 */
const cptr stat_names[6] =
{
#ifdef JP
	"r :", "m\ :", " :", "p :", "ϋv :", " :"
#else
	"STR : ", "INT : ", "WIS : ", "DEX : ", "CON : ", "CHR : "
#endif

};

/*
 * Abbreviations of damaged stats
 */
const cptr stat_names_reduced[6] =
{
#ifdef JP
	"rx:", "m\x:", "x:", "px:", "ϋvx:", "x:"
#else
	"Str : ", "Int : ", "Wis : ", "Dex : ", "Con : ", "Chr : "
#endif

};


/*
 * Certain "screens" always use the main screen, including News, Birth,
 * Dungeon, Tomb-stone, High-scores, Macros, Colors, Visuals, Options.
 *
 * Later, special flags may allow sub-windows to "steal" stuff from the
 * main window, including File dump (help), File dump (artifacts, uniques),
 * Character screen, Small scale map, Previous Messages, Store screen, etc.
 *
 * The "ctrl-i" (tab) command flips the "Display inven/equip" and "Display
 * equip/inven" flags for all windows.
 *
 * The "ctrl-g" command (or pseudo-command) should perhaps grab a snapshot
 * of the main screen into any interested windows.
 */
const cptr window_flag_desc[32] =
{
#ifdef JP
	"/ꗗ",
#else
	"Display inven/equip",
#endif

#ifdef JP
	"/ꗗ",
#else
	"Display equip/inven",
#endif

#ifdef JP
	"ꗗ",
#else
	"Display spell list",
#endif

#ifdef JP
	"LN^",
#else
	"Display character",
#endif
		
#ifdef JP
	"ẼX^[\",
#else
	"Display monsters in sight",
#endif		

	NULL,
#ifdef JP
	"bZ[W",
#else
	"Display messages",
#endif

#ifdef JP
	"_WS̐}",
#else
	"Display overhead view",
#endif

#ifdef JP
	"X^[̎vo",
#else
	"Display monster recall",
#endif

#ifdef JP
	"ACȅڍ",
#else
	"Display object recall",
#endif

#ifdef JP
	"̎͂\", 
#else
	"Display dungeon view",
#endif

#ifdef JP
	"LOBe",
#else
	"Display snap-shot",
#endif

	///mod140428
	"̃ACeꗗ",
	NULL,
#ifdef JP
	"{[OEbZ[W",
#else
	"Display borg messages",
#endif

#ifdef JP
	"{[OEXe[^X",
#else
	"Display borg status",
#endif

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL
};


/*
 * Available Options
 *
 */

 /*:::IvVꗗ@ŃRgAEgIvVϐcĂΎg邪Z[u[hȂ̂Œ*/

 //ł̃ftHgloption_info[].normpref-opt.prf̗LqĂH
 //ڍוs

const option_type option_info[] =
{
	/*** Input Options ***/

#ifdef JP
	{ &rogue_like_commands,         FALSE, OPT_PAGE_INPUT, 0, 0,
	"rogue_like_commands",          "[OL[zugp" },
#else
	{ &rogue_like_commands,         FALSE, OPT_PAGE_INPUT, 0, 0,
	"rogue_like_commands",          "Rogue-like commands" },
#endif

#ifdef JP
	{ &always_pickup,               FALSE, OPT_PAGE_INPUT, 0, 5,
	"always_pickup",                "ɃACeE" },
#else
	{ &always_pickup,               FALSE, OPT_PAGE_INPUT, 0, 5,
	"always_pickup",                "Pick things up by default" },
#endif

#ifdef JP
	{ &carry_query_flag,            FALSE, OPT_PAGE_INPUT, 0, 3,
	"carry_query_flag",             "ACeEOɊmF" },
#else
	{ &carry_query_flag,            FALSE, OPT_PAGE_INPUT, 0, 3,
	"carry_query_flag",             "Prompt before picking things up" },
#endif

#ifdef JP
	{ &quick_messages,              TRUE,  OPT_PAGE_INPUT, 0, 1,
	"quick_messages",               "NCbNEbZ[Wgp" },
#else
	{ &quick_messages,              TRUE,  OPT_PAGE_INPUT, 0, 1,
	"quick_messages",               "Activate quick messages" },
#endif

#ifdef JP
	{ &auto_more,                   FALSE, OPT_PAGE_INPUT, 2, 6,
	"auto_more",                    "L[҂ȂŘAŃbZ[W\" },
#else
	{ &auto_more,                   FALSE, OPT_PAGE_INPUT, 2, 6,
	"auto_more",                    "Automatically clear '-more-' prompts" },
#endif

#ifdef JP
	{ &command_menu,                TRUE,  OPT_PAGE_INPUT, 2, 7,
	"command_menu",                 "j[ɂR}hILɂ" },
#else
	{ &command_menu,                TRUE,  OPT_PAGE_INPUT, 2, 7,
	"command_menu",                 "Enable command selection menu" },
#endif

#ifdef JP
	{ &other_query_flag,            FALSE, OPT_PAGE_INPUT, 0, 2,
	"other_query_flag",             "̃ACegpƂɊmF" },
#else
	{ &other_query_flag,            FALSE, OPT_PAGE_INPUT, 0, 2,
	"other_query_flag",             "Prompt for floor item selection" },
#endif

#ifdef JP
	{ &use_old_target,              FALSE, OPT_PAGE_INPUT, 0, 4,
	"use_old_target",               "ɈȑÕ^[Qbgw肷" },
#else
	{ &use_old_target,              FALSE, OPT_PAGE_INPUT, 0, 4,
	"use_old_target",               "Use old target by default" },
#endif

#ifdef JP
	{ &always_repeat,               TRUE,  OPT_PAGE_INPUT, 0, 6,
	"always_repeat",                "R}hJԂ" },
#else
	{ &always_repeat,               TRUE,  OPT_PAGE_INPUT, 0, 6,
	"always_repeat",                "Repeat obvious commands" },
#endif

#ifdef JP
	{ &confirm_destroy,             FALSE, OPT_PAGE_INPUT, 5, 3,
	"confirm_destroy",              "ulvȃACej󂷂鎞mF" },
#else
	{ &confirm_destroy,             FALSE, OPT_PAGE_INPUT, 5, 3,
	"confirm_destroy",              "Prompt for destruction of known worthless items" },
#endif

#ifdef JP
	{ &confirm_wear,                TRUE,  OPT_PAGE_INPUT, 5, 4,
	"confirm_wear",                 "ꂽ𑕔鎞mF" },
#else
	{ &confirm_wear,                TRUE,  OPT_PAGE_INPUT, 5, 4,
	"confirm_wear",                 "Confirm to wear/wield known cursed items" },
#endif

#ifdef JP
	{ &confirm_quest,               TRUE,  OPT_PAGE_INPUT, 1, 9,
	"confirm_quest",                "NGXg߂ĊKiœOɊmF" },
#else
	{ &confirm_quest,               TRUE,  OPT_PAGE_INPUT, 1, 9,
	"confirm_quest",                "Prompt before exiting a quest level" },
#endif

#ifdef JP
	{ &target_pet,                  FALSE, OPT_PAGE_INPUT, 2, 5,
	"target_pet",                   "ybg^[Qbgɂ" },
#else
	{ &target_pet,                  FALSE, OPT_PAGE_INPUT, 2, 5,
	"target_pet",                   "Allow targetting pets" },
#endif

#ifdef ALLOW_EASY_OPEN
#ifdef JP
	{ &easy_open,                   TRUE,  OPT_PAGE_INPUT, 5, 7,
	"easy_open",                    "IɃhAJ" },
#else
	{ &easy_open,                   TRUE,  OPT_PAGE_INPUT, 5, 7,
	"easy_open",                    "Automatically open doors" },
#endif
#endif /* ALLOW_EASY_OPEN */

#ifdef ALLOW_EASY_DISARM
#ifdef JP
	{ &easy_disarm,                 TRUE,  OPT_PAGE_INPUT, 5, 8,
	"easy_disarm",                  "I㩂" },
#else
	{ &easy_disarm,                 TRUE,  OPT_PAGE_INPUT, 5, 8,
	"easy_disarm",                  "Automatically disarm traps" },
#endif
#endif /* ALLOW_EASY_DISARM */

#ifdef ALLOW_EASY_FLOOR /* TNB */
#ifdef JP
	{ &easy_floor,                  FALSE, OPT_PAGE_INPUT, 5, 9,
	"easy_floor",                   "ŏdȂACeXg" },
#else
	{ &easy_floor,                  FALSE, OPT_PAGE_INPUT, 5, 9,
	"easy_floor",                   "Display floor stacks in a list" },
#endif
#endif /* ALLOW_EASY_FLOOR -- TNB */

#ifdef JP
	{ &use_command,                 FALSE, OPT_PAGE_INPUT, 5, 10,
	"use_command",                  "ug(a)vR}hŃACełg" },
#else
	{ &use_command,                 FALSE, OPT_PAGE_INPUT, 5, 10,
	"use_command",                  "Allow unified use command" },
#endif

#ifdef JP
	{ &over_exert,                  FALSE, OPT_PAGE_INPUT, 0, 29,
	"over_exert",                   "MPȂĂ@ɒ킷" },
#else
	{ &over_exert,                  FALSE, OPT_PAGE_INPUT, 0, 29,
	"over_exert",                   "Allow casting spells when short of mana" },
#endif

#ifdef JP
	{ &numpad_as_cursorkey,         TRUE, OPT_PAGE_INPUT, 2, 31,
	"numpad_as_cursorkey",          "GfB^ŃeL[J[\L[ƂĎg" },
#else
	{ &numpad_as_cursorkey,         TRUE, OPT_PAGE_INPUT, 2, 31,
	"numpad_as_cursorkey",          "Use numpad keys as cursor keys in editor mode" },
#endif

	/*** Map Screen Options ***/

#ifdef JP
	{ &center_player,               FALSE, OPT_PAGE_MAPSCREEN, 5, 11,
	"center_player",                "ɃvC[𒆐Sɒu(*x*)" },
#else
	{ &center_player,               FALSE, OPT_PAGE_MAPSCREEN, 5, 11,
	"center_player",                "Center map while walking (*slow*)" },
#endif

#ifdef JP
	{ &center_running,              TRUE,  OPT_PAGE_MAPSCREEN, 5, 12,
	"center_running",               "Ă鎞łSɒu" },
#else
	{ &center_running,              TRUE,  OPT_PAGE_MAPSCREEN, 5, 12,
	"center_running",               "Centering even while running" },
#endif

#ifdef JP
	{ &view_yellow_lite,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 28,
	"view_yellow_lite",             "͈̔͂ʂȐFŕ\" },
#else
	{ &view_yellow_lite,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 28,
	"view_yellow_lite",             "Use special colors for torch-lit grids" },
#endif

#ifdef JP
	{ &view_bright_lite,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 29,
	"view_bright_lite",             "E͈̔͂ʂȐFŕ\" },
#else
	{ &view_bright_lite,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 29,
	"view_bright_lite",             "Use special colors for 'viewable' grids" },
#endif

#ifdef JP
	{ &view_granite_lite,           TRUE,  OPT_PAGE_MAPSCREEN, 1, 30,
	"view_granite_lite",            "ǂʂȐFŕ\(d)" },
#else
	{ &view_granite_lite,           TRUE,  OPT_PAGE_MAPSCREEN, 1, 30,
	"view_granite_lite",            "Use special colors for wall grids (slow)" },
#endif

#ifdef JP
	{ &view_special_lite,           TRUE,  OPT_PAGE_MAPSCREEN, 1, 31,
	"view_special_lite",            "ʂȐFŕ\(d)" },
#else
	{ &view_special_lite,           TRUE,  OPT_PAGE_MAPSCREEN, 1, 31,
	"view_special_lite",            "Use special colors for floor grids (slow)" },
#endif

#ifdef JP
	{ &view_perma_grids,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 6,
	"view_perma_grids",             "邢ꏊ͂̂܂܂ɂ" },
#else
	{ &view_perma_grids,            TRUE,  OPT_PAGE_MAPSCREEN, 1, 6,
	"view_perma_grids",             "Map remembers all perma-lit grids" },
#endif

#ifdef JP
	{ &view_torch_grids,            FALSE, OPT_PAGE_MAPSCREEN, 1, 7,
	"view_torch_grids",             "ŏƂ炵ꏊ͂̂܂܂ɂ" },
#else
	{ &view_torch_grids,            FALSE, OPT_PAGE_MAPSCREEN, 1, 7,
	"view_torch_grids",             "Map remembers all torch-lit grids" },
#endif

#ifdef JP
	{ &view_unsafe_grids,           FALSE, OPT_PAGE_MAPSCREEN, 1, 8,
	"view_unsafe_grids",            "gbvmς݂łȂꏊ\" },
#else
	{ &view_unsafe_grids,           FALSE, OPT_PAGE_MAPSCREEN, 1, 8,
	"view_unsafe_grids",            "Map marked by detect traps" },
#endif

#ifdef JP
	{ &view_reduce_view,            FALSE, OPT_PAGE_MAPSCREEN, 1, 17,
	"view_reduce_view",             "Xł͎" },
#else
	{ &view_reduce_view,            FALSE, OPT_PAGE_MAPSCREEN, 1, 17,
	"view_reduce_view",             "Reduce view-radius in town" },
#endif

#ifdef JP
	{ &fresh_before,                TRUE,  OPT_PAGE_MAPSCREEN, 1, 23,
	"fresh_before",                 "AR}hɉʂĕ`悵" },
#else
	{ &fresh_before,                TRUE,  OPT_PAGE_MAPSCREEN, 1, 23,
	"fresh_before",                 "Flush output while continuous command" },
#endif

#ifdef JP
	{ &fresh_after,                 FALSE, OPT_PAGE_MAPSCREEN, 1, 24,
	"fresh_after",                  "R}hɉʂɍĕ`悵" },
#else
	{ &fresh_after,                 FALSE, OPT_PAGE_MAPSCREEN, 1, 24,
	"fresh_after",                  "Flush output after monster's move" },
#endif

#ifdef JP
	{ &fresh_message,               FALSE, OPT_PAGE_MAPSCREEN, 1, 25,
	"fresh_message",                "bZ[W̌ɉʂĕ`悷" },
#else
	{ &fresh_message,               FALSE, OPT_PAGE_MAPSCREEN, 1, 25,
	"fresh_message",                "Flush output after every message" },
#endif

#ifdef JP
	{ &hilite_player,               FALSE, OPT_PAGE_MAPSCREEN, 1, 27,
	"hilite_player",                "vC[ɃJ[\킹" },
#else
	{ &hilite_player,               FALSE, OPT_PAGE_MAPSCREEN, 1, 27,
	"hilite_player",                "Hilite the player with the cursor" },
#endif

#ifdef JP
	{ &display_path,                FALSE, OPT_PAGE_MAPSCREEN, 2, 8,
	"display_path",                 "@̋OՂ\" },
#else
	{ &display_path,                FALSE, OPT_PAGE_MAPSCREEN, 2, 8,
	"display_path",                 "Display actual path before shooting" },
#endif

	/*** Text Display Options ***/

#ifdef JP
	{ &plain_descriptions,          TRUE,  OPT_PAGE_TEXT, 5, 1,
	"plain_descriptions",           "ACe̋Lqȗɂ" },
#else
	{ &plain_descriptions,          TRUE,  OPT_PAGE_TEXT, 5, 1,
	"plain_descriptions",           "Plain object descriptions" },
#endif

#ifdef JP
	{ &plain_pickup,                FALSE, OPT_PAGE_TEXT, 6, 6,
	"plain_pickup",                 "uEvbZ[Wȗ" },
#else
	{ &plain_pickup,                FALSE, OPT_PAGE_JAPANESE_ONLY, 6, 6,
	"plain_pickup",                 "Plain pickup messages(japanese only)" },
#endif

#ifdef JP
	{ &always_show_list,            TRUE,  OPT_PAGE_TEXT, 4, 0,
	"always_show_list",             "Iɂ͏Ɉꗗ\" },
#else
	{ &always_show_list,            TRUE,  OPT_PAGE_TEXT, 4, 0,
	"always_show_list",             "Always show list when choosing items" },
#endif

#ifdef JP
	{ &depth_in_feet,               FALSE, OPT_PAGE_TEXT, 0, 7,
	"depth_in_feet",                "_W̐[tB[gŕ\" },
#else
	{ &depth_in_feet,               FALSE, OPT_PAGE_TEXT, 0, 7,
	"depth_in_feet",                "Show dungeon level in feet" },
#endif

#ifdef JP
	{ &show_labels,                 TRUE,  OPT_PAGE_TEXT, 0, 10,
	"show_labels",                  "ꗗőꏊ\" },
#else
	{ &show_labels,                 TRUE,  OPT_PAGE_TEXT, 0, 10,
	"show_labels",                  "Show labels in object listings" },
#endif

#ifdef JP
	{ &show_weights,                TRUE,  OPT_PAGE_TEXT, 0, 11,
	"show_weights",                 "ACeꗗŏdʂ\" },
#else
	{ &show_weights,                TRUE,  OPT_PAGE_TEXT, 0, 11,
	"show_weights",                 "Show weights in object listings" },
#endif

#ifdef JP
	{ &show_item_graph,             TRUE,  OPT_PAGE_TEXT, 2, 0,
	"show_item_graph",              "ACẽV{\" },
#else
	{ &show_item_graph,             TRUE,  OPT_PAGE_TEXT, 2, 0,
	"show_item_graph",              "Show items graphics" },
#endif

#ifdef JP
	{ &equippy_chars,               TRUE,  OPT_PAGE_TEXT, 1, 12,
	"equippy_chars",                "Xe[^Xɕő\" },
#else
	{ &equippy_chars,               TRUE,  OPT_PAGE_TEXT, 1, 12,
	"equippy_chars",                "Display 'equippy' chars" },
#endif

#ifdef JP
	{ &display_mutations,           FALSE, OPT_PAGE_TEXT, 5, 0,
	"display_mutations",            "'C'R}hœˑRψق\" },
#else
	{ &display_mutations,           FALSE, OPT_PAGE_TEXT, 5, 0,
	"display_mutations",            "Display mutations in 'C'haracter Display" },
#endif

#ifdef JP
	{ &compress_savefile,           FALSE, OPT_PAGE_TEXT, 1, 26,
	"compress_savefile",            "Z[uEt@C̃bZ[Wk" },
#else
	{ &compress_savefile,           FALSE, OPT_PAGE_TEXT, 1, 26,
	"compress_savefile",            "Compress messages in savefiles" },
#endif

#ifdef JP
	{ &abbrev_extra,                FALSE, OPT_PAGE_TEXT, 2, 10,
	"abbrev_extra",                 "ACeɒǉϐ/\̗͂̂" },
#else
	{ &abbrev_extra,                FALSE, OPT_PAGE_TEXT, 2, 10,
	"abbrev_extra",                 "Describe obj's extra resistances by abbreviation" },
#endif

#ifdef JP
	{ &abbrev_all,                  FALSE, OPT_PAGE_TEXT, 2, 11,
	"abbrev_all",                   "ACeɑSĂ̑ϐ/\̗͂̂" },
#else
	{ &abbrev_all,                  FALSE, OPT_PAGE_TEXT, 2, 11,
	"abbrev_all",                   "Describe obj's all resistances by abbreviation" },
#endif

#ifdef JP
	{ &exp_need,                    FALSE, OPT_PAGE_TEXT, 2, 12,
	"exp_need",                     "̃xɕKvȌol\" },
#else
	{ &exp_need,                    FALSE, OPT_PAGE_TEXT, 2, 12,
	"exp_need",                     "Show the experience needed for next level" },
#endif

#ifdef JP
	{ &ignore_unview,               FALSE, OPT_PAGE_TEXT, 2, 13,
	"ignore_unview",                "EÕX^[̍s\Ȃ" },
#else
	{ &ignore_unview,               FALSE, OPT_PAGE_TEXT, 2, 13,
	"ignore_unview",                "Ignore whenever any monster does" },
#endif

	{ &refresh_mon_list,                FALSE,  OPT_PAGE_TEXT, 4, 21,
	"refresh_mon_list",                 "sOɎEX^[XgXV(d)" },

	{ &show_throwing_dam,                FALSE,  OPT_PAGE_TEXT, 7, 6,
	"show_throwing_dam",                 "̓_[W\" },

	{ &show_special_info,                FALSE,  OPT_PAGE_TEXT, 7, 10,
	"show_special_info",                 "ACê̑̓ȏ\" },



	/*** Game-Play ***/

#ifdef JP
	{ &stack_force_notes,           TRUE,  OPT_PAGE_GAMEPLAY, 0, 8,
	"stack_force_notes",            "قȂ̃ACe܂Ƃ߂" },
#else
	{ &stack_force_notes,           TRUE,  OPT_PAGE_GAMEPLAY, 0, 8,
	"stack_force_notes",            "Merge inscriptions when stacking" },
#endif

#ifdef JP
	{ &stack_force_costs,           FALSE, OPT_PAGE_GAMEPLAY, 0, 9,
	"stack_force_costs",            "قȂ銄\̃ACe܂Ƃ߂" },
#else
	{ &stack_force_costs,           FALSE, OPT_PAGE_GAMEPLAY, 0, 9,
	"stack_force_costs",            "Merge discounts when stacking" },
#endif

#ifdef JP
	{ &expand_list,                 TRUE,  OPT_PAGE_GAMEPLAY, 1, 5,
	"expand_list",                  "uꗗvR}hg" },
#else
	{ &expand_list,                 TRUE,  OPT_PAGE_GAMEPLAY, 1, 5,
	"expand_list",                  "Expand the power of the list commands" },
#endif

#ifdef JP
	{ &small_levels,                TRUE,  OPT_PAGE_GAMEPLAY, 0, 30,
	"small_levels",                 "ɏtA̐\ɂ" },
#else
	{ &small_levels,                TRUE,  OPT_PAGE_GAMEPLAY, 0, 30,
	"small_levels",                 "Allow unusually small dungeon levels" },
#endif

#ifdef JP
	{ &always_small_levels,         FALSE, OPT_PAGE_GAMEPLAY, 2, 3,
	"always_small_levels",          "ɔɏtA𐶐" },
#else
	{ &always_small_levels,         FALSE, OPT_PAGE_GAMEPLAY, 2, 3,
	"always_small_levels",          "Always create unusually small dungeon levels" },
#endif

#ifdef JP
	{ &empty_levels,                TRUE,  OPT_PAGE_GAMEPLAY, 0, 31,
	"empty_levels",                 "ۂ́uA[ivx̐\ɂ" },
#else
	{ &empty_levels,                TRUE,  OPT_PAGE_GAMEPLAY, 0, 31,
	"empty_levels",                 "Allow empty 'arena' levels" },
#endif

#ifdef JP
	{ &bound_walls_perm,            FALSE, OPT_PAGE_GAMEPLAY, 2, 1,
	"bound_walls_perm",             "_W̊Oǂivɂ" },
#else
	{ &bound_walls_perm,            FALSE, OPT_PAGE_GAMEPLAY, 2, 1,
	"bound_walls_perm",             "Boundary walls become 'permanent wall'" },
#endif

	{ &gun_free_world,            FALSE, OPT_PAGE_GAMEPLAY, 7, 11,
	"gun_free_world",             "eoȂ" },

	{ &always_check_arms,            FALSE, OPT_PAGE_GAMEPLAY, 7, 12,
	"always_check_arms",             "EƍɕʁX̕ƂɊmF" },

#ifdef JP
	{ &last_words,                  TRUE,  OPT_PAGE_GAMEPLAY, 0, 28,
///msg131221
	"last_words",                   "Q[IɈꌾRgc" },
#else
	{ &last_words,                  TRUE,  OPT_PAGE_GAMEPLAY, 0, 28,
	"last_words",                   "Leave last words when your character dies" },
#endif

	{ &auto_dump,                  TRUE,  OPT_PAGE_GAMEPLAY, 4, 6,
	"auto_dump",                   "_vt@Cݒ肷" },

#ifdef WORLD_SCORE
#ifdef JP
	{ &send_score,                  TRUE,  OPT_PAGE_GAMEPLAY, 4, 7,
	"send_score",                   "XRAT[o(ŗp)ɃQ[f[^𑗂" },
#else
	{ &send_score,                  TRUE,  OPT_PAGE_GAMEPLAY, 4, 6,
	"send_score",                   "Send score dump to the world score server" },
#endif
#endif
	{ &ex_attack_msg,                  FALSE,  OPT_PAGE_GAMEPLAY, 6, 0,
///msg131221
	"ex_attack_msg",                   "ŨbZ[Wɕω" },



#ifdef JP
	{ &allow_debug_opts,            FALSE, OPT_PAGE_GAMEPLAY, 6, 11,
	"allow_debug_opts",             "fobO/\IvV" },
#else
	{ &allow_debug_opts,            FALSE, OPT_PAGE_GAMEPLAY, 6, 11,
	"allow_debug_opts",             "Allow use of debug/cheat options" },
#endif

	/*** Disturbance ***/

#ifdef JP
	{ &find_ignore_stairs,          FALSE, OPT_PAGE_DISTURBANCE, 0, 16,
	"find_ignore_stairs",           "Ki͒ʉ߂" },
#else
	{ &find_ignore_stairs,          FALSE, OPT_PAGE_DISTURBANCE, 0, 16,
	"find_ignore_stairs",           "Run past stairs" },
#endif

#ifdef JP
	{ &find_ignore_doors,           TRUE,  OPT_PAGE_DISTURBANCE, 0, 17,
	"find_ignore_doors",            "hA͒ʉ߂" },
#else
	{ &find_ignore_doors,           TRUE,  OPT_PAGE_DISTURBANCE, 0, 17,
	"find_ignore_doors",            "Run through open doors" },
#endif

#ifdef JP
	{ &find_cut,                    FALSE, OPT_PAGE_DISTURBANCE, 0, 18,
	"find_cut",                     "Ȃp΂߂ɍŒZŒʉ߂" },
#else
	{ &find_cut,                    FALSE, OPT_PAGE_DISTURBANCE, 0, 18,
	"find_cut",                     "Run past known corners" },
#endif

#ifdef JP
	{ &check_abort,                 TRUE,  OPT_PAGE_DISTURBANCE, 1, 18,
	"check_abort",                  "AR}h̓L[͂Œf" },
#else
	{ &check_abort,                 TRUE,  OPT_PAGE_DISTURBANCE, 1, 18,
	"check_abort",                  "Check for user abort while continuous command" },
#endif

#ifdef JP
	{ &flush_failure,               TRUE,  OPT_PAGE_DISTURBANCE, 1, 20,
	"flush_failure",                "lXȃ~Xɓ͂NA" },
#else
	{ &flush_failure,               TRUE,  OPT_PAGE_DISTURBANCE, 1, 20,
	"flush_failure",                "Flush input on various failures" },
#endif

#ifdef JP
	{ &flush_disturb,               FALSE, OPT_PAGE_DISTURBANCE, 1, 21,
	"flush_disturb",                "Qɓ͂NA" },
#else
	{ &flush_disturb,               FALSE, OPT_PAGE_DISTURBANCE, 1, 21,
	"flush_disturb",                "Flush input whenever disturbed" },
#endif

#ifdef JP
	{ &disturb_move,                FALSE, OPT_PAGE_DISTURBANCE, 0, 20,
	"disturb_move",                 "ǂ̃X^[Ăs𒆎~" },
#else
	{ &disturb_move,                FALSE, OPT_PAGE_DISTURBANCE, 0, 20,
	"disturb_move",                 "Disturb whenever any monster moves" },
#endif

#ifdef JP
	{ &disturb_high,                FALSE, OPT_PAGE_DISTURBANCE, 1, 3,
	"disturb_high",                 "x̍X^[s𒆎~" },
#else
	{ &disturb_high,                FALSE, OPT_PAGE_DISTURBANCE, 1, 3,
	"disturb_high",                 "Disturb whenever high-level monster moves" },
#endif

#ifdef JP
	{ &disturb_near,                TRUE,  OPT_PAGE_DISTURBANCE, 0, 21,
	"disturb_near",                 "ẼX^[s𒆎~" },
#else
	{ &disturb_near,                TRUE,  OPT_PAGE_DISTURBANCE, 0, 21,
	"disturb_near",                 "Disturb whenever viewable monster moves" },
#endif

#ifdef JP
	{ &disturb_pets,                FALSE, OPT_PAGE_DISTURBANCE, 5, 6,
	"disturb_pets",                 "Ẽybgs𒆎~" },
#else
	{ &disturb_pets,                FALSE, OPT_PAGE_DISTURBANCE, 5, 6,
	"disturb_pets",                 "Disturb when visible pets move" },
#endif

#ifdef JP
	{ &disturb_panel,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 22,
	"disturb_panel",                "ʃXN[ɍs𒆎~" },
#else
	{ &disturb_panel,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 22,
	"disturb_panel",                "Disturb whenever map panel changes" },
#endif

#ifdef JP
	{ &disturb_state,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 23,
	"disturb_state",                "̃Xe[^Xωɍs𒆎~" },
#else
	{ &disturb_state,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 23,
	"disturb_state",                "Disturb whenever player state changes" },
#endif

#ifdef JP
	{ &disturb_minor,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 24,
	"disturb_minor",                "ׂȂƂNĂs𒆎~" },
#else
	{ &disturb_minor,               TRUE,  OPT_PAGE_DISTURBANCE, 0, 24,
	"disturb_minor",                "Disturb whenever boring things happen" },
#endif

#ifdef JP
	{ &ring_bell,                   FALSE, OPT_PAGE_DISTURBANCE, 0, 14,
	"ring_bell",                    "G[Ƀr[v炷" },
#else
	{ &ring_bell,                   FALSE, OPT_PAGE_DISTURBANCE, 0, 14,
	"ring_bell",                    "Audible bell (on errors, etc)" },
#endif

#ifdef JP
	{ &disturb_trap_detect,         TRUE,  OPT_PAGE_DISTURBANCE, 0, 27,
	"disturb_trap_detect",          "gbvm͈͊Oɏo钼Oɍs𒆎~" },
#else
	{ &disturb_trap_detect,         TRUE,  OPT_PAGE_DISTURBANCE, 0, 27,
	"disturb_trap_detect",          "Disturb when leaving trap detected area" },
#endif

#ifdef JP
	{ &alert_trap_detect,           FALSE, OPT_PAGE_DISTURBANCE, 0, 25,
	"alert_trap_detect",            "gbvm͈͊Oɏo钼OɌx" },
#else
	{ &alert_trap_detect,           FALSE, OPT_PAGE_DISTURBANCE, 0, 25,
	"alert_trap_detect",            "Alert when leaving trap detected area" },
#endif

	/*** Birth Options ***/
///del131222 l؂Ȃ
#if 0
#ifdef JP
	{ &manual_haggle,               FALSE, OPT_PAGE_BIRTH, 1, 0,
	"manual_haggle",                "XŒl؂" },
#else
	{ &manual_haggle,               FALSE, OPT_PAGE_BIRTH, 1, 0,
	"manual_haggle",                "Manually haggle in stores" },
#endif
#endif
/*
#ifdef JP
	{ &easy_band,                   FALSE, OPT_PAGE_BIRTH, 6, 31,
	"easy_band",                    "SҗpȒP[h(*)" },
#else
	{ &easy_band,                   FALSE, OPT_PAGE_BIRTH, 6, 31,
	"easy_band",                    "Easy Mode (*)" },
#endif
*/

///mod150103
	{ &birth_bonus_20,                 FALSE,  OPT_PAGE_BIRTH, 1, 14,
	"birth_bonus_20",                  "{[iX|CgŒ(*)" },
	{ &birth_bonus_10,                 FALSE,  OPT_PAGE_BIRTH, 1, 15,
	"birth_bonus_10",                  "{[iX|CgȂ(*)" },
	{ &ironman_no_bonus,                 FALSE,  OPT_PAGE_BIRTH, 1, 16,
	"ironman_no_bonus",                  "(Slp){[iX|CgȂ(*)" },

/*
#ifdef JP
	{ &smart_learn,                 TRUE,  OPT_PAGE_BIRTH, 1, 14,
	"smart_learn",                  "X^[͎swK(*)" },
#else
	{ &smart_learn,                 TRUE,  OPT_PAGE_BIRTH, 1, 14,
	"smart_learn",                  "Monsters learn from their mistakes (*)" },
#endif

#ifdef JP
	{ &smart_cheat,                 FALSE, OPT_PAGE_BIRTH, 1, 15,
	"smart_cheat",                  "X^[̓vC[݂̎˂(*)" },
#else
	{ &smart_cheat,                 FALSE, OPT_PAGE_BIRTH, 1, 15,
	"smart_cheat",                  "Monsters exploit players weaknesses (*)" },
#endif
*/
/*
#ifdef JP
	{ &vanilla_town,                FALSE, OPT_PAGE_BIRTH, 6, 0,
	"vanilla_town",                 "c̊X/NGXgƍrȂ" },
#else
	{ &vanilla_town,                FALSE, OPT_PAGE_BIRTH, 6, 0,
	"vanilla_town",                 "Use 'vanilla' town without quests and wilderness" },
#endif

#ifdef JP
	{ &lite_town,                   FALSE, OPT_PAGE_BIRTH, 6, 1,
	"lite_town",                    "K͂ȊX/rȂ" },
#else
	{ &lite_town,                   FALSE, OPT_PAGE_BIRTH, 6, 1,
	"lite_town",                    "Use 'lite' town without a wilderness" },
#endif
*/

#ifdef JP
	{ &ironman_shops,               FALSE, OPT_PAGE_BIRTH, 6, 2,
	"ironman_shops",                "(Slp)XƉ䂪ƂgpȂ(*)" },
#else
	{ &ironman_shops,               FALSE, OPT_PAGE_BIRTH, 6, 2,
	"ironman_shops",                "Stores are permanently closed (*)" },
#endif

#ifdef JP
	{ &ironman_small_levels,        FALSE, OPT_PAGE_BIRTH, 6, 3,
	"ironman_small_levels",         "(Slp)ɔɏtA𐶐(*)" },
#else
	{ &ironman_small_levels,        FALSE, OPT_PAGE_BIRTH, 6, 3,
	"ironman_small_levels",         "Always create unusually small dungeon levels (*)" },
#endif
/*
#ifdef JP
	{ &ironman_downward,            FALSE, OPT_PAGE_BIRTH, 6, 4,
	"ironman_downward",             "(Slp)A҂ƏKiȂ(*)" },
#else
	{ &ironman_downward,            FALSE, OPT_PAGE_BIRTH, 6, 4,
	"ironman_downward",             "Disable recall and use of up stairs (*)" },
#endif
*/
///mod140406ǉ

#ifdef JP
	{ &ironman_empty_levels,        FALSE, OPT_PAGE_BIRTH, 6, 8,
	"ironman_empty_levels",         "(Slp)ɋۂ̃A[ix𐶐(*)" },
#else
	{ &ironman_empty_levels,        FALSE, OPT_PAGE_BIRTH, 6, 8,
	"ironman_empty_levels",         "Always create empty 'arena' levels (*)" },
#endif

	{ &ironman_no_fixed_art,            FALSE, OPT_PAGE_BIRTH, 6, 4,
	"ironman_no_fixed_art",             "ŒA[eBt@NgoȂ(*)" },

#ifdef JP
	{ &ironman_rooms,               FALSE, OPT_PAGE_BIRTH, 6, 12,
	"ironman_rooms",                "ɕʂłȂ𐶐(*)" },
#else
	{ &ironman_rooms,               FALSE, OPT_PAGE_BIRTH, 6, 12,
	"ironman_rooms",                "Always generate very unusual rooms (*)" },
#endif
/*
#ifdef JP
	{ &ironman_nightmare,           FALSE, OPT_PAGE_BIRTH, 6, 18,
	"ironman_nightmare",            "(Slp)[h(͑Ss𗝂łI)(*)" },
#else
	{ &ironman_nightmare,           FALSE, OPT_PAGE_BIRTH, 6, 18,
	"ironman_nightmare",            "Nightmare mode(it isn't even remotely fair!)(*)" },
#endif
	*/
	{ &no_capture_book,                 FALSE, OPT_PAGE_BIRTH, 6, 13,
	"no_capture_book",                  "d{oȂ(*)" },

	// 6,136,15
#ifdef JP
	{ &left_hander,                 FALSE, OPT_PAGE_BIRTH, 6, 15,
	"left_hander",                  "ł" },
#else
	{ &left_hander,                 FALSE, OPT_PAGE_BIRTH, 6, 13,
	"left_hander",                  "Left-Hander" },
#endif
#ifdef JP
	{ &preserve_mode,               TRUE,  OPT_PAGE_BIRTH, 6, 14,
	"preserve_mode",                "`̃ACe蓦ĂĐ(*)" },
#else
	{ &preserve_mode,               TRUE,  OPT_PAGE_BIRTH, 6, 14,
	"preserve_mode",                "Preserve artifacts (*)" },
#endif
///mod140511 I[g[[
/*
#ifdef JP
	{ &autoroller,                  TRUE,  OPT_PAGE_BIRTH, 6, 15,
	"autoroller",                   "\͒lɃI[g[[gp(*)" },
#else
	{ &autoroller,                  TRUE,  OPT_PAGE_BIRTH, 6, 15,
	"autoroller",                   "Allow use of autoroller for stats (*)" },
#endif
*/
///del131221 ̊iEnʃIvV
#if 0
#ifdef JP
	{ &autochara,                   FALSE, OPT_PAGE_BIRTH, 6, 16,
	"autochara",                   "̊i/nʂɃI[g[[gp" },
#else
	{ &autochara,                   FALSE, OPT_PAGE_BIRTH, 6, 16,
	"autochara",                    "Autoroll for weight, height and social status" },
#endif
#endif

#ifdef JP
	{ &powerup_home,                TRUE,  OPT_PAGE_BIRTH, 4, 3,
	"powerup_home",                 "䂪Ƃg(*)" },
#else
	{ &powerup_home,                TRUE,  OPT_PAGE_BIRTH, 4, 3,
	"powerup_home",                 "Increase capacity of your home (*)" },
#endif

	/*** Easy Object Auto-Destroyer ***/

#ifdef JP
	{ &destroy_items,               FALSE, OPT_PAGE_AUTODESTROY, 7, 0,
	"destroy_items",                "ACe̊ȈՎjgp" },
#else
	{ &destroy_items,               FALSE, OPT_PAGE_AUTODESTROY, 7, 0,
	"destroy_items",                "Use easy auto-destroyer" },
#endif

#ifdef JP
	{ &destroy_feeling,             FALSE, OPT_PAGE_AUTODESTROY, 7, 8,
	"destroy_feeling",              "ȈՊӒ肵ƂjKp" },
#else
	{ &destroy_feeling,             FALSE, OPT_PAGE_AUTODESTROY, 7, 8,
	"destroy_feeling",              "Apply auto-destroy as sense feeling" },
#endif

#ifdef JP
	{ &destroy_identify,            FALSE, OPT_PAGE_AUTODESTROY, 7, 9,
	"destroy_identify",             "Ӓ肵ƂjKp" },
#else
	{ &destroy_identify,            FALSE, OPT_PAGE_AUTODESTROY, 7, 9,
	"destroy_identify",             "Apply auto-destroy as identify an item" },
#endif

#ifdef JP
	{ &leave_worth,                 TRUE,  OPT_PAGE_AUTODESTROY, 7, 2,
	"leave_worth",                  "i$1ȏ̃ACe͉󂳂Ȃ" },
#else
	{ &leave_worth,                 TRUE,  OPT_PAGE_AUTODESTROY, 7, 2,
	"leave_worth",                  "Auto-destroyer leaves known worthy items" },
#endif

#ifdef JP
	{ &leave_equip,                 FALSE, OPT_PAGE_AUTODESTROY, 7, 3,
	"leave_equip",                  "/h͉󂳂Ȃ" },
#else
	{ &leave_equip,                 FALSE, OPT_PAGE_AUTODESTROY, 7, 3,
	"leave_equip",                  "Auto-destroyer leaves weapons and armour" },
#endif

#ifdef JP
	{ &leave_chest,                 TRUE,  OPT_PAGE_AUTODESTROY, 7, 7,
	"leave_chest",                  "JĂȂ͉󂳂Ȃ" },
#else
	{ &leave_chest,                 TRUE,  OPT_PAGE_AUTODESTROY, 7, 7,
	"leave_chest",                  "Auto-destroyer leaves closed chests" },
#endif
/*
#ifdef JP
	{ &leave_wanted,                TRUE,  OPT_PAGE_AUTODESTROY, 7, 4,
	"leave_wanted",                 "܋̎/͉󂳂Ȃ" },
#else
	{ &leave_wanted,                TRUE,  OPT_PAGE_AUTODESTROY, 7, 4,
	"leave_wanted",                 "Auto-destroyer leaves wanted corpses" },
#endif

#ifdef JP
	{ &leave_corpse,                FALSE, OPT_PAGE_AUTODESTROY, 7, 5,
	"leave_corpse",                 "/͉󂳂Ȃ" },
#else
	{ &leave_corpse,                FALSE, OPT_PAGE_AUTODESTROY, 7, 5,
	"leave_corpse",                 "Auto-destroyer leaves corpses and skeletons" },
#endif

	//7,6́u̓_[W\vɕύX
#ifdef JP
	{ &leave_junk,                  FALSE, OPT_PAGE_AUTODESTROY, 7, 6,
	"leave_junk",                   "炭͉󂳂Ȃ" },
#else
	{ &leave_junk,                  FALSE, OPT_PAGE_AUTODESTROY, 7, 6,
	"leave_junk",                   "Auto-destroyer leaves junk" },
#endif
	*/
#ifdef JP
	{ &leave_special,               TRUE,  OPT_PAGE_AUTODESTROY, 7, 1,
//	"leave_special",                "푰/EƂœʂɕKvȃACe͉󂳂Ȃ" },
	"leave_special",                "̎푰/EƂɗLpȃACe͉󂳂Ȃ" },
#else
	{ &leave_special,               TRUE,  OPT_PAGE_AUTODESTROY, 7, 1,
	"leave_special",                "Auto-destroyer leaves items your race/class needs" },
#endif

	/*** Play-record Options ***/

#ifdef JP
	{ &record_fix_art,              TRUE,  OPT_PAGE_PLAYRECORD, 4, 11,
	"record_fix_art",               "ŒA[eBt@Ng̓L^" },
#else
	{ &record_fix_art,              TRUE,  OPT_PAGE_PLAYRECORD, 4, 11,
	"record_fix_art",               "Record fixed artifacts" },
#endif

#ifdef JP
	{ &record_rand_art,             TRUE,  OPT_PAGE_PLAYRECORD, 4, 12,
	"record_rand_art",              "_A[eBt@Ng̓L^" },
#else
	{ &record_rand_art,             TRUE,  OPT_PAGE_PLAYRECORD, 4, 12,
	"record_rand_art",              "Record random artifacts" },
#endif

#ifdef JP
	{ &record_destroy_uniq,         TRUE,  OPT_PAGE_PLAYRECORD, 4, 13,
	"record_destroy_uniq",          "j[NX^[|ƂL^" },
#else
	{ &record_destroy_uniq,         TRUE,  OPT_PAGE_PLAYRECORD, 4, 13,
	"record_destroy_uniq",          "Record when destroy unique monster" },
#endif

#ifdef JP
	{ &record_fix_quest,            TRUE,  OPT_PAGE_PLAYRECORD, 4, 14,
	"record_fix_quest",             "ŒNGXg̒BL^" },
#else
	{ &record_fix_quest,            TRUE,  OPT_PAGE_PLAYRECORD, 4, 14,
	"record_fix_quest",             "Record fixed quests" },
#endif

#ifdef JP
	{ &record_rand_quest,           TRUE,  OPT_PAGE_PLAYRECORD, 4, 15,
	"record_rand_quest",            "_NGXg̒BL^" },
#else
	{ &record_rand_quest,           TRUE,  OPT_PAGE_PLAYRECORD, 4, 15,
	"record_rand_quest",            "Record random quests" },
#endif

#ifdef JP
	{ &record_maxdepth,             TRUE,  OPT_PAGE_PLAYRECORD, 4, 16,
	"record_maxdepth",              "Ő[KXVƂɋL^" },
#else
	{ &record_maxdepth,             TRUE,  OPT_PAGE_PLAYRECORD, 4, 16,
	"record_maxdepth",              "Record movements to deepest level" },
#endif

#ifdef JP
	{ &record_stair,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 17,
	"record_stair",                 "K̈ړL^" },
#else
	{ &record_stair,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 17,
	"record_stair",                 "Record recall and stair movements" },
#endif

#ifdef JP
	{ &record_buy,                  TRUE,  OPT_PAGE_PLAYRECORD, 4, 18,
	"record_buy",                   "ACe̍wL^" },
#else
	{ &record_buy,                  TRUE,  OPT_PAGE_PLAYRECORD, 4, 18,
	"record_buy",                   "Record purchased items" },
#endif

#ifdef JP
	{ &record_sell,                 FALSE, OPT_PAGE_PLAYRECORD, 4, 19,
	"record_sell",                  "ACe̔pL^" },
#else
	{ &record_sell,                 FALSE, OPT_PAGE_PLAYRECORD, 4, 19,
	"record_sell",                  "Record sold items" },
#endif

#ifdef JP
	{ &record_danger,               TRUE,  OPT_PAGE_PLAYRECORD, 4, 20,
	"record_danger",                "s`ɂȂƂL^" },
#else
	{ &record_danger,               TRUE,  OPT_PAGE_PLAYRECORD, 4, 20,
	"record_danger",                "Record hitpoint warning" },
#endif
/* 4,21́uɃX^[XgXVvɕύX
#ifdef JP
	{ &record_arena,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 21,
	"record_arena",                 "A[ił̏L^" },
#else
	{ &record_arena,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 21,
	"record_arena",                 "Record arena victories" },
#endif
*/
#ifdef JP
	{ &record_ident,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 22,
	"record_ident",                 "̃ACe̎ʂL^" },
#else
	{ &record_ident,                TRUE,  OPT_PAGE_PLAYRECORD, 4, 22,
	"record_ident",                 "Record first identified items" },
#endif

#ifdef JP
	{ &record_named_pet,            FALSE, OPT_PAGE_PLAYRECORD, 4, 23,
	"record_named_pet",             "Oybg̏L^" },
#else
	{ &record_named_pet,            FALSE, OPT_PAGE_PLAYRECORD, 4, 23,
	"record_named_pet",             "Record informations of named pets" },
#endif

	/*** End of Table ***/

	{ NULL,                         0, 0, 0, 0,
	NULL,                           NULL }
};


#ifdef JP
const cptr chaos_patrons[MAX_PATRON] =
{
	"X[^[",
	"}x[h",
	"`[hX",
	"nCIn[",
	"LVIo[O",

	"sA[",
	"o",
	"AIb`",
	"C[J[",
	"i[W",

	"o",
	"R[",
	"X[lbV",
	"i[O",
	"eB[`",

	"JC"
};
#else
const cptr chaos_patrons[MAX_PATRON] =
{
	"Slortar",
	"Mabelode",
	"Chardros",
	"Hionhurn",
	"Xiombarg",

	"Pyaray",
	"Balaan",
	"Arioch",
	"Eequor",
	"Narjhan",

	"Balo",
	"Khorne",
	"Slaanesh",
	"Nurgle",
	"Tzeentch",

	"Khaine"
};
#endif


const int chaos_stats[MAX_PATRON] =
{
	A_CON,  /* Slortar */
	A_CON,  /* Mabelode */
	A_STR,  /* Chardros */
	A_STR,  /* Hionhurn */
	A_STR,  /* Xiombarg */

	A_INT,  /* Pyaray */
	A_STR,  /* Balaan */
	A_INT,  /* Arioch */
	A_CON,  /* Eequor */
	A_CHR,  /* Narjhan */

	-1,     /* Balo */
	A_STR,  /* Khorne */
	A_CHR,  /* Slaanesh */
	A_CON,  /* Nurgle */
	A_INT,  /* Tzeentch */

	A_STR,  /* Khaine */
};




const int chaos_rewards[MAX_PATRON][20] =
{
	/* Slortar the Old: */
	{
		REW_WRATH, REW_CURSE_WP, REW_CURSE_AR, REW_RUIN_ABL, REW_LOSE_ABL,
		REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_POLY_WND, REW_POLY_SLF,
		REW_POLY_SLF, REW_POLY_SLF, REW_GAIN_ABL, REW_GAIN_ABL, REW_GAIN_EXP,
		REW_GOOD_OBJ, REW_CHAOS_WP, REW_GREA_OBJ, REW_AUGM_ABL, REW_AUGM_ABL
	},

	/* Mabelode the Faceless: */
	{
		REW_WRATH, REW_CURSE_WP, REW_CURSE_AR, REW_H_SUMMON, REW_SUMMON_M,
		REW_SUMMON_M, REW_IGNORE, REW_IGNORE, REW_POLY_WND, REW_POLY_WND,
		REW_POLY_SLF, REW_HEAL_FUL, REW_HEAL_FUL, REW_GAIN_ABL, REW_SER_UNDE,
		REW_CHAOS_WP, REW_GOOD_OBJ, REW_GOOD_OBJ, REW_GOOD_OBS, REW_GOOD_OBS
	},

	/* Chardros the Reaper: */
	{
		REW_WRATH, REW_WRATH, REW_HURT_LOT, REW_PISS_OFF, REW_H_SUMMON,
		REW_SUMMON_M, REW_IGNORE, REW_IGNORE, REW_DESTRUCT, REW_SER_UNDE,
		REW_GENOCIDE, REW_MASS_GEN, REW_MASS_GEN, REW_DISPEL_C, REW_GOOD_OBJ,
		REW_CHAOS_WP, REW_GOOD_OBS, REW_GOOD_OBS, REW_AUGM_ABL, REW_AUGM_ABL
	},

	/* Hionhurn the Executioner: */
	{
		REW_WRATH, REW_WRATH, REW_CURSE_WP, REW_CURSE_AR, REW_RUIN_ABL,
		REW_IGNORE, REW_IGNORE, REW_SER_UNDE, REW_DESTRUCT, REW_GENOCIDE,
		REW_MASS_GEN, REW_MASS_GEN, REW_HEAL_FUL, REW_GAIN_ABL, REW_GAIN_ABL,
		REW_CHAOS_WP, REW_GOOD_OBS, REW_GOOD_OBS, REW_AUGM_ABL, REW_AUGM_ABL
	},

	/* Xiombarg the Sword-Queen: */
	{
		REW_TY_CURSE, REW_TY_CURSE, REW_PISS_OFF, REW_RUIN_ABL, REW_LOSE_ABL,
		REW_IGNORE, REW_POLY_SLF, REW_POLY_SLF, REW_POLY_WND, REW_POLY_WND,
		REW_GENOCIDE, REW_DISPEL_C, REW_GOOD_OBJ, REW_GOOD_OBJ, REW_SER_MONS,
		REW_GAIN_ABL, REW_CHAOS_WP, REW_GAIN_EXP, REW_AUGM_ABL, REW_GOOD_OBS
	},


	/* Pyaray the Tentacled Whisperer of Impossible Secretes: */
	{
		REW_WRATH, REW_TY_CURSE, REW_PISS_OFF, REW_H_SUMMON, REW_H_SUMMON,
		REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_POLY_WND, REW_POLY_SLF,
		REW_POLY_SLF, REW_SER_DEMO, REW_HEAL_FUL, REW_GAIN_ABL, REW_GAIN_ABL,
		REW_CHAOS_WP, REW_DO_HAVOC, REW_GOOD_OBJ, REW_GREA_OBJ, REW_GREA_OBS
	},

	/* Balaan the Grim: */
	{
		REW_TY_CURSE, REW_HURT_LOT, REW_CURSE_WP, REW_CURSE_AR, REW_RUIN_ABL,
		REW_SUMMON_M, REW_LOSE_EXP, REW_POLY_SLF, REW_POLY_SLF, REW_POLY_WND,
		REW_SER_UNDE, REW_HEAL_FUL, REW_HEAL_FUL, REW_GAIN_EXP, REW_GAIN_EXP,
		REW_CHAOS_WP, REW_GOOD_OBJ, REW_GOOD_OBS, REW_GREA_OBS, REW_AUGM_ABL
	},

	/* Arioch, Duke of Hell: */
	{
		REW_WRATH, REW_PISS_OFF, REW_RUIN_ABL, REW_LOSE_EXP, REW_H_SUMMON,
		REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_POLY_SLF,
		REW_POLY_SLF, REW_MASS_GEN, REW_SER_DEMO, REW_HEAL_FUL, REW_CHAOS_WP,
		REW_CHAOS_WP, REW_GOOD_OBJ, REW_GAIN_EXP, REW_GREA_OBJ, REW_AUGM_ABL
	},

	/* Eequor, Blue Lady of Dismay: */
	{
		REW_WRATH, REW_TY_CURSE, REW_PISS_OFF, REW_CURSE_WP, REW_RUIN_ABL,
		REW_IGNORE, REW_IGNORE, REW_POLY_SLF, REW_POLY_SLF, REW_POLY_WND,
		REW_GOOD_OBJ, REW_GOOD_OBJ, REW_SER_MONS, REW_HEAL_FUL, REW_GAIN_EXP,
		REW_GAIN_ABL, REW_CHAOS_WP, REW_GOOD_OBS, REW_GREA_OBJ, REW_AUGM_ABL
	},

	/* Narjhan, Lord of Beggars: */
	{
		REW_WRATH, REW_CURSE_AR, REW_CURSE_WP, REW_CURSE_WP, REW_CURSE_AR,
		REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_POLY_SLF, REW_POLY_SLF,
		REW_POLY_WND, REW_HEAL_FUL, REW_HEAL_FUL, REW_GAIN_EXP, REW_AUGM_ABL,
		REW_GOOD_OBJ, REW_GOOD_OBJ, REW_CHAOS_WP, REW_GREA_OBJ, REW_GREA_OBS
	},

	/* Balo the Jester: */
	{
		REW_WRATH, REW_SER_DEMO, REW_CURSE_WP, REW_CURSE_AR, REW_LOSE_EXP,
		REW_GAIN_ABL, REW_LOSE_ABL, REW_POLY_WND, REW_POLY_SLF, REW_IGNORE,
		REW_DESTRUCT, REW_MASS_GEN, REW_CHAOS_WP, REW_GREA_OBJ, REW_HURT_LOT,
		REW_AUGM_ABL, REW_RUIN_ABL, REW_H_SUMMON, REW_GREA_OBS, REW_AUGM_ABL
	},

	/* Khorne the Bloodgod: */
	{
		REW_WRATH, REW_HURT_LOT, REW_HURT_LOT, REW_H_SUMMON, REW_H_SUMMON,
		REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_SER_MONS, REW_SER_DEMO,
		REW_POLY_SLF, REW_POLY_WND, REW_HEAL_FUL, REW_GOOD_OBJ, REW_GOOD_OBJ,
		REW_CHAOS_WP, REW_GOOD_OBS, REW_GOOD_OBS, REW_GREA_OBJ, REW_GREA_OBS
	},

	/* Slaanesh: */
	{
		REW_WRATH, REW_PISS_OFF, REW_PISS_OFF, REW_RUIN_ABL, REW_LOSE_ABL,
		REW_LOSE_EXP, REW_IGNORE, REW_IGNORE, REW_POLY_WND, REW_SER_DEMO,
		REW_POLY_SLF, REW_HEAL_FUL, REW_HEAL_FUL, REW_GOOD_OBJ, REW_GAIN_EXP,
		REW_GAIN_EXP, REW_CHAOS_WP, REW_GAIN_ABL, REW_GREA_OBJ, REW_AUGM_ABL
	},

	/* Nurgle: */
	{
		REW_WRATH, REW_PISS_OFF, REW_HURT_LOT, REW_RUIN_ABL, REW_LOSE_ABL,
		REW_LOSE_EXP, REW_IGNORE, REW_IGNORE, REW_IGNORE, REW_POLY_SLF,
		REW_POLY_SLF, REW_POLY_WND, REW_HEAL_FUL, REW_GOOD_OBJ, REW_GAIN_ABL,
		REW_GAIN_ABL, REW_SER_UNDE, REW_CHAOS_WP, REW_GREA_OBJ, REW_AUGM_ABL
	},

	/* Tzeentch: */
	{
		REW_WRATH, REW_CURSE_WP, REW_CURSE_AR, REW_RUIN_ABL, REW_LOSE_ABL,
		REW_LOSE_EXP, REW_IGNORE, REW_POLY_SLF, REW_POLY_SLF, REW_POLY_SLF,
		REW_POLY_SLF, REW_POLY_WND, REW_HEAL_FUL, REW_CHAOS_WP, REW_GREA_OBJ,
		REW_GAIN_ABL, REW_GAIN_ABL, REW_GAIN_EXP, REW_GAIN_EXP, REW_AUGM_ABL
	},

	/* Khaine: */
	{
		REW_WRATH, REW_HURT_LOT, REW_PISS_OFF, REW_LOSE_ABL, REW_LOSE_EXP,
		REW_IGNORE,   REW_IGNORE,   REW_DISPEL_C, REW_DO_HAVOC, REW_DO_HAVOC,
		REW_POLY_SLF, REW_POLY_SLF, REW_GAIN_EXP, REW_GAIN_ABL, REW_GAIN_ABL,
		REW_SER_MONS, REW_GOOD_OBJ, REW_CHAOS_WP, REW_GREA_OBJ, REW_GOOD_OBS
	}
};

///mod140216 fUGtFNgύX
/*:::,UށAŒ჌x,s,dd,ds,,d(ŏIdʂ͂̒lLv|)*/

const martial_arts_new ma_blows_new[] =
{
	{ "%sB",					 MELEE_MODE_PUNCH1,1, 0, 1, 5, 0 ,4},
	{ "%sB",				 MELEE_MODE_PUNCH1,10, 0, 2, 5, 0 ,4},
	{ "%sɑUp`H킹B",			 MELEE_MODE_PUNCH1,15, 0, 3, 5, 0 ,4},
	{ "%sv؂艣B",				 MELEE_MODE_PUNCH1,20, 10, 4, 5, 0 ,3},
	{ "%s^RɂB",			 MELEE_MODE_PUNCH1,25, 5, 5, 5, MELEE_STUN ,4},
	{ "%s։EXg[gH킹B",  MELEE_MODE_PUNCH1,30, 15, 6, 6, 0 ,5},
	{ "%s֐˂H킹B",		 MELEE_MODE_PUNCH1,35, 15, 7, 7, MELEE_STUN ,8},

	{ "%sRB",                 MELEE_MODE_KICK1,1, 0, 1, 7, 0 ,5},
	{ "%sփNULbNH킹B",   MELEE_MODE_KICK1,5, 0, 2, 7, 0 ,5},
	{ "%s։񂵏RH킹B",   MELEE_MODE_KICK1,12, 0, 2, 9, 0 ,6},
	{ "%sRグI",             MELEE_MODE_KICK1,20, 10, 3, 7, 0 ,7},
	{ "%sR񂵂I",             MELEE_MODE_KICK1,30, 15, 4, 7, MELEE_STUN ,8},
	{ "%sRďRďR܂I",MELEE_MODE_KICK1,40, 25, 7, 7, MELEE_STUN2 ,10},

	{ "%sl̔őłB",       MELEE_MODE_FISH_TAIL,1, 0, 4, 7, MELEE_STUN2 ,10},
	{ "%sl̔łԂ@I",   MELEE_MODE_FISH_TAIL,15, 0, 6, 7, MELEE_STUN2 ,12},
	{ "%sl̔œガ|I",   MELEE_MODE_FISH_TAIL,30, 20, 10, 7, MELEE_STUN3 ,15},
	{ "%sl̔łԂ΂I", MELEE_MODE_FISH_TAIL,45, 40, 12,10, MELEE_STUN3 ,20},

	{ "%sɊݕtI",             MELEE_MODE_BITE,1, 0, 2, 6, 0 ,6},
	{ "%sɐHtI",             MELEE_MODE_BITE,10, 0, 3, 6, 0 ,7},
	{ "%sꖂtI",             MELEE_MODE_BITE,20, 10, 4, 6, 0 ,8},
	{ "%sɉs˂ĂI",     MELEE_MODE_BITE,30, 20, 7, 7, 0 ,10},
	{ "%sꖂĐU񂵂I",   MELEE_MODE_BITE,40, 30, 10, 10, MELEE_STUN2 ,11},

	{ "%s~B",             MELEE_MODE_CLAW,1, 0, 1, 9, 0 ,2},
	{ "%s~zB",             MELEE_MODE_CLAW,7, 0, 2, 9, 0 ,3},
	{ "%ss܂œ˂B",         MELEE_MODE_CLAW,15, 0, 3, 9, 0 ,4},
	{ "%ss܂Ő؂􂢂I",     MELEE_MODE_CLAW,24, 0, 5, 9, 0 ,6},
	{ "%ss܂ŊтI",		MELEE_MODE_CLAW,29, 20, 7, 9, 0 ,8},
	{ "%ss܂łȂ܂؂ɂI",		MELEE_MODE_CLAW,34, 20, 8, 9, 0 ,8},
	{ "%ss܂Ŗő؂ɂI",		MELEE_MODE_CLAW,40, 30, 9, 9, 0 ,8},

	{ "%sH߂Œ@B",           MELEE_MODE_DRILL,1, 0, 1, 6, 0 ,1},
	{ "%sH߂œ˂B",           MELEE_MODE_DRILL,5, 0, 1, 8, 0 ,2},
	{ "%sH߂œガB",           MELEE_MODE_DRILL,10, 0, 2, 8, 0 ,4},
	{ "%sH߂Œ߂B",           MELEE_MODE_DRILL,15, 10, 3, 8, MELEE_STUN ,6},
	{ "%sH߂Œ@B",           MELEE_MODE_DRILL,20, 15, 4, 8, MELEE_STUN ,8},
	{ "ΉԂH߂%sB",           MELEE_MODE_DRILL,30, 20, 7, 9, MELEE_ELEC ,10},
	{ "H߂̗ȂƋ%sтI",   MELEE_MODE_DRILL,40, 40, 10, 11, MELEE_ELEC ,12},

	{ "%sB",         MELEE_MODE_PUNCH_ONI,1, 0, 3, 5, 0 ,8},
	{ "%s΂B",         MELEE_MODE_PUNCH_ONI,10, 0, 5, 6, MELEE_STUN ,10},
	{ "%s𓊂΂B",         MELEE_MODE_PUNCH_ONI,20, 0, 6, 8, MELEE_STUN ,10},
	{ "|Ŝ悤Ȍ%s֒@܂ꂽI",    MELEE_MODE_PUNCH_ONI,30, 25, 9, 11, MELEE_STUN2 ,12},
	{ "%s@tnʂɑ匊JI",    MELEE_MODE_PUNCH_ONI,40, 35, 11, 12, MELEE_STUN3 ,15},

	{ "%s@B",						MELEE_MODE_KASEN,1, 0, 1, 7, 0 ,3},
	{ "тL%słB",         MELEE_MODE_KASEN,6, 0, 2, 5, 0 ,4},
	{ "тĥ悤%sB",   MELEE_MODE_KASEN,10, 3, 3, 5, 0 ,5},
	{ "т̎肪%sɐH񂾁B",			MELEE_MODE_KASEN,15, 0, 5, 5, MELEE_KASEN ,6},
	{ "Ƒł%s֓ˌI",				MELEE_MODE_KASEN,20, 10, 4, 7, MELEE_STUN ,3},
	{ "%s֓dH킹I",		MELEE_MODE_KASEN,24, 11, 5, 5, MELEE_ELEC ,3},
	{ "т̎肪%sтI",				MELEE_MODE_KASEN,28, 20, 7, 7, MELEE_KASEN ,8},
	{ "dc%s֔тI",			MELEE_MODE_KASEN,33, 27, 9, 9, MELEE_STUN2 ,12},
	{ "邪%s֐fI",			MELEE_MODE_KASEN,37, 25, 8, 8, MELEE_WATER ,7},
	{ "т̎肪%sׂI",			MELEE_MODE_KASEN,40, 25, 10, 10, MELEE_KASEN ,10},
	{ "%sтŗߎAU񂵂Ē@I",		MELEE_MODE_KASEN,45, 40, 12, 12, MELEE_KASEN ,16},

	{ "%słB",         MELEE_MODE_SHIELD,1, 0, 1, 5, 0 ,4},
	{ "\%s֑̓肵B",  MELEE_MODE_SHIELD,30, 10, 2, 5, MELEE_STUN ,4},

	{ "%sɓ˂H킹B",     MELEE_MODE_HEADBUTT,1, 0, 2, 5, MELEE_STUN ,3},
	{ "%sɋȓ˂H킹B",     MELEE_MODE_HEADBUTT,15, 0, 4, 5, MELEE_STUN ,5},
	{ "|Ŝ悤ȐΓ%sɒ@܂ꂽI",     MELEE_MODE_HEADBUTT,35, 20, 8, 8, MELEE_STUN2 ,8},

	{ "%spœ˂B",             MELEE_MODE_HORNS,1, 0, 1, 10, 0 ,3},
	{ "%sxpœ˂B",         MELEE_MODE_HORNS,15, 0, 2, 10, 0 ,4},
	{ "%s֊pȑ̓I",     MELEE_MODE_HORNS,35, 15, 5, 10, MELEE_STUN ,8},

	{ "%s傫Ȋpœ˂B",             MELEE_MODE_BIGHORN,1, 0, 3, 10, 0 ,3},
	{ "%spłЂ󒆂֓グI", MELEE_MODE_BIGHORN,15, 0, 4, 10, MELEE_STUN ,6},
	{ "%sȊpŊтI",				MELEE_MODE_BIGHORN,30, 10, 6, 10, 0 ,8},
	{ "%sȊpň􂢂I",			MELEE_MODE_BIGHORN,40, 15, 10, 10, 0 ,12},

	{ "%s𑾂KőłB",       MELEE_MODE_BIGTAIL,1, 0, 2, 7, 0 ,4},
	{ "%sxȐKőłB",   MELEE_MODE_BIGTAIL,15, 0, 4, 7, MELEE_STUN ,6},
	{ "%sxȐKœガB",   MELEE_MODE_BIGTAIL,30, 10, 6, 7, MELEE_STUN ,8},
	{ "xȐKȂグ%sɒ@ꂽI", MELEE_MODE_BIGTAIL,40, 30, 9,9, MELEE_STUN2 ,12},

	{ "%s𓥂݂I",       MELEE_MODE_GIGA_KICK,1, 0, 9, 10, 0 ,10},
	{ "%sR΂I",       MELEE_MODE_GIGA_KICK,10, 10, 11, 10, MELEE_STUN2 ,15},
	{ "%s𓥂ݒׂI",       MELEE_MODE_GIGA_KICK,20, 20, 11, 12, 0 ,20},

	{ "%s𕥂΂I",       MELEE_MODE_GIGA_PUNCH,1,  0, 8, 10, MELEE_STUN2 ,10},
	{ "%sԂ񓊂I",       MELEE_MODE_GIGA_PUNCH,20, 20, 10, 12, MELEE_STUN3 ,15},
	{ "Ȍ%s@ׂI",       MELEE_MODE_GIGA_PUNCH,40, 25, 13, 13, MELEE_STUN3 ,20},

	{ "Ȃ̑̂烊Xяo%s֋򂢕tI",     MELEE_MODE_ULTIMATE,1, 5, 6, 10, 0 ,4},
	{ "ȃ^R̂悤ȐG肪%sߏグI",       MELEE_MODE_ULTIMATE,10,  0, 8, 10, MELEE_STUN2 ,10},
	{ "rnA%s؂􂢂I",       MELEE_MODE_ULTIMATE,20,  0, 10, 10, 0 ,10},
	{ "dHˏoAɂꂪsjAɕϐg%s֐H炢I",       MELEE_MODE_ULTIMATE,40,  20, 12, 10, 0 ,10},
	{ "ú@@@@@@@ƃH[bIHv",       MELEE_MODE_ULTIMATE,48, 40, 15, 15, MELEE_STUN3 ,20},

	{ "%s֒ʔwH킹B",           MELEE_MODE_LONGARM,1, 0, 1, 8, 0 ,3},
	{ "%sփSS̏eB",         MELEE_MODE_LONGARM,10, 0, 2, 8, 0 ,4},
	{ "Ȃ̘rւ̂悤ɐLт%sߏグB",     MELEE_MODE_LONGARM,20, 15, 4, 8, MELEE_STUN ,8},
	{ "%sփSS̋@֏eI",         MELEE_MODE_LONGARM,30, 20, 6, 8, 0 ,4},
	{ "%sփNveBbNj[hI",     MELEE_MODE_LONGARM,40, 25, 8, 8, MELEE_STUN ,8},

	{ "%s։s܂H񂾁B",           MELEE_MODE_VAMP,1, 0, 1, 8, MELEE_VAMP ,2},
	{ "%s։s˂ĂB",           MELEE_MODE_VAMP,20, 10, 2, 8, MELEE_VAMP ,3},
	{ "%sɊݕtÂ܂܋󒆂ɓグI",           MELEE_MODE_VAMP,30, 10, 5, 8, MELEE_VAMP ,3},
	{ "啂%sY^Y^ɂI",           MELEE_MODE_VAMP,40, 30, 8, 8, MELEE_VAMP ,8},

	{ "%sփ`bvH킹B",					    MELEE_MODE_PUNCH_NINJA,1, 0, 3, 5, 0 ,6},
	{ "%sփJH킹B",				    MELEE_MODE_PUNCH_NINJA,5, 0, 5, 5, 0 ,8},
	{ "%sփEC`Ep`H킹I",			MELEE_MODE_PUNCH_NINJA,10, 5, 7, 5, 0 ,10},
	{ "%sփAo}IgVH킹I",				MELEE_MODE_PUNCH_NINJA,20, 10, 8, 8, 0 ,12},
	{ "%s֑΋||Ep`H킹I",         MELEE_MODE_PUNCH_NINJA,30, 20,10,10, 0 ,14},
	{ "%sփ_uE|Ep`H킹I",         MELEE_MODE_PUNCH_NINJA,40, 30,12,12, 0 ,16},

	{ "%sփPELbNH킹B",				    MELEE_MODE_KICK_NINJA,1, 0, 5, 5, 0 ,6},
	{ "%s֓`̃T}[\gLbNH킹I",		    MELEE_MODE_KICK_NINJA,25, 10, 7, 7, 0 ,8},
	{ "%sփhSEgrQH킹I",		    MELEE_MODE_KICK_NINJA,30, 20, 9, 9, 0 ,10},
	{ "%sփ^c}LPH킹I",				    MELEE_MODE_KICK_NINJA,40, 30, 12, 12, 0 ,15},

	{ "%sȒ܂ň~I",     MELEE_MODE_BEAST,1,   0, 6, 10, 0 ,4},
	{ "%s񂾁I",					MELEE_MODE_BEAST,10,  0, 8, 10, 0 ,7},
	{ "%srŏRI",			MELEE_MODE_BEAST,20, 10, 10, 10, MELEE_STUN ,10},
	{ "%s֋ȑ̓d|I", MELEE_MODE_BEAST,30, 20, 12, 10, MELEE_STUN2 ,13},
	{ "%s֋ȉ˂ĂI",     MELEE_MODE_BEAST,40, 30, 13, 14, MELEE_STUN2 ,20},

	{ "%ss܂œ˂B",			MELEE_MODE_EX_CLAW,1,   0, 3, 9, 0 ,3},
	{ "%ss܂Ő؂􂢂I",		MELEE_MODE_EX_CLAW,12,  5, 5, 9, 0 ,4},
	{ "%ss܂ŊтI",			MELEE_MODE_EX_CLAW,20, 10, 7, 9, 0 ,5},
	{ "%sԂaI",				MELEE_MODE_EX_CLAW,27, 15, 9, 9, 0 ,7},
	{ "%sȂ܂؂ɂI",			MELEE_MODE_EX_CLAW,33, 20,10, 9, 0 ,8},
	{ "%saĎaĎa܂I",	MELEE_MODE_EX_CLAW,39, 25,11, 9, 0 ,9},
	{ "P܂%ső؂ɂI",   MELEE_MODE_EX_CLAW,43, 30,14, 9, 0 ,12},

	{ "%s֓ZB",     MELEE_MODE_SLIME,1, 0, 2, 2, MELEE_SLOW ,4},
	{ "%snI",     MELEE_MODE_SLIME,20, 30, 5, 5, MELEE_MELT ,8},
	{ "%sI",     MELEE_MODE_SLIME,40, 30, 8, 8, MELEE_MELT ,10},

	{ "l̉΂%sĂI",     MELEE_MODE_ATAGO,1, 0, 13, 16, MELEE_ATAGO,10},

	{ "%sGB",     MELEE_MODE_KOISHI,1, 0, 1, 1, 0 ,1},
	{ "̂%s֓B",     MELEE_MODE_KOISHI,5, 0, 3, 3, 0 ,3},
	{ "%sB",     MELEE_MODE_KOISHI,7, 0, 5, 4, 0 ,5},
	{ "݂B",     MELEE_MODE_KOISHI,10, 10, 2, 7, MELEE_STUN ,3},
	{ "Xq낤Ƃ肪%sɓB",     MELEE_MODE_KOISHI,15, 0, 2, 10, MELEE_STUN2 ,5},
	{ "G%sɓB",     MELEE_MODE_KOISHI,20, 0, 2, 10, MELEE_STUN2 ,5},
	{ "Ԃт܂Ƃ%s˔΂ꂽB",     MELEE_MODE_KOISHI,25, 20, 6, 6, MELEE_STUN ,5},
	{ "ȓd%s𐁂΂I",     MELEE_MODE_KOISHI,30, 0, 4, 10, MELEE_STUN ,5},
	{ "ˑRKN炢%s֞hB",     MELEE_MODE_KOISHI,33, 0, 4, 9, 0 ,4},
	{ "T[hAC̃R[hڂ̂悤%słB",     MELEE_MODE_KOISHI,36, 10, 3, 10, MELEE_STUN2 ,6},
	{ "ɕ`n[g}[N%sɓB",     MELEE_MODE_KOISHI,39, 0, 4, 9, 0 ,4},
	{ "%sKNɕsꂽB",     MELEE_MODE_KOISHI,44, 40, 8, 10, 0 ,10},

	{ "%s֑̓肵B",     MELEE_MODE_MIST,1, 0, 2, 5, MELEE_SLOW ,4},
	{ "%s𕢂B",     MELEE_MODE_MIST,12, 0, 3, 6, MELEE_SLOW ,4},
	{ "%sݍ񂾁B",     MELEE_MODE_MIST,23, 0, 4, 7, MELEE_SLOW ,7},
	{ "̂悤ɐ%s˂B",     MELEE_MODE_MIST,36, 20, 5, 8, 0 ,10},
	{ "ȏb̌`Ƃ%s֓ːiI",     MELEE_MODE_MIST,44, 40, 7, 9, 0 ,15},

	{ "Ȓ܂%s؂􂢂I",       MELEE_MODE_DRAGON,1,  0, 10, 10, 0 ,10},
	{ "ȐK%sガI",       MELEE_MODE_DRAGON,1,  0, 10, 12, MELEE_STUN3 ,15},
	{ "%s֌ċ}~Â܂܉ׂI",       MELEE_MODE_DRAGON,1, 0, 13, 13, MELEE_STUN3 ,20},
	{ "Ȋp%sтI",       MELEE_MODE_DRAGON,1, 0, 15, 12, 0 ,12},
	{ "ȉ傪%s􂢂I",       MELEE_MODE_DRAGON,1, 0, 15, 15, 0 ,20},
	{ "%s֋ȉΉ𐁂tI",       MELEE_MODE_DRAGON,1, 0, 16, 16,MELEE_ATAGO ,10},

	{ "%s@B",						MELEE_MODE_CIRNO,1, 0, 1, 3, 0 ,2},
	{ "%sB",						MELEE_MODE_CIRNO,3, 5, 2, 3, 0 ,2},
	{ "%sփwbhXCfBOB",		MELEE_MODE_CIRNO,10, 5, 3, 4, 0 ,4},
	{ "X%s֑̓肵B",		MELEE_MODE_CIRNO,15, 10, 3, 4, MELEE_COLD ,6},
	{ "%sRB",				MELEE_MODE_CIRNO,20, 10, 4, 6, 0 ,4},
	{ "%s֕X𓊂B",				MELEE_MODE_CIRNO,24, 16, 3, 6, MELEE_COLD ,4},
	{ "͂̋C}ɉI",			MELEE_MODE_CIRNO,30, 20, 4, 6, MELEE_COLD ,5},
	{ "%sփX[p[ACXLbNH킹I",   MELEE_MODE_CIRNO,35, 25, 6, 6, MELEE_COLD ,8},
	{ "%sX̌ŎaI",				MELEE_MODE_CIRNO,40, 30, 7, 7, MELEE_COLD ,10},
	{ "%s֋ȕX𓊂I",		MELEE_MODE_CIRNO,43, 40, 10, 10, MELEE_STUN2 ,15},

	{ "%s֏H킹B",   				MELEE_MODE_PUNCH2,1, 0, 1, 7, 0 ,6},
	{ "%s֐˂H킹B",   			MELEE_MODE_PUNCH2,4, 0, 2, 5, 0 ,8},
	{ "%sփc[p`H킹B",   	MELEE_MODE_PUNCH2,8, 5, 3, 5, MELEE_STUN ,6},
	{ "%s蓁œ˂B",                 	MELEE_MODE_PUNCH2,12, 8, 4, 5, 0 ,3},
	{ "%s֔]VIłH킹B",   		MELEE_MODE_PUNCH2,16, 10, 5, 5, MELEE_STUN2 ,5},
	{ "%sփK[p`H킹B",   		MELEE_MODE_PUNCH2,19, 10, 5, 6, MELEE_STUN ,6},
	{ "%sփn}[p`킹B",       MELEE_MODE_PUNCH2,21, 15, 6, 5, 0 ,10},
	{ "%s֕킹B",                 MELEE_MODE_PUNCH2,24, 20, 6, 7, 0 ,10},
	{ "%sփAbp[JbgH킹B",   	MELEE_MODE_PUNCH2,27, 20, 7, 6, MELEE_STUN2 ,8},
	{ "%sփVAtbNH킹B",   	MELEE_MODE_PUNCH2,30, 25, 7, 7, 0 ,8},
	{ "%sփX}bVH킹B",   		MELEE_MODE_PUNCH2,33, 30, 8, 7, MELEE_STUN2 ,10},
	{ "%sփ}VKWuH킹B",   	MELEE_MODE_PUNCH2,36, 25, 8, 8, MELEE_STUN ,6},
	{ "s蓁%sI",                 MELEE_MODE_PUNCH2,39, 30, 9, 9, 0 ,6},
	{ "%s֐lA˂H킹I",   	MELEE_MODE_PUNCH2,42, 35, 8, 12, MELEE_STUN ,10},
	{ "%s֗H킹I",   			MELEE_MODE_PUNCH2,45, 43, 10, 11, MELEE_STUN2 ,12},
	{ "%s֕FH킹I",   			MELEE_MODE_PUNCH2,48, 45, 12, 12, MELEE_STUN3 ,15},

	{ "%sփ[LbNB",               MELEE_MODE_KICK2,1, 0, 1, 7, 0 ,5},
	{ "%s֑ORH킹B",   			MELEE_MODE_KICK2,7, 0, 2, 7, 0 ,8},
	{ "%sփhbvLbN킹B",  		MELEE_MODE_KICK2,10, 10, 3, 7, MELEE_STUN ,9},
	{ "%sƂ킹B",  			MELEE_MODE_KICK2,15, 10, 3, 8, MELEE_STUN ,8},
	{ "%sփ[O\obgH킹B",   MELEE_MODE_KICK2,20, 15, 4, 7, 0 ,10},
	{ "%s֊ʕGRH킹B",   		MELEE_MODE_KICK2,25, 20, 6, 8, MELEE_STUN2 ,10},
	{ "%s֐RH킹I", 		MELEE_MODE_KICK2,30, 30, 8, 8, MELEE_STUN2 ,11},
	{ "%sփCAE[AEWERpb\H킹I", MELEE_MODE_KICK2,35, 35, 10, 8, MELEE_STUN ,11},
	{ "%s֐rH킹I",				MELEE_MODE_KICK2,39, 35, 10, 9, MELEE_STUN2 ,10},
	{ "%sփT}[\gLbNH킹I",	MELEE_MODE_KICK2,44, 40, 10, 12, MELEE_STUN3 ,12},

	{ "%s֘rU񂵂B",                 	MELEE_MODE_YOSHIKA,1, 0, 1, 5, 0 ,3},
	{ "%sЂB",           		MELEE_MODE_YOSHIKA,3, 0, 2, 6, 0 ,3},
	{ "%s֑̓肵B",                 	MELEE_MODE_YOSHIKA,8, 10, 4, 4, 0 ,7},
	{ "%s܂œ˂B",                 	MELEE_MODE_YOSHIKA,12, 15, 3, 6, MELEE_POIS ,4},
	{ "%s֗rU艺낵B",                 	MELEE_MODE_YOSHIKA,20, 40, 6, 4, MELEE_STUN ,6},
	{ "L̂%s񂾁B",              	MELEE_MODE_YOSHIKA,27, 30, 7, 5, MELEE_POIS ,5},
	{ "%s֓ˌI",                 	MELEE_MODE_YOSHIKA,31, 40, 7, 7, MELEE_STUN2 ,10},
	{ "ŉtH܂%s؂􂢂I",           MELEE_MODE_YOSHIKA,36, 30, 8, 7, MELEE_POIS ,8},
	{ "ꂽ傪%s􂢂I",          MELEE_MODE_YOSHIKA,40, 40,  9, 10, MELEE_POIS ,12},
	{ "dP܂%ső؂ɂI",     MELEE_MODE_YOSHIKA,47, 44, 11, 13, MELEE_POIS ,12},

	{ "ڂɂ܂ʓ%s˂I",       	MELEE_MODE_LIGHTSPEED,1, 0, 5, 5, MELEE_STUN ,3},
	{ "ՌgƋ%s֓ˌI",       	MELEE_MODE_LIGHTSPEED,10, 30, 8, 8, MELEE_STUN3 ,12},
	{ "%s̎삯Y^Y^ɂI",       	MELEE_MODE_LIGHTSPEED,20, 30, 10, 10, MELEE_STUN2 ,6},
	{ "uŐ\̑Ō%sɒ@܂ꂽI",       	MELEE_MODE_LIGHTSPEED,30, 40, 14, 14, MELEE_STUN2 ,9},

	{ "%sGB",                 	MELEE_MODE_MEDI,1, 0, 1, 5, MELEE_POIS ,1},
	{ "%s@B",                 	MELEE_MODE_MEDI,5, 0, 2, 5, MELEE_POIS ,3},
	{ "%s֑̓肵B",             MELEE_MODE_MEDI,12, 0, 3, 6, MELEE_POIS ,4},
	{ "%s֓ł𐁂tB",         MELEE_MODE_MEDI,20, 20, 5, 7, MELEE_POIS ,4},
	{ "%s֓ł𐁂񂾁I",         MELEE_MODE_MEDI,30, 25, 8, 8, MELEE_POIS ,6},
	{ "%s̑̂ɌłZI",  MELEE_MODE_MEDI,40, 40, 10, 10, MELEE_POIS ,10},

	{ "]Ă΂%s֔񂾁B",			MELEE_MODE_MIND,1, 0, 3, 3, 0 ,4},
	{ "₪%s֒B",				MELEE_MODE_MIND,7, 10, 4, 4, MELEE_STUN ,8},
	{ "%s͒nʂɌtꂽB",		MELEE_MODE_MIND,12, 20, 5, 5, MELEE_SLOW ,6},
	{ "%s֓dB",						MELEE_MODE_MIND,18, 20, 6, 6, MELEE_ELEC ,6},
	{ "%sɕAnʂɒ@ꂽI",   MELEE_MODE_MIND,24, 15, 7, 7, MELEE_STUN ,6},
	{ "%sɃGlM[ՌgH킹I",     MELEE_MODE_MIND,30, 20, 8, 9, MELEE_STUN2 ,10},
	{ "ˑR%s̑̂I",				MELEE_MODE_MIND,36, 20, 9, 9, MELEE_COLD,5},
	{ "ˑR%s̑̂RオI",				MELEE_MODE_MIND,38, 20, 9, 10, MELEE_FIRE,5},
	{ "%s̑̂PꂽI",				MELEE_MODE_MIND,40, 25, 10, 10, 0,7},
	{ "nƋɑn􂯁A%sۂݍ񂾁I",    MELEE_MODE_MIND,45, 40, 12, 12, MELEE_STUN2 ,12},

	{ "%s֏Ȓ΂B",           MELEE_MODE_YUYUKO,1, 0, 2, 5, MELEE_STUN ,2},
	{ "H삪%s֑̓肵B",           MELEE_MODE_YUYUKO,6, 5, 2, 7, 0 ,3},
	{ "H삪%s𕥂B",           MELEE_MODE_YUYUKO,11, 10, 2, 9, MELEE_SLOW ,4},
	{ "傫Ȓʂ`%sガB",  MELEE_MODE_YUYUKO,16, 10, 4, 6, 0 ,6},
	{ "Ȃ璈Ԃ肵B",			  MELEE_MODE_YUYUKO,22, 20, 5, 7, 0 ,8},
	{ "w悩܏̌%s֕ꂽB",       MELEE_MODE_YUYUKO,28, 25, 7, 8, 0 ,1},
	{ "󒆂ŒƋɑ傫]B",     MELEE_MODE_YUYUKO,33, 20, 8, 9, 0 ,8},
	{ "H삽%sֈĂɓˌB",         MELEE_MODE_YUYUKO,39, 25, 9, 10, MELEE_STUN ,9},
	{ "P%s𕢂sB",           MELEE_MODE_YUYUKO,44, 35, 10, 12, MELEE_STUN3 ,12},

	{ "%sɂ񂾁B",           MELEE_MODE_TOZIKO,1, 0, 1, 6, 0 ,2},
	{ "%s։ΉԂ΂B",           MELEE_MODE_TOZIKO,8, 0, 2, 6, 0 ,2},
	{ "%s֑̓肵B",           MELEE_MODE_TOZIKO,14, 0, 3, 6, 0 ,5},
	{ "%s֕dB",           MELEE_MODE_TOZIKO,20, 20, 4, 6, MELEE_ELEC ,4},
	{ "%s֌dH킹I",           MELEE_MODE_TOZIKO,27, 30, 5, 7, MELEE_ELEC ,4},
	{ "%s̓ɗI",           MELEE_MODE_TOZIKO,34, 35, 7, 7, MELEE_ELEC ,7},
	{ "%s֓{̗軂I",           MELEE_MODE_TOZIKO,40, 40, 10, 13, MELEE_ELEC ,10},

	{ "%s̏ɗB",           MELEE_MODE_KISUME1,1, 0, 3, 8, MELEE_STUN ,8},
	{ "%s̓֋ɗI", MELEE_MODE_KISUME2,1, 0, 5, 11, MELEE_STUN ,12},
	{ "Ƌ%s֗I",     MELEE_MODE_KISUME3,1, 0, 8, 15, MELEE_STUN2 ,16},
	{ "؂%s֗I",     MELEE_MODE_KISUME4,1, 0, 12, 20, MELEE_STUN3 ,20},
	{ "nh邪%s̏ɗI",           MELEE_MODE_KISUME5,1, 0, 16, 25, MELEE_STUN3 ,25},

	{ "%s│ł؂ƒ@B",		MELEE_MODE_MIKO,1, 0, 2, 3, 0 ,2},
	{ "%s│œ˂B",			MELEE_MODE_MIKO,5, 2, 3, 3, 0 ,2},
	{ "│]%słB",		MELEE_MODE_MIKO,11, 5, 4, 3, 0 ,3},
	{ "%s│Ŏv؂ςI",	MELEE_MODE_MIKO,16, 8, 5, 5, MELEE_STUN ,4},
	{ "Z%sRB",		MELEE_MODE_MIKO,20, 12, 6, 8, MELEE_FIRE ,6},
	{ "傫Ur%s؂􂢂I",	MELEE_MODE_MIKO,24, 10, 7, 5, 0 ,5},
	{ "%sRĔRオ点I",	MELEE_MODE_MIKO,28, 15, 8, 8, MELEE_FIRE ,8},
	{ "ɕ`ւ%s؂􂢂I",	MELEE_MODE_MIKO,32, 25, 9, 8, 0 ,7},
	{ "Ȑn󂩂%s֓˂oI",	MELEE_MODE_MIKO,38, 30, 10, 10, 0 ,9},
	{ "PV%s֌č~蒍I",	MELEE_MODE_MIKO,45, 35, 11, 12, 0 ,12},

	{ "o%s@B",			MELEE_MODE_KOKORO,1, 0, 2, 3, 0 ,2},
	{ "%słB",			MELEE_MODE_KOKORO,7, 0, 3, 3, 0 ,3},
	{ "%s֓ːiB",				MELEE_MODE_KOKORO,12, 10, 4, 4, 0 ,7},
	{ "ʂ̈%s֔킳B",			MELEE_MODE_KOKORO,16, 25, 5, 3, MELEE_STUN2 ,4},
	{ "㓁\A%s֎a肩B",		MELEE_MODE_KOKORO,21, 10, 5, 5, 0 ,6},
	{ "ɐ%s֌Č]I",	MELEE_MODE_KOKORO,27, 20, 6, 5, 0 ,6},
	{ "C̕o%se΂I",		MELEE_MODE_KOKORO,30, 20, 7, 5, MELEE_STUN ,6},
	{ "%s㓁ő܂ɐ؂􂢂I",		MELEE_MODE_KOKORO,36, 25, 9, 9, 0 ,8},
	{ "̖ʂ%s֔񂾁I",			MELEE_MODE_KOKORO,40, 35, 8, 10, MELEE_STUN3 ,8},
	{ "%s𕑂悤ɐ؂荏񂾁I",		MELEE_MODE_KOKORO,48, 45, 12, 12, 0 ,15},

	{ "%s蓁őłB",						MELEE_MODE_NINJA,1, 0, 1, 3, 0 ,1},
	{ "%s蓁œ˂B",						MELEE_MODE_NINJA,6, 0, 1, 6, 0 ,2},
	{ "Ȃ̘r˂悤%s֐LтB",	MELEE_MODE_NINJA,15, 0, 2, 4, 0 ,2},
	{ "n悤%s֔тB",		MELEE_MODE_NINJA,21, 10, 2, 6, 0 ,3},
	{ "䓁̂悤Ȏ蓁%s؂􂢂B",		MELEE_MODE_NINJA,27, 20, 3, 6, 0 ,4},
	{ "̂悤%sPB",				MELEE_MODE_NINJA,33, 30, 4, 6, 0 ,5},
	{ "|Ŝ悤Ȋю肪%sтI",			MELEE_MODE_NINJA,40, 35, 5, 7, 0 ,6},
	{ "p%sPI",					MELEE_MODE_NINJA,46, 40, 8, 8, 0 ,10},

	{ "%s֑̓肵B",						MELEE_MODE_CHEN,1, 0, 1, 9, 0 ,3},
	{ "%s֔тB",						MELEE_MODE_CHEN,6, 0, 2, 9, MELEE_STUN ,3},
	{ "%scsɈ~I",				MELEE_MODE_CHEN,15, 5, 3, 9, 0 ,5},
	{ "%s֓VՂ悤ȃAbp[I",   MELEE_MODE_CHEN,22, 12, 5, 9, MELEE_STUN ,6},
	{ "%s̔w֑f肱݊PI",		MELEE_MODE_CHEN,30, 20, 7, 9, 0 ,8},
	{ "]%s֓˂񂾁I",				MELEE_MODE_CHEN,36, 20, 8, 10, MELEE_STUN ,10},
	{ "%s֐Ԑ̋Ce@I",			MELEE_MODE_CHEN,45, 35, 10, 11, MELEE_STUN2 ,12},


	{ "%s𕿎ۂ̊pŒ@B",                 MELEE_MODE_MURASA1, 1, 0, 1, 7, 0 ,1},
	{ "%sRB",         		        	MELEE_MODE_MURASA1, 6, 0, 2, 5, 0 ,4},
	{ "%s𐅂̓oPcŉI",         MELEE_MODE_MURASA1,11, 0, 3, 5, 0 ,6},
	{ "%sRグI",         		        MELEE_MODE_MURASA1,16, 5, 4, 5, 0 ,5},
	{ "%s̏ɕdI",                 	MELEE_MODE_MURASA1,21, 10, 5, 7, 0 ,8},
	{ "%sdŉI",                 		MELEE_MODE_MURASA1,25, 20, 6, 7, MELEE_STUN ,10},
	{ "%sRďRďR܂I",         MELEE_MODE_MURASA1,30, 25, 6, 8, 0 ,5},
	{ "%s֕d@tI",              	   	MELEE_MODE_MURASA1,35, 30, 7, 9, MELEE_STUN2 ,10},
	{ "ȕd%s@ׂI",             MELEE_MODE_MURASA1,40, 35, 8, 10, MELEE_STUN2 ,12},

	{ "%s𕿎ۂ̊pŒ@B",                 	MELEE_MODE_MURASA2, 1, 0, 1, 9, 0 ,3},
	{ "%sPB",  	               	MELEE_MODE_MURASA2, 8, 0, 3, 8, 0 ,4},
	{ "%sgPI",            	     		MELEE_MODE_MURASA2, 15, 0, 5, 7, MELEE_WATER ,8},
	{ "%sɂ݂AɈ荞񂾁I",     MELEE_MODE_MURASA2, 22, 10, 6, 8, MELEE_SINK ,7},
	{ "%sɕdԂĐɒ@񂾁I",			MELEE_MODE_MURASA2, 28, 20, 7, 8, MELEE_SINK ,10},
	{ "ʂ疳̘r%s֐LтEE",			MELEE_MODE_MURASA2, 35, 30, 9, 10, MELEE_SINK ,8},
	{ "QNA%sۂݍ񂾁I",       	MELEE_MODE_MURASA2, 43, 40, 10, 12, MELEE_SINK ,13},

	{ "%sB",								MELEE_MODE_SHINMYOU2, 1, 0, 1, 7, 0 ,1},
	{ "%sRB",         		        		MELEE_MODE_SHINMYOU2, 7, 0, 2, 7, 0 ,4},
	{ "%sɘoR蓖ĂB",						MELEE_MODE_SHINMYOU2,13, 0, 3, 6, 0 ,6},
	{ "%s֑̓肵B",         					MELEE_MODE_SHINMYOU2,18, 5, 5, 5, 0 ,5},
	{ "%s֘o@B",                 		MELEE_MODE_SHINMYOU2,24, 10, 6, 7,0 ,8},
	{ "oɏăR}lY~̂悤%s֓ːiI", MELEE_MODE_SHINMYOU2,28, 20, 7, 7, MELEE_STUN ,5},
	{ "ŏȍƂ%sI",					MELEE_MODE_SHINMYOU2,33, 25, 8, 8, MELEE_STUN ,8},
	{ "]o%s񂾁I",           MELEE_MODE_SHINMYOU2,39, 30, 9, 9, 0 ,10},
	{ "%s֌đłȍƂԂ񂵂I",       MELEE_MODE_SHINMYOU2,43, 35, 10, 11, MELEE_STUN2 ,12},

	{ "%s@B",               MELEE_MODE_REIMU1,1, 0, 1, 7, 0 ,3},
	{ "%sRB",					MELEE_MODE_REIMU1,4, 0, 2, 5, 0 ,5},
	{ "%s։RH킹B",		MELEE_MODE_REIMU1,7, 0, 2, 6, 0 ,6},
	{ "%sփnCLbNH킹B",	MELEE_MODE_REIMU1,10, 0, 2, 8, MELEE_STUN ,6},
	{ "%s֏H킹B",			MELEE_MODE_REIMU1,14, 5, 3, 8, 0 ,6},
	{ "%s֔яRH킹B",     MELEE_MODE_REIMU1,18, 10, 4, 7, 0 ,7},
	{ "%s֗тRH킹B",   MELEE_MODE_REIMU1,23, 15, 5, 7, 0 ,7},
	{ "%s֑ołH킹I",       MELEE_MODE_REIMU1,27, 15, 6, 7, MELEE_STUN ,8},
	{ "%s֋tRH킹I",   MELEE_MODE_REIMU1,32, 20, 7, 7, 0 ,8},
	{ "%s֎OpяRH킹I", MELEE_MODE_REIMU1,36, 25,  8,  8, MELEE_STUN ,8},
	{ "%s֏VrH킹I",		MELEE_MODE_REIMU1,40, 25,  9, 10, MELEE_STUN2 ,10},
	{ "%s֓Ve_rI",		MELEE_MODE_REIMU1,45, 35, 12, 12, MELEE_STUN3 ,14},

	{ "%sւD\tB",         MELEE_MODE_REIMU2,1, 0, 2, 7, MELEE_SLAY_EVIL ,3},
	{ "%s֋Ȍ아B",		MELEE_MODE_REIMU2,6, 0, 3, 6, MELEE_SLAY_EVIL ,6},
	{ "EWJ%s𗍂߂ƂB",	MELEE_MODE_REIMU2,12, 5, 5, 7, MELEE_SLAY_EVIL ,6},
	{ "%s։Ĵ悤ɎD~点I",   MELEE_MODE_REIMU2,18, 10, 7, 7, MELEE_SLAY_EVIL ,7},
	{ "Eˏo%sӂ΂I", MELEE_MODE_REIMU2,24, 15, 7, 9, MELEE_STUN2 ,8},
	{ "uԈړ%s̏ォPI", MELEE_MODE_REIMU2,30, 20,  8, 10, MELEE_STUN2 ,8},
	{ "%s։AzʂI",			MELEE_MODE_REIMU2,35, 25, 10, 12, MELEE_SLAY_EVIL ,10},
	{ "%s֔EwI",		MELEE_MODE_REIMU2,40, 35, 13, 13, MELEE_STUN3 ,14},
	{ "%s։AzS_ʂI",		MELEE_MODE_REIMU2,45, 40, 16, 16, MELEE_SLAY_EVIL ,14},

	{ "%sɂ񂾁B",								MELEE_MODE_D_LORD,1, 0, 2, 7, 0 ,3},
	{ "%s֍ibNH킹I",				MELEE_MODE_D_LORD,20, 10, 12, 12, MELEE_ATAGO ,6},
	{ "%sփlIT^CpNgH킹I",		MELEE_MODE_D_LORD,31, 30, 8, 8, MELEE_POIS ,3},
	{ "%sփJ~eBGhH킹I",			MELEE_MODE_D_LORD,32, 10, 10, 10, 0 ,7},
	{ "%sփTCRLlVXH킹I",			MELEE_MODE_D_LORD,33, 20, 12, 12, MELEE_STUN3 ,7},
	{ "%sփ_[NlXC[WH킹I", MELEE_MODE_D_LORD,40, 35, 13, 13, MELEE_STUN3 ,10},
	{ "%sփg_OOp`H킹I", MELEE_MODE_D_LORD,47, 45, 16, 16, MELEE_STUN3 ,10},

	{ "%s~B",							MELEE_MODE_REMY_HAND,1, 0, 1, 7, 0 ,3},
	{ "%ss܂Ő؂􂢂I",					MELEE_MODE_REMY_HAND,7, 0, 3, 5, 0 ,5},
	{ "%ss܂Ő؂グI",					MELEE_MODE_REMY_HAND,12, 0, 6, 6, 0 ,6},
	{ "%s֐GꂽB",								MELEE_MODE_REMY_HAND,18, 0, 6, 7, MELEE_VAMP ,6},
	{ "%sֈ􂭂悤ȃtbNI",			MELEE_MODE_REMY_HAND,26, 5, 7, 9, MELEE_STUN ,6},
	{ "%s傫܂ɐ؂􂢂I",			MELEE_MODE_REMY_HAND,34, 20, 10, 11, 0 ,7},
	{ "g\̃I[%s𐁂΂I",		MELEE_MODE_REMY_HAND,45, 40, 13, 13, MELEE_STUN3 ,18},

	{ "%sܐŏRB",							MELEE_MODE_REMY_KICK,1, 0, 2, 5, 0 ,3},
	{ "%sɏRグI",						MELEE_MODE_REMY_KICK,10, 0, 3, 8, MELEE_STUN ,5},
	{ "啂%s֔񂾁B",				MELEE_MODE_REMY_KICK,17, 0, 5, 8, MELEE_VAMP ,6},
	{ "%s֒@悤ȋ󒆉]RI",	MELEE_MODE_REMY_KICK,24, 10, 8, 8, MELEE_STUN ,7},
	{ "%s֐؂􂭂悤ȏRI",			MELEE_MODE_REMY_KICK,33, 15, 8, 11, MELEE_STUN ,8},
	{ "x悤%sR܂I",				MELEE_MODE_REMY_KICK,40, 25, 10, 12, MELEE_STUN2 ,10},

	{ "%słB",							MELEE_MODE_REMY_OTHER,1, 0, 1, 7, 0 ,3},
	{ "%s֊悤ȃXCfBOB",		MELEE_MODE_REMY_OTHER,8, 0, 3, 5, 0 ,5},
	{ "傫Ȃ%s֒@܂ꂽI",		MELEE_MODE_REMY_OTHER,12, 0, 4, 6, MELEE_STUN ,6},
	{ "%s֋zREB",					MELEE_MODE_REMY_OTHER,20, 10, 6, 8, MELEE_VAMP ,6},
	{ "%s֒eۂ̂悤ɓːiI",					MELEE_MODE_REMY_OTHER,28, 10, 8, 8, MELEE_STUN2 ,10},
	{ "˔@pA%s̔wォPI",       MELEE_MODE_REMY_OTHER,32, 20, 9, 10, MELEE_STUN ,8},
	{ "ĥ悤%sI",				MELEE_MODE_REMY_OTHER,38, 25, 10, 10, 0 ,12},
	{ "啂%sY^Y^ɂI",			MELEE_MODE_REMY_OTHER,40, 30, 11, 11, MELEE_VAMP ,7},
	{ "gI[Z%s֐ݓˌI",		MELEE_MODE_REMY_OTHER,43, 35, 12, 12, MELEE_STUN3 ,14},

	{ "%sɓeRH킹B",						MELEE_MODE_NITORI,1, 0, 2, 3, 0 ,2},
	{ "]vy%sɓĂI",					MELEE_MODE_NITORI,7, 0, 4, 4, 0 ,3},
	{ "ȃol%se΂I",					MELEE_MODE_NITORI,12, 0, 5, 6, 0 ,6},
	{ "bNO[uяo%sփAbp[H킹I",	MELEE_MODE_NITORI,18, 12, 6, 7, MELEE_STUN2 ,7},
	{ "bNhяo%sI",			MELEE_MODE_NITORI,26, 20, 7, 8, 0 ,8},
	{ "bNSяo%sɒI",			MELEE_MODE_NITORI,34, 30, 9, 9, MELEE_STUN2 ,10},
	{ "hƃWFbgbN%s֓ˌI",	MELEE_MODE_NITORI,45, 40, 11, 11, 0 ,12},



	{ "%sփ`bvB",							  	MELEE_MODE_HIZIRI,1, 0, 2, 5, 0 ,4},
	{ "%s֑̓肵B",								MELEE_MODE_HIZIRI,3, 0, 3, 5, MELEE_STUN ,6},
	{ "%s蓁œ˂B",							  	MELEE_MODE_HIZIRI,5, 0, 4, 5, 0 ,5},
	{ "%s֐؂􂭂悤Ȏ蓁킹B",           MELEE_MODE_HIZIRI,8, 3, 5, 5, 0 ,6},
	{ "%s֋ȃtbN킹B",                 MELEE_MODE_HIZIRI,10, 5, 6, 5, MELEE_STUN ,7},
	{ "%sƌ؋ňŎaB",   					MELEE_MODE_HIZIRI,12, 5, 7, 5, 0 ,5},
	{ "삪剻%słB",                 	MELEE_MODE_HIZIRI,15, 10, 6, 7, MELEE_SLAY_EVIL ,5},
	{ "%sƌ؋ňŎaグB",                 	MELEE_MODE_HIZIRI,18, 10, 6, 7, 0 ,9},
	{ "%s֔яR킹B",                 	MELEE_MODE_HIZIRI,20, 10, 7, 7, MELEE_STUN ,10},
	{ "ƌ؋ň\%s֓ːiI",				MELEE_MODE_HIZIRI,23, 15, 8, 8, MELEE_STUN ,8},
	{ "%sƌ؋ňŊтI",			         	MELEE_MODE_HIZIRI,27, 20, 8, 8, 0 ,9},
	{ "%sȋCŒe΂I",				MELEE_MODE_HIZIRI,30, 20, 8, 8, MELEE_STUN3 ,5},
	{ "%sƌ؋ňő܂ɎaI",			    MELEE_MODE_HIZIRI,32, 25, 8, 9, 0 ,9},
	{ "%s֖@͂̏ՌgH킹I",				 	MELEE_MODE_HIZIRI,35, 25, 9, 9, MELEE_SLAY_EVIL ,8},
	{ "%sƌ؋ňłԂaI",				 	MELEE_MODE_HIZIRI,38, 25, 10, 10, 0 ,12},
	{ "%sֈ􂭂悤ȔяR킹I",       MELEE_MODE_HIZIRI,40, 30, 11, 11, MELEE_STUN2 ,12},
	{ "%s֖ڂɂ܂ʘA𗁂тI",   			MELEE_MODE_HIZIRI,42, 35, 12, 12, MELEE_STUN ,10},
	{ "%s֑ẑ悤ȈЌI",   				MELEE_MODE_HIZIRI,45, 40, 12, 13, MELEE_SLAY_EVIL ,12},
	{ "V~Ăȏ%s@ׂI",   	MELEE_MODE_HIZIRI,48, 45, 13, 13, MELEE_STUN3 ,15},


	{ "%sɂ񂾁B",					MELEE_MODE_NUE,1, 0, 2, 6, MELEE_NUE ,4},
	{ "%s񂾁I",					MELEE_MODE_NUE,6, 0, 4, 6, 0 ,7},
	{ "ւ̐K%sߏグI",     MELEE_MODE_NUE,11,0, 5, 7, MELEE_STUN ,8},
	{ "%s֓ːiI",					MELEE_MODE_NUE,17, 10, 7, 9, MELEE_STUN ,12},
	{ "%s֖iB",					MELEE_MODE_NUE,21, 10, 7, 9, MELEE_NUE ,6},
	{ "%s֕dI",					MELEE_MODE_NUE,25, 10, 8, 8, MELEE_ELEC ,12},
	{ "ւ̐K%s։˂ĂI", MELEE_MODE_NUE,30, 10, 8, 9, MELEE_POIS ,10},
	{ "%s֕sgȌt𚑂B",		MELEE_MODE_NUE,34, 20, 10, 10, MELEE_NUE ,12},
	{ "s܂%s~zI",		MELEE_MODE_NUE,39, 10, 12, 12, 0 ,10},
	{ "%sɗI",				MELEE_MODE_NUE,42, 20, 13, 13, MELEE_ELEC ,12},
	{ "%s͓̍ɕ܂ꂽB",		MELEE_MODE_NUE,46, 35, 13, 14, MELEE_POIS ,15},

	{ "%s𐧌_ŉB",				MELEE_MODE_UTSUHO,1, 0, 2, 4, 0 ,4},
	{ "%ŝ悤ȑŏRB",			MELEE_MODE_UTSUHO,4, 0, 2, 5, 0 ,4},
	{ "%s։Ή˂I",				MELEE_MODE_UTSUHO,8, 0, 1, 7, MELEE_FIRE ,1},
	{ "%s𐧌_œガB",			MELEE_MODE_UTSUHO,12, 0, 2, 6, MELEE_STUN ,5},
	{ "%ŝ悤ȑœ݂B",		MELEE_MODE_UTSUHO,15, 0, 3, 5, 0 ,6},
	{ "%sGĔR₵I",				MELEE_MODE_UTSUHO,18, 10, 2, 6, MELEE_FIRE ,2},
	{ "%s֓ːiI",						MELEE_MODE_UTSUHO,20, 15, 3, 7, MELEE_STUN ,5},
	{ "%s֐_U艺낵B",			MELEE_MODE_UTSUHO,23, 10, 4, 6, 0 ,8},
	{ "%sփwQCU[I",			MELEE_MODE_UTSUHO,25, 20, 4, 8, MELEE_FIRE ,9},
	{ "%ŝ悤ȑŏRグI",		MELEE_MODE_UTSUHO,29, 15, 6, 7, MELEE_STUN ,8},
	{ "%sփT}[\gLbNI",	MELEE_MODE_UTSUHO,32, 20, 7, 7, 0 ,8},
	{ "%s̎͂ő܂ɔNI",MELEE_MODE_UTSUHO,36, 30, 5, 7, MELEE_FIRE ,8},
	{ "e%słI",				MELEE_MODE_UTSUHO,39, 30,  7,  7, MELEE_STUN ,5},
	{ "%s֋ȉ΋𓊂I",		MELEE_MODE_UTSUHO,41, 30,  7, 8, MELEE_FIRE ,12},
	{ "%s֊js\_CuI",	 MELEE_MODE_UTSUHO,43, 35, 11, 11, MELEE_STUN2 ,15},
	{ "%s̉狐ȉΒオI",MELEE_MODE_UTSUHO,46, 37, 10, 18, MELEE_FIRE ,16},

	{ "%sւႪݏLbNB",             MELEE_MODE_MA,1, 0, 1, 3, 0 ,3},
	{ "%sփE~[EhD[킹I",       MELEE_MODE_MA,2, 20, 1, 1, 0 ,30},
	{ "%sփW(O[)I",               MELEE_MODE_MA,3, 0, 2, 5, 0 ,3},
	{ "%s֑oł킹I",            	    MELEE_MODE_MA,4, 2, 2, 6, 0 ,5},
	{ "%s֓SHI",            	    		MELEE_MODE_MA,5, 3, 2, 9, 0 ,1},
	{ "%sփu[tbNI",      	    MELEE_MODE_MA,6, 3, 2, 7, MELEE_STUN ,6},
	{ "%sփJK[LbNI",            	MELEE_MODE_MA,7, 5, 3, 5, 0 ,4},
	{ "%sփX[p[˂I",            	MELEE_MODE_MA,8, 4, 3, 6, MELEE_STUN ,8},
	{ "%s֐I",            				MELEE_MODE_MA,9, 2, 3, 6, 0 ,3},
	{ "%s֗rI",                 	MELEE_MODE_MA,10, 3, 3, 7, 0 ,5},
	{ "%s֗dI",                 		MELEE_MODE_MA,11, 7, 4, 7, 0 ,10},
	{ "%s֑Ők킹I",                 	MELEE_MODE_MA,12, 10, 5, 5, MELEE_STUN2 ,1},
	{ "%s֖kl\a킹I",               MELEE_MODE_MA,13, 7, 5, 6, 0 ,5},
	{ "%s֎ce킹I",  					MELEE_MODE_MA,14, 12, 6, 6, MELEE_STUN ,7},
	{ "%sփpXyV킹I",  			MELEE_MODE_MA,15, 13, 5, 7, 0 ,5},
	{ "%sփWFmTChJb^[I",  		MELEE_MODE_MA,16, 10, 6, 6, 0 ,8},
	{ "%s֋󈳌킹I",  					MELEE_MODE_MA,17, 7, 5, 5, MELEE_STUN ,5},
	{ "%s֘T啗킹I",  				MELEE_MODE_MA,18, 15, 7, 7, 0 ,10},
	{ "%s֔؝r킹I",  				MELEE_MODE_MA,19, 12, 7, 8, 0 ,6},
	{ "%sDDT킹I",						MELEE_MODE_MA,20, 18, 8, 8, MELEE_STUN2 ,10},
	{ "%sփq[gibNI",               MELEE_MODE_MA,21, 15, 6, 6, MELEE_FIRE ,5},
	{ "%sփ}bnp`I",                 MELEE_MODE_MA,22, 12, 7, 7, MELEE_STUN ,4},
	{ "%s֌ՙI",  						MELEE_MODE_MA,23, 18, 8, 8, 0 ,10},
	{ "%sփ_Ch_XgI",           MELEE_MODE_MA,24, 15, 6, 7, MELEE_COLD ,5},
	{ "%s֖klS􌝂I",  					MELEE_MODE_MA,25, 18, 9, 9, MELEE_STUN ,8},
	{ "%s֒n̒f킹I",  			MELEE_MODE_MA,26, 21, 8, 7, 0 ,12},
	{ "%sփp[QCU[I",               MELEE_MODE_MA,27, 16, 6, 7, MELEE_FIRE ,4},
	{ "%s֓V̗rI",  				MELEE_MODE_MA,28, 20, 7, 8, MELEE_STUN ,9},
	{ "%sփt[XpC킹I",  	MELEE_MODE_MA,29, 25, 10, 10, 0 ,14},
	{ "%sփneBOXI",           MELEE_MODE_MA,30, 28, 8, 9, 0 ,18},
	{ "%s֎_SI",                 	MELEE_MODE_MA,31, 25, 8, 9, 0 ,18},
	{ "%sֈrE旳_˂킹I",       MELEE_MODE_MA,32, 27, 7, 8, MELEE_FIRE ,10},
	{ "%s֋藠킹I",               	MELEE_MODE_MA,33, 30, 10, 10, 0,5},
	{ "%sփMNeBJ}Oi킹I",   MELEE_MODE_MA,34, 25, 8, 8, MELEE_STUN ,7},
	{ "%sփAp`I",      				MELEE_MODE_MA,35, 30, 4, 12, MELEE_STUN3 ,12},
	{ "%sփWFbg\jbN}bnp`I",	MELEE_MODE_MA,36, 27, 6, 11, 0 ,9},
	{ "%sփ_[NlXC[W킹I",	MELEE_MODE_MA,37, 32, 10, 10, MELEE_STUN ,10},
	{ "%sփJ~eBGh킹I",			MELEE_MODE_MA,38, 30, 9, 9, 0 ,15},
	{ "%sփ^CK[uCN킹I",			MELEE_MODE_MA,39, 36, 9, 9, MELEE_STUN2 ,10},
	{ "%sփhS[p`I",               MELEE_MODE_MA,40, 35, 10, 10, MELEE_STUN3 ,12},
	{ "%s֓l`򉍗I",       MELEE_MODE_MA,41, 40, 11, 12, 0 ,10},
	{ "%sփyKTXI",       		MELEE_MODE_MA,42, 38, 11, 11, MELEE_STUN2 ,11},
	{ "%sփt@Ciw킹I",       	MELEE_MODE_MA,43, 37, 10, 12, MELEE_STUN2 ,16},
	{ "uʖʖʖʖʖʖʖʃ@IIv",	MELEE_MODE_MA,44, 35, 11, 12, MELEE_STUN ,8},
	{ "%s֎׉Eł킹I",       	MELEE_MODE_MA,45, 40, 10, 10, MELEE_ATAGO ,12},
	{ "%sփI[GNXL[VI",   MELEE_MODE_MA,46, 40, 10, 10, MELEE_COLD ,12},
	{ "%s֖I",       				MELEE_MODE_MA,47, 40, 12, 12, 0 ,16},
	{ "%sփrbOoCpNg킹I",		MELEE_MODE_MA,48, 43, 12, 14, MELEE_STUN2 ,15},
	{ "%sփWFbgEgDEWFbgEApJ[킹I",MELEE_MODE_MA,49, 45, 13, 13, MELEE_STUN3 ,12},
	{ "%s֒edeeI",				MELEE_MODE_MA,50, 48, 13, 15, MELEE_ELEC ,20},

	{ "%s͂B",								MELEE_MODE_SUWAKO,1, 0, 1, 7, 0 ,3},
	{ "%sR܂I",							MELEE_MODE_SUWAKO,4, 0, 2, 5, 0 ,5},
	{ "%s֔тB",							MELEE_MODE_SUWAKO,7, 0, 2, 6, 0 ,6},
	{ "%sSւőłB",						MELEE_MODE_SUWAKO,10, 0, 2, 8, 0 ,3},
	{ "%sփJGуAbp[킹I",		MELEE_MODE_SUWAKO,14, 5, 3, 8, MELEE_STUN2 ,7},
	{ "̊^ɏ%s֑̓肵I",				MELEE_MODE_SUWAKO,18, 10, 4, 7, 0 ,9},
	{ "%s̑Ԍ򂪕oI",			MELEE_MODE_SUWAKO,22, 15, 5, 7, 0 ,7},
	{ "₪nяo%s֒I",       MELEE_MODE_SUWAKO,26, 15, 7, 7, MELEE_STUN ,8},
	{ "]Sւ%s؂􂢂I",				MELEE_MODE_SUWAKO,29, 20, 8, 7, 0 ,8},
	{ "^̂悤ȃI[%se΂I",		MELEE_MODE_SUWAKO,33, 20, 8, 8, 0 ,8},
	{ "Ȋ̎肪%sݑłI",			MELEE_MODE_SUWAKO,37, 30,  9,  9, MELEE_STUN ,12},
	{ "Ő̋%s֍~蒍I",			MELEE_MODE_SUWAKO,41, 30, 10, 10, 0 ,8 },
	{ "ւ̂悤ȋ₪%sۂݍ񂾁I",		MELEE_MODE_SUWAKO,45, 40, 12, 12, MELEE_STUN3 ,18},

	{ "%sKŃttB",					MELEE_MODE_RAN,1, 0, 1, 10, MELEE_STUN3 ,1},
	{ "%sKŒߏグI",						MELEE_MODE_RAN,25, 0, 5, 7, MELEE_STUN ,3},
	{ "˂悤%s֑̓肵I",				MELEE_MODE_RAN,35, 15, 8, 9, MELEE_STUN ,8},
	{ "]Ȃ%s֓ˌI",			MELEE_MODE_RAN,40, 30, 12, 12, MELEE_STUN2 ,10},

	{ "%s˂΂B",							  	MELEE_MODE_TENSHI,1, 0, 2, 5, 0 ,4},
	{ "%sRB",							  	MELEE_MODE_TENSHI,5, 0, 4, 5, 0 ,5},
	{ "%s֓˂킹B",						MELEE_MODE_TENSHI,10, 3, 5, 5, MELEE_STUN ,6},
	{ "%s֕Ił킹B",   					MELEE_MODE_TENSHI,14, 5, 7, 5, 0 ,5},
	{ "%s֔яR킹B",                 	MELEE_MODE_TENSHI,18, 10, 6, 7,0 ,5},
	{ "%sv΂ŉB",                 			MELEE_MODE_TENSHI,22, 10, 6, 7, MELEE_STUN ,9},
	{ "v΂U肩Ԃ%s֒@I",				MELEE_MODE_TENSHI,25, 15, 8, 8, MELEE_STUN2 ,9},
	{ "%sփT}[\gLbN킹I",			MELEE_MODE_TENSHI,30, 20, 8, 8, 0 ,9},
	{ "%s̑v΂˂ꂽI",					MELEE_MODE_TENSHI,36, 25, 8, 8, MELEE_STUN ,5},
	{ "v΂ɏ%s֗I",						MELEE_MODE_TENSHI,40, 25, 9, 9, MELEE_STUN2 ,8},
	{ "₪W܂Ă%sԂI",				 	MELEE_MODE_TENSHI,44, 35, 10, 10, 0 ,12},
	{ "V~Ăȗv΂%s@ׂI",   	MELEE_MODE_TENSHI,48, 45, 12, 12, MELEE_STUN2 ,15},

	{ "%s֏H킹B",   				MELEE_MODE_MEIRIN,1, 0, 2, 5, 0 ,6},
	{ "%s֒i˂H킹B",   			MELEE_MODE_MEIRIN,4, 0, 3, 5, 0 ,8},
	{ "%s蓁œ˂B",                 	MELEE_MODE_MEIRIN,9, 5, 4, 5, 0 ,3},
	{ "%s֑ڂH킹B",   			MELEE_MODE_MEIRIN,12, 8, 5, 5, 0 ,5},
	{ "%s֔wςH킹B",   			MELEE_MODE_MEIRIN,16, 10, 6, 5, MELEE_STUN ,6},
	{ "%s֍~؏RH킹B",				MELEE_MODE_MEIRIN,19, 12, 7, 5, 0 ,6},
	{ "%s֔jRC킹B",               MELEE_MODE_MEIRIN,22, 18, 7, 6, 0 ,10},
	{ "%s֋CCB",						MELEE_MODE_MEIRIN,25, 20, 7, 7, MELEE_STUN ,8},
	{ "%s։krH킹B",				MELEE_MODE_MEIRIN,28, 20, 8, 7, 0 ,8},
	{ "%s֍gH킹B",   			MELEE_MODE_MEIRIN,31, 25, 8, 8, MELEE_STUN ,10},
	{ "%s֒ngB",   				MELEE_MODE_MEIRIN,34, 25, 8, 9, 0 ,12},
	{ "%s֓VrH킹B",   			MELEE_MODE_MEIRIN,37, 25, 9, 9, 0 ,6},
	{ "%s֑QH킹I",   			MELEE_MODE_MEIRIN,40, 30, 9, 10, MELEE_STUN ,10},
	{ "%s֗^H킹I",   			MELEE_MODE_MEIRIN,42, 35, 10, 10, 0 ,10},
	{ "%s֐n]eH킹I",   		MELEE_MODE_MEIRIN,44, 40, 11, 11, MELEE_STUN2 ,12},
	{ "%s֕RʋɖCH킹I",   		MELEE_MODE_MEIRIN,47, 45, 12, 12, MELEE_STUN3 ,15},

	{ "%s|R|R@B",                 				MELEE_MODE_SUMIREKO,1, 0, 1, 3, 0 ,3},
	{ "%sփqbvA^bNB",           				MELEE_MODE_SUMIREKO,6, 0, 2, 3, 0 ,3},
	{ "%sփJ[h΂B",								MELEE_MODE_SUMIREKO,10, 3, 3, 4, 0 ,7},
	{ "%sփoXW𓊂B",                 		MELEE_MODE_SUMIREKO,15, 10, 3, 6, 0 ,4},
	{ "%s֓HWU艺낵B",                 		MELEE_MODE_SUMIREKO,20, 10, 4, 4, 0 ,6},
	{ "%s̑}z[̊WƐoI",       MELEE_MODE_SUMIREKO,26, 20, 6, 5, MELEE_WATER ,5},
	{ "I˂%s񂾁I",                 			MELEE_MODE_SUMIREKO,31, 20, 7, 7, 0 ,7},
	{ "%s֌ēd|ꂽB",							MELEE_MODE_SUMIREKO,36, 30, 8, 9, MELEE_STUN ,8},
	{ "%s֓S𓊂I",								MELEE_MODE_SUMIREKO,40, 30, 10, 10, 0 ,12},
	{ "ȓdgn𗧂Ă%s̏֓|ꂽI",		MELEE_MODE_SUMIREKO,45, 40, 8, 14, MELEE_STUN2 ,14},

	{ "_R%sɂ񂾁B",                 		MELEE_MODE_ICHIRIN,1, 0, 1, 5, 0 ,1},
	{ "_R%sςB",           		MELEE_MODE_ICHIRIN,7, 0, 2, 6, 0 ,4},
	{ "_R%sI",                 	MELEE_MODE_ICHIRIN,12, 6, 3, 5, 0 ,8},
	{ "_R%sփc[p`I",             MELEE_MODE_ICHIRIN,16, 10, 3, 6, MELEE_STUN ,6},
	{ "_R%s֌dI",                 	MELEE_MODE_ICHIRIN,21, 15, 4, 5, MELEE_ELEC ,3},
	{ "_R%s͂ݓ΂I",              	MELEE_MODE_ICHIRIN,27, 20, 6, 6, 0 ,8},
	{ "_R̋Ȍ%sɗI",                 	MELEE_MODE_ICHIRIN,31, 20, 7, 7, MELEE_STUN ,10},
	{ "_RƋɗł킹I",        MELEE_MODE_ICHIRIN,36, 30, 8, 8, MELEE_ELEC ,6},
	{ "_R%s֓{̗łI",          	MELEE_MODE_ICHIRIN,40, 30, 10, 10, 0 ,10},
	{ "_R%s֟Ӑg̋Xg[gI",    MELEE_MODE_ICHIRIN,44, 40, 12, 12, MELEE_STUN2 ,15},

	{ "_R%s^RɂI",        MELEE_MODE_ICHIRIN2,1, 0, 8, 8, MELEE_STUN ,5},

	{ "%sփ[LbNH킹B",   	MELEE_MODE_MOKOU,1, 0, 1, 5, 0 ,3},
	{ "%sփNULbNH킹B",   	MELEE_MODE_MOKOU,6, 0, 2, 4, 0 ,4},
	{ "%s֏ȉ΋΂B",   		MELEE_MODE_MOKOU,10, 0, 1, 8, MELEE_FIRE ,3},
	{ "%sփ{fBu[H킹B",   	MELEE_MODE_MOKOU,15, 6, 3, 4, 0 ,6},
	{ "%sR鑫ŏRグI",   		MELEE_MODE_MOKOU,19, 10, 4, 5, MELEE_STUN ,5},
	{ "%sɎNI",   	MELEE_MODE_MOKOU,23, 16, 3, 6, MELEE_FIRE ,8},
	{ "ԔMH%słI", MELEE_MODE_MOKOU,28, 20, 4, 5, MELEE_FIRE ,1},
	{ "R錝%sI",   	MELEE_MODE_MOKOU,32, 26, 6, 7, MELEE_STUN ,8},
	{ "%sΒ܂Ŏa􂢂I",   			MELEE_MODE_MOKOU,36, 25, 4, 10, MELEE_FIRE ,5},
	{ "ȉ΋%s֒@I",   	MELEE_MODE_MOKOU,40, 32, 8, 8, MELEE_FIRE ,10},
	{ "%sΒ܂ŖőaɂI",   		MELEE_MODE_MOKOU,43, 35, 6, 12, MELEE_FIRE ,8},
	{ "%s֊MċrH킹I",   MELEE_MODE_MOKOU,47, 45, 10, 12, MELEE_FIRE ,12},

	{ "%s𕽎łB",		      				MELEE_MODE_KANAKO,1, 0, 1, 7, 0 ,2},
	{ "%sׂ߂̌䒌őłB",     			MELEE_MODE_KANAKO,7, 0, 2, 6, 0 ,4},
	{ "%s͂ނɊ܂ꂽB",   			MELEE_MODE_KANAKO,14, 7, 3, 5, 0 ,6},
	{ "䒌Lт%s˂B",       			MELEE_MODE_KANAKO,19, 5, 4, 5, 0 ,7},
	{ "%s̓ォ䒌ĂI",       		MELEE_MODE_KANAKO,24, 10, 4, 9, MELEE_STUN ,8},
	{ "%sɓ{̗軂I",		      		MELEE_MODE_KANAKO,28, 25, 3, 12, MELEE_ELEC ,10},
	{ "%s֌䒌̃tXCOH킹I",       MELEE_MODE_KANAKO,32, 25, 5, 12, MELEE_STUN ,8},
	{ "瞂_C%s֒@tꂽI",   			MELEE_MODE_KANAKO,36, 30, 8, 8, MELEE_SLAY_EVIL ,5},
	{ "n狐Ȍ䒌яo%s𐁂΂I",  	MELEE_MODE_KANAKO,40, 37, 10, 13, MELEE_STUN ,12},
	{ "V狐Ȍ䒌~Ă%s@ׂI",   	MELEE_MODE_KANAKO,47, 45, 10, 15, MELEE_STUN2 ,16},

	{ "%s𑳂ł͂B",					MELEE_MODE_FUTO,1, 0, 1, 3, 0 ,2},
	{ "%s։]UH킹B",			MELEE_MODE_FUTO,10, 5, 2, 4, 0 ,7},
	{ "%s֏ȗNB",			MELEE_MODE_FUTO,15, 10, 3, 5, 0 ,6},
	{ "%s։΋𓊂B",				MELEE_MODE_FUTO,20, 10, 3, 4, MELEE_FIRE ,4},
	{ "%s֑M@B",				MELEE_MODE_FUTO,25, 20, 4, 7, MELEE_STUN ,5},
	{ "%s͓ˑRRオI",				MELEE_MODE_FUTO,30, 20, 4, 6, MELEE_FIRE ,8},
	{ "%s̑₪яoI",			MELEE_MODE_FUTO,34, 25, 5, 6, MELEE_STUN ,6},
	{ "%s͑嗳Ɋ܂ꂽI",				MELEE_MODE_FUTO,38, 30, 10, 10, 0 ,10},
	{ "%s̑狐ȉΒオI",		MELEE_MODE_FUTO,42, 40, 10, 12, MELEE_FIRE ,12},
	{ "V̔֏Mɏ%s֓ˌI",		MELEE_MODE_FUTO,45, 40, 12, 12, MELEE_STUN2 ,12},

	{ "%sⴂł͂B",						MELEE_MODE_MARISA,1, 0, 1, 7, 0 ,1},
	{ "%sⴂœ˂B",						MELEE_MODE_MARISA,4, 0, 2, 5, 0 ,3},
	{ "%sɃqbvA^bNH킹B",		MELEE_MODE_MARISA,8, 0, 2, 6, MELEE_STUN ,7},
	{ "%sɐ΂B",					MELEE_MODE_MARISA,12, 10, 2, 8, 0 ,3},
	{ "%sⴂ̃tXCO킹I",		MELEE_MODE_MARISA,16, 5, 3, 8, 0 ,6},
	{ "ⴂɏ%sɓːiI",				MELEE_MODE_MARISA,20, 15, 4, 7, MELEE_STUN ,12},
	{ "̖tr%sɓB",	MELEE_MODE_MARISA,24, 10, 5, 6, MELEE_POIS ,7},
	{ "%sɃ~AY}XEB[v킹I",	MELEE_MODE_MARISA,28, 20, 5, 7, 0 ,7},
	{ "%s̓ォ琯~蒍I",			MELEE_MODE_MARISA,32, 25, 6, 7, 0 ,8},
	{ "%sɃWAXgCN킹I",	MELEE_MODE_MARISA,36, 30, 7, 7, MELEE_STUN ,8},
	{ "%sɃ~bpT[킹I",		MELEE_MODE_MARISA,40, 32,  8,  8, MELEE_ELEC ,8},
	{ "%sɓr唚I",			MELEE_MODE_MARISA,43, 35, 10, 10, MELEE_STUN2 ,10},
	{ "%sɃTOCU[킹I",		MELEE_MODE_MARISA,47, 45, 12, 12, MELEE_ATAGO ,16},

	{ "̒e%s֕ꂽB",					MELEE_MODE_BENBEN,1, 0, 7, 7, MELEE_STUN ,3},
	{ "ܐ̌Q%sPI",			MELEE_MODE_BENBEN,33, 20, 8, 8, 0 ,5},
	{ "Ռg%s𐁂΂I",					MELEE_MODE_BENBEN,36, 30, 9, 9, MELEE_STUN ,7},
	{ "ܐ̌%s؂􂢂I",				MELEE_MODE_BENBEN,39, 30, 10, 10, 0 ,7},
	{ "jł̐%s֒@ꂽI",			MELEE_MODE_BENBEN,44, 35, 11, 11, MELEE_STUN2 ,9},
	{ "̌X%sтI",				MELEE_MODE_BENBEN,48, 40, 12, 12, 0 ,12},

	{ "%sB",				MELEE_MODE_HINA,1, 0, 1, 2, 0 ,5},
	{ "%sɔ΂݂B",		MELEE_MODE_HINA,8, 0, 2, 2, 0 ,5},
	{ "%sɋߊB",			MELEE_MODE_HINA,15, 5, 3, 4, 0 ,6},
	{ "%sɌ肩B",		MELEE_MODE_HINA,22, 10, 4, 5, 0 ,6},
	{ "%sɎoB",	MELEE_MODE_HINA,28, 20, 5, 5, 0 ,7},
	{ "%sɐGꂽB",			MELEE_MODE_HINA,34, 25, 5, 6, MELEE_STUN ,8},
	{ "%sɚB",		MELEE_MODE_HINA,40, 35, 5, 7, 0 ,10},
	{ "%sDiB",	MELEE_MODE_HINA,44, 40, 5, 10, MELEE_STUN2 ,15},

	{ "Tj[%sRB",					MELEE_MODE_3_FAIRIES,1, 0, 1, 4, 0 ,3},
	{ "i]񂾁B",							MELEE_MODE_3_FAIRIES,6, 5, 1, 1, MELEE_STUN ,3},
	{ "Tj[%s̑OŌI",				MELEE_MODE_3_FAIRIES,7, 0, 2, 7, MELEE_SLAY_EVIL ,5},
	{ "Ol%sɔтI",				MELEE_MODE_3_FAIRIES,15, 5, 4, 7, 0 ,6},
	{ "Ol%sRI",				MELEE_MODE_3_FAIRIES,24, 10, 6, 7, 0 ,8},
	{ "Ol%s֋ȑMI",			MELEE_MODE_3_FAIRIES,32, 20, 6, 6, MELEE_SLAY_EVIL ,8},
	{ "%sɃO[ggCAOH킹I",	MELEE_MODE_3_FAIRIES,38, 30, 8, 7, 0 ,10},
	{ "%sɃtFA[I[o[hCuH킹I",	MELEE_MODE_3_FAIRIES,45, 40, 10, 10, MELEE_STUN2 ,12},

	{ "%so`őłB",						MELEE_MODE_RAIKO,1, 0, 1, 3, 0 ,2},
	{ "%sRB",							MELEE_MODE_RAIKO,8, 5, 2, 4, 0 ,7},
	{ "%s𓥂݂B",						MELEE_MODE_RAIKO,14, 10, 3, 5, 0 ,6},
	{ "%sɑ̓肵B",						MELEE_MODE_RAIKO,20, 10, 3, 4, 0 ,4},
	{ "ۂ%s֍I",				MELEE_MODE_RAIKO,24, 20, 4, 7, MELEE_STUN ,5},
	{ "h%sɕdI",					MELEE_MODE_RAIKO,28, 20, 4, 6, MELEE_ELEC ,5},
	{ "%sRďRďR܂I",			MELEE_MODE_RAIKO,32, 25, 7, 6, 0 ,6},
	{ "̃o`%s𗐑łI",				MELEE_MODE_RAIKO,35, 30, 8, 8, MELEE_STUN ,8},
	{ "%s̓ɗI",					MELEE_MODE_RAIKO,39, 32, 8, 10, MELEE_ELEC ,10},
	{ "%snCr[gɑł炵I",			MELEE_MODE_RAIKO,43, 35, 10, 11, MELEE_STUN ,10},
	{ "Ռg%s𐁂΂I",				MELEE_MODE_RAIKO,48, 43, 12, 12, MELEE_STUN2 ,13},

	{ "%sRB",								MELEE_MODE_MAMIZOU,1, 0, 1, 6, 0 ,3},
	{ "%s哿ŉB",						MELEE_MODE_MAMIZOU,6, 0, 2, 4, 0 ,4},
	{ "%sɉ̉𐁂tB",					MELEE_MODE_MAMIZOU,11, 6, 1, 1, MELEE_SLOW ,1},
	{ "%s哿łԂ@I",					MELEE_MODE_MAMIZOU,16, 3, 3, 5, MELEE_STUN ,5},
	{ "񓔂ɕςz%sɒ@I",		MELEE_MODE_MAMIZOU,21, 0, 2, 8, MELEE_FIRE ,3},
	{ "A~Lɕςz%s֎atI",		MELEE_MODE_MAMIZOU,26, 10, 5, 6,  0,3},
	{ "ޕrƂɕςz%s̏ɗI",	MELEE_MODE_MAMIZOU,30, 11, 3, 12, MELEE_STUN ,3},
	{ "Z%s񂾁EE",					MELEE_MODE_MAMIZOU,33, 20, 6, 6, MELEE_NUE ,8},
	{ "ʂ肩ׂɕςz%sׂI",		MELEE_MODE_MAMIZOU,37, 27, 9, 9, 0 ,12},
	{ "nɉ%s̓ɗI",				MELEE_MODE_MAMIZOU,41, 32, 10, 10, MELEE_STUN2 ,10},
	{ "zƈꏏ%s𝆂݂ɂI",		MELEE_MODE_MAMIZOU,45, 40, 12, 12, MELEE_STUN ,12},

	{ "%sɔ΂݂B",							  	MELEE_MODE_YUKARI,1, 0, 2, 5, MELEE_NUE ,4},
	{ "oA%s؂ƑłB",				MELEE_MODE_YUKARI,5, 0, 4, 5, 0 ,5},
	{ "%sRB",									MELEE_MODE_YUKARI,10, 3, 5, 5, MELEE_STUN ,6},
	{ "XL}eяo%sy􂵂B",   		MELEE_MODE_YUKARI,14, 5, 7, 5, 0 ,5},
	{ "%s̏ォ΂B",                 	MELEE_MODE_YUKARI,18, 10, 6, 7,MELEE_STUN ,5},
	{ "XL}瓹HWяo%sɌ˂I",   MELEE_MODE_YUKARI,22, 10, 6, 7, MELEE_STUN ,9},
	{ "XL}%s؂􂢂I",						MELEE_MODE_YUKARI,25, 15, 8, 8, 0 ,9},
	{ "̔s%sPI",						MELEE_MODE_YUKARI,30, 20, 8, 8, MELEE_NUE ,9},
	{ "XL}瑲kяo%sɓ˂hI",	MELEE_MODE_YUKARI,36, 25, 8, 8, 0 ,5},
	{ "%słȌEɕ߂I",					MELEE_MODE_YUKARI,40, 25, 9, 9, MELEE_STUN ,8},
	{ "%s𕢂sEE",					MELEE_MODE_YUKARI,44, 35, 10, 10, 0 ,12},
	{ "̃XL}%sݍő唚NI", MELEE_MODE_YUKARI,48, 45, 12, 12, MELEE_STUN2 ,15},

	{ "%seŉB",					MELEE_MODE_GUN_HANDGUN,1, 0,  2, 3, 0 ,3},
	{ "eg%sԂ񉣂I",		MELEE_MODE_GUN_HANDGUN,25,15, 4, 8, 0 ,6},

	{ "%segœ˂B",				MELEE_MODE_GUN_LONGBARREL,1, 0,1, 6, 0 ,3},
	{ "%s֏eg̃tXCOH킹I",	MELEE_MODE_GUN_LONGBARREL,20,20,3, 8, 0 ,8},
	{ "%s֏e@tI",			MELEE_MODE_GUN_LONGBARREL,35,20,5, 8, 0 ,10},

	{ "%seœ˂B",				MELEE_MODE_GUN_BAYONET,1, 0,2, 8, 0 ,4},
	{ "%s֏e̗˂I",		MELEE_MODE_GUN_BAYONET,12,5,4, 8, 0 ,6},
	{ "e\%s֓ˌI",			MELEE_MODE_GUN_BAYONET,24,10,6, 8, 0 ,8},
	{ "%seŊтI",				MELEE_MODE_GUN_BAYONET,36,25,9, 9, 0 ,10},

	{ "%sCgłԂ񉣂B",			MELEE_MODE_GUN_LAUNCHER,1, 0, 1, 12, 0 ,6},
	{ "%s֖Cg@tI",			MELEE_MODE_GUN_LAUNCHER,30,20,5, 8, MELEE_STUN ,12},

	//̍U̎AꏈōU͂ɏe̍U/4Z
	//v1.1.21 1/81/4ɂɎce𔽉f
	{ "ȑe]%słB",				MELEE_MODE_GUN_TWOHAND,1, 0,  1, 4, 0 ,4},
	{ "ߋ%s֓񒚌e𗐎˂I",				MELEE_MODE_GUN_TWOHAND,20,10, 3, 4, 0 ,5},
	{ "%s̎pf荞ݗ닗ˌI",		MELEE_MODE_GUN_TWOHAND,30,20, 4, 5, MELEE_STUN ,6},
	{ "%sɌăGrWvȂˌI",		MELEE_MODE_GUN_TWOHAND,35,25, 5, 5, 0 ,8},
	{ "[TgȂ%s֏eA˂I",				MELEE_MODE_GUN_TWOHAND,40,20, 6, 6, 0 ,10},
	{ "x悤%s֏ee@݁AؗɎcS߂I",	MELEE_MODE_GUN_TWOHAND,45,40, 8, 8, MELEE_STUN2 ,14},

	//v1.1.19 ǂ
	{ "%sɕIłH킹B",   						MELEE_MODE_UDONGE,1, 0, 1, 5, 0 ,3},
	{ "%sɉRH킹B",   						MELEE_MODE_UDONGE,7, 5, 2, 5, 0 ,5},
	{ "%sɂ񂾁B",   									MELEE_MODE_UDONGE,15, 5, 4, 5, MELEE_NUE ,2},
	{ "%sɉ񂵏RH킹B",							MELEE_MODE_UDONGE,21, 10, 5, 5, MELEE_STUN ,7},
	{ "ǂ炩oŖ%sɓB",   		MELEE_MODE_UDONGE,27, 20, 6, 6, MELEE_POIS ,6},
	{ "%s𗼑œ݂B",								MELEE_MODE_UDONGE,32, 25, 4, 12, MELEE_STUN ,9},
	{ "%sɉB",   							MELEE_MODE_UDONGE,38, 30, 8, 8, MELEE_NUE ,5},
	{ "%sɌOɁiieBbNbhACY)H킹I", MELEE_MODE_UDONGE,44, 40, 10, 10, MELEE_STUN3 ,12},

	//v1.1.20  dʕύX
	{ "LԂ%s֑̓肵B",						MELEE_MODE_ORIN,1, 0, 2, 6, MELEE_NEKOGURUMA ,1},
	{ "%sLԂŒ˔΂I",					MELEE_MODE_ORIN,20,10,4, 7, MELEE_NEKOGURUMA ,1},
	{ "%sLԂ瀂I",							MELEE_MODE_ORIN,30,20,6, 8, MELEE_NEKOGURUMA ,1},
	{ "%sLԂŐ΂I",					MELEE_MODE_ORIN,40,35,9, 9, MELEE_NEKOGURUMA ,1},

	//v1.1.20 m@obNX^bup
	{ "Ȃ͕R\ĔEъ..",				MELEE_MODE_SNEAKING,1,  0, 3, 3, 0 ,1},
	{ "Ȃ͐΂l߂܂\ĔEъ..",	MELEE_MODE_SNEAKING,10, 5, 4, 4, 0 ,1},
	{ "Ȃ͐}\ĔEъ..",		MELEE_MODE_SNEAKING,20,15, 5, 5, 0 ,1},
	{ "Ȃ͋CzEĔEъ..",			MELEE_MODE_SNEAKING,30,25, 6, 6, 0 ,1},
	{ "Ȃ̓Xv[\ĔEъ..",		MELEE_MODE_SNEAKING,45,40,12,12, 0 ,1},

	//v1.1.37 ϐg
	{ "ê悤Ȃ̂%sɗ݂B",           MELEE_MODE_HYAKKI,1, 0, 3, 3, MELEE_SLOW ,1},
	{ "e܂%s~B",           		MELEE_MODE_HYAKKI,7, 0, 3, 5, 0 ,4},
	{ "e̊p%s˂B",                 		MELEE_MODE_HYAKKI,12, 7, 2, 10, MELEE_STUN ,8},
	{ "e܂%s~zB",					MELEE_MODE_HYAKKI,16, 12, 5, 5, 0 ,6},
	{ "ẻ傪%s֊ݕtB",                 	MELEE_MODE_HYAKKI,21, 15, 6, 6, MELEE_VAMP ,8},
	{ "e%sߏグI",              			MELEE_MODE_HYAKKI,27, 20, 7, 7, MELEE_SLOW ,2},
	{ "ẻ傪%sтI",                 		MELEE_MODE_HYAKKI,32, 25, 5, 10,MELEE_VAMP ,10},
	{ "ȉe%s֔тI",				MELEE_MODE_HYAKKI,36, 30, 9,  9, MELEE_STUN ,12},
	{ "e܂%sőaɂI",          	MELEE_MODE_HYAKKI,40, 30, 11, 11, 0 ,10},
	{ "e̊{傪%sۂݍ񂾁I",					MELEE_MODE_HYAKKI,45, 40, 12, 12, MELEE_VAMP ,10},

	//v1.1.42 h~[
	{ "XqLт%s˂B",					MELEE_MODE_DOREMY, 1,  0,  2,  3, 0 ,3 },
	{ "nbN%sɌĒˋNB",		MELEE_MODE_DOREMY, 5,  0,  2,  5, 0 ,5 },
	{ "%s̏ɃNbV_CuB",				MELEE_MODE_DOREMY,10,  0,  2,  6, MELEE_STUN ,6 },
	{ "r%sɑ̓肵B",						MELEE_MODE_DOREMY,14,  5,  2,  8, MELEE_SLEEP ,3 },
	{ "%sɃxbh𓊂I",					MELEE_MODE_DOREMY,18, 10,  5,  5, 0 ,7 },
	{ "%s̎Ńbp𐁂I",					MELEE_MODE_DOREMY,22, 15,  6,  6, MELEE_STUN ,7 },
	{ "̑ʂɏ%sɓːiI",			MELEE_MODE_DOREMY,26, 20,  5,  8, MELEE_SLEEP ,9 },
	{ "%sɃxbhRقǓI",				MELEE_MODE_DOREMY,30, 20,  6, 10, 0 ,8 },
	{ "%sɃh~[|bsOI",			MELEE_MODE_DOREMY,34, 25,  6,  8, MELEE_SLEEP ,8 },
	{ "%s̎Ŏv؂胉bp𐁂I",			MELEE_MODE_DOREMY,38, 30,  8,  8, MELEE_STUN2 ,10 },
	{ "r%s𝆂݂ɂI",				MELEE_MODE_DOREMY,42, 30,  7, 10, MELEE_SLEEP ,8 },
	{ "̉%sׂI",					MELEE_MODE_DOREMY,47, 40, 10, 12, MELEE_SLEEP ,16 },

	//v1.1.46 1
	{ "%sɋ񂾁B",								MELEE_MODE_JYOON_1, 1, 0, 1, 4, 0 ,1 },
	{ "%s݂֒͂B",								MELEE_MODE_JYOON_1, 5, 0, 1, 6, 0 ,4 },
	{ "%sB",									MELEE_MODE_JYOON_1,10, 0, 1, 8, 0 ,5 },
	{ "%sɃAbp[H킹B",						MELEE_MODE_JYOON_1,15, 5, 2, 4, 0 ,6 },
	{ "%sɓ˂B",								MELEE_MODE_JYOON_1,20,10, 2, 6, MELEE_STUN ,8 },
	{ "%sɃG{[hbvB",				MELEE_MODE_JYOON_1,25,10, 3, 5, 0 ,6 },
	{ "%sɈЈIȕpH킹B",				MELEE_MODE_JYOON_1,30,20, 4, 6, 0 ,6 },
	{ "%s̋q͂ŎグėhԂB",			MELEE_MODE_JYOON_1,35,20, 5, 6, MELEE_STUN ,3 },
	{ "%sŘAp`H킹B",			MELEE_MODE_JYOON_1,40,30, 6, 7, 0 ,7 },
	{ "%sɓ@Ďv؂Ԃ񉣂I",		MELEE_MODE_JYOON_1,45,35, 8, 8, MELEE_STUN ,16},

	//2
	{ "hȐ%sガB",						MELEE_MODE_JYOON_2, 1, 0, 2, 8, 0 ,5 },
	{ "uhobO%sԂ@B",				MELEE_MODE_JYOON_2,10, 0, 4, 8, 0 ,6 },
	{ "Ȃ̌Ăю~߂^NV[%s𒵂˂I",		MELEE_MODE_JYOON_2,15, 0, 6, 7, 0 ,12 },
	{ "嗱̕΂%s̓֍~蒍B",				MELEE_MODE_JYOON_2,20,10, 8, 8, MELEE_STUN ,3 },
	{ "̐%sPB",						MELEE_MODE_JYOON_2,25,20, 9, 9, MELEE_SLOW ,1 },
	{ "%s֋P΂̘AI",				MELEE_MODE_JYOON_2,30,20,10,10, 0 ,7 },
	{ "̃gl[h%s𐁂΂I",			MELEE_MODE_JYOON_2,35,25,12,12, MELEE_STUN ,8 },
	{ "%s֎D΂Tĉ΂I",				MELEE_MODE_JYOON_2,40,30,13,13, MELEE_FIRE ,1 },
	{ "TU炵Ȃ%s֓ˌI",		MELEE_MODE_JYOON_2,44,30,15,15, MELEE_STUN2 ,12 },
	{ "ῂX|bgCg𗁂тėx܂I",		MELEE_MODE_JYOON_2,48,40,18,18, MELEE_STUN3 ,20 },

	//v1.1.48 (X[p[nR_)
	{ "̃I[%sɗ݂B",					MELEE_MODE_SUPER_SHION,1,0,12,12, MELEE_STUN ,1 },
	{ "|̈ÍI[%s񂾁B",					MELEE_MODE_SUPER_SHION,20,10,12,12, MELEE_STUN2 ,10 },
	{ "%s͕sK̃I[ɓۂݍ܂ꂽI",				MELEE_MODE_SUPER_SHION,30,20,20,20, MELEE_STUN2 ,12 },
	{ "%s̉^CzI",					MELEE_MODE_SUPER_SHION,40,30,25,25, MELEE_STUN3 ,16 },


	{ "I[pdummy",0,0,0,1,1,0}
};

///sys fUGtFNgƈЗ͈ꗗ\
/*:::,Œ჌x,s,dd,ds,*/
/*
const martial_arts ma_blows[MAX_MA] =
{
#ifdef JP
	{ "%sB",                          1, 0, 1, 5, 0 },
	{ "%sRB",                           2, 0, 1, 7, 0 },
	{ "%sɐ˂킵B",                         3, 0, 1, 9, 0 },
	{ "%sɕGR킵B",             5, 5, 2, 4, MA_KNEE },
	{ "%sɕIł킵B",            7, 5, 1, 12, 0 },
	{ "%sɑ̓肵B",                           9, 10, 2, 6, 0 },
	{ "%sRB",                           11, 10, 3, 6, MA_SLOW },
	{ "%sɃAbp[킵B",                       13, 12, 5, 5, 6 },
	{ "%sɓiR킵B",                    16, 15, 5, 6, 8 },
	{ "%sɔL܌킵B",          20, 20, 5, 8, 0 },
	{ "%sɒr킵B",           24, 25, 6, 8, 10 },
	{ "%sɘh܏P킵B",       28, 25, 7, 9, 0 },
	{ "%sɉ񂵏R킵B",         32, 30, 8, 10, 10 },
	{ "%sɓS킵B",          35, 35, 8, 11, 10 },
	{ "%sɔr킵B",         39, 35, 8, 12, 12 },
	{ "%sɏ킵B",         43, 35, 9, 12, 16 },
	{ "%sɐΔjV킵B",       48, 40, 10, 13, 18 },
#else
	{ "You punch %s.",                          1, 0, 1, 4, 0 },
	{ "You kick %s.",                           2, 0, 1, 6, 0 },
	{ "You strike %s.",                         3, 0, 1, 7, 0 },
	{ "You hit %s with your knee.",             5, 5, 2, 3, MA_KNEE },
	{ "You hit %s with your elbow.",            7, 5, 1, 8, 0 },
	{ "You butt %s.",                           9, 10, 2, 5, 0 },
	{ "You kick %s.",                           11, 10, 3, 4, MA_SLOW },
	{ "You uppercut %s.",                       13, 12, 4, 4, 6 },
	{ "You double-kick %s.",                    16, 15, 5, 4, 8 },
	{ "You hit %s with a Cat's Claw.",          20, 20, 5, 5, 0 },
	{ "You hit %s with a jump kick.",           25, 25, 5, 6, 10 },
	{ "You hit %s with an Eagle's Claw.",       29, 25, 6, 6, 0 },
	{ "You hit %s with a circle kick.",         33, 30, 6, 8, 10 },
	{ "You hit %s with an Iron Fist.",          37, 35, 8, 8, 10 },
	{ "You hit %s with a flying kick.",         41, 35, 8, 10, 12 },
	{ "You hit %s with a Dragon Fist.",         45, 35, 10, 10, 16 },
	{ "You hit %s with a Crushing Blow.",       48, 35, 10, 12, 18 },
#endif

};
*/
/*:::\EƂ̊iE̕σx[X_[W*100 Xe[^Xʂł̕\p*/
const int monk_ave_damage[PY_MAX_LEVEL+1][3] =
{
  {0, 0, 0},
  {249, 249, 249},
  {324, 324, 324},
  {382, 438, 382},
  {382, 439, 382},
  {390, 446, 390},
  {394, 473, 394},
  {425, 528, 425},
  {430, 535, 430},
  {505, 560, 435},
  {517, 575, 444},
  {566, 655, 474},
  {585, 713, 486},
  {653, 843, 527},
  {678, 890, 544},
  {703, 973, 558},
  {765, 1096, 596},
  {914, 1146, 614},
  {943, 1240, 629},
  {971, 1276, 643},
  {1018, 1350, 667},
  {1063, 1464, 688},
  {1099, 1515, 705},
  {1128, 1559, 721},
  {1153, 1640, 735},
  {1336, 1720, 757},
  {1387, 1789, 778},
  {1430, 1893, 794},
  {1610, 2199, 863},
  {1666, 2280, 885},
  {1713, 2401, 908},
  {1755, 2465, 925},
  {1909, 2730, 984},
  {2156, 2891, 1009},
  {2218, 2970, 1031},
  {2319, 3107, 1063},
  {2404, 3290, 1098},
  {2477, 3389, 1125},
  {2544, 3483, 1150},
  {2771, 3899, 1228},
  {2844, 3982, 1259},
  {3129, 4064, 1287},
  {3200, 4190, 1313},
  {3554, 4674, 1432},
  {3614, 4738, 1463},
  {3679, 4853, 1485},
  {3741, 4905, 1512},
  {3785, 4943, 1538},
  {4141, 5532, 1652},
  {4442, 5581, 1679},
  {4486, 5636, 1702},
};

/*
 * Table of game-generated inscriptions (indexed by the defines in
 * defines.h). -- RG
 */
const cptr game_inscriptions[] =
{
	NULL,            /* FEEL_NONE */
#ifdef JP
	"Ă",    /* FEEL_BROKEN */
	"낵",      /* FEEL_TERRIBLE */
	"l",        /* FEEL_WORTHLESS */
	"Ă",  /* FEEL_CURSED */
	"㎿ȏ",      /* FEEL_UNCURSED */
	"",            /* FEEL_AVERAGE */
	"㎿",          /* FEEL_GOOD */
	"i",        /* FEEL_EXCELLENT */
	"ʐ",        /* FEEL_SPECIAL */
#else
	"broken",        /* FEEL_BROKEN */
	"terrible",      /* FEEL_TERRIBLE */
	"worthless",     /* FEEL_WORTHLESS */
	"cursed",        /* FEEL_CURSED */
	"uncursed",      /* FEEL_UNCURSED */
	"average",       /* FEEL_AVERAGE */
	"good",          /* FEEL_GOOD */
	"excellent",     /* FEEL_EXCELLENT */
	"special",       /* FEEL_SPECIAL */
#endif

};

const kamae kamae_shurui[MAX_KAMAE] =
{
#ifdef JP
	{"", 25, ""},
	{"", 30, ""},
	{"", 35, ""},
	{"鐝", 40, ""},
#else
	{"Genbu", 25, "(Black Tortoise) "},
	{"Byakko", 30, "(White Tiger) "},
	{"Seiryuu", 35, "(Blue Dragon) "},
	{"Suzaku", 40, "(Red Phoenix) "},
#endif
};

const kamae kata_shurui[MAX_KATA] =
{
#ifdef JP
	{"", 25, ""},
	{"o", 30, ""},
	{"~S", 35, ""},
	{"z", 40, ""},
#else
	{"Iai", 25, ""},
	{"Huujin", 30, ""},
	{"Kouki", 35, ""},
	{"Musou", 40, ""},
#endif
};

const cptr exp_level_str[5]=
#ifdef JP
{"[S]", "[]", "[n]", "[GLXp[g]", "[Bl]"};
#else
{"[Unskilled]", "[Beginner]", "[Skilled]", "[Expert]", "[Master]"};
#endif

/* Weird melee attack types when hallucinating */
///system õW[NbZ[W
#ifdef JP
const cptr silly_attacks[MAX_SILLY_ATTACK] =
{
	"͂Ȃ̉Ƃ̒Еc炸HsB",
	"Ȃ̉3ăƌB",
	"ɂ΂܂킳ꂽB",
	"͈lŔw̐w~B",
	"͎߂̂hB",
	"ɃWōUꂽB",
	"Ȃ̖jDł΂B",
	"Ȃ̑OŃ|[WOB",
	"ɃAJx[ꂽB",
	"Ɂu_̍v̓P߂ꂽB",
	"Ƀb[܂ꂽB",
	"ɂ݂ꂽB",
	"͂ȂƗxB",
	"Ɋɂ炭ꂽB",
	"Ɏ؋̕ԍς܂ꂽB",
	"ɃXJ[g߂ꂽB",
	"͂Ȃ̎葊B",
	"𖞂オꂽB",
	"爤̍ꂽB",
	"͂Ȃ500~ŌقB",
	"͂Ȃ100̔閧ɂĔMB",
	"j[ƖB",
	"͂ȂɋCB",
	"͂Ȃ|SB",
	"ɏꂽB",
	"̓Ae}̎I",
	"͂Ȃ̃XpCNubNB",
	"̓XChړB",
	"͏R}h̓͂ɎsB",
	"͊gUgC𔭎˂B",
	"̓fX[@B",
	"ɃC_[LbNōUꂽB",
	"ɓTԈȓŃrfIlɌȂƎʎ􂢂ꂽB",
	"̓pveB",
	"̓X[p[EgMNeBJ}OiB",
	"ɂႪݏLbNŃnꂽB",
	"ɃWFbgXg[A^bNꂽB",
	"͂Ȃəł߂āu1A2A3A_[bIvƋ񂾁B",
	"́uȂI΂΂΂IvƂċ삯oB",
	"uA[xX̊GvƌĐÂɖڂB",
	"͌Buϋؓ{A^JIv",
};

/* Note: %s for strfmt() */
const cptr silly_attacks2[MAX_SILLY_ATTACK] =
{
	"%sɏP|̂B",
	"%s̉3ăƌB",
	"%s΂܂킵B",
	"%sɈlŔw̐w~B",
	"%sɎ߂̂hB",
	"%sWōUB",
	"%s̖jDł΂B",
	"%s̑OŃ|[WOB",
	"%sɃAJx[B",
	"%sɁu_̍v̓P߂B",
	"%sɃb[܂B",
	"%sɂ݂ꂽB",
	"%sƗxB",
	"%s̊ɂ炭B",
	"%sɎ؋̕ԍς܂B",
	"%s̃XJ[g߂B",
	"%s̎葊B",
	"%s𖞂オB",
	"%sɈ̍B",
	"%s500~ŌقB",
	"%s100̔閧ɂĔMB",
	"j[ƖB",
	"%sɋCB",
	"%s|SB",
	"%sB",
	"Ae}̎I",
	"%s̃XpCNubNB",
	"XChړB",
	"R}h̓͂ɎsB",
	"%sɊgUgC𔭎˂B",
	"%sɃfX[@B",
	"%sC_[LbNōUB",
	"%sɓTԈȓŃrfIlɌȂƎʎ􂢂B",
	"pveB",
	"%sɃX[p[EgMNeBJ}OiB",
	"%sႪݏLbNŃnB",
	"%sɃWFbgXg[A^bNB",
	"%səł߂āu1A2A3A_[bIvƋ񂾁B",
	"uȂI΂΂΂IvƂċ삯oB",
	"uA[xX̊GvƌĐÂɖڂB",
	"Buϋؓ{A^JIv",
};
#else
const cptr silly_attacks[MAX_SILLY_ATTACK] =
{
	"smothers",
	"hugs",
	"humiliates",
	"whips",
	"kisses",

	"disgusts",
	"pees all over",
	"passes the gas on",
	"makes obscene gestures at",
	"licks",

	"stomps on",
	"swallows",
	"drools on",
	"misses",
	"shrinks",

	"emasculates",
	"evaporates",
	"solidifies",
	"digitizes",
	"insta-kills",

	"massacres",
	"slaughters",
	"drugs",
	"psychoanalyzes",
	"deconstructs",

	"falsifies",
	"disbelieves",
	"molests",
	"pusupusu",
};
#endif


/*
 * The table of "symbol info" -- each entry is a string of the form
 * "X:desc" where "X" is the trigger, and "desc" is the "info".
 */
/*:::e̐Bident_info[][0]Ώۂ̕ɂȂĂB[2]ȍ~͎voȂǂ̐̂߂̂*/
///mod131231 X^[V{ύX
const cptr ident_info[] =
{
#ifdef JP
	" :È",
	"!:, IC",
	"\":݊",
	"#:(BhA)/A/C",
	"$:()",
	"%:z(n₩Ήp)",
	"&:",
	"':JhA",
	"(:炩h",
	"):",
	"*:܂񂾍z܂͋`̉",
	"+:hA",
	",:Hו, ΂LmR",
	"-:@_, bh",
	".:",
	"/:Ə󕐊(AbNX/pCN/)",
	"0:GgXւ̓",
	"1:G݉̓",
	"2:h̓",
	"3:X̓",
	"4:Ǝ̓Xւ̓",
	"5:@BX̓X̓",
	"6:@̓X̓",
	"7:ubN}[Pbg̓",
	"8:_ւ̓",
	"9:X̓",
	"::",
	";:̒/̃[",
	"<:Ki",
	"=:w",
	">:Ki",
	"?:",
	"@:vC[",
	"A:Vg",
	"B:",
	"C:",
	"D:ÑhS/CA[",
	"E:G^",
	"F:d",
	"G:S[Xg",
	"H:L/G^",
	"I:",
	"J:wr",
	"K:͓",
	"L:b`",
	"M:঒",
	"N:̐",
	"O:I[K/S",
	"P:l^",
	"Q:NCXO(ł)",
	"R:঒/",
	"S:_i",
	"T:g",
	"U:㋉f[",
	"V:opCA",
	"W:Cg/CX/",
	"X:][/U/",
	"Y:^d/l^d",
	"Z:[t@[nEh",
	"[:A[}[",
	"\\:݊(CX/`/)",
	"]:X̖h",
	"^:gbv",
	"_:",
	"`:l`C",
	"a:A",
	"b:RE",
	"c:Jf/w/嶂Ȃ",
	"d:hS",
	"e:ڋ",
	"f:lRȂ̏b",
	"g:S[/l`/@B",
	"h:l",
	"i:xgxg",
	"j:[[",
	"k:R{hEbl",
	"l:",
	"m:h",
	"n:i[K",
	"o:I[N",
	"p:l/lԌ^",
	"q:lb",
	"r:lY~/e",
	"s:XPg",
	"t:V",
	"u:f[",
	"v:{ebNX",
	"w:CV/Q",
	/* "x:unused", */
	"y:^d",
	"z:]r/~C",
	"{:ѓ̒e(/e)",
	"|:(\[h/_K[/)",
	"}:ѓ(|/NX{E/XO)",
	"~:/n◬(X̃ACe)",
#else
	" :A dark grid",
	"!:A potion (or oil)",
	"\":An amulet (or necklace)",
	"#:A wall (or secret door) / a plant / a gas",
	"$:Treasure (gold or gems)",
	"%:A vein (magma or quartz)",
	"&:A chest",
	"':An open door",
	"(:Soft armor",
	"):A shield",
	"*:A vein with treasure or a ball monster",
	"+:A closed door",
	",:Food (or mushroom patch)",
	"-:A wand (or rod)",
	".:Floor",
	"/:A polearm (Axe/Pike/etc)",
	"0:Entrance to Museum",
	"1:Entrance to General Store",
	"2:Entrance to Armory",
	"3:Entrance to Weaponsmith",
	"4:Entrance to Temple",
	"5:Entrance to Alchemy shop",
	"6:Entrance to Magic store",
	"7:Entrance to Black Market",
	"8:Entrance to your home",
	"9:Entrance to the bookstore",
	"::Rubble",
	";:A glyph of warding / an explosive rune",
	"<:An up staircase",
	"=:A ring",
	">:A down staircase",
	"?:A scroll",
	"@:You",
	"A:Angel",
	"B:Bird",
	"C:Canine",
	"D:Ancient Dragon/Wyrm",
	"E:Elemental",
	"F:Dragon Fly",
	"G:Ghost",
	"H:Hybrid",
	"I:Insect",
	"J:Snake",
	"K:Killer Beetle",
	"L:Lich",
	"M:Multi-Headed Reptile",
	"N:Mystery Living",
	"O:Ogre",
	"P:Giant Humanoid",
	"Q:Quylthulg (Pulsing Flesh Mound)",
	"R:Reptile/Amphibian",
	"S:Spider/Scorpion/Tick",
	"T:Troll",
	"U:Major Demon",
	"V:Vampire",
	"W:Wight/Wraith/etc",
	"X:Xorn/Xaren/etc",
	"Y:Yeti",
	"Z:Zephyr Hound",
	"[:Hard armor",
	"\\:A hafted weapon (mace/whip/etc)",
	"]:Misc. armor",
	"^:A trap",
	"_:A staff",
	"`:A figurine or statue",
	"a:Ant",
	"b:Bat",
	"c:Centipede",
	"d:Dragon",
	"e:Floating Eye",
	"f:Feline",
	"g:Golem",
	"h:Hobbit/Elf/Dwarf",
	"i:Icky Thing",
	"j:Jelly",
	"k:Kobold",
	"l:Aquatic monster",
	"m:Mold",
	"n:Naga",
	"o:Orc",
	"p:Person/Human",
	"q:Quadruped",
	"r:Rodent",
	"s:Skeleton",
	"t:Townsperson",
	"u:Minor Demon",
	"v:Vortex",
	"w:Worm/Worm-Mass",
	/* "x:unused", */
	"y:Yeek",
	"z:Zombie/Mummy",
	"{:A missile (arrow/bolt/shot)",
	"|:An edged weapon (sword/dagger/etc)",
	"}:A launcher (bow/crossbow/sling)",
	"~:Fluid terrain (or miscellaneous item)",
#endif

	NULL
};


/*
 * The table of monsters' blow effects
 */
const mbe_info_type mbe_info[MAX_RBE] =
{
	{  0, 0,             }, /* None      */
	{ 60, GF_MISSILE,    }, /* HURT      */
	{  5, GF_POIS,       }, /* POISON    */
	{ 20, GF_DISENCHANT, }, /* UN_BONUS  */
	{ 15, GF_MISSILE,    }, /* UN_POWER  */ /* ToDo: Apply the correct effects */
	{  5, GF_MISSILE,    }, /* EAT_GOLD  */
	{  5, GF_MISSILE,    }, /* EAT_ITEM  */
	{  5, GF_MISSILE,    }, /* EAT_FOOD  */
	{  5, GF_MISSILE,    }, /* EAT_LITE  */
	{  0, GF_ACID,       }, /* ACID      */
	{ 10, GF_ELEC,       }, /* ELEC      */
	{ 10, GF_FIRE,       }, /* FIRE      */
	{ 10, GF_COLD,       }, /* COLD      */
	{  2, GF_MISSILE,    }, /* BLIND     */
	{ 10, GF_CONFUSION,  }, /* CONFUSE   */
	{ 10, GF_MISSILE,    }, /* TERRIFY   */
	{  2, GF_OLD_SLEEP,    }, /* PARALYZE  */ ///mod160130 MISSILEύX
	{  0, GF_MISSILE,    }, /* LOSE_STR  */
	{  0, GF_MISSILE,    }, /* LOSE_INT  */
	{  0, GF_MISSILE,    }, /* LOSE_WIS  */
	{  0, GF_MISSILE,    }, /* LOSE_DEX  */
	{  0, GF_MISSILE,    }, /* LOSE_CON  */
	{  0, GF_MISSILE,    }, /* LOSE_CHR  */
	{  2, GF_MISSILE,    }, /* LOSE_ALL  */
	{ 60, GF_ROCKET,     }, /* SHATTER   */
	{  5, GF_MISSILE,    }, /* EXP_10    */
	{  5, GF_MISSILE,    }, /* EXP_20    */
	{  5, GF_MISSILE,    }, /* EXP_40    */
	{  5, GF_MISSILE,    }, /* EXP_80    */
	{  5, GF_POIS,       }, /* DISEASE   */
	{  5, GF_TIME,       }, /* TIME      */
	{  5, GF_MISSILE,    }, /* EXP_VAMP  */
	{  5, GF_MANA,       }, /* DR_MANA   */
	{ 60, GF_MISSILE,    }, /* SUPERHURT */
	///mod150609 XCÂĒǉ
	{ 10, GF_INACT,  }, /* INERTIA   */
	{ 20, GF_SOUND,  }, /* STUN   */
	{ 10, GF_CHAOS,  }, /* CHAOS   */
	{ 10, GF_FIRE,  }, /* ELEMENT   */
	{ 10, GF_CHAOS,  }, /* MUTATE   */
	{ 30, GF_HOLY_FIRE,  }, /* SMITE   */
	{ 10, GF_WATER,  }, /* DROWN   */
	{ 30, GF_NETHER,  }, /* KILL   */
	{ 10, GF_NETHER,  }, /* CURSE   */
	{ 10, GF_LITE,  }, /* PHOTO   */
	{ 10, GF_ACID,  }, /* MELT   */
	{ 60, GF_SHARDS,  }, /* BLEED   */
	{ 20, GF_REDEYE,  }, /* INSANITY   */
	{ 10, GF_MISSILE,  }, /* HUNGER   */

};


/*
 * The table of features' actions
 */
const byte feature_action_flags[FF_FLAG_MAX] =
{
	0, /* LOS */
	0, /* PROJECT */
	0, /* MOVE */
	0, /* PLACE */
	0, /* DROP */
	0, /* SECRET */
	0, /* NOTICE */
	0, /* REMEMBER */
	0, /* OPEN */
	0, /* CLOSE */
	FAF_CRASH_GLASS, /* BASH */
	0, /* SPIKE */
	FAF_DESTROY, /* DISARM */
	0, /* STORE */
	FAF_DESTROY | FAF_CRASH_GLASS, /* TUNNEL */
	0, /* MAY_HAVE_GOLD */
	0, /* HAS_GOLD */
	0, /* HAS_ITEM */
	0, /* DOOR */
	0, /* TRAP */
	0, /* STAIRS */
	0, /* GLYPH */
	0, /* LESS */
	0, /* MORE */
	0, /* RUN */
	0, /* FLOOR */
	0, /* WALL */
	0, /* PERMANENT */
	0, /* INNER */
	0, /* OUTER */
	0, /* SOLID */
	0, /* HIT_TRAP */

	0, /* BRIDGE */
	0, /* RIVER */
	0, /* LAKE */
	0, /* BRIDGED */
	0, /* COVERED */
	0, /* GLOW */
	0, /* ENSECRET */
	0, /* WATER */
	0, /* LAVA */
	0, /* SHALLOW */
	0, /* DEEP */
	0, /* FILLED */
	FAF_DESTROY | FAF_CRASH_GLASS, /* HURT_ROCK */
	0, /* HURT_FIRE */
	0, /* HURT_COLD */
	0, /* HURT_ACID */
	0, /* ICE */
	0, /* ACID */
	0, /* OIL */
	0, /* XXX04 */ //PLATE
	0, /* CAN_CLIMB */
	0, /* CAN_FLY */
	0, /* CAN_SWIM */
	0, /* CAN_PASS */
	0, /* CAN_OOZE */
	0, /* CAN_DIG */
	0, /* HIDE_ITEM */
	0, /* HIDE_SNEAK */
	0, /* HIDE_SWIM */
	0, /* HIDE_DIG */
	0, /* KILL_HUGE */
	0, /* KILL_MOVE */

	0, /* PICK_TRAP */
	0, /* PICK_DOOR */
	0, /* ALLOC */
	0, /* CHEST */
	0, /* DROP_1D2 */
	0, /* DROP_2D2 */
	0, /* DROP_GOOD */
	0, /* DROP_GREAT */
	0, /* HURT_POIS */
	0, /* HURT_ELEC */
	0, /* HURT_WATER */
	0, /* HURT_BWATER */
	0, /* USE_FEAT */
	0, /* GET_FEAT */
	0, /* GROUND */
	0, /* OUTSIDE */
	0, /* EASY_HIDE */
	0, /* EASY_CLIMB */
	0, /* MUST_CLIMB */
	0, /* TREE */
	0, /* NEED_TREE */
	0, /* BLOOD */
	0, /* DUST */
	0, /* SLIME */
	0, /* PLANT */
	0, /* XXX2 */ //SPIDER_NEST
	0, /* INSTANT */
	0, /* EXPLODE */
	0, /* TIMED */
	0, /* ERUPT */
	0, /* STRIKE */
	0, /* SPREAD */

	0, /* SPECIAL */
	FAF_DESTROY | FAF_NO_DROP | FAF_CRASH_GLASS, /* HURT_DISI */
	0, /* QUEST_ENTER */
	0, /* QUEST_EXIT */
	0, /* QUEST */
	0, /* SHAFT */
	0, /* MOUNTAIN */
	0, /* BLDG */
	0, /* MINOR_GLYPH */
	0, /* PATTERN */
	0, /* TOWN */
	0, /* ENTRANCE */
	0, /* MIRROR */
	0, /* UNPERM */
	0, /* TELEPORTABLE */
	0, /* CONVERT */
	0, /* GLASS */
};


/*
 * Define flags, effect type, name for dragon breath activation
 */
 /*:::hSZ̃uX@̊Zϐ_ɑI΂*/
 ///item res hSZ̃uX
 ///mod131229 hSZ̃uX@Ɛ_ǉ@̃uX폜
const dragonbreath_type dragonbreath_info[] = {
	{ TR_RES_ACID, GF_ACID, _("_", "acid") },
	{ TR_RES_ELEC, GF_ELEC, _("d", "lightning") },
	{ TR_RES_FIRE, GF_FIRE, _("Ή", "fire") },
	{ TR_RES_COLD, GF_COLD, _("C", "cold") },
	{ TR_RES_POIS, GF_POIS, _("", "poison") },
	{ TR_RES_WATER, GF_WATER, _("", "water") },
	{ TR_RES_HOLY, GF_HOLY_FIRE, _("j", "holy") },
	{ TR_RES_LITE, GF_LITE, _("M", "light") },
	{ TR_RES_DARK, GF_DARK, _("Í", "dark") },
	{ TR_RES_SHARDS, GF_SHARDS, _("j", "shard") },
//	{ TR_RES_CONF, GF_CONFUSION, _("", "confusion") },
	{ TR_RES_SOUND, GF_SOUND, _("", "sound") },
//	{ TR_RES_NEXUS, GF_NEXUS, _("ʍ", "nexus") },
	{ TR_RES_NETHER, GF_NETHER, _("n", "nether") },
	{ TR_RES_CHAOS, GF_CHAOS, _("JIX", "chaos") },
	{ TR_RES_DISEN, GF_DISENCHANT, _("", "disenchant") },
	{ 0, 0, NULL }
};

/*
 * Define flags, levels, values of activations
 */
const activation_type activation_info[] =
{
	{ "SUNLIGHT", ACT_SUNLIGHT, 10, 250, {10, 0},
	  _("z", "beam of sunlight") },
	{ "BO_MISS_1", ACT_BO_MISS_1, 10, 250, {2, 0},
	  _("}WbNE~TC(2d6)", "magic missile (2d6)") },
	{ "BA_POIS_1", ACT_BA_POIS_1, 10, 300, {4, 0},
	  _("L_(12)", "stinking cloud (12)") },
	{ "BO_ELEC_1", ACT_BO_ELEC_1, 20, 250, {5, 0},
	  _("T_[E{g(4d8)", "lightning bolt (4d8)") },
	{ "BO_ACID_1", ACT_BO_ACID_1, 20, 250, {6, 0},
	  _("AVbhE{g(5d8)", "acid bolt (5d8)") },
	{ "BO_COLD_1", ACT_BO_COLD_1, 20, 250, {7, 0},
	  _("ACXE{g(6d8)", "frost bolt (6d8)") },
	{ "BO_FIRE_1", ACT_BO_FIRE_1, 20, 250, {8, 0},
	  _("t@CAE{g(9d8)", "fire bolt (9d8)") },
	{ "BA_COLD_1", ACT_BA_COLD_1, 30, 750, {6, 0},
	  _("ACXE{[(48)", "ball of cold (48)") },
	{ "BA_FIRE_1", ACT_BA_FIRE_1, 30, 1000, {9, 0},
	  _("t@CAE{[(72)", "ball of fire (72)") },
	{ "DRAIN_1", ACT_DRAIN_1, 30, 500, {12, 0},
	  _("U(100)", "a strangling attack (100)") },
	{ "BA_COLD_2", ACT_BA_COLD_2, 40, 1250, {12, 0},
	  _("ACXE{[(100)", "ball of cold (100)") },
	{ "BA_ELEC_2", ACT_BA_ELEC_2, 40, 1500, {12, 0},
	  _("T_[E{[(100)", "ball of lightning (100)") },
	{ "BA_FIRE_2", ACT_BA_FIRE_2, 40, 1500, {15, 0},
	  _("t@CAE{[(120)", "large fire ball (120)") },
	{ "DRAIN_2", ACT_DRAIN_2, 40, 750, {15, 0},
	  _("͋z(120)", "drain life (120)") },
	{ "VAMPIRE_1", ACT_VAMPIRE_1, 40, 1000, {20, 0},
	  _("zhC(3*50)", "vampiric drain (3*50)") },
	{ "BO_MISS_2", ACT_BO_MISS_2, 40, 1000, {20, 0},
	  _("(150)", "arrows (150)") },
	{ "BA_FIRE_3", ACT_BA_FIRE_3, 60, 1750, {40, 0},
	  _("t@CAE{[(300)", "fire ball (300)") },
	{ "BA_COLD_3", ACT_BA_COLD_3, 70, 2500, {50, 0},
	  _("ACXE{[(400)", "ball of cold (400)") },
	{ "BA_ELEC_3", ACT_BA_ELEC_3, 70, 2500, {70, 0},
	  _("T_[E{[(500)", "ball of lightning (500)") },
	{ "WHIRLWIND", ACT_WHIRLWIND, 50, 7500, {25, 0},
	  _("J}C^`", "whirlwind attack") },
	{ "VAMPIRE_2", ACT_VAMPIRE_2, 50, 2500, {40, 0},
	  _("zhC(3*100)", "vampiric drain (3*100)") },
	{ "CALL_CHAOS", ACT_CALL_CHAOS, 70, 5000, {35, 0},
	  _("׏", "call chaos") },
	{ "ROCKET", ACT_ROCKET, 70, 5000, {20, 0},
	  _("Pbg(120+x)", "launch rocket (120+level)") },
	{ "DISP_EVIL", ACT_DISP_EVIL, 50, 4000, {50, 0},
	  _("׈ގU(x5)", "dispel evil (x5)") },
	{ "BA_MISS_3", ACT_BA_MISS_3, 50, 1500, {50, 0},
	  _("Gg̃uX(300)", "elemental breath (300)") },
	{ "DISP_GOOD", ACT_DISP_GOOD, 50, 3500, {50, 0},
	  _("PǑގU(x5)", "dispel good (x5)") },
	{ "BO_MANA", ACT_BO_MANA, 40, 1500, {20, 0},
	  _("@̖(150)", "a magical arrow (150)") },
	{ "BA_WATER", ACT_BA_WATER, 50, 2000, {25, 0},
	  _("EH[^[E{[(200)", "water ball (200)") },
	{ "BA_STAR", ACT_BA_STAR, 50, 2200, {25, 0},
	  _("X^[E{[(200)", "large star ball (200)") },
	{ "BA_DARK", ACT_BA_DARK, 50, 2200, {30, 0},
	  _("Í̗(250)", "darkness storm (250)") },
	{ "BA_MANA", ACT_BA_MANA, 70, 2500, {30, 0},
	  _("̗͂(250)", "a mana storm (250)") },
	{ "PESTICIDE", ACT_PESTICIDE, 10, 500, {10, 0},
	  _("Q̋쏜", "dispel small life") },
	{ "BLINDING_LIGHT", ACT_BLINDING_LIGHT, 30, 5000, {40, 0},
	  _("ῂ", "blinding light") },
	{ "BIZARRE", ACT_BIZARRE, 90, 10000, {50, 0},
	  _("M", "bizarre things") },
	{ "CAST_BA_STAR", ACT_CAST_BA_STAR, 70, 7500, {100, 0},
	  _("X^[E{[E_Xg(150)", "cast star balls (150)") },
	{ "BLADETURNER", ACT_BLADETURNER, 80, 20000, {80, 0},
	  _("Gg̃uX(300), mCgAjAϐ", "breathe elements (300), hero, bless, and resistance") },
	{ "BA_ACID_1", ACT_BA_ACID_1, 30, 1000, {12, 0},
	  _("AVbhE{[(100)", "ball of acid (100)") },
	{ "BR_FIRE", ACT_BR_FIRE, 50, 5000, {-1, 0},
	  _("Ή̃uX (200)", "fire breath (200)") },
	{ "BR_COLD", ACT_BR_COLD, 50, 5000, {-1, 0},
	  _("C̃uX (200)", "cold breath (200)") },
	{ "BR_DRAGON", ACT_BR_DRAGON, 70, 10000, { 30, 0 },
	  "" /* built by item_activation_dragon_breath() */ },

	{ "CONFUSE", ACT_CONFUSE, 10, 500, {10, 0},
	  _("pjbNEX^[", "confuse monster") },
	{ "SLEEP", ACT_SLEEP, 10, 750, {15, 0},
	  _("͂̃X^[𖰂点", "sleep nearby monsters") },
	{ "QUAKE", ACT_QUAKE, 30, 600, {20, 0},
	  _("nk", "earthquake") },
	{ "TERROR", ACT_TERROR, 20, 2500, {-1, 0},
	  _("Q", "terror") },
	{ "TELE_AWAY", ACT_TELE_AWAY, 20, 2000, {15, 0},
	  _("e|[gEAEFC", "teleport away") },
	{ "BANISH_EVIL", ACT_BANISH_EVIL, 40, 2000, {250, 0},
	  _("׈", "banish evil") },
	{ "GENOCIDE", ACT_GENOCIDE, 50, 10000, {500, 0},
	  _("E", "genocide") },
	{ "MASS_GENO", ACT_MASS_GENO, 50, 10000, {1000, 0},
	  _("ӖE", "mass genocide") },
	{ "SCARE_AREA", ACT_SCARE_AREA, 20, 2500, {20, 0},
	  _("X^[Q", "frighten monsters") },
	{ "AGGRAVATE", ACT_AGGRAVATE, 0, 100, {0, 0},
	  _("X^[{点", "aggravete monsters") },

	{ "CHARM_ANIMAL", ACT_CHARM_ANIMAL, 40, 7500, {200, 0},
	  _("", "charm animal") },
	{ "CHARM_UNDEAD", ACT_CHARM_UNDEAD, 40, 10000, {333, 0},
	  _("Afbh]", "enslave undead") },
	{ "CHARM_OTHER", ACT_CHARM_OTHER, 40, 10000, {400, 0},
	  _("X^[", "charm monster") },
	{ "CHARM_ANIMALS", ACT_CHARM_ANIMALS, 40, 12500, {500, 0},
	  _("Fa", "animal friendship") },
	{ "CHARM_OTHERS", ACT_CHARM_OTHERS, 40, 17500, {750, 0},
	  _("Ӗ", "mass charm") },
	{ "SUMMON_ANIMAL", ACT_SUMMON_ANIMAL, 50, 10000, {200, 300},
	  _("", "summon animal") },
	{ "SUMMON_PHANTOM", ACT_SUMMON_PHANTOM, 50, 12000, {200, 200},
	  _("쏢", "summon phantasmal servant") },
	{ "SUMMON_ELEMENTAL", ACT_SUMMON_ELEMENTAL, 50, 15000, {750, 0},
	  _("G^", "summon elemental") },
	{ "SUMMON_DEMON", ACT_SUMMON_DEMON, 50, 20000, {666, 0},
	  _("", "summon demon") },
	{ "SUMMON_UNDEAD", ACT_SUMMON_UNDEAD, 50, 20000, {666, 0},
	  _("Afbh", "summon undead") },
	{ "SUMMON_HOUND", ACT_SUMMON_HOUND, 50, 15000, {300, 0},
	  _("nEh", "summon hound") },
	{ "SUMMON_DAWN", ACT_SUMMON_DAWN, 50, 15000, {500, 0},
	  _("ł̎tc", "summon the Legion of the Dawn") },
	{ "SUMMON_OCTOPUS", ACT_SUMMON_OCTOPUS, 50, 15000, {300, 0},
	  _("̑Q", "summon octopus") },

	{ "CHOIR_SINGS", ACT_CHOIR_SINGS, 60, 20000, {300, 0},
	  _("(777)AAmCg", "heal 777 hit points, curing and heloism") },
	{ "CURE_LW", ACT_CURE_LW, 10, 500, {10, 0},
	  _("|/̗͉(30)", "remove fear and heal 30 hp") },
	{ "CURE_MW", ACT_CURE_MW, 20, 750, {3, 3},
	  _("(4d8)", "heal 4d8 and wounds") },
	{ "CURE_POISON", ACT_CURE_POISON, 10, 1000, {5, 0},
	  _("|/ŏ", "remove fear and cure poison") },
	{ "REST_LIFE", ACT_REST_LIFE, 40, 7500, {450, 0},
	  _("ol", "restore life levels") },
	{ "REST_ALL", ACT_REST_ALL, 30, 15000, {750, 0},
	  _("SXe[^Xƌol", "restore stats and life levels") },
	{ "CURE_700", ACT_CURE_700, 40, 10000, {250, 0},
	  _("̗͉(700)", "heal 700 hit points") },
	{ "CURE_1000", ACT_CURE_1000, 50, 15000, {888, 0},
	  _("̗͉(1000)", "heal 1000 hit points") },
	{ "CURING", ACT_CURING, 30, 5000, {100, 0},
	  _("", "curing") },
	{ "CURE_MANA_FULL", ACT_CURE_MANA_FULL, 60, 20000, {777, 0},
	  _("͕", "restore mana") },

	{ "ESP", ACT_ESP, 30, 1500, {100, 0},
	  _("epV[( 25+d30)", "telepathy (dur 25+d30)") },
	{ "BERSERK", ACT_BERSERK, 10, 800, {75, 0},
	  _("m(25+d25^[)", "berserk (25+d25 turns)") },
	{ "PROT_EVIL", ACT_PROT_EVIL, 30, 5000, {100, 0},
	  _("Ύ׈E( 3*x+d25)", "protect evil (dur level*3 + d25)") },
	{ "RESIST_ALL", ACT_RESIST_ALL, 30, 5000, {111, 0},
	  _("Sϐ( 20+d20)", "resist elements (dur 20+d20)") },
	{ "SPEED", ACT_SPEED, 40, 15000, {250, 0},
	  _("( 20+d20)", "speed (dur 20+d20)") },
	{ "XTRA_SPEED", ACT_XTRA_SPEED, 40, 25000, {200, 200},
	  _("( 75+d75)", "speed (dur 75+d75)") },
	{ "WRAITH", ACT_WRAITH, 90, 25000, {1000, 0},
	  _("H̉( (x/2)+d(x/2))", "wraith form (dur level/2 + d(level/2))") },
	{ "INVULN", ACT_INVULN, 90, 25000, {1000, 0},
	  _("G( 8+d8)", "invulnerability (dur 8+d8)") },
	{ "HELO", ACT_HELO, 10, 500, {30, 30},
	  _("mCg", "heroism") },
	{ "HELO_SPEED", ACT_HELO_SPEED, 30, 20000, {100, 200},
	  _("mCg, Xs[h( 50+d50^[)", "hero and +10 to speed (50)") },
	{ "RESIST_ACID", ACT_RESIST_ACID, 20, 2000, {40, 40},
	  _("_ւ̑ϐ( 20+d20)", "resist acid (dur 20+d20)") },
	{ "RESIST_FIRE", ACT_RESIST_FIRE, 20, 2000, {40, 40},
	  _("Ήւ̑ϐ( 20+d20)", "resist fire (dur 20+d20)") },
	{ "RESIST_COLD", ACT_RESIST_COLD, 20, 2000, {40, 40},
	  _("Cւ̑ϐ( 20+d20)", "resist cold (dur 20+d20)") },
	{ "RESIST_ELEC", ACT_RESIST_ELEC, 20, 2000, {40, 40},
	  _("dւ̑ϐ( 20+d20)", "resist elec (dur 20+d20)") },
	{ "RESIST_POIS", ACT_RESIST_POIS, 20, 2000, {40, 40},
	  _("łւ̑ϐ( 20+d20)", "resist poison (dur 20+d20)") },

	{ "LIGHT", ACT_LIGHT, 10, 150, {10, 10},
	  _("C~l[V", "light area (dam 2d15)") },
	{ "MAP_LIGHT", ACT_MAP_LIGHT, 30, 500, {50, 50},
	  _("@̒n}ƌ", "light (dam 2d15) & map area") },
	{ "DETECT_ALL", ACT_DETECT_ALL, 30, 1000, {55, 55},
	  _("Sm", "detection") },
	{ "DETECT_XTRA", ACT_DETECT_XTRA, 50, 12500, {100, 0},
	  _("SmATA*Ӓ*", "detection, probing and identify true") },
	{ "ID_FULL", ACT_ID_FULL, 50, 10000, {75, 0},
	  _("*Ӓ*", "identify true") },
	{ "ID_PLAIN", ACT_ID_PLAIN, 20, 1250, {10, 0},
	  _("Ӓ", "identify spell") },
	{ "RUNE_EXPLO", ACT_RUNE_EXPLO, 40, 4000, {0, 0},
	  _("̃[(MP20gp)", "explosive rune") },
	{ "RUNE_PROT", ACT_RUNE_PROT, 60, 10000, {400, 0},
	  _("̃[", "rune of protection") },
	{ "SATIATE", ACT_SATIATE, 10, 2000, {100, 0},
	  _("󕠏[", "satisfy hunger") },
	{ "DEST_DOOR", ACT_DEST_DOOR, 10, 100, {10, 0},
	  _("hAj", "destroy doors") },
	{ "STONE_MUD", ACT_STONE_MUD, 20, 1000, {3, 0},
	  _("Ηn", "stone to mud") },
	{ "RECHARGE", ACT_RECHARGE, 30, 1000, {70, 0},
	  _("͏[U", "recharging") },
	{ "ALCHEMY", ACT_ALCHEMY, 50, 10000, {50, 0}, //v1.1.48 [U^[50050
	  _("Bp", "alchemy") },
	{ "DIM_DOOR", ACT_DIM_DOOR, 50, 10000, {100, 0},
	  _("̔", "dimension door") },
	{ "TELEPORT", ACT_TELEPORT, 10, 2000, {25, 0},
	  _("e|[g", "teleport") },
	{ "RECALL", ACT_RECALL, 30, 7500, {200, 0},
	  _("A҂̏", "word of recall") },
	{ "JUDGE", ACT_JUDGE, 90, 50000, {20, 20},
	  _("̗͂ƈւɐ痢ƋA", "a telekinesis (500 lb)") },
	{ "TELEKINESIS", ACT_TELEKINESIS, 20, 5500, {25, 25},
	  _("̂񂹂(d25kg܂)", "clairvoyance and recall, draining you") },
	{ "DETECT_UNIQUE", ACT_DETECT_UNIQUE, 40, 10000, {200, 0},
	  _("̊Kɂ郆j[NX^[\", "list of the uniques on the level") },
	{ "ESCAPE", ACT_ESCAPE, 10, 3000, {35, 0},
	  _("", "a getaway") },
	{ "DISP_CURSE_XTRA", ACT_DISP_CURSE_XTRA, 40, 30000, {0, 0},
	  _("**ƒ", "dispel curse and probing") },
	{ "BRAND_FIRE_BOLTS", ACT_BRAND_FIRE_BOLTS, 40, 20000, {999, 0},
	  _("ñt@CAE{g", "fire branding of bolts") },
	{ "RECHARGE_XTRA", ACT_RECHARGE_XTRA, 70, 30000, {200, 0},
	  _("͏[U", "recharge item") },
	{ "LORE", ACT_LORE, 10, 30000, {0, 0},
	  _("댯𔺂Ӓ", "perilous identify") },
	{ "SHIKOFUMI", ACT_SHIKOFUMI, 10, 10000, {100, 100},
	  _("lғ", "shiko") },
	{ "PHASE_DOOR", ACT_PHASE_DOOR, 10, 1500, {10, 0},
	  _("V[gEe|[g", "blink") },
	{ "DETECT_ALL_MONS", ACT_DETECT_ALL_MONS, 30, 3000, {150, 0},
	  _("SX^[m", "detect all monsters") },
	{ "ULTIMATE_RESIST", ACT_ULTIMATE_RESIST, 90, 20000, {777, 0},
	  _("mCgAjAɂ̑ϐ", "hero, bless, and ultimate resistance") },

	{ "CAST_OFF", ACT_CAST_OFF, 30, 15000, {100, 0},
	  _("E߂ƏFR", "cast it off and cosmic heroism") },
	{ "FISHING", ACT_FISHING, 0, 100, {0, 0},
	  _("ނ", "fishing") },
	{ "INROU", ACT_INROU, 40, 15000, {150, 150},
	  _("̃A", "reveal your identity") },
	{ "MURAMASA", ACT_MURAMASA, 0, 0, {-1, 0},
	  _("r͂̏㏸", "increase STR") },
	{ "BLOODY_MOON", ACT_BLOODY_MOON, 0, 0, {3333, 0},
	  _("ύX", "change zokusei") },
	{ "CRIMSON", ACT_CRIMSON, 0, 50000, {5, 0},
	  _("t@CAI", "fire!") },
	{ "NERUNERUNERUNE", ACT_NERUNERUNERUNE, 0, 2000, {0, 0},
	  _("댯𔺂", "Umai!") },
	{ "ALTER_REALITY", ACT_ALTER_REALITY, 0, 5000, {300, 0},
	  _("ϗe", "alter reality") },

	{ "KOGASA_LASER", ACT_KOGASA_LASER, 0, 100, {4, 0},
	  _("P[U[", "fire!") },
	{ "KOGASA_LASER", ACT_KOGASA_ROCKET, 0, 10000, {15, 0},
	  _("PPbg", "fire!") },
	{ "HYPER_BERSERK", ACT_HYPER_BERSERK, 0, 1000, {0, 0},
	  _("댯𔺂m", "berserk") },
	{ "DRINK", ACT_DRINK, 0, 100, {0, 0},
	  _("", "drink!") },
	{ "ROBERTA", ACT_ROBERTA, 30, 5000, {200, 0},
	  _("E+E(200)", "grenade") },
	{ "WALTER", ACT_WALTER, 30, 5000, {200, 0},
	  _("EU(200)", "string") },
	{ "DETECT_ITEM", ACT_DETECT_ITEM, 10, 200, {10, 0},
	  _("_EWO", "Dowsing") },
	{ "SANAGI", ACT_SANAGI, 10, 2000, {0, 0},
	  _("mCgƑ", "sanagi") },
	{ "DER_FREISCHUTZ", ACT_DER_FREISCHUTZ, 0, 50000, {10, 0},
	  _("e̎ˎ", "fire") },
	{ "GOKASHITIKIN", ACT_GOKASHITIKIN, 0, 5000, {0, 0},
	  _("Ռg(_[W150 MP40gp)", "fire") },
	{ "SUMMON_FOUNTAIN", ACT_SUMMON_FOUNTAIN, 70, 10000, {30, 30},
	  _("O@No", "koubou") },

	{ "TORNADO", ACT_TORNADO, 50, 7500, {25, 0},
	  _("(200)", "whirlwind attack") },

	{ "TRAPEZOHEDRON", ACT_TRAPEZOHEDRON, 80, 10000, {0, 0},
	  _("***댯***𔺂[", "Trapezohedron") },

	{ "DETECT_ARTIFACT", ACT_DETECT_ARTIFACT, 80, 10000, {100, 0},
	  _("`̕im", "Detect Artifact") },

	{ "LUNATIC_TIME", ACT_LUNATIC_TIME, 0, 5000, {0, 0},
	  _("ieBbN^C", "berserk") },
	{ "SUMMON_GHOSTS", ACT_SUMMON_GHOSTS, 40, 6000, {50, 0},
	  _("H", "summon_ghosts") },
	{ "TRANSPORT_ITEM", ACT_TRANSPORT_ITEM, 80, 10000, {50, 100},
	  _("ACe]", "summon_ghosts") },
	{ "TOYOHIME", ACT_TOYOHIME, 70, 10000, {10, 0},
	  _("򉻂̕", "disintegrate") },
	{ "MIGHTY_THROW", ACT_MIGHTY_THROW, 40, 5000, {0, 0},
	  _("͓(x4)", "mighty throw") },

	{ "FINAL_STRIKE", ACT_FINAL_STRIKE, 70, 1000, {0, 0},
	  _("t@CiXgCN", "Final Strike") },

	{ "GUN_VARIABLE", ACT_GUN_VARIABLE, 10, 10, {0, 0},
	  _("ώˌ(̃bZ[WooO)", "Final Strike") },


	  //e̔_[W̎̏cmd2.cdo_cmd_fire_gun_aux()Ȃ̂Œ
	{ "YAKUZA_GUN", ACT_YAKUZA_GUN, 50, 3000, {5, 0},
	  _("((1d20)*20)", "Final Strike") },
	{ "BFG9000", ACT_BFG9000, 90, 30000, {6, 0},
	  _("Pbg(8d100+800)", "Final Strike") },
	{ "BAROQUE", ACT_BAROQUE, 60, 10000, {7, 0},
	  _("őPbg(500)", "Final Strike") },

	{ "HARKONNEN2", ACT_HARKONNEN2, 100, 50000, {16, 0},
	  _("uEfB[~v", "Final Strike") },
	{ "SHIOMITSUTAMA", ACT_SHIOMITSUTAMA, 100, 50000, {10, 10},
	  _("QU(_[W100+1d100)", "Final Strike") },
	{ "DAZZLE", ACT_DAZZLE, 40, 2500, {10, 10},
	  _("f", "dazzle") },
	{ "MID_RANGE_ATTACK", ACT_MID_RANGE_ATTACK, 50, 5000, {0, 0},
	  _("L΂(_[W100+1d100 MP30gp)", "fire") },
	{ "BO_INACT", ACT_BO_INACT, 20, 3000, {10, 0},
	  _("x݂̃{g(4d6)", "ball of iner (4d6)") },

	  { "MATARA", ACT_MATARA, 50, 10000, {100, 0},
	  _("ۂ炷", "dazzle") },
	  { "HYAKKIYAKOU", ACT_HYAKKIYAKOU, 30, 10000, {10, 10},
	  _("SSs", "summon tsukumo") },

	  { "SWORD_DANCE", ACT_SWORD_DANCE, 50, 10000,{ 0, 16 },
		  _("̕", "sword_dance") },

	{ NULL, 0, 0, 0, {0, 0},
	  "" }
};

///mod140222 p_ptr->stat_ind[A_???]ĉ炩Ɏg߂̗ 0-47
const int adj_general[STAT_HYPERMAX-2] =
{
	1,1,1,1,2,2,2,//3-9
	3,3,3,4,4,4,5,5,6,6,//10-19
	7,7,8,8,9,9,10,10,11,12,//20-29
	13,14,15,16,18,20,22,24,26,28,//30-39
	30,32,34,36,38,40,42,44,46,48,50//40-50

};

const struct souvenir_type souvenir_table[] =
{

	//gِ[ 30-50 @Oڂ▂ȂǐFX
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_TELEPORTATION,32,45,100,1},
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_REMOVE_CURSE,32,40,140,1},
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_MAPPING,32,40,100,1},
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_CURING,32,45,70,1},
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_SPEED,36,50,80,1},
	{DUNGEON_KOUMA,TV_STAFF,SV_STAFF_PROBING,36,48,90,1},

	{DUNGEON_KOUMA,TV_WAND,SV_WAND_TELEPORT_AWAY,32,48,100,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_DISARMING,32,48,100,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_STONE_TO_MUD,32,48,100,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_DRAIN_LIFE ,44,48,30,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_ACID_BALL ,40,45,25,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_ELEC_BALL ,40,45,25,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_FIRE_BALL ,40,45,25,1},
	{DUNGEON_KOUMA,TV_WAND,SV_WAND_COLD_BALL ,40,45,25,1},
	{DUNGEON_KOUMA,TV_ROD,SV_ROD_DETECTION ,45,50,10,1},
	{DUNGEON_KOUMA,TV_ROD,SV_ROD_IDENTIFY ,45,50,10,1},
	{DUNGEON_KOUMA,TV_ROD,SV_ROD_SPEED ,47,50,5,1},
	{DUNGEON_KOUMA,TV_ROD,SV_ROD_ILLUMINATION ,32,40,50,1},
	{DUNGEON_KOUMA,TV_SCROLL,SV_SCROLL_ACQUIREMENT ,48,50,3,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_FREE_ACTION,30,36,70,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_RES_FEAR,30,36,70,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_STR,32,50,30,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_DEX,32,50,30,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_CON,32,50,30,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_PROTECTION,32,50,30,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_ELEC,40,50,20,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_ACID,40,50,20,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_FLAMES,40,50,20,1},
	{DUNGEON_KOUMA,TV_RING,SV_RING_ICE,40,50,20,1},
	{DUNGEON_KOUMA,TV_LITE,SV_LITE_FEANOR,30,45,30,1},
	{DUNGEON_KOUMA,TV_RIBBON,SV_RIBBON,32,50,50,1},
	{DUNGEON_KOUMA,TV_AMULET,SV_AMULET_CHARISMA,48,50,10,1},
	{DUNGEON_KOUMA,TV_BOOK_ELEMENT,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_FORESEE,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_ENCHANT,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_SUMMONS,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_MYSTIC ,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_LIFE   ,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_PUNISH ,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_NATURE ,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_TRANSFORM,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_DARKNESS,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_NECROMANCY,2,48,50,50,1},
	{DUNGEON_KOUMA,TV_BOOK_CHAOS	,2,48,50,50,1},

	//A 60-72hSfނ
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_DRAGONSCALE,62,72,20,3},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_DRAGONNAIL,65,72,10,1},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_GARNET,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_AMETHYST,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_AQUAMARINE,62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_MOONSTONE,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_PERIDOT,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_OPAL,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_TOPAZ,	62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_LAPISLAZULI,62,72,100,2},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_EMERALD ,66,72,30,1},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_RUBY ,66,72,30,1},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_SAPPHIRE ,66,72,30,1},
	{DUNGEON_DRAGON,TV_MATERIAL	,SV_MATERIAL_DIAMOND ,70,72,10,1},

	//̑@10-20 ۉOƃqJSP
	//X̗ؒǉ
	{DUNGEON_GENBU,TV_MATERIAL	,SV_MATERIAL_HIKARIGOKE ,12,20,250,3},
	{DUNGEON_GENBU,TV_MATERIAL	,SV_MATERIAL_HEMATITE ,17,20,150,6},
	{DUNGEON_GENBU,TV_MATERIAL	,SV_MATERIAL_ICESCALE 	 ,19,20,20,3},

	//nJ@35-50 z΂fz΂Ɛ΍
	{DUNGEON_ZIGOKUDANI,TV_MATERIAL	,SV_MATERIAL_ARSENIC  ,37,50,100,4},
	{DUNGEON_ZIGOKUDANI,TV_MATERIAL	,SV_MATERIAL_MERCURY  ,45,50,50,3},
	{DUNGEON_ZIGOKUDANI,TV_MATERIAL	,SV_MATERIAL_ISHIZAKURA  ,37,50,70,3},

	//ˁ@40-50 FX@
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_MAGNETITE	 ,42,50,100,3},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_MITHRIL 	 ,42,50,30,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_ADAMANTITE  ,42,50,20,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_GELSEMIUM 	 ,42,50,50,3},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_GARNET 	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_AMETHYST 	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_AQUAMARINE  ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_MOONSTONE 	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_PERIDOT  	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_OPAL  	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_TOPAZ   	 ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_LAPISLAZULI ,42,50,100,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_EMERALD  	 ,45,50,10,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_RUBY   	 ,45,50,10,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_SAPPHIRE    ,45,50,10,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_DRAGONSCALE ,45,50, 5,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_METEORICIRON,48,50, 1,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_DRAGONNAIL  ,49,50, 2,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_HIHIIROKANE ,50,50, 1,1}, //weird_luck()ʂKv
	{DUNGEON_MUEN,TV_SOUVENIR	,SV_SOUVENIR_KAPPA_5	,50,50,1,1},
	{DUNGEON_MUEN,TV_SOUVENIR	,SV_SOUVENIR_PRISM		,45,50,5,1},
	{DUNGEON_MUEN,TV_SOUVENIR	,SV_SOUVENIR_KAPPA_ARM	,48,50,2,1},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_ICESCALE 	 ,42,50,20,2},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_TAKAKUSAGORI ,43,50,40,3},
	{DUNGEON_MUEN,TV_MATERIAL	,SV_MATERIAL_IZANAGIOBJECT,48,50, 2,1},

	//n@΍ACUiMIuWFNg
	{DUNGEON_EX_HELL,TV_MATERIAL	,SV_MATERIAL_ISHIZAKURA		,41,45,30,3},
	{DUNGEON_EX_HELL,TV_MATERIAL	,SV_MATERIAL_IZANAGIOBJECT  ,46,50, 5,1},

	//q_@1-30(񃌃A)
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_GARNET 	 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_AMETHYST 	 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_AQUAMARINE  ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_MOONSTONE 	 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_PERIDOT  	 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_OPAL  		 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_TOPAZ   	 ,5,30,50,1},
	{DUNGEON_TAISHI,TV_MATERIAL	,SV_MATERIAL_LAPISLAZULI ,5,30,50,1},

	//@̐X[@24-36LmR⑐Ȃ
	{DUNGEON_FOREST,TV_MATERIAL	,SV_MATERIAL_GELSEMIUM ,27,32,70,1},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CURE_POISON ,25,32,200,5},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CURE_BLINDNESS  ,25,32,100,5},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CURE_CONFUSION  ,25,32,100,5},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CURE_PARANOIA  ,25,32,100,5},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CURE_SERIOUS   ,25,32,100,6},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_RESTORING    ,33,36,30,2},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_MANA       ,28,36,50,7},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_BERSERK     ,27,36,40,5},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_POISON		,25,30,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_BLINDNESS  ,25,30,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_PARANOIA   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_CONFUSION  ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_HALLUCINATION   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_PARALYSIS  ,25,30,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_WEAKNESS   ,25,30,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_SICKNESS   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_STUPIDITY  ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_NAIVETY   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_UNHEALTH   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_DISEASE   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_RESTORE_STR   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_RESTORE_CON   ,25,32,50,3},
	{DUNGEON_FOREST,TV_MATERIAL	,SV_MATERIAL_TAKAKUSAGORI ,30,32,15,3},

	{ DUNGEON_FOREST,TV_MUSHROOM	,SV_MUSHROOM_PUFFBALL      ,25,36,100,4 },


	//̐E 30-70

	{DUNGEON_DREAM_WORLD,TV_MATERIAL	,SV_MATERIAL_NIGHTMARE_FRAGMENT,35,70,30,3},
	{DUNGEON_DREAM_WORLD,TV_MATERIAL	,SV_MATERIAL_HOPE_FRAGMENT,55,70,5,1},

	//S
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_MAGNETITE	 ,10,50,50,3},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_MITHRIL 	 ,40,90,20,3},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_ADAMANTITE  ,55,100,15,3},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_DRAGONSCALE ,60,100,15,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_DRAGONNAIL  ,75,100,5,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_GARNET,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_AMETHYST,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_AQUAMARINE,30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_MOONSTONE,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_PERIDOT,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_OPAL,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_TOPAZ,	30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_LAPISLAZULI,30,70,50,2},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_EMERALD 	,65,100,10,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_RUBY	,65,100,10,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_SAPPHIRE	,65,100,10,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_DIAMOND 	,80,100,5,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_METEORICIRON,85,100,2,1},
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_HIHIIROKANE ,90,100,3,1}, //weird_luck()ʂKv
	{DUNGEON_ANGBAND,TV_MATERIAL	,SV_MATERIAL_IZANAGIOBJECT,50,100, 2,1},

	///mod160220 S邢ׂ͍̗̈ŃACeJ[hɓBEXTRA[hȊOł͖B
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,500,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,300,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,240,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,160,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,80,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,40,1},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,20,2},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,10,2},
	{DUNGEON_ANGBAND,TV_ITEMCARD	,SV_ITEMCARD,1,100,5,3},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,200,1},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,100,1},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,50,1},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,30,1},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,20,1},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,10,2},
	{DUNGEON_CHAOS	,TV_ITEMCARD	,SV_ITEMCARD,101,127,5,3},


	{0,0,0,0,0,0,0} //I[pdummy
};



struct machine_type machine_table[MAX_MACHINE] =
{
	{ 20,TV_SOFTDRINK,SV_DRINK_WATER,30,0,0}, //SC
	{ 30,TV_FLASK,SV_FLASK_OIL,3,0,30}, //Kq
	{ 40,0,0,20,0,0}, //Me
	{ 45,TV_FLASK,SV_FLASK_BATTERY,20,0,20}, //hA[
	{ 50,TV_FLASK,SV_FLASK_OIL,1,100,0}, //Ήˊ
	{ 50,TV_FLASK,SV_FLASK_BATTERY,30,20,20}, //̃[_[
	{ 55,0,0,1,0,0}, //󒆋
	{ 55,TV_FLASK,SV_FLASK_ROCKET,5,0,0}, //WFbgn}[
	{ 60,TV_FLASK,SV_FLASK_ROCKET,5,0,30}, //PbeBA
	{ 60,TV_MATERIAL,SV_MATERIAL_MOTOR_BULLET,10,40,0}, //}VK
	{ 65,TV_FLASK,SV_FLASK_ENERGY_WHITE,20,10,25}, //[U[K
	{ 65,TV_FLASK,SV_FLASK_BATTERY,50,0,20}, //XJE^[
	{ 70,TV_FLASK,SV_FLASK_ENERGY_RED,7,0,0}, //ΑoA
	{ 70,0,0,1,0,0}, //KNbV
	{ 75,TV_FLASK,SV_FLASK_BATTERY,4,20,30}, //\[_[
	{ 75,TV_FLASK,SV_FLASK_ENERGY_WHITE,12,20,0}, //vY}K
	{ 80,TV_FLASK,SV_FLASK_ENERGY_BLUE,5,0,30}, //e|[^[
	{ 80,TV_MATERIAL,SV_MATERIAL_CANNONBALL,1,70,0}, //JmC
	{ 85,TV_FLASK,SV_FLASK_ENERGY_BLACK,5,20,20}, //tHm[U[
	{ 85,TV_FLASK,SV_FLASK_ENERGY_BLUE,7,0,20}, //u
	{ 90,TV_MATERIAL,SV_MATERIAL_GATLING_BULLET,10,40,0}, //KgOC
	{ 90,TV_FLASK,SV_FLASK_ENERGY_RED,5,10,10}, //Ζ@oA
	{ 95,0,0,1,0,0}, //E
	{100,TV_FLASK,SV_FLASK_ENERGY_BLACK,10,0,20}, //ΕoA
	{105,0,0,4,25,5}, //APbg`[
	{110,TV_FLASK,SV_FLASK_ENERGY_BLACK,16,30,30}, //}C_Xnh
	{115,TV_FLASK,SV_FLASK_ENERGY_PARTICLE,25,0,0}, //j[gmK
	{120,TV_FLASK,SV_FLASK_ENERGY_WAVEMOTION,3,0,0}, //gC
	{125,TV_FLASK,SV_FLASK_ENERGY_HYPERSPACE,5,0,0}, //gCCg][
	{150,TV_FLASK,SV_FLASK_ENERGY_HYPERSPACE,1,0,0}, //N.E.P

};

/*:::GWjAMh̏ՕiB̂߂̕i*/
int engineer_guild_supply_table[MAX_MACHINE_SUPPLY][2] ={
	{TV_SOFTDRINK,SV_DRINK_WATER},
	{TV_FLASK,SV_FLASK_OIL },
	{TV_FLASK,SV_FLASK_BATTERY },
	{TV_FLASK,SV_FLASK_ROCKET },
	{TV_FLASK,SV_FLASK_ENERGY_RED },
	{TV_FLASK,SV_FLASK_ENERGY_BLUE },
	{TV_FLASK,SV_FLASK_ENERGY_WHITE },
	{TV_FLASK,SV_FLASK_ENERGY_BLACK },
	{TV_MATERIAL,SV_MATERIAL_MOTOR_BULLET },
	{TV_MATERIAL,SV_MATERIAL_CANNONBALL },
	{TV_MATERIAL,SV_MATERIAL_GATLING_BULLET },
	{TV_FLASK,SV_FLASK_ENERGY_PARTICLE},
	{TV_FLASK,SV_FLASK_ENERGY_WAVEMOTION },
	{TV_FLASK,SV_FLASK_ENERGY_HYPERSPACE },
};


/*:::Â܂ˌnpX^[@VXg*/
/*:::̃xՓxȂǂ̊eڂ͐EɂĂ͖*/
/*:::z̓YRF4,5,6,9̏0*/
const monspells2 monspell_list2[MAX_MONSPELLS2+1] =
{
/* level,  smana,  fail, use_stat, use_words, attack_spell,priority, name */
{ 0,  0,  0, 0, FALSE,FALSE, 0,"(zp_~[)"},

{ 1,    1,   10, A_CON, TRUE,FALSE,5,  ""},
{ 1,    2,   20, A_CHR, FALSE,TRUE,1, "e"},
{ 24,  25,  70, A_INT, TRUE, FALSE,3,"͏"},
{ 36,  45,  70, A_STR, FALSE,TRUE,2, "Pbg"},
{ 5,    6,  20, A_DEX, FALSE,TRUE,2, "ˌ"},
{ 30,  40,  70, A_CON, FALSE,TRUE,2, "ȂuX"},
{ 35,  42,  75, A_CON, FALSE,TRUE,2, "n̍΂̃uX"},
{ 20,  25,  55, A_CON, FALSE,TRUE,2, "ANAuX"},
{ 15,  30,  50, A_CON, FALSE,TRUE,1, "_̃uX"},
{ 15,  30,  50, A_CON, FALSE,TRUE,1, "d̃uX"},

{ 15,  30,  50, A_CON, FALSE,TRUE,1, "̃uX"},
{ 15,  30,  50, A_CON, FALSE,TRUE,1, "C̃uX"},
{ 20,  30,  50, A_CON, FALSE,TRUE,1, "KX̃uX"},
{ 27,  27,  60, A_CON, FALSE,TRUE,2, "ñuX"},
{ 25,  25,  60, A_CON, FALSE,TRUE,2, "M̃uX"},
{ 25,  25,  60, A_CON, FALSE,TRUE,2, "Í̃uX"},
{ 45,  65,  80, A_CON, TRUE,TRUE, 2,"gC"},
{ 28,  32,  60, A_CON, TRUE,TRUE,2, "Ռg̃uX"},
{ 30,  32,  60, A_CON, FALSE,TRUE,2, "JIX̃uX"},
{ 30,  36,  60, A_CON, FALSE,TRUE,2, "򉻂̃uX"},

{ 35,  40,  70, A_CON, FALSE,TRUE,2, "ʍ̃uX"},
{ 30,  30,  60, A_CON, FALSE,TRUE,2, "ԋt]̃uX"},
{ 25,  36,  55, A_CON, FALSE,TRUE,2, "x݂̃uX"},
{ 25,  32,  55, A_CON, FALSE,TRUE,2, "d͂̃uX"},
{ 30,  36,  60, A_CON, FALSE,TRUE,2, "jЂ̃uX"},
{ 20,  30,  50, A_CON, FALSE,TRUE,2, "vY}̃uX"},
{ 28,  32,  60, A_STR, FALSE,TRUE,2, "Ce"},
{ 32,  40,  70, A_CON, FALSE,TRUE,2, "͂̃uX"},
{ 0,  0,  0, A_CON, FALSE, 0,FALSE,"(ʍs1͎gps)"},
{ 25,  35,  60, A_CON, FALSE,TRUE,2, "jM̃uX"},

{ 28,  24,  75, A_INT, TRUE,TRUE, 3,"OX"},
{ 30,  33,  60, A_CON, FALSE,TRUE,2, "̃uX"},
{ 18,  12,  50,  A_INT, TRUE,TRUE,4, "AVbhE{["}, //RF5
{ 16,  11,  50,  A_INT, TRUE,TRUE,4, "T_[E{["},
{ 18,  13,  50,  A_INT, TRUE,TRUE,4, "t@CAE{["},
{ 16,  11,  50,  A_INT, TRUE,TRUE,4, "ACXE{["},
{  5,    5,  30,  A_INT, TRUE,TRUE,4, "L_"},
{ 27,   27,  60, A_INT, TRUE,TRUE,3, "n"},
{ 29,   24,  65, A_INT, TRUE,TRUE,3, "EH[^[E{["},
{ 45,   50,  85, A_INT, TRUE,TRUE,3, "̗͂"},

{ 40,   40,  85, A_INT, TRUE,TRUE,3, "Í̗"},
{ 10,    5,   50, A_INT, FALSE,FALSE,4, "͋z"},
{ 20,   10,   60, A_INT, FALSE,FALSE,5, "_U"},
{ 15,   16,   55, A_INT, FALSE,FALSE,4, "]U"},
{ 3,   2,   25, A_INT, TRUE,FALSE,5, "y̎"},
{ 9,   5,   30, A_INT, TRUE,FALSE,5, "d̎"},
{ 15,   8,   35, A_INT, TRUE,FALSE,4, "v̎"},
{ 25,   12,   40, A_INT, TRUE,TRUE,4, "̌"},
{ 9,  7,  30,  A_INT, TRUE,TRUE, 5,"AVbhE{g"},
{ 8,  6,  30,  A_INT, TRUE,TRUE, 5,"T_[E{g"},

{ 10,  8,  30,  A_INT, TRUE,TRUE, 5,"t@CAE{g"},
{ 9,  6,  30,  A_INT, TRUE,TRUE, 5,"ACXE{g"},
{ 40,   40,  85, A_INT, TRUE,TRUE, 3,"M̗"},
{ 20,   17,  55, A_INT, TRUE,TRUE, 4,"n̖"},
{ 18,   16,  60, A_INT, TRUE,TRUE, 4,"EH[^[E{g"},
{ 23,   18,  75, A_INT, TRUE,TRUE, 4,"̖͂"},
{ 27,   21,  65, A_INT, TRUE,TRUE, 4,"vY}E{g"},
{ 20,   16,  70, A_INT, TRUE,TRUE, 4,"Ɋ̖"},
{ 1,   1,  20, A_INT, TRUE,TRUE, 5,"}WbNE~TC"},
{ 5,   3,  30, A_INT, TRUE,FALSE, 5,"Q"},

{ 8,   4,  30, A_INT, TRUE,FALSE, 5,"Ӗ"},
{ 10,   5,  40, A_INT, TRUE,FALSE, 5,""},
{ 12,   5,  40, A_INT, TRUE,FALSE, 5,""},
{ 15,   5,  40, A_INT, TRUE,FALSE, 5,""},
{ 35,  30,  70, A_INT, TRUE,FALSE, 3,""}, //RF6
{ 40,  36,  85, A_INT, TRUE,TRUE, 3,"jł̎"},
{ 32,  36,   80, A_WIS, TRUE,FALSE, 2,""},
{ 47,  100,   90, A_INT, TRUE,FALSE, 2,"G"},
{ 3,  3,   20, A_INT, TRUE,FALSE, 3,"V[gEe|[g"},
{ 12,  10,   30, A_INT, TRUE,FALSE, 2,"e|[g"},

{ 48, 255,   90, A_INT, FALSE,FALSE, 2,"UE[h"},
{ 0,  0,  0, A_CON, FALSE,FALSE, 0,"(ʍs2͎gps)"},
{ 24,  20,   50, A_INT, TRUE,FALSE, 3,"e|[gEobN"},
{ 20,  16,   30, A_INT, TRUE,FALSE, 2,"e|[gEAEFC"},
{ 0,  0,   0, A_INT, TRUE,FALSE, 0,"()"}, 
{ 32,  30,   70, A_WIS, FALSE,TRUE, 1,"̌"},
{ 5,  3,   20, A_INT, FALSE,FALSE, 5,"CgEGA"},
{ 5,  3,   20, A_INT, FALSE,FALSE, 6,"gbv"},
{ 15,  6,   40, A_INT, FALSE,FALSE, 6,"L"},
{ 40, 32,   80, A_CHR, FALSE,TRUE, 2,"RY~bNEz["},

{ 30, 36,   70, A_CHR, TRUE,FALSE, 5,"~"},
{ 45, 100,   90, A_INT, TRUE,FALSE, 4,"TCo[f["},
{ 25, 20,   60, A_INT, TRUE,FALSE, 4,"X^[̏"},
{ 35, 40,   80, A_INT, TRUE,FALSE, 3,"X^["},
{ 20, 30,   60, A_INT, TRUE,FALSE, 5,"A"},
{ 20, 30,   60, A_INT, TRUE,FALSE, 5,""},
{ 35, 60,   80, A_INT, TRUE,FALSE, 4,"nEh"},
{ 32, 48,   70, A_INT, TRUE,FALSE, 4,"qh"},
{ 36, 48,   70, A_INT, TRUE,FALSE, 4,"Vg"},
{ 30, 36,   70, A_INT, TRUE,FALSE, 4,""},

{ 27, 26,   60, A_INT, TRUE,FALSE, 4,"Afbh"},
{ 30, 40,   70, A_INT, TRUE,FALSE, 3,"hS"},
{ 40, 80,   80, A_INT, TRUE,FALSE, 2,"ʃAfbh"},
{ 45, 90,   85, A_INT, TRUE,FALSE, 2,"ÑhS"},
{ 50, 120,  90, A_INT, TRUE,FALSE, 2,"Ao[̉"},
{ 50, 100,  90, A_INT, TRUE,FALSE, 2,"j[NX^["},
{ 36,  60,  85, A_INT, TRUE,TRUE, 1,"̗"}, //RF9
{ 36,  60,  85, A_INT, TRUE,TRUE, 1,"X̗"}, 
{ 36,  60,  85, A_INT, TRUE,TRUE, 1,"̗"}, 
{ 36,  60,  85, A_INT, TRUE,TRUE, 1,"_̗"}, 

{ 35,  48,  75, A_INT, TRUE,TRUE, 2,"őf̗"}, 
{ 36,  38,  80, A_INT, TRUE,TRUE, 3,"̋"}, 
{ 32,  32,  80, A_INT, TRUE,TRUE, 3,"q"}, 
{ 32,  25,  70, A_INT, TRUE,TRUE, 3,"ǰׂ"}, 
{ 36,  55,  85, A_INT, TRUE,TRUE, 2,"eIXgCN"}, 
{ 42,  35,  85, A_INT, TRUE,TRUE, 3,"Ԙc"}, 
{ 3,   2,   25, A_INT, TRUE,FALSE, 4,"̂܂Ȃ"},
{ 9,   5,   30, A_INT, TRUE,FALSE, 4,"Ȃ錾t"},
{ 15,   8,   35, A_INT, TRUE,FALSE, 3,"ޖ̎"},
{ 25,   12,   40, A_INT, TRUE,TRUE, 3,"jׂ̈"},

{ 23,   16,  55, A_INT, TRUE,TRUE, 3,"Ȃ"},
{ 40,  64,  90, A_INT, FALSE,TRUE, 2,"^[U["},
{ 20,   16,  50, A_INT, TRUE,TRUE, 3,"̃{g"},
{ 27, 30,   60, A_INT, TRUE,FALSE, 4,""},
{ 25,   32,  55, A_INT, FALSE,TRUE, 3,"[U["},
{ 0,  0,  0, A_CON, FALSE,FALSE, 0,"()"},
{ 48,  80,  75, A_INT, TRUE,TRUE, 3,"wEt@CA"},
{ 48,  80,  75, A_INT, TRUE,TRUE, 3,"z[[Et@CA"},
{ 45,  96,  80, A_INT, FALSE,FALSE, 2,"t@CiXp[N"},
{ 27,  24,  60, A_INT, FALSE,TRUE, 4,""}, 

{ 40,  36,  70, A_INT, TRUE,FALSE, 2,"*j*"}, 
{ 38,  50,   80, A_INT, TRUE,FALSE, 3,"_i"},
{ 44, 85,   85, A_INT, TRUE,FALSE, 2,"㋉"},
{ 25, 30,   60, A_INT, TRUE,FALSE, 4,"d"},
{ 25,  15,  50, A_INT, FALSE,FALSE, 3,"אڃe|[g"},
{ 35,  25,  70, A_INT, FALSE,FALSE, 2,"EOאڃe|[g"},
{ 40,  48,  85, A_INT, TRUE,FALSE, 3,"CVg"},
{ 5,    5,   20, A_CON, TRUE,FALSE, 5, "x"},

};




const cptr stat_desc[6] =
{
#ifdef JP
	"r", "m\", "", "p", "ϋv", ""
#else
	"STR : ", "INT : ", "WIS : ", "DEX : ", "CON : ", "CHR : "
#endif

};

///mod150805 AX
cptr alice_doll_name[INVEN_DOLL_NUM_MAX] = 
{
	"Cl`",
	"Hl`",
	"Il`",
	"ϓ֐l`",
	"IAl`",
	"l`",
	"SAel`",
};
//v1.1.46 
cptr jyoon_inven2_finger_name[JYOON_INVEN2_NUM] =
{
	"Elw",
	"E蒆w",
	"Ew",
	"E菬w",
	"lw",
	"蒆w",
	"w",
	"菬w",
};

///mod150811  info\\͉s
struct marisa_magic_type marisa_magic_table[MARISA_MAX_MAGIC_KIND] =
{
	{"Tt@CA","Ή̃uX^UB",
	{30,0,0,0,0,0,0,0},FALSE},
	{"|Xj[N","G𐁂΂NOƂ郍PbgUB",
	{0,0,0,12,0,7,3,0},FALSE},
	{"i[Xp[N","d̃r[B",
	{0,0,30,0,0,0,0,0},FALSE},
	{"Xe~TC","^[Qbg̈ʒu覐Α̏ȃ{[𔭐B",
	{0,0,0,0,0,0,20,0},FALSE},

	{"EBb`CC","w肵^[Qbgɓːi͑̃_[W^B\\rŏQɓƎ~܂B",
	{5,0,5,5,0,0,0,0},FALSE},
	{"O","̗͂300񕜂łƐ؂菝B",
	{0,5,0,5,0,5,0,0},TRUE},
	{"~lXXgCN","M̃PbgB",
	{0,0,0,10,0,0,0,0},FALSE},
	{"GXP[vxVeB","אڂGSĂɖ͑UsA\\̌uŒZ̃e|[gsB",
	{0,0,5,0,0,10,0,0},FALSE},

	{"R[hCtFm","C̃uX^UB",
	{0,30,0,0,0,0,0,0},FALSE},
	{"fr_g[`","߂̃^[Qbg̈ʒuɒn̏NB",
	{20,0,0,0,20,0,0,0},FALSE},
	{"}WbNhC~TC","G̗͂z{gB\\ɂ͌ʂȂB",
	{0,0,0,0,10,10,0,0},FALSE},
	{"pthbO","^[Qbg̈ʒuɎ_̃{[𔭐B",
	{10,10,10,0,0,0,0,0},FALSE},

	{"hSeI","߂̃^[Qbg̏ꏊɋ͂ȊjM̃{[𔭐B",
	{100,0,100,0,0,0,50,20},FALSE},
	{"I[vjo[X","ȆSĂɑ΂覐ΑUsB",
	{0,0,0,100,0,0,100,50},FALSE},
	{"}WbNAu\[o[","莞ԁA͂̓Gg@zMP񕜂B\\xȓG̖@͋zɎs邱ƂB\\uX⃍PbgȂǈꕔ̓Z͋złȂB",
	{0,0,0,0,50,50,0,20},FALSE},
	{"CxgzCY","̂ꏊ𒆐Sɋ͂ȏd͑̃{[𔭐B",
	{0,0,0,0,150,0,50,30},FALSE},

	{"͖","MPől܂ŉ񕜂B",
	{0,0,0,20,20,20,0,20},TRUE},
	{"O","̗͂ől܂ŉ񕜂SẴXe[^XُB",
	{0,50,0,50,0,0,0,20},TRUE},
	{"X^[_Xg@G","̎͂ɋ͂ȑM̃{[AŔB",
	{0,0,0,100,0,100,50,0},FALSE},
	{"I[[Y\[[VXe","ꎞIɌfUɑ΂ϐƉΉI[𓾂B",
	{50,50,50,50,0,0,0,0},FALSE},

	{"rbON`","͂̍L͈͂*j*B",
	{0,0,0,0,50,50,50,50},FALSE},
	{"_[NXp[N","͂ȈÍ̃[U[B",
	{100,0,100,0,100,0,0,0},FALSE},
	{"IJeBV","߂̓GtAB\\̏ƂɔJ1d3̃_[W󂯂B\\R邱ƂAj[NX^[ɂ͌ʂȂB",
	{0,0,0,0,0,200,0,0},FALSE},
	{"fB[vGRWJ{","^[Qbg̈ʒuɋ͂ȃJIX̃{[𔭐B\\Ɋ܂Ǝg_[W󂯂̂ŒӁB",
	{100,100,100,0,0,0,0,0},FALSE},

	{"t@CiXp[N","ɂ߂ċ͂ȕ𑮐̃[U[B",
	{0,0,0,0,0,0,0,300},FALSE},
	{"I[[Yjo[X","ꎞIɑSĂ̑ϐAAC㏸𓾂ĂقڑSẴ_[W2/3ɌyB",
	{100,100,100,100,100,100,100,0},FALSE},
	{"AeBbgV[gEF[u","tȂSĂɑ΂͂ȃvY}̍UsB",
	{200,200,200,200,0,0,0,100},FALSE},
	{"uCWOX^[","ːiB\\ǂȂǂj󂵗ǂGɋɂ߂đ傫ȃ_[W^Đ΂A\\ׂw͂łȂB",
	{500,0,0,200,0,200,200,300},FALSE},

};

cptr marisa_essence_name[8] = {"","X","","","","","","",};

//PNGXg
int kaguya_quest_art_list[KAGUYA_QUEST_MAX] = 
{ART_KAGUYA_TSUBAME,ART_KAGUYA_HINEZUMI,ART_KAGUYA_HOTOKE,ART_KAGUYA_DRAGON,ART_KAGUYA_HOURAI};



/*:::t̍fޕ\
 * {ޗTV,ޗSV,܎؂RXg,
 * {_,d,,,,,ϗe,_l}
 */
const drug_material_type drug_material_table[] =
{

//Material
	//qJSP
	{TV_MATERIAL,SV_MATERIAL_HIKARIGOKE,400,
	{0,0,0,0,-100,250,50,100}},
	//f
	{TV_MATERIAL,SV_MATERIAL_ARSENIC,640,
	{0,0,0,0,300,-300,0,-50}},
	//
	{TV_MATERIAL,SV_MATERIAL_MERCURY,750,
	{100,100,100,100,300,0,50,50}},
	//̗
	{TV_MATERIAL,SV_MATERIAL_DRAGONSCALE,2300,
	{200,200,200,200,200,0,0,0}},
	//̒
	{TV_MATERIAL,SV_MATERIAL_DRAGONNAIL,12000,
	{500,500,500,500,500,500,500,500}},
	//QZ~E
	{TV_MATERIAL,SV_MATERIAL_GELSEMIUM,1000,
	{0,0,0,0,800,-300,0,0}},
	//X̗
	{TV_MATERIAL,SV_MATERIAL_ICESCALE,1800,
	{0,0,0,1200,0,0,0,0}},
	//̂
	{TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1250,
	{0,0,0,100,200,0,0,-400}},
	//]̌
	{TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,4400,
	{0,0,0,0,-600,800,0,600}},
	//Y
	{TV_MATERIAL,SV_MATERIAL_COAL,50,
	{0,0,7,0,5,-5,10,0}},
	//Š|
	{TV_MATERIAL,SV_MATERIAL_TAKAKUSAGORI,2400,
	{0,300,300,300,-300,500,700,0}},
	//~XeE
	{TV_MATERIAL,SV_MATERIAL_MYSTERIUM,32000,
	{1200,1200,1200,1200,0,-1200,1200,0}},
	//ɜQ
	{TV_MATERIAL,SV_MATERIAL_IZANAGIOBJECT,16000,
	{-200,-200,-200,-200,-200,0,500,1100}},
	//΍
	{TV_MATERIAL,SV_MATERIAL_ISHIZAKURA,450,
	{0,0,0,0,0,-100,50,-100}},

//Kinoko
	//ł̃LmR
	{TV_MUSHROOM,SV_MUSHROOM_POISON ,50,
	{0,0,0,0,50,-10,5,0}},
	//Ӗڑ
	{TV_MUSHROOM,SV_MUSHROOM_BLINDNESS ,35,
	{40,0,0,0,25,0,15,0}},
	//|
	{TV_MUSHROOM,SV_MUSHROOM_PARANOIA ,25,
	{25,0,0,25,20,0,5,-30}},
	//
	{TV_MUSHROOM,SV_MUSHROOM_CONFUSION ,35,
	{0,25,25,0,10,0,20,-15}},
	//o
	{TV_MUSHROOM,SV_MUSHROOM_HALLUCINATION ,50,
	{0,0,0,0,20,0,30,-30}},
	//
	{TV_MUSHROOM,SV_MUSHROOM_PARALYSIS ,15,
	{0,40,0,20,20,0,0,0}},
	//Ǝ
	{TV_MUSHROOM,SV_MUSHROOM_WEAKNESS ,60,
	{40,0,-50,0,30,-20,-40,0}},
	//aC
	{TV_MUSHROOM,SV_MUSHROOM_SICKNESS ,60,
	{-50,30,0,0,30,-20,-20,0}},
	//m
	{TV_MUSHROOM,SV_MUSHROOM_STUPIDITY ,65,
	{0,-50,0,20,20,-30,0,-20}},
	//
	{TV_MUSHROOM,SV_MUSHROOM_NAIVETY ,65,
	{0,0,20,-50,20,-20,0,-20}},
	//a
	{TV_MUSHROOM,SV_MUSHROOM_UNHEALTH ,120,
	{20,20,20,20,70,-30,0,-50}},
	//a
	{TV_MUSHROOM,SV_MUSHROOM_DISEASE ,120,
	{20,20,20,20,70,-30,0,-50}},

	//ŏ
	{TV_MUSHROOM,SV_MUSHROOM_CURE_POISON ,90,
	{0,0,0,0,-300,0,0,0}},
	//Ӗڎ
	{TV_MUSHROOM,SV_MUSHROOM_CURE_BLINDNESS ,80,
	{0,0,0,0,0,45,45,0}},
	//|
	{TV_MUSHROOM,SV_MUSHROOM_CURE_PARANOIA ,50,
	{0,10,10,0,0,10,0,20}},
	//Eo
	{TV_MUSHROOM,SV_MUSHROOM_CURE_CONFUSION ,60,
	{0,0,0,0,0,20,0,30}},
	//d
	{TV_MUSHROOM,SV_MUSHROOM_CURE_SERIOUS ,100,
	{10,10,0,0,-20,50,0,5}},

	//r͕
	{TV_MUSHROOM,SV_MUSHROOM_RESTORE_STR ,70,
	{0,20,20,0,0,30,0,0}},
	//ϋv͕
	{TV_MUSHROOM,SV_MUSHROOM_RESTORE_CON ,70,
	{20,0,0,20,0,30,0,0}},
	//S
	{TV_MUSHROOM,SV_MUSHROOM_RESTORING ,750,
	{40,40,40,40,-200,200,-50,100}},
	//J
	{TV_MUSHROOM,SV_MUSHROOM_MANA ,310,
	{0,0,0,0,0,80,0,70}},
	//m
	{TV_MUSHROOM,SV_MUSHROOM_BERSERK ,220,
	{-30,50,50,-30,30,-20,40,50}},

	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_RED ,150,
	{0,0,100,-25,0,0,0,0}},
	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_WHITE ,150,
	{0,0,-25,100,0,0,0,0}},
	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_BLUE ,150,
	{-25,100,0,0,0,0,0,0}},
	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_BLACK ,150,
	{100,-25,0,0,0,0,0,0}},
	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_GREEN ,150,
	{0,0,0,0,100,-25,10,0}},
	//΂ɍʐF
	{TV_MUSHROOM,SV_MUSHROOM_MON_GAUDY ,300,
	{0,0,0,0,50,50,250,0}},
	//΂DF
	{TV_MUSHROOM,SV_MUSHROOM_MON_GRAY ,300,
	{0,0,0,0,250,-250,0,-100}},
	//΂
	{TV_MUSHROOM,SV_MUSHROOM_MON_CLEAR ,300,
	{0,0,0,0,0,0,-400,50}},

	//X[p[LmR
	{TV_MUSHROOM,SV_MUSHROOM_MON_SUPER ,16000,
	{0,0,0,0,0,500,2400,0}},
	//@LmR
	{TV_MUSHROOM,SV_MUSHROOM_MON_L_BLUE ,450,
	{50,50,50,50,50,0,50,0}},

	//IjtXx
	{ TV_MUSHROOM,SV_MUSHROOM_PUFFBALL ,500,
	{ 0,0,0,0,0,100,200,0 } },

//

	//̂
	{TV_POTION,SV_POTION_SLOWNESS ,30,
	{10,0,0,10,10,0,0,0}},
	//
	{TV_POTION,SV_POTION_POISON ,60,
	{0,0,0,0,30,-30,0,0}},
	//Ӗ
	{TV_POTION,SV_POTION_BLINDNESS ,35,
	{10,-5,0,0,10,-5,4,0}},
	//
	{TV_POTION,SV_POTION_SLEEP ,12,
	{0,0,0,0,0,0,0,-30}},
	//Lr
	{TV_POTION,SV_POTION_LOSE_MEMORIES ,360,
	{0,100,0,0,0,0,100,-100}},

	//j
	{TV_POTION,SV_POTION_RUINATION ,3000,
	{-200,-200,-200,-200,200,-200,200,-200}},
	//Ǝ`X
	{TV_POTION,SV_POTION_DEC_STR ,50,
	{0,0,-30,30,15,-10,0,0}},
	{TV_POTION,SV_POTION_DEC_INT ,50,
	{0,-30,30,0,15,-10,0,0}},
	{TV_POTION,SV_POTION_DEC_WIS ,50,
	{0,0,-30,30,15,-10,0,0}},
	{TV_POTION,SV_POTION_DEC_DEX ,50,
	{30,0,0,-30,15,-10,0,0}},
	{TV_POTION,SV_POTION_DEC_CON ,50,
	{0,30,-30,0,15,-10,0,0}},
	{TV_POTION,SV_POTION_DEC_CHR ,50,
	{30,-30,0,0,15,-10,0,0}},

	//
	{TV_POTION,SV_POTION_DETONATIONS ,1500,
	{0,0,600,-300,0,0,50,0}},
	//
	{TV_POTION,SV_POTION_DEATH ,3000,
	{0,0,0,0,1000,-1000,0,-600}},
	//ԊO
	{TV_POTION,SV_POTION_INFRAVISION ,10,
	{0,0,0,0,0,0,10,0}},
	//F
	{TV_POTION,SV_POTION_DETECT_INVIS ,30,
	{0,0,-5,0,-5,0,25,25}},
	//
	{TV_POTION,SV_POTION_SLOW_POISON ,20,
	{0,0,0,0,-50,0,0,0}},
	//
	{TV_POTION,SV_POTION_CURE_POISON ,10,
	{0,0,0,0,-50,0,0,0}},
	//̒m炸
	{TV_POTION,SV_POTION_BOLDNESS ,40,
	{0,0,15,-15,0,5,5,10}},
	//Xs[h
	{TV_POTION,SV_POTION_SPEED ,100,
	{0,30,0,30,0,0,20,20}},
	//ω
	{TV_POTION,SV_POTION_RESIST_HEAT ,60,
	{0,0,40,0,0,0,20,0}},
	//ϗ
	{TV_POTION,SV_POTION_RESIST_COLD ,60,
	{0,0,0,40,0,0,20,0}},
	//q[[
	{TV_POTION,SV_POTION_HEROISM ,40,
	{0,0,10,-20,0,0,0,30}},
	//m
	{TV_POTION,SV_POTION_BESERK_STRENGTH ,200,
	{0,50,50,-30,20,-20,30,50}},

	//yǎ
	{TV_POTION,SV_POTION_CURE_LIGHT ,10,
	{0,0,0,0,-5,5,0,0}},
	//dǎ
	{TV_POTION,SV_POTION_CURE_SERIOUS ,20,
	{0,0,0,0,-10,10,0,0}},
	//v
	{TV_POTION,SV_POTION_CURE_CRITICAL ,70,
	{0,0,0,10,-20,20,0,5}},
	//̗͉
	{TV_POTION,SV_POTION_HEALING ,350,
	{-20,-20,-20,-20,-50,200,0,20}},
	//*̗͉*
	{TV_POTION,SV_POTION_STAR_HEALING ,2400,
	{-50,-50,-50,-50,-400,800,0,50}},
	//
	{TV_POTION,SV_POTION_LIFE ,8000,
	{-100,-100,-100,-100,-1000,1000,-300,300}},

	//͕
	{TV_POTION,SV_POTION_RESTORE_MANA ,800,
	{50,50,50,50,0,50,50,200}},
	//ol
	{TV_POTION,SV_POTION_RESTORE_EXP ,70,
	{0,0,0,0,-50,20,-30,0}},
	//ŕ`͉
	{TV_POTION,SV_POTION_RES_STR ,50,
	{0,0,30,-30,0,20,10,0}},
	{TV_POTION,SV_POTION_RES_INT ,50,
	{0,30,-30,0,0,20,10,0}},
	{TV_POTION,SV_POTION_RES_WIS ,50,
	{0,0,30,-30,0,20,10,0}},
	{TV_POTION,SV_POTION_RES_DEX ,50,
	{-30,0,0,30,0,20,10,0}},
	{TV_POTION,SV_POTION_RES_CON ,50,
	{0,-30,30,0,0,20,10,0}},
	{TV_POTION,SV_POTION_RES_CHR ,50,
	{-30,30,0,0,0,20,10,0}},
	//ŕ`
	{TV_POTION,SV_POTION_INC_STR ,2500,
	{0,0,300,-100,0,0,400,0}},
	{TV_POTION,SV_POTION_INC_INT ,2500,
	{0,300,-100,0,0,0,0,400}},
	{TV_POTION,SV_POTION_INC_WIS ,2500,
	{0,0,300,-100,0,0,0,400}},
	{TV_POTION,SV_POTION_INC_DEX ,2500,
	{-100,0,0,300,0,0,400,0}},
	{TV_POTION,SV_POTION_INC_CON ,2500,
	{0,-100,300,0,0,0,400,0}},
	{TV_POTION,SV_POTION_INC_CHR ,2500,
	{-100,300,0,0,0,0,0,400}},
	//
	{TV_POTION,SV_POTION_AUGMENTATION ,25000,
	{500,500,500,500,0,0,700,300}},

	//[
	{TV_POTION,SV_POTION_ENLIGHTENMENT ,500,
	{0,0,0,0,0,0,0,300}},
	//*[*
	{TV_POTION,SV_POTION_STAR_ENLIGHTENMENT ,18000,
	{0,300,0,300,0,300,0,1600}},
	//ȕ
	{TV_POTION,SV_POTION_SELF_KNOWLEDGE ,1200,
	{0,0,0,0,0,0,-400,400}},

	//o
	{TV_POTION,SV_POTION_EXPERIENCE ,12000,
	{200,200,200,200,200,200,200,600}},
	//ϐ
	{TV_POTION,SV_POTION_RESISTANCE ,250,
	{50,50,50,50,50,0,50,0}},
	//
	{TV_POTION,SV_POTION_CURING ,120,
	{0,0,0,0,-30,50,-30,50}},
	//
	{TV_POTION,SV_POTION_INVULNERABILITY ,24000,
	{0,0,0,0,0,800,-400,1600}},
	//V
	{TV_POTION,SV_POTION_NEW_LIFE ,14000,
	{0,0,0,0,0,700,700,700}},
	//lI悵
	{TV_POTION,SV_POTION_NEO_TSUYOSHI ,700,
	{0,0,0,0,0,0,300,-300}},
	//悵
	{TV_POTION,SV_POTION_TSUYOSHI ,150,
	{0,0,0,0,100,-50,100,-50}},
	//ˑRψ
	{TV_POTION,SV_POTION_POLYMORPH ,3000,
	{0,0,0,0,100,100,500,0}},
	//ȂɂȂ
	{TV_POTION,SV_POTION_NANIKASUZUSHIKUNARU ,6000,
	{0,0,-1600,1600,500,-500,0,0}},
	//ғł̖
	{TV_POTION,SV_POTION_POISON2 ,300,
	{0,0,0,0,200,-100,20,-50}},
	//
	{TV_POTION,SV_POTION_LOVE ,6000,
	{-200,400,400,-200,0,100,400,400}},

//
	//_
	{TV_COMPOUND,SV_COMPOUND_STRONG_ACID ,200,
	{300,0,50,-50,0,0,50,0}},	
	//K
	{TV_COMPOUND,SV_COMPOUND_HAPPY ,360,
	{0,0,0,0,20,-20,0,-100}},	
	//ؓ
	{TV_COMPOUND,SV_COMPOUND_MUSCLE_DRUG ,550,
	{0,30,30,-70,0,50,200,-20}},	
	//ΐ
	{TV_COMPOUND,SV_COMPOUND_BREATH_OF_FIRE ,500,
	{0,0,300,-100,0,0,150,00}},	

	//iCgA
	{TV_COMPOUND,SV_COMPOUND_NIGHTMARE ,480,
	{0,0,0,0,150,-50,100,-300}},	
	//mo̖
	{TV_COMPOUND,SV_COMPOUND_KOKUSHI ,1200,
	{0,0,0,0,0,200,200,200}},
	//*h{*
	{TV_COMPOUND,SV_COMPOUND_STAR_FEEDING ,1300,
	{0,0,0,0,0,200,500,-300}},	
	//~NILVQ
	{TV_COMPOUND,SV_COMPOUND_MICRO_OCSIGEN ,22000,
	{1200,0,0,0,0,-1600,0,0}},
	//œt
	{TV_COMPOUND,SV_COMPOUND_YOKOSHIMA ,3200,
	{0,50,0,200,500,0,320,-700}},	
	//**
	{TV_COMPOUND,SV_COMPOUND_STAR_DETORNATION ,5000,
	{0,0,1200,-1000,0,0,0,0}},	
	//l̖
	{TV_COMPOUND,SV_COMPOUND_TITAN ,12500,
	{50,50,50,50,0,600,1200,0}},	
	//C`R
	{TV_COMPOUND,SV_COMPOUND_ICHIKORORI ,27000,
	{800,800,0,0,1600,-1600,0,-500}},	
	//Yp
	{TV_COMPOUND,SV_COMPOUND_MAGICAL_ECO_BOMB ,3000,
	{-100,-100,-100,-100,-100,-100,500,-100}},	
//ق
	//s̉H
	{TV_SOUVENIR,SV_SOUVENIR_PHOENIX_FEATHER,50000,
	{500,0,3200,-1600,0,1600,1600,1600}},
	//ȗ
	{TV_SOUVENIR,SV_SOUVENIR_BIG_EGG,60000,
	{0,0,0,0,0,0,1600,1600}},
	//͓̌ܐFb
	{TV_SOUVENIR,SV_SOUVENIR_KAPPA_5,36000,
	{800,800,800,800,800,800,800,800}},
	//XChAXChW[X
	{TV_FOOD,SV_FOOD_SLIMEMOLD ,100,
	{30,0,0,0,50,50,200,-30}},
	{TV_SOFTDRINK,SV_DRINK_SLIME_MOLD ,100,
	{30,0,0,0,50,50,200,-30}},
	//󕠏[̐O
	{TV_FOOD,SV_FOOD_SENTAN ,200,
	{0,0,0,0,0,100,0,40}},
	//~Nt[c
	{TV_SWEETS,SV_SWEETS_MIRACLE_FRUIT ,1400,
	{50,50,50,50,50,50,300,0}},

	//
	{TV_SOFTDRINK,SV_DRINK_WATER ,1,
	{0,0,0,0,0,1,0,0}},
	//W[X
	{TV_SOFTDRINK,SV_DRINK_APPLE_JUICE ,5,
	{0,0,0,0,0,1,3,0}},
	{TV_SOFTDRINK,SV_DRINK_GRAPE_JUICE ,5,
	{0,0,0,0,0,1,3,0}},



	//܂(R؂ꂾƍޗƂĎgȂ悤ɂĂ?)
	{TV_LITE,SV_LITE_TORCH,5,
	{0,0,3,0,0,0,1,0}},
	//
	{TV_FLASK,SV_FLASK_OIL,5,
	{0,0,5,-2,0,0,0,0}},



	{0,0,0,{0,0,0,0,0,0,0,0}} //I[p_~[
};



/*:::t̍\
 * {iTV,iSV,{Փx,
 * {_,d,,,,,ϗe,_Kvl,
 * {RXg,ŒKvfTV,ŒKvfSV}
 */
 //_~[63܂œo^ł͂
 //ԉD悳̂œޗD悵Ή
 //̏Ԃ͊tOɎĝő}ƃZ[uf[^݊Ȃ
const drug_compound_type drug_compound_table[] =
{
	{TV_MATERIAL,SV_MATERIAL_COAL,0,{0,0,0,0,0,0,0,0},10000,1,0,0}, //Y@n_p_~[sp

	//̎F̖
	{TV_POTION,SV_POTION_DETECT_INVIS,50,
	{0,0,0,4,0,4,4,0},
	80,5,0,0},
	//ω΂̖
	{TV_POTION,SV_POTION_RESIST_HEAT,60,
	{0,0,12,0,0,0,5,0},
	100,7,0,0},
	//ϗ̖
	{TV_POTION,SV_POTION_RESIST_COLD,60,
	{0,0,0,12,0,0,5,0},
	100,7,0,0},
	//_
	{TV_COMPOUND,SV_COMPOUND_STRONG_ACID,65,
	{25,0,0,0,0,0,0,0},
	300,6,0,0},
	//m̖
	{TV_POTION,SV_POTION_BESERK_STRENGTH,63,
	{0,0,20,-1,3,0,0,10},
	250,4,0,0},
	//Xs[h̖
	{TV_POTION,SV_POTION_SPEED,70,
	{-20,20,0,0,-2,0,10,3},
	200,6,0,0},
	//ғł̖
	{TV_POTION,SV_POTION_POISON2,67,
	{0,0,0,0,50,-20,0,0},
	320,4,0,0},


	//K
	{TV_COMPOUND,SV_COMPOUND_HAPPY,60,
	{0,0,0,0,0,0,20,-20},
	400,5,0,0},
	//ϐ̖
	{TV_POTION,SV_POTION_RESISTANCE,90,
	{5,5,5,5,5,0,20,0},
	500,3,0,0},
	//ؓ
	{TV_COMPOUND,SV_COMPOUND_MUSCLE_DRUG,77,
	{0,0,10,0,0,30,30,0},
	800,5,0,0},
	//ΐ
	{TV_COMPOUND,SV_COMPOUND_BREATH_OF_FIRE,85,
	{0,0,100,0,0,0,20,0},
	700,4,0,0},
	//̗͉񕜂̖
	{TV_POTION,SV_POTION_HEALING,110,
	{0,0,0,0,-30,100,0,10},
	500,4,0,0},
	//l
	{TV_COMPOUND,SV_COMPOUND_NINGYO,90,
	{100,0,0,0,100,0,200,-100},
	1000,1,0,0},
	//QZ~EEGKX̂
	{TV_COMPOUND,SV_COMPOUND_GELSEMIUM_TEA,75,
	{0,0,0,0,300,-100,0,0},
	500,4,TV_MATERIAL,SV_MATERIAL_GELSEMIUM},
	//WLm̖
	{TV_COMPOUND,SV_COMPOUND_JEKYLL,80,
	{0,50,0,0,50,-50,100,-50},
	700,4,0,0},

	//ӒۃiCgA^Cv(t)
	{TV_COMPOUND,SV_COMPOUND_NIGHTMARE,100,
	{30,30,30,30,100,0,0,-100},
	500,6,0,0},
	//TCoC}
	{TV_COMPOUND,SV_COMPOUND_SAIBAIMAN,120,
	{100,0,0,0,0,200,150,0},
	700,3,0,0},
	//̖
	{TV_POTION,SV_POTION_DETONATIONS,115,
	{100,20,300,0,0,0,0,0},
	2000,3,0,0},
	//mo̖
	{TV_COMPOUND,SV_COMPOUND_KOKUSHI,110,
	{30,30,30,30,30,30,30,30},
	1600,4,0,0},

	//*h{*
	{TV_COMPOUND,SV_COMPOUND_STAR_FEEDING,118,
	{-5,-5,-5,-5,20,100,100,0},
	2400,3,0,0},
	//b
	{TV_COMPOUND,SV_COMPOUND_METAMOR_BEAST,132,
	{0,50,50,0,0,100,400,-50},
	2000,3,0,0},
	//
	{TV_POTION,SV_POTION_LOVE,130,
	{0,100,0,0,-100,0,100,300},
	3000,3,0,0},
	//Ȃ
	{TV_POTION,SV_POTION_NANIKASUZUSHIKUNARU,125,
	{0,0,0,1000,300,0,0,-100},
	8000,3,0,0},

	//[ւ̖ VsȂ
	{TV_POTION,SV_POTION_ENLIGHTENMENT,120,
	{0,0,0,0,0,0,-100,300},
	3000,3,0,0},

	//o̖
	{TV_POTION,SV_POTION_EXPERIENCE,140,
	{0,0,0,0,0,500,-300,500},
	10000,1,0,0},
	//~NILVQ
	{TV_COMPOUND,SV_COMPOUND_MICRO_OCSIGEN,150,
	{200,200,200,200,200,200,200,0},
	15000,3,0,0},
	//**̖
	{TV_COMPOUND,SV_COMPOUND_STAR_DETORNATION,156,
	{200,0,750,-200,0,0,100,0},
	12000,4,0,0},
	//œt
	{TV_COMPOUND,SV_COMPOUND_YOKOSHIMA,162,
	{0,0,0,0,300,0,200,-500},
	8000,3,0,0},
	//l̖
	{TV_COMPOUND,SV_COMPOUND_TITAN,166,
	{0,0,0,0,0,500,1200,0},
	10000,2,0,0},
	//leC`R̖
	{TV_COMPOUND,SV_COMPOUND_ICHIKORORI,170,
	{0,0,0,0,1200,-1200,0,-300},
	20000,2,0,0},
	//̖
	{TV_POTION,SV_POTION_INVULNERABILITY,180,
	{0,0,0,0,0,0,0,1500},
	100000,1,0,0},

	// VsȂ
	{TV_COMPOUND,SV_COMPOUND_ANTIMATTER,170,
	{-300,-300,-300,-300,-300,0,1000,0},
	10000,3,0,0},
	//V VsȂ
	{TV_COMPOUND,SV_COMPOUND_SUPER_SPEED,175,
	{0,700,0,700,0,0,700,700},
	20000,2,0,0},
	// VsȂ
	{TV_COMPOUND,SV_COMPOUND_METAMOR_DRAGON,180,
	{0,500,500,500,0,0,1200,500},
	15000,2,TV_MATERIAL,SV_MATERIAL_DRAGONNAIL},

	//Ήr
	{TV_COMPOUND,SV_COMPOUND_MOLOTOV_COCKTAIL,40,
	{0,0,7,-2,0,0,1,0},
	100,1,TV_FLASK,SV_FLASK_OIL},

	//̖
	{TV_POTION,SV_POTION_LIFE,160,
	{100,100,100,100,-100,400,0,150},
	10000,2,TV_MATERIAL,SV_MATERIAL_MERCURY},

	//̖I VsȂ
	{TV_ALCOHOL,SV_ALCOHOL_GOLDEN_MEAD,165,
	{0,0,0,500,0,0,300,300},
	30000,2,TV_POTION,SV_POTION_RESISTANCE},

	//H̖ VsȂ
	{TV_COMPOUND,SV_COMPOUND_HOURAI,200,
	{0,0,0,0,0,-1600,800,1600},
	100000,1,0,0},

	{0,0,0,{0,0,0,0,0,0,0,0},0,0,0,0} //I[p_~[
};


/*:::`e[u zY0-71ځA8-152ځEEƂȂ*/
//܂ŃVsQƗpȂ̂ōe[uςSČ؂Kv
const drug_recipe_type drug_recipe_table[32] =
{
	//ꊪ
	//Ήr
	{TV_COMPOUND,SV_COMPOUND_MOLOTOV_COCKTAIL,
		TV_FLASK,SV_FLASK_OIL,TV_LITE,SV_LITE_TORCH,0,0},
	//F
	{TV_POTION,SV_POTION_DETECT_INVIS,
		TV_POTION,SV_POTION_CURE_CRITICAL,TV_POTION,SV_POTION_INFRAVISION,0,0},
	//ω
	{TV_POTION,SV_POTION_RESIST_HEAT,
		TV_MUSHROOM,SV_MUSHROOM_MON_RED,TV_POTION,SV_POTION_INFRAVISION,0,0},
	//ϗ
	{TV_POTION,SV_POTION_RESIST_COLD,
		TV_MUSHROOM,SV_MUSHROOM_MON_WHITE,TV_POTION,SV_POTION_INFRAVISION,0,0},
	//_
	{TV_COMPOUND,SV_COMPOUND_STRONG_ACID,
		TV_MUSHROOM,SV_MUSHROOM_MON_BLACK,0,0,0,0},
	//m
	{TV_POTION,SV_POTION_BESERK_STRENGTH,
		TV_POTION,SV_POTION_RES_STR,TV_MUSHROOM,SV_MUSHROOM_CURE_PARANOIA,TV_MUSHROOM,SV_MUSHROOM_POISON},
	//Xs[h
	{TV_POTION,SV_POTION_SPEED,
		TV_POTION,SV_POTION_CURE_CRITICAL,TV_POTION,SV_POTION_RES_INT,TV_POTION,SV_POTION_RES_DEX},
	//ғ
	{TV_POTION,SV_POTION_POISON2,
		TV_MUSHROOM,SV_MUSHROOM_POISON,TV_MUSHROOM,SV_MUSHROOM_POISON,0,0},

	//
	//K
	{TV_COMPOUND,SV_COMPOUND_HAPPY,
		TV_MUSHROOM,SV_MUSHROOM_HALLUCINATION,0,0,0,0},
	//ϐ
	{TV_POTION,SV_POTION_RESISTANCE,
		TV_MUSHROOM,SV_MUSHROOM_PARANOIA,TV_MUSHROOM,SV_MUSHROOM_CONFUSION,0,0},
	//ؓ
	{TV_COMPOUND,SV_COMPOUND_MUSCLE_DRUG,
		TV_MUSHROOM,SV_MUSHROOM_CURE_SERIOUS,TV_POTION,SV_POTION_RESIST_HEAT,TV_POTION,SV_POTION_RESIST_COLD},
	//ΐ
	{TV_COMPOUND,SV_COMPOUND_BREATH_OF_FIRE,
		TV_MUSHROOM,SV_MUSHROOM_BERSERK,TV_MUSHROOM,SV_MUSHROOM_MON_RED,0,0},
	//̗͉񕜖
	{TV_POTION,SV_POTION_HEALING,
		TV_POTION,SV_POTION_CURING,TV_POTION,SV_POTION_CURING,0,0},
	//l
	{TV_COMPOUND,SV_COMPOUND_NINGYO,
		TV_COMPOUND,SV_COMPOUND_STRONG_ACID,TV_COMPOUND,SV_COMPOUND_HAPPY,TV_POTION,SV_POTION_POLYMORPH},
	//QZ~E
	{TV_COMPOUND,SV_COMPOUND_GELSEMIUM_TEA,
		TV_MATERIAL,SV_MATERIAL_GELSEMIUM,0,0,0,0},
	//WL
	{TV_COMPOUND,SV_COMPOUND_JEKYLL,
		TV_POTION,SV_POTION_POISON2,TV_POTION,SV_POTION_LOSE_MEMORIES,0,0},

	//O
	//ӒۃiCgA
	{TV_COMPOUND,SV_COMPOUND_NIGHTMARE,
		TV_MATERIAL,SV_MATERIAL_MERCURY,TV_POTION,SV_POTION_NEO_TSUYOSHI,0,0},
	//TCoC}
	{TV_COMPOUND,SV_COMPOUND_SAIBAIMAN,
		TV_POTION,SV_POTION_HEALING,TV_COMPOUND,SV_COMPOUND_STRONG_ACID,TV_COMPOUND,SV_COMPOUND_MUSCLE_DRUG},
	//
	{TV_POTION,SV_POTION_DETONATIONS,
		TV_COMPOUND,SV_COMPOUND_STRONG_ACID,TV_COMPOUND,SV_COMPOUND_BREATH_OF_FIRE,TV_POTION,SV_POTION_SPEED},
	//mo
	{TV_COMPOUND,SV_COMPOUND_KOKUSHI,
		TV_MUSHROOM,SV_MUSHROOM_MANA,TV_POTION,SV_POTION_RESISTANCE,0,0},
	//*엿*
	{TV_COMPOUND,SV_COMPOUND_STAR_FEEDING,
		TV_POTION,SV_POTION_HEALING,TV_POTION,SV_POTION_POLYMORPH,0,0},
	//b
	{TV_COMPOUND,SV_COMPOUND_METAMOR_BEAST,
		TV_MATERIAL,SV_MATERIAL_TAKAKUSAGORI,TV_POTION,SV_POTION_POISON2,0,0},
	//
	{TV_POTION,SV_POTION_LOVE,
		TV_POTION,SV_POTION_RESTORE_MANA,TV_MATERIAL,SV_MATERIAL_HIKARIGOKE,TV_MUSHROOM,SV_MUSHROOM_MON_BLUE},
	//ȂɂȂ
	{TV_POTION,SV_POTION_NANIKASUZUSHIKUNARU,
		TV_MATERIAL,SV_MATERIAL_ICESCALE,TV_POTION,SV_POTION_POISON2,TV_POTION,SV_POTION_POISON2},

	//ŏI
	//o
	{TV_POTION,SV_POTION_EXPERIENCE,
		TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,TV_POTION,SV_POTION_SELF_KNOWLEDGE,0,0},
	//~NILVQ
	{TV_COMPOUND,SV_COMPOUND_MICRO_OCSIGEN,
		TV_MATERIAL,SV_MATERIAL_DRAGONSCALE,TV_COMPOUND,SV_COMPOUND_KOKUSHI,0,0},
	//**̖
	{TV_COMPOUND,SV_COMPOUND_STAR_DETORNATION,
		TV_POTION,SV_POTION_DETONATIONS,TV_COMPOUND,SV_COMPOUND_STRONG_ACID,TV_MUSHROOM,SV_MUSHROOM_MON_RED},
	//̖
	{TV_POTION,SV_POTION_LIFE,
		TV_MATERIAL,SV_MATERIAL_MERCURY,TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,0,0},
	//œt
	{TV_COMPOUND,SV_COMPOUND_YOKOSHIMA,
		TV_POTION,SV_POTION_RUINATION,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,0,0},

	//l̖
	{TV_COMPOUND,SV_COMPOUND_TITAN,
		TV_COMPOUND,SV_COMPOUND_STAR_FEEDING,TV_POTION,SV_POTION_POLYMORPH,TV_COMPOUND,SV_COMPOUND_KOKUSHI},

	//leC`R̖
	{TV_COMPOUND,SV_COMPOUND_ICHIKORORI,
		TV_POTION,SV_POTION_DEATH,TV_MATERIAL,SV_MATERIAL_GELSEMIUM,0,0},
	//̖
	{TV_POTION,SV_POTION_INVULNERABILITY,
		TV_MATERIAL,SV_MATERIAL_IZANAGIOBJECT,TV_POTION,SV_POTION_ENLIGHTENMENT,TV_POTION,SV_POTION_SELF_KNOWLEDGE},

};





/*:::GNXgNGXgVe[u*/
//level,a_idx,tv,sv,am_mode,num
ex_quest_rew_type ex_quest_reward_table[] =
{
	//I[NNG@BꖪAΉ̎wցA̗͉񕜖AXs[h
	{10,0,TV_CLOAK,SV_CLOAK_STEALTH,(AM_NO_FIXED_ART | AM_GOOD),1},
	{10,0,TV_RING,SV_RING_FLAMES,(AM_NO_FIXED_ART | AM_GOOD),1},
	{10,0,TV_CHEST,SV_CHEST_MARIPO_03,0L,1},
	{10,0,TV_CHEST,SV_CHEST_MARIPO_07,0L,1},

	//~~bN@გm炸wցA{AΗn_
	{20,0,TV_RING,SV_RING_FREE_ACTION,(AM_NO_FIXED_ART | AM_GOOD),1},
	{20,0,TV_RIBBON,SV_RIBBON,(AM_NO_FIXED_ART | AM_GOOD | AM_GREAT),1},
	{20,0,TV_CHEST,SV_CHEST_MARIPO_04,0L,1},

	//Hmف@SmbhAAEFC_Aύw
	{30,0,TV_ROD,SV_ROD_DETECTION,0L,1},
	{30,0,TV_CHEST,SV_CHEST_MARIPO_05,0L,1},
	{30,0,TV_RING,SV_RING_RES_CONFUSION,(AM_NO_FIXED_ART | AM_GOOD),1},

	//󕨌Ɂ@ϓŎwցA̋wցAXsbh
	{40,0,TV_CHEST,SV_CHEST_MARIPO_12,0L,1},
	{40,0,TV_CHEST,SV_CHEST_BYAKUREN,0L,1},
	{40,0,TV_ROD,SV_ROD_SPEED,0L,1},

	//N[@VA򔠁AσJIXw
	{50,0,TV_CHEST,SV_CHEST_CLONE,0L,1},
	{50,0,TV_CHEST,SV_CHEST_EIRIN,0L,1},
	{50,0,TV_RING,SV_RING_RES_CHAOS,(AM_NO_FIXED_ART | AM_GOOD),1},

	//Â@VAdAj̏
	{60,0,TV_CHEST,SV_CHEST_OLDCASTLE,0L,1},
	{60,0,TV_CHEST,SV_CHEST_MARIPO_14,0L,1},
	{60,0,TV_CHEST,SV_CHEST_MARIPO_19,0L,1},

	//t@̖*2AepXA~Al
	{70,0,TV_POTION,SV_POTION_AUGMENTATION,0L,2},
	{70,0,TV_AMULET,SV_AMULET_TELEPATHY,(AM_NO_FIXED_ART | AM_GOOD),1},
	{70,0,TV_CHEST,SV_CHEST_SATORI,0L,1},

	//l@j׃A~AHߔAXs
	{80,0,TV_CHEST,SV_CHEST_GRASSROOT,0L,1},
	{80,0,TV_CHEST,SV_CHEST_MARIPO_23,0L,1},
	{80,0,TV_CHEST,SV_CHEST_FAIRY,0L,1},

	//GbN@R̕΁AAo[ÅZA
	{90,ART_JUDGE,0,0,0L,1},
	{90,ART_AMBER,0,0,0L,1},
	{90,0,TV_CHEST,SV_CHEST_HECATIA,0L,1},
	{90,0,TV_CHEST,SV_CHEST_SEIJA,0L,1},


	{0,0,0,0,(0L),0}, //I[_~[

};



/*:::ebp[^e[u zYesvalɑΉ*/
//object_prep()Ƃ̐lobject_typelɊi[AACT_GUN_VARIABLEɂĎˌƂ̌ʂo
//GS⁙̂Ƃ̒l{Ƃď
//GFType,ProjectType,charge,bullets

//Fcharge*bulletsl32ȉɂȂȂƂȂBڍׂdo_cmd_fire_gun_aux()
const gun_base_param_type gun_base_param_table[SV_FIRE_GUN_MAX+1] =
{
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,0,1}, //n_p_~[
	{GF_MISSILE,GUN_FIRE_MODE_BOLT,2,7}, //ieBbNK
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,8,1}, //e
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,3,6}, //e
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,6,4}, //e

	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,3,6}, //ie
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,8,1}, //}XPbge

	{GF_SHARDS,GUN_FIRE_MODE_BREATH,7,1}, //Uee
	{GF_ARROW,GUN_FIRE_MODE_DEFAULT,4,5}, //}Oi
	{GF_LITE,GUN_FIRE_MODE_BEAM,6,3}, //e
	{GF_ROCKET,GUN_FIRE_MODE_ROCKET,12,1}, //P
};



//GF_XXXƑ{ΉtBd͂Ȃق
const cptr gf_desc_name[MAX_GF] =
{
	"(Ȃ)",
	"d","","_","C","Ή",
	"(ݒ)","(ݒ)","(ݒ)","̌","",
	"ˌ","vY}","(ݒ)","","M",
	"Í","M","Í","(ݒ)","j",
	"","","C","x","(ݒ)",
	"","覐","Ɋ","(ݒ)","JIX",
	//30
	"n","","ʍ","ԋt]","d",
	"(ݒ)","(ݒ)","(ݒ)","(ݒ)","ΗnH",
	"hAj","㩔j","(ݒ)","(ݒ)","Εǐ",
	"hA","㩐","Xѐ","(ݒ)","(ݒ)",
	"N[","`FW","񕜃X^[","","",
	"","","͋z","(ݒ)","(ݒ)",
	//60
	"҃AEFC","׈AEFC","e|AEFC","ҋ|","׈|",
	"|","AfbhގU","","","ގU",
	"_[W","Pbg","jM","[","",
	"Εǐ","̌","NO","","n̍",
	"","","Җ","","_g",
	"_z","eLlVX","{","_xz","Pǃ_[W",
	//90
	"͋z","_U","]U","1","2",
	"3","4","jł̎","ߊl","ҕ",
	"Җ","ӎ","(ʏU)","f","E",
	"Be","","n␶","̎","V[J[C",
	"X[p[C","*̗͉*","","","׈",
	"","Ԙc","RY~bNz[","j1","j2",
	//120
	"j3","j4","","","ƂăhJ[",
	"̐n","IC","_","","߈",
	"\EXeB[","","d","dގU","m[UEBi[",
	"Ԕ؊1","N.E.P","󓃃r[","Ԕ؊2","",
	"O̖","Ԕ","ʕω","[[","bh}WbN",
	"OOj","hAω","","炵","֓炵",
	//150
	"炵","w偂̑","M","uCWOX^[","\EXJv`A",
	"","C","r["
};


/*:::puيEƂ̐ڐGv̒n`tOƃX^[̑Ή\@قǗDx*/
occult_contact_type occult_contact_table[] = 
{
	{FF_PATTERN,0,			0,		MON_LESSER_O_G,	"up^[vΉԂU炵A"},//bT[AU[Sbh@p^[
	{FF_OPEN,	FF_DROP,	0,		MON_FLUTIST,"J[eJ"},//t[gtҁ@J[e
	{FF_WATER,	FF_DEEP,	0,		MON_SPAWN_CTH,	"Â̒ꂩ"},//NgDt̗Ƃq@[
	{FF_DOOR,	0,			0,		MON_TINDALOS,	"hAg̊p"},//eB_X@hA
	{FF_TREE,	0,			0,		MON_SPAWN_SHUB,"؁X̊Ԃ"},//Vu=jOX̍eRrFX

	{FF_SHAFT,	0,			0,		MON_SHOGGOTH,"ÂB̉"},//VSXFB
	{FF_TRAP,	FF_MORE,	0,		MON_FLYING_POLYP,"Ƃ˂̉"},//Ӗڂ̂́@Ƃ˂ƊKi
	{FF_STAIRS,	FF_MORE,	0,		MON_FLYING_POLYP,"Kỉ"},
	{FF_WATER,	FF_DEEP,	0,		MON_DEEP_ONE,	"Â̒ꂩ"},//[́@[

	{FF_CAN_DIG,	0,		0,		MON_LLOIGOR,"̌Ԃ"},//CK[F
	{FF_LAVA,	FF_DEEP,	0,		MON_CHTHONIAN,"n̒"},//Ng[jAF[n

	{FF_MOUNTAIN,	0,		0,		MON_NIGHTGAUNT,	"R̂قê悤Ȃ̂򗈂A"},//SFR
	{FF_MOUNTAIN,	0,		0,		MON_MI_GO,	"R琁ɏ"},//~SEFR
	{FF_CAN_FLY,	0,		FF_MOVE,MON_COLOUR_OUTOFSPACE	,"Â̒"},//َ̐FʁFÂ@͎̏RĂ͂܂̂ŎR̉

	{0,0,0,0,"I[p_~["},//r_idx0Ȃ烋[vI
};

//v1.1.21
/*:::mxAbvŏKZ\̈ꗗ*/
soldier_skill_type soldier_skill_table[SOLDIER_SKILL_ARRAY_MAX][SOLDIER_SKILL_NUM_MAX+1]=
{
	{	//ˌZ\
		{0,"ˌZ\","n[_~["},//_~[name̓_vo͎Ɏg
		{0,"ˌ","x5ȍ~ɓGZԌEZuˌvgp\ɂȂB"},
		{0,"z[NAC","e̐㏸A̎F̔\͂𓾂B"},
		{0,"wbhVbg","ZuwbhVbgvgp\ɂȂB"},
		{0,"NCbNh[","eɂˌɗvsԂ25%ZkAȇύXɗvsԂ50%ZkB"},
		{0,"eiX","łȂeɑ΂Ă1/2̑xőes悤ɂȂB"},
		{0,"AˋZ\","Zusbht@CAvgp\ɂȂB"},
		{35,"EF|}X^[","ˌ̖ɏ㏸A\\ЎŏeeƂ̃yieBቺB"},
		{40,"C^[Zv^[","Ɍĕꂽ{[⃍Pbg𒆊mŌƂ悤ɂȂB\\{gEr[EuXɂ͌ʂȂBPbg`[ȊȌe𑕔ĂƂłȂƎgȂB"},
		{45,"}A[~[","ee̕[啝ɍB"},

	},
	{	//Z\
		{0,"Z\","n[_~["},
		{0,"Zip","Z̑ƓɃ_CX{[iX𓾂B"},
		{0,"b̗͌","ŕEpEϋv͂+2B"},
		{0,"ߐڎˌZp","X^[ɎߋŎˌƂNeBJqbg₷ȂB"},
		{0,"ꌂE@","אڍÛƈuŗEZuqbgAEFCvgp\ɂȂB"},
		{0,"nB","G|ƂMP񕜂悤ɂȂB"},
		{0,"BsZp","B\͂㏸B܂ĂGɋߐڍUsƂ_[W^悤ɂȂB"},
		{35,"ɌKZp","ZuSϐvg悤ɂȂB"},
		{40,"]","ꎞIɉƋmƓ̋𓾂uAhiRg[vgp\ɂȂB"},
		{45,"[TEF|","ACƋߐڍU\͂㏸AHPől10%㏸AߐڍU񐔂+1B"},

	},
	{	//HZ\
		{0,"HZ\","n[_~["},
		{0,"HZp","E@Z\㏸B\\܂x5ȍ~ɓZugbvEhAjvg悤ɂȂB"},
		{0,"Zp","TZ\㏸B\\܂x10ɂȂƁuӒvg悤ɂȂB"},
		{0,"QZp","אڂꂩΒn`ɂuoP[hݒuvgp\ɂȂB"},
		{0,"|[^ݒu","tȀɓӏ܂Ń|[^n`ݒułA|[^ԂړłB\\e|[gWQ̌ʂ󂯂ȂB\\Oӏڈȍ~ݒu悤ƂƌÂ|[^珇ɏB"},
		{0,"jZp","eݒuBe10Q[^[ɔ͂ɔjБ_[W^B\\_[W󂯂̂ŒӁB"},
		{0,"^p","MPől50%㏸B"},
		{35,"KNbV","ӂ*j*B"},
		{40,"","ëЗ͂1.5{ɂȂ蔚ja4ObhɂȂB"},
		{45,"Ζ","jЖƉu𓾂B܂ݒueRNł悤ɂȂB"},

	},
	{	//eZ\
		{0,"eZ\","n[_~["},
		{0,"_̊","x5œZuXLEX^[vg悤ɂȂB\\܂ZuGv͈̔͂LB"},
		{0,"fe","ύXĎˌueeύXv̓Zgp\ɂȂB\\uΉevuXevudevunev̎l̏eegB"},
		{0,"̒m","m\ƌ+2AZ\㏸B"},
		{0,"Z\","XɂƂBZ\㏸B\\̂ƂߐڍUˌsƃNeBJqbg㏸B"},
		{0,"ʑe","ZueeύXvɁA\\uMevuzevuՌevud͒evǉB"},
		{0,"_Z\","Zu_WvKB"},
		{35,"Βe","fތnACeeۂɂueۉHv̓Zgp\ɂȂA\\ueeύXvł̒eۂgpċ͂Ȏˌ邱ƂłB"},
		{40,"iCgrW","Èłł悤ɂȂB\\ÈłŋߐڍUeɂˌsƂNeBJqbg㏸B\\EɗȂX^[ɂ͌ʂB"},
		{45,"e̎ˎ","ˌƑSĂ̎ˌ̃NeBJqbgl啝ɑB\\܂A[eBt@Ngue̎ˎv_WƎ͂̓G̐ɉċB"},

	},

};


/*:::m̒eۊe[u*/
//zYp_ptr->magic_num1[]̓YSSM_***ɈvAce̊ǗɎgB
//cost,name,info,change_bullet,use_ammo
soldier_bullet_type soldier_bullet_table[] =
{
	{0,"n[_~[","",0},

	//̓ZSSM_ƃ_~[**
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},

	//11-14 ΉAXAde
	{8,"Ήe","З2{̉ΉɂȂB",SS_M_ELEM_BULLET},
	{8,"Xe","З2{̗CɂȂB",SS_M_ELEM_BULLET},
	{8,"de","З2{̓dɂȂB",SS_M_ELEM_BULLET},
	{8,"ne","З2{̎_ɂȂB",SS_M_ELEM_BULLET},
	//15-18 
	{24,"Me","MɎアG3{̃_[W^A𖾂邭锼a2̃PbgɂȂB",SS_M_HIGH_BULLET},
	{24,"ze","͋z̃{gɂȂB˂ȂB",SS_M_HIGH_BULLET},
	{24,"Ռe","̃r[ɂȂB",SS_M_HIGH_BULLET},
	{24,"d͒e","d͑̔a2̃{[ɂȂB",SS_M_HIGH_BULLET},
	//19-30\
	{0,"_~[","",0},
	{0,"_~[","",0},

	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	{0,"_~[","",0},
	//31-48Βe
	{0,"ғŒe","З3{̓őɂȂB",SS_M_MATERIAL_BULLET},
	{0,"bE̒e","bɑ΂ĈЗ͂3{ɂȂNeBJqbg㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"͒e","ɑ΂ĈЗ͂3{ɂȂNeBJqbg㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"j̒e","dEAfbhEf[ɑ΂ĈЗ͂2{ɂȂB\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"̒e","lԂɑ΂ĈЗ͂3{ɂȂNeBJqbg啝ɏ㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"z̒e","s郂X^[ɑ΂ĈЗ͂2{ɂȂNeBJqbg㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"̒e","ׂ̐͂ɈЗ1.5{A\\dEAfbhEf[ɑ΂ĈЗ͂3{ɂȂB\\NeBJqbg㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"dʒe","З2{̒ʏ̎ˌɂȂB\\NeBJqbg㏸B˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"hSuXe","3{̈З͂̃uXɂȂB",SS_M_MATERIAL_BULLET},
	{0,"̒e","З3{̋ɊPbgɂȂB",SS_M_MATERIAL_BULLET},
	{0,"E̒e","ɑ΂ĈЗ͂3{ɂȂNeBJqbg啝ɏ㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"_E̒e","_iɑ΂ĈЗ͂3{ɂȂNeBJqbg啝ɏ㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"̒e","n̋ƉΎ_̃X^[ɑ΂ĈЗ͂3{ɂȂNeBJqbg㏸B\\{gł˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"Ȃe","З3{̔jבPbgɂȂB",SS_M_MATERIAL_BULLET},
	{0,"^g̒e","З5{̉Ήr[ɂȂB",SS_M_MATERIAL_BULLET},
	{0,"e","З4{̌̌̃r[ɂȂB",SS_M_MATERIAL_BULLET},
	{0,"e","З4{̒ʏˌɂȂB\\NeBJqbg啝ɏ㏸B˂ȂB",SS_M_MATERIAL_BULLET},
	{0,"F̒e","З10{̕𑮐^r[ɂȂB",SS_M_MATERIAL_BULLET},




	{-1,"I[_~[","",0},
};

/*:::m̒eۍ쐬e[u*/
//SSM_*,mat_tval,mat_sval,prod_num
soldier_bullet_making_type soldier_bullet_making_table[] =
{
	{SSM_SLAY_ANIMAL,TV_MATERIAL,SV_MATERIAL_HEMATITE,1},
	{SSM_SLAY_NONLIV,TV_MATERIAL,SV_MATERIAL_MAGNETITE,1},
	{SSM_POIS,TV_MATERIAL,SV_MATERIAL_ARSENIC,2},
	{SSM_SILVER,TV_MATERIAL,SV_MATERIAL_MERCURY,2},
	{SSM_SILVER,TV_MATERIAL,SV_MATERIAL_MITHRIL,2},
	{SSM_HEAVY,TV_MATERIAL,SV_MATERIAL_ADAMANTITE,2},
	{SSM_BREATH,TV_MATERIAL,SV_MATERIAL_DRAGONNAIL,2},
	{SSM_SLAY_DRAGON,TV_MATERIAL,SV_MATERIAL_DRAGONSCALE,2},
	{SSM_POIS,TV_MATERIAL,SV_MATERIAL_GELSEMIUM,3},

	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_GARNET,1},
	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_AMETHYST,1},
	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_AQUAMARINE,1},

	{SSM_DIAMOND,TV_MATERIAL,SV_MATERIAL_DIAMOND,1},

	{SSM_HOLY,TV_MATERIAL,SV_MATERIAL_EMERALD,1},
	{SSM_SLAY_ANIMAL,TV_MATERIAL,SV_MATERIAL_MOONSTONE,1},
	{SSM_RED,TV_MATERIAL,SV_MATERIAL_RUBY,1},
	{SSM_SLAY_FLYER,TV_MATERIAL,SV_MATERIAL_PERIDOT,1},
	{SSM_HOLY,TV_MATERIAL,SV_MATERIAL_SAPPHIRE,1},
	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_OPAL,1},
	{SSM_SLAY_FLYER,TV_MATERIAL,SV_MATERIAL_TOPAZ,1},
	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_LAPISLAZULI,1},

	{SSM_METEOR,TV_MATERIAL,SV_MATERIAL_METEORICIRON,1},
	{SSM_HIHIIROKANE,TV_MATERIAL,SV_MATERIAL_HIHIIROKANE,1},
	{SSM_ICE,TV_MATERIAL,SV_MATERIAL_ICESCALE,1},

	{SSM_NIGHTMARE,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1},
	{SSM_HOLY,TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,1},
	{SSM_SLAY_DEITY,TV_MATERIAL,SV_MATERIAL_IZANAGIOBJECT,1},
	{SSM_SLAY_HUMAN,TV_MATERIAL,SV_MATERIAL_ISHIZAKURA,1},
	{SSM_SLAY_EVIL,TV_MATERIAL,SV_MATERIAL_BROKEN_NEEDLE,1},

	{0,0,0,0},//I[_~[
};

torrent_quest_score_type torrent_quest_score_list[] =
{
	{300,CLASS_WAKASAGI,-1,"킩P"},
	{600,CLASS_KOMACHI,-1,"ˁ@"},
	{1500,CLASS_NITORI,-1,"͏@ɂƂ"},
	{2400,CLASS_SHINMYOUMARU,CLASS_SHINMYOU_2,"@j"},

};

//v1.1.32 NXƓꐫi
const player_seikaku seikaku_info_special[MAX_SEIKAKU_SPECIAL] =
{
	//͓ꐫiIłȂNXp̃_~[
	{
		"(pi)",
		"(pi)",
		"Ordinary",
		{  0,  0,  0,  0,  0,  0 },
		0,  0,  0,  0,  0,  0,  0,  0,
		0, 0
		,TRUE
	},
	//v1.1.32 `mp
	{
		"Ă",
		"Ă",
		"Sunburnt",
		{  3,  3,  3,  3,  3,  3 },
		5,  5,  5,  0,  5,  5,  30,  30,
		5, 0
		,FALSE
	},
	//v1.1.32b p`[p
	{
		"s",
		"s",
		"bibliomaniac",
		{ -2,  2,  2,  -2,  -2,  0 },
		-5,  5,  5,  -2,  -5,  -5,  -50,  -50,
		-2, 1
		,FALSE
	},
	//v1.1.34 p
	{
		"RȂDI",
		"RȂDI",
		"Favorite",
		{  1,  -1,  0,  1,  1,  0 },
		-20,  5,  -5,  -2,  -20,  0,  20,  20,
		2, 0
		,FALSE
	},
	//v1.1.44 ǂ񂰐p
	{
		"̐E",
		"̐E",
		"Dreamdweller",
		{ 1,  -1,  -1,  1,  1,  -1 },
		0,  0, 0, -2, 0,  0,  10,  10,
		0, 0
		,FALSE
	},
	//v1.1.52 俎qp
	{
		"ɔY܂",
		"ɔY܂",
		"Violetdetector",
		{ 0,  0,  0,  0,  0,  0 },
		0,  0, 0, 0, 0,  0,  0,  0,
		0, 0
		,FALSE
	},

};

cptr skill_exp_desc[SKILL_EXP_MAX] =
{
	"i","","n","񓁗","",
	"()","()","()","()","()",
	"Z","","","݊","_",
	"","","","|","NX{E",
	"e"
};



//v1.1.51	u̐Eɍs()vR}hŌ閲̑I
//desc,need_points,level,min,max
const nightmare_stage_type	nightmare_stage_table[NIGHTMARE_DIARY_STAGE_LEV_MAX] =
{
	{ "j",0,10,50 ,500 },
	{ "j",300,20,500,2000 },
	{ "Ηj",3000,30,2000,8000 },
	{ "j",20000,40,8000,20000 },
	{ "ؗj",50000,50,20000,40000 },
	{ "j",150000,60,40000,80000 },
	{ "yj",300000,70,80000,120000 },
	{ "^̈",1000000,100,240000,999999 },//lev100-127܂ŕϓ
};


//v1.1.51	u̐Eɍs()vR}hŕVt[o[ACeɋL镶̕i
//r_idx,class_idx,conj1,phrase,conj2,position
//eLƂɁu10ȏvƁu1`9vpositionlŒݒ肵Ȃƃt[Y̌ɂȂ\
//5l킹Đڑ25ȓɐ̂ł܂蒷̂𑝂₳Ȃ
const nightmare_spellname_type	nightmare_spellname_table[] =
{
	{MON_RUMIA,CLASS_RUMIA,NULL,"~bhiCg",NULL,15},
	{ MON_RUMIA,CLASS_RUMIA,NULL,"_[NTCh","IuU",20 },
	{ MON_RUMIA,CLASS_RUMIA,NULL,"C",NULL,7 },
	{ MON_RUMIA,CLASS_RUMIA,"IuU","[",NULL,0 },

	{ MON_CIRNO,CLASS_CIRNO,NULL,"ACVN",NULL,16 },
	{ MON_CIRNO,CLASS_CIRNO,NULL,"p[tFNg",NULL,16 },
	{ MON_CIRNO,CLASS_CIRNO,NULL,"Ⓚ@",NULL,0 },
	{ MON_CIRNO,CLASS_CIRNO,NULL,"tFA[",NULL,12 },

	{ MON_MEIRIN,CLASS_MEIRIN,NULL,"ZMl",NULL,16 },
	{ MON_MEIRIN,CLASS_MEIRIN,NULL,"X",NULL,0 },
	{ MON_MEIRIN,CLASS_MEIRIN,NULL,"nV",NULL,12 },
	{ MON_MEIRIN,CLASS_MEIRIN,NULL,"Ɍ",NULL,0 },

	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"㋉",NULL,0 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"","",20 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"AOj",NULL,18 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"WF[tBbV",NULL,18 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"tHXg",NULL,18 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"Gh",NULL,18 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"tA",NULL,0 },
	{ MON_PATCHOULI,CLASS_PATCHOULI,NULL,"Zi",NULL,7 },

	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"El",NULL,6 },
	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"閶","",25 },
	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"Ct[V",NULL,12 },
	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"ft[V",NULL,12 },
	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"WbN","EUE",12 },
	{ MON_SAKUYA,CLASS_SAKUYA,"UE","[h",NULL,0 },
	{ MON_SAKUYA,CLASS_SAKUYA,"","E",NULL,0 },
	{ MON_SAKUYA,CLASS_SAKUYA,NULL,"",NULL,14 },

	{ MON_REMY,CLASS_REMY,NULL,"X^[","Iu",16 },
	{ MON_REMY,CLASS_REMY,NULL,"V[g",NULL,0 },
	{ MON_REMY,CLASS_REMY,NULL,"}WbN",NULL,0 },
	{ MON_REMY,CLASS_REMY,NULL,"c",NULL,18 },
	{ MON_REMY,CLASS_REMY,NULL,"s",NULL,15 },
	{ MON_REMY,CLASS_REMY,NULL,"}Cn[g",NULL,14 },
	{ MON_REMY,CLASS_REMY,NULL,"XNu",NULL,5 },
	{ MON_REMY,CLASS_REMY,NULL,"S",NULL,0 },
	{ MON_REMY,CLASS_REMY,NULL,"~jA","",21 },

	{ MON_F_SCARLET,CLASS_FLAN,NULL,"JSJS",NULL,5 },
	{ MON_F_SCARLET,CLASS_FLAN,"","H",NULL,7 },
	{ MON_F_SCARLET,CLASS_FLAN,"","ȂȂ邩H",NULL,0 },
	{ MON_F_SCARLET,CLASS_FLAN,NULL,"ւꂽ",NULL,20 },

	{ MON_LETTY,CLASS_LETTY,NULL,"e[u",NULL,10 },
	{ MON_LETTY,CLASS_LETTY,NULL,"R[h",NULL,12 },
	{ MON_LETTY,CLASS_LETTY,NULL,"Xibv",NULL,7 },
	{ MON_LETTY,CLASS_LETTY,NULL,"ECi[",NULL,3 },

	{ MON_CHEN,CLASS_CHEN,NULL,"",NULL,4 },
	{ MON_CHEN,CLASS_CHEN,NULL,"",NULL,8 },
	{ MON_CHEN,CLASS_CHEN,NULL,"",NULL,16 },
	{ MON_CHEN,CLASS_CHEN,NULL,"",NULL,12 },

	{ MON_ALICE,CLASS_ALICE,NULL,"",NULL,12 },
	{ MON_ALICE,CLASS_ALICE,NULL,"","",20 },
	{ MON_ALICE,CLASS_ALICE,NULL,"݂",NULL,6 },
	{ MON_ALICE,CLASS_ALICE,NULL,"ʌ","",12 },
	{ MON_ALICE,CLASS_ALICE,NULL,"h[Y",NULL,16 },
	{ MON_ALICE,CLASS_ALICE,NULL,"X[TCh",NULL,16 },

	{ MON_LUNASA,CLASS_LUNASA,NULL,"R[",NULL,8 },
	{ MON_LUNASA,CLASS_LUNASA,"E","\Cu",NULL,0 },
	{ MON_LUNASA,CLASS_LUNASA,NULL,"mCY",NULL,12 },
	{ MON_LUNASA,CLASS_LUNASA,NULL,"t@g",NULL,15 },

	{ MON_MERLIN,CLASS_MERLIN,NULL,"t@^Y",NULL,3 },
	{ MON_MERLIN,CLASS_MERLIN,NULL,"qm",NULL,16 },
	{ MON_MERLIN,CLASS_MERLIN,NULL,"\E",NULL,16 },
	{ MON_MERLIN,CLASS_MERLIN,NULL,"vY",NULL,18 },

	{ MON_LYRICA,CLASS_LYRICA,NULL,"vY",NULL,18 },
	{ MON_LYRICA,CLASS_LYRICA,NULL,"J","E",22 },
	{ MON_LYRICA,CLASS_LYRICA,NULL,"",NULL,0 },
	{ MON_LYRICA,CLASS_LYRICA,NULL,"_t",NULL,3 },

	{ MON_YOUMU,CLASS_YOUMU,NULL,"a",NULL,1 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"a",NULL,1 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"a",NULL,1 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"M",NULL,1 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"SR{","",14 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"",NULL,22 },
	{ MON_YOUMU,CLASS_YOUMU,NULL,"őa",NULL,0 },

	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"|Wg","EIuE",21 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"ҕK","",24 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"S[Xg",NULL,12 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"n","",11 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"","",14 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"i",NULL,0 },
	{ MON_YUYUKO,CLASS_YUYUKO,NULL,"s",NULL,18 },

	{ MON_RAN,CLASS_RAN,NULL,"ϒKd",NULL,15 },
	{ MON_RAN,CLASS_RAN,NULL,"AeBbg",NULL,18 },
	{ MON_RAN,CLASS_RAN,NULL,"ufBXg",NULL,8 },
	{ MON_RAN,CLASS_RAN,NULL,"`[~O",NULL,2 },
	{ MON_RAN,CLASS_RAN,NULL,"-Illusion-",NULL,0 },
	{ MON_RAN,CLASS_RAN,NULL,"ϋK","",18 },

	{ MON_YUKARI,CLASS_YUKARI,NULL,"ƌ","",18 },
	{ MON_YUKARI,CLASS_YUKARI,NULL,"",NULL,4 },
	{ MON_YUKARI,CLASS_YUKARI,"","_B",NULL,0 },
	{ MON_YUKARI,CLASS_YUKARI,NULL,"Tɐ",NULL,14 },
	{ MON_YUKARI,CLASS_YUKARI,NULL,"͓I","",14 },
	{ MON_YUKARI,CLASS_YUKARI,NULL,"{",NULL,0 },
	{ MON_YUKARI,CLASS_YUKARI,"","",NULL,0 },
	{ MON_YUKARI,CLASS_YUKARI,NULL,"Ԃpw",NULL,20 },

	{ MON_WRIGGLE,CLASS_WRIGGLE,NULL,"n","",20 },
	{ MON_WRIGGLE,CLASS_WRIGGLE,NULL,"Xg[",NULL,3 },
	{ MON_WRIGGLE,CLASS_WRIGGLE,NULL,"iCgoO",NULL,12 },
	{ MON_WRIGGLE,CLASS_WRIGGLE,NULL,"GߊO","",30 },

	{ MON_MYSTIA,CLASS_MYSTIA,NULL,"","",15 },
	{ MON_MYSTIA,CLASS_MYSTIA,NULL,"^钆","",25 },
	{ MON_MYSTIA,CLASS_MYSTIA,NULL,"\O",NULL,3 },
	{ MON_MYSTIA,CLASS_MYSTIA,NULL,"_Cu",NULL,5 },
	{ MON_MYSTIA,CLASS_MYSTIA,NULL,"_u",NULL,0 },

	{ MON_KEINE,CLASS_KEINE,NULL,"NCVX",NULL,0 },
	{ MON_KEINE,CLASS_KEINE,NULL,"qXg[",NULL,4 },
	{ MON_KEINE,CLASS_KEINE,NULL,"20XXN","@",32 },
	{ MON_KEINE,CLASS_KEINE,NULL,"s~bh",NULL,5 },
	{ MON_KEINE,CLASS_KEINE,NULL,"z",NULL,15 },

	{ MON_TEWI,CLASS_TEWI,NULL,"","",15 },
	{ MON_TEWI,CLASS_TEWI,"","fe",NULL,12 },
	{ MON_TEWI,CLASS_TEWI,"","",NULL,7 },

	{ MON_UDONGE,CLASS_UDONGE,NULL,"}Ch",NULL,12 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"ieBbN",NULL,18 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"ieBbN",NULL,18 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"ieBbN",NULL,18 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"Pbg","ECE",12 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"t[",NULL,2 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"o[W",NULL,6 },
	{ MON_UDONGE,CLASS_UDONGE,NULL,"p",NULL,12 },

	{ MON_EIRIN,CLASS_EIRIN,NULL,"Q[",NULL,1 },
	{ MON_EIRIN,CLASS_EIRIN,NULL,"A|",NULL,16 },
	{ MON_EIRIN,CLASS_EIRIN,NULL,"ICJl",NULL,12 },
	{ MON_EIRIN,CLASS_EIRIN,NULL,"⒆","",22 },
	{ MON_EIRIN,CLASS_EIRIN,"","",NULL,0 },
	{ MON_EIRIN,CLASS_EIRIN,"","@",NULL,3 },

	{ MON_KAGUYA,CLASS_KAGUYA,NULL,"ܐF","",14 },
	{ MON_KAGUYA,CLASS_KAGUYA,NULL,"uAghS",NULL,16 },
	{ MON_KAGUYA,CLASS_KAGUYA,"","e","",18 },
	{ MON_KAGUYA,CLASS_KAGUYA,NULL,"t","",21 },
	{ MON_KAGUYA,CLASS_KAGUYA,"","C",NULL,4 },

	{ MON_MOKOU,CLASS_MOKOU,NULL,"E[",NULL,0 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"E[",NULL,14 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"tFjbNX",NULL,4 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"tFjbNX",NULL,16 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"Ēa",NULL,0 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"tW}",NULL,14 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"HPCm",NULL,4 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"","",16 },
	{ MON_MOKOU,CLASS_MOKOU,NULL,"TWF}","",16 },
	{ MON_MOKOU,CLASS_MOKOU,"","",NULL,0 },

	{ MON_SHIZUHA,CLASS_SHIZUHA,NULL,"t",NULL,4 },
	{ MON_SHIZUHA,CLASS_SHIZUHA,NULL,"tH[",NULL,12 },

	{ MON_MINORIKO,CLASS_MINORIKO,NULL,"I[^",NULL,12 },
	{ MON_MINORIKO,CLASS_MINORIKO,NULL,"XC[g|eg",NULL,8 },
	{ MON_MINORIKO,CLASS_MINORIKO,NULL,"H̋","",0 },
	{ MON_MINORIKO,CLASS_MINORIKO,"","̐S",NULL,0 },

	{ MON_HINA,CLASS_MINORIKO,NULL,"_l","",12 },
	{ MON_HINA,CLASS_MINORIKO,NULL,"obh",NULL,10 },
	{ MON_HINA,CLASS_MINORIKO,NULL,"~XtH[`",NULL,16 },
	{ MON_HINA,CLASS_MINORIKO,"","l`",NULL,1 },

	{ MON_NITORI,CLASS_NITORI,NULL,"āI",NULL,40 },
	{ MON_NITORI,CLASS_NITORI,NULL,"ׁI",NULL,40 },
	{ MON_NITORI,CLASS_NITORI,NULL,"͓","",12 },
	{ MON_NITORI,CLASS_NITORI,NULL,"̂с[",NULL,11 },
	{ MON_NITORI,CLASS_NITORI,NULL,"Kq",NULL,4 },
	{ MON_NITORI,CLASS_NITORI,NULL,"K",NULL,1 },

	{ MON_MOMIZI,CLASS_MOMIZI,NULL,"oCg",NULL,4 },
	{ MON_MOMIZI,CLASS_MOMIZI,NULL,"Ji",NULL,6 },
	{ MON_MOMIZI,CLASS_MOMIZI,NULL,"Cr[Y",NULL,16 },

	{ MON_SHAMEIMARU,CLASS_AYA,NULL,"_",NULL,16 },
	{ MON_SHAMEIMARU,CLASS_AYA,NULL,"T^",NULL,12 },
	{ MON_SHAMEIMARU,CLASS_AYA,NULL,"o[Xg",NULL,3 },
	{ MON_SHAMEIMARU,CLASS_AYA,NULL,"V~","",18 },
	{ MON_SHAMEIMARU,CLASS_AYA,NULL,"B",NULL,10 },


	{ MON_SANAE,CLASS_SANAE,"","",NULL,0 },
	{ MON_SANAE,CLASS_SANAE,NULL,"܍L",NULL,20 },
	{ MON_SANAE,CLASS_SANAE,NULL,"~N",NULL,15 },
	{ MON_SANAE,CLASS_SANAE,NULL,"t[c",NULL,5 },
	{ MON_SANAE,CLASS_SANAE,NULL,"㎚",NULL,16 },
	{ MON_SANAE,CLASS_SANAE,NULL,"Xl[NJ",NULL,3 },

	{ MON_KANAKO,CLASS_KANAKO,NULL,"GNXpfbh","E",18 },
	{ MON_KANAKO,CLASS_KANAKO,NULL,"IoV",NULL,3 },
	{ MON_KANAKO,CLASS_KANAKO,NULL,"_","",16 },
	{ MON_KANAKO,CLASS_KANAKO,"","",NULL,0 },
	{ MON_KANAKO,CLASS_KANAKO,NULL,"}Ee","EIuE",12 },

	{ MON_SUWAKO,CLASS_SUWAKO,NULL,"P",NULL,17 },
	{ MON_SUWAKO,CLASS_SUWAKO,NULL,"~ł܂",NULL,0 },
	{ MON_SUWAKO,CLASS_SUWAKO,NULL,"zK",NULL,23 },
	{ MON_SUWAKO,CLASS_SUWAKO,NULL,"",NULL,3 },
	{ MON_SUWAKO,CLASS_SUWAKO,"","ۂ܂",NULL,8 },

	{ MON_KISUME,CLASS_KISUME,NULL,"",NULL,14 },
	{ MON_KISUME,CLASS_KISUME,"","",NULL,8 },
	{ MON_KISUME,CLASS_KISUME,"","",NULL,3 },

	{ MON_YAMAME,CLASS_YAMAME,NULL,"Lv`[",NULL,12 },
	{ MON_YAMAME,CLASS_YAMAME,NULL,"J_^",NULL,16 },
	{ MON_YAMAME,CLASS_YAMAME,NULL,"[v",NULL,3 },
	{ MON_YAMAME,CLASS_YAMAME,NULL,"s","",22 },
	{ MON_YAMAME,CLASS_YAMAME,NULL,"Ma",NULL,6 },

	{ MON_PARSEE,CLASS_PARSEE,NULL,"O[AC","h",14 },
	{ MON_PARSEE,CLASS_PARSEE,NULL,"X^[",NULL,6 },
	{ MON_PARSEE,CLASS_PARSEE,NULL,"V","",20 },
	{ MON_PARSEE,CLASS_PARSEE,NULL,"WFV[",NULL,13 },

	{ MON_YUGI,CLASS_YUGI,NULL,"lV`",NULL,40 },
	{ MON_YUGI,CLASS_YUGI,NULL,"]R",NULL,22 },
	{ MON_YUGI,CLASS_YUGI,NULL,"KE",NULL,9 },

	{ MON_SATORI,CLASS_SATORI,NULL,"o","",30 },
	{ MON_SATORI,CLASS_SATORI,NULL,"zN","-",40 },
	{ MON_SATORI,CLASS_SATORI,NULL,"e",NULL,20 },
	{ MON_SATORI,CLASS_SATORI,NULL,"}Ch",NULL,16 },

	{ MON_ORIN,CLASS_ORIN,NULL,"",NULL,16 },
	{ MON_ORIN,CLASS_ORIN,NULL,"",NULL,3 },
	{ MON_ORIN,CLASS_ORIN,NULL,"n","",22 },
	{ MON_ORIN,CLASS_ORIN,NULL,"Lbg",NULL,16 },
	{ MON_ORIN,CLASS_ORIN,NULL,"EH[N",NULL,7 },
	{ MON_ORIN,CLASS_ORIN,NULL,"",NULL,4 },

	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"s\",NULL,0 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"tA",NULL,3 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"K",NULL,10 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"MK",NULL,10 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"j[NA",NULL,16 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"t[W",NULL,3 },
	{ MON_UTSUHO,CLASS_UTSUHO,NULL,"nɊy",NULL,18 },

	{ MON_KOISHI,CLASS_KOISHI,NULL,"Ch","",16 },
	{ MON_KOISHI,CLASS_KOISHI,"","J",NULL,1 },
	{ MON_KOISHI,CLASS_KOISHI,NULL,"cl","",20 },
	{ MON_KOISHI,CLASS_KOISHI,"","Ă邼",NULL,0 },
	{ MON_KOISHI,CLASS_KOISHI,"","c",NULL,0 },
	{ MON_KOISHI,CLASS_KOISHI,NULL,"[Y",NULL,7 },

	{ MON_NAZRIN,CLASS_NAZRIN,NULL,"bh",NULL,3 },
	{ MON_NAZRIN,CLASS_NAZRIN,NULL,"yf",NULL,7 },
	{ MON_NAZRIN,CLASS_NAZRIN,NULL,"x",NULL,18 },
	{ MON_NAZRIN,CLASS_NAZRIN,NULL,"fBeN^[",NULL,0 },

	{ MON_KOGASA,CLASS_KOGASA,NULL,"炩",NULL,20 },
	{ MON_KOGASA,CLASS_KOGASA,NULL,"",NULL,22 },
	{ MON_KOGASA,CLASS_KOGASA,NULL,"YP","",16 },
	{ MON_KOGASA,CLASS_KOGASA,"EUE","C{[",NULL,0 },
	{ MON_KOGASA,CLASS_KOGASA,NULL,"sb`[Ԃ",NULL,4 },

	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"񂱂",NULL,12 },
	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"X}bV",NULL,2 },
	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"ڋ",NULL,5 },
	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"ⓚp","",22 },
	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"ɂ傫",NULL,7 },
	{ MON_ICHIRIN,CLASS_ICHIRIN,NULL,"ؗȂ",NULL,25 },

	{ MON_MURASA,CLASS_MURASA,NULL,"v",NULL,13 },
	{ MON_MURASA,CLASS_MURASA,NULL,"A",NULL,5 },
	{ MON_MURASA,CLASS_MURASA,NULL,"AJ[",NULL,3 },
	{ MON_MURASA,CLASS_MURASA,NULL,"H[ebNX",NULL,3 },
	{ MON_MURASA,CLASS_MURASA,NULL,"HD",NULL,17 },

	{ MON_SHOU,CLASS_SHOU,NULL,"^CK[",NULL,6 },
	{ MON_SHOU,CLASS_SHOU,NULL,"gW[",NULL,3 },
	{ MON_SHOU,CLASS_SHOU,NULL,"","",12 },
	{ MON_SHOU,CLASS_SHOU,NULL,"","",16 },

	{ MON_BYAKUREN,CLASS_BYAKUREN,"","I[",NULL,2 },
	{ MON_BYAKUREN,CLASS_BYAKUREN,NULL,"l",NULL,16 },
	{ MON_BYAKUREN,CLASS_BYAKUREN,NULL,"l",NULL,3 },
	{ MON_BYAKUREN,CLASS_BYAKUREN,"","@",NULL,1 },
	{ MON_BYAKUREN,CLASS_BYAKUREN,NULL,"@",NULL,5 },

	{ MON_NUE,CLASS_NUE,NULL,"UFOP",NULL,0 },
	{ MON_NUE,CLASS_NUE,NULL,"V","",24 },
	{ MON_NUE,CLASS_NUE,NULL,"̕s","",21 },
	{ MON_NUE,CLASS_NUE,NULL,"L",NULL,7 },
	{ MON_NUE,CLASS_NUE,NULL,"","",21 },
	{ MON_NUE,CLASS_NUE,NULL,"_[N",NULL,7 },
	{ MON_NUE,CLASS_NUE,NULL,"K","I",16 },

	{ MON_KYOUKO,CLASS_KYOUKO,NULL,"`[W","h",13 },
	{ MON_KYOUKO,CLASS_KYOUKO,NULL,"NC",NULL,7 },
	{ MON_KYOUKO,CLASS_KYOUKO,NULL,"]iX",NULL,6 },
	{ MON_KYOUKO,CLASS_KYOUKO,NULL,"XN[",NULL,3 },
	{ MON_KYOUKO,CLASS_KYOUKO,NULL,"O",NULL,2 },

	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"ȂȂ",NULL,18 },
	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"}[_[",NULL,2 },
	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"C[^[",NULL,3 },
	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"]r",NULL,12 },
	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"N[",NULL,4 },
	{ MON_YOSHIKA,CLASS_YOSHIKA,NULL,"fUCA",NULL,12 },

	{ MON_SEIGA,CLASS_SEIGA,NULL,"EH[",NULL,18 },
	{ MON_SEIGA,CLASS_SEIGA,NULL,"^I",NULL,12 },
	{ MON_SEIGA,CLASS_SEIGA,NULL,"ٓ",NULL,5 },
	{ MON_SEIGA,CLASS_SEIGA,NULL,"^L[",NULL,6 },

	{ MON_TOZIKO,CLASS_TOZIKO,NULL,"KSEW",NULL,14 },
	{ MON_TOZIKO,CLASS_TOZIKO,NULL,"TCN",NULL,5 },
	{ MON_TOZIKO,CLASS_TOZIKO,NULL,"gl[h",NULL,3 },


	{ MON_FUTO,CLASS_FUTO,"","V֏",NULL,0 },
	{ MON_FUTO,CLASS_FUTO,NULL,"","",18 },
	{ MON_FUTO,CLASS_FUTO,NULL,"","",16 },
	{ MON_FUTO,CLASS_FUTO,NULL,"",NULL,6 },
	{ MON_FUTO,CLASS_FUTO,NULL,"]",NULL,4 },
	{ MON_FUTO,CLASS_FUTO,NULL,"j","",18 },

	{ MON_MIKO,CLASS_MIKO,NULL,"鏈","",25 },
	{ MON_MIKO,CLASS_MIKO,NULL,"̏","",21 },
	{ MON_MIKO,CLASS_MIKO,NULL,"OZ",NULL,11 },
	{ MON_MIKO,CLASS_MIKO,NULL,"\","",12 },
	{ MON_MIKO,CLASS_MIKO,NULL,"[U[",NULL,8 },
	{ MON_MIKO,CLASS_MIKO,NULL,"䂱","",14 },
	{ MON_MIKO,CLASS_MIKO,NULL,"",NULL,6 },

	{ MON_WAKASAGI,CLASS_WAKASAGI,NULL,"EFCu",NULL,6 },
	{ MON_WAKASAGI,CLASS_WAKASAGI,NULL,"tBbV",NULL,7 },
	{ MON_WAKASAGI,CLASS_WAKASAGI,NULL,"XN[","Iu",16 },
	{ MON_WAKASAGI,CLASS_WAKASAGI,NULL,"Xbv",NULL,3 },

	{ MON_SEKIBANKI,CLASS_BANKI,NULL,"C",NULL,1 },
	{ MON_SEKIBANKI,CLASS_BANKI,NULL,"N",NULL,13 },
	{ MON_SEKIBANKI,CLASS_BANKI,NULL,"}`vPCeBu",NULL,16 },
	{ MON_SEKIBANKI,CLASS_BANKI,NULL,"wbh",NULL,5 },

	{ MON_KAGEROU,CLASS_KAGEROU,NULL,"ɉ삦",NULL,18 },
	{ MON_KAGEROU,CLASS_KAGEROU,NULL,"Et",NULL,8 },
	{ MON_KAGEROU,CLASS_KAGEROU,NULL,"t@O",NULL,6 },
	{ MON_KAGEROU,CLASS_KAGEROU,NULL,"t[",NULL,18 },

	{ MON_BENBEN,CLASS_BENBEN,NULL,"_","",15 },
	{ MON_BENBEN,CLASS_BENBEN,NULL,"XRA",NULL,4 },
	{ MON_BENBEN,CLASS_BENBEN,"","ATu",NULL,0 },
	{ MON_BENBEN,CLASS_BENBEN,NULL,"M",NULL,12 },

	{ MON_YATSUHASHI,CLASS_YATSUHASHI,NULL,"s","",13 },
	{ MON_YATSUHASHI,CLASS_YATSUHASHI,NULL,"ڗ",NULL,12 },
	{ MON_YATSUHASHI,CLASS_YATSUHASHI,"","c",NULL,3 },
	{ MON_YATSUHASHI,CLASS_YATSUHASHI,"","ً",NULL,5 },

		//ׂ͏oȂ

	{ MON_SHINMYOUMARU,CLASS_SHINMYOUMARU,"","l",NULL,5 },
	{ MON_SHINMYOUMARU,CLASS_SHINMYOUMARU,NULL,"O","",18 },
	{ MON_SHINMYOUMARU,CLASS_SHINMYOUMARU,"","傫Ȃ",NULL,0 },
	{ MON_SHINMYOUMARU,CLASS_SHINMYOUMARU,"","j",NULL,3 },
	{ MON_SHINMYOUMARU,CLASS_SHINMYOUMARU,NULL,"ړ˂",NULL,7 },

	{ MON_RAIKO,CLASS_RAIKO,NULL,"a",NULL,18 },
	{ MON_RAIKO,CLASS_RAIKO,"","{","",12 },
	{ MON_RAIKO,CLASS_RAIKO,NULL,"ff",NULL,10 },
	{ MON_RAIKO,CLASS_RAIKO,NULL,"p[JX",NULL,7 },
	{ MON_RAIKO,CLASS_RAIKO,NULL,"V[",NULL,3 },
	{ MON_RAIKO,CLASS_RAIKO,NULL,"r[g",NULL,5 },
	{ MON_RAIKO,CLASS_RAIKO,NULL,"E[t@[",NULL,8 },

	{ MON_KASEN,CLASS_KASEN,NULL,"hSY",NULL,16 },
	{ MON_KASEN,CLASS_KASEN,NULL,"OE",NULL,3 },
	{ MON_KASEN,CLASS_KASEN,NULL,"veEX",NULL,6 },
	{ MON_KASEN,CLASS_KASEN,NULL,"z[N",NULL,11 },


	{ MON_SUIKA,CLASS_SUIKA,NULL,"~bVO",NULL,16 },
	{ MON_SUIKA,CLASS_SUIKA,NULL,"p[",NULL,3 },
	{ MON_SUIKA,CLASS_SUIKA,NULL,"",NULL,0 },
	{ MON_SUIKA,CLASS_SUIKA,NULL,"XEH[",NULL,3 },
	{ MON_SUIKA,CLASS_SUIKA,NULL,"SS",NULL,16 },

	{ MON_IKU,CLASS_IKU,NULL,"h",NULL,4 },
	{ MON_IKU,CLASS_IKU,"","̔@",NULL,0 },
	{ MON_IKU,CLASS_IKU,NULL,"{̎g",NULL,16 },
	{ MON_IKU,CLASS_IKU,NULL,"GLe","",20 },

	{ MON_TENSHI,CLASS_TENSHI,"","",NULL,1 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"vX",NULL,4 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"Vn",NULL,19 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"Sl","",16 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"Sd","",16 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"ECzX","",15 },
	{ MON_TENSHI,CLASS_TENSHI,NULL,"v",NULL,12 },

	{ MON_KOKORO,CLASS_KOKORO,NULL,"|[bV",NULL,0 },
	{ MON_KOKORO,CLASS_KOKORO,NULL,"L[",NULL,10 },
	{ MON_KOKORO,CLASS_KOKORO,NULL,"{y",NULL,16 },
	{ MON_KOKORO,CLASS_KOKORO,NULL,"Í",NULL,12 },

	{ MON_MEDICINE,CLASS_MEDICINE,"","",NULL,5 },
	{ MON_MEDICINE,CLASS_MEDICINE,NULL,"JT","",15 },
	{ MON_MEDICINE,CLASS_MEDICINE,NULL,"KVO",NULL,12 },
	{ MON_MEDICINE,CLASS_MEDICINE,NULL,"K[f",NULL,0 },

	{ MON_YUUKA,CLASS_YUUKA,"","J",NULL,5 },
	{ MON_YUUKA,CLASS_YUUKA,NULL,"Ԓ",NULL,20 },

	{ MON_KOMACHI,CLASS_KOMACHI,NULL,"z","",16 },
	{ MON_KOMACHI,CLASS_KOMACHI,NULL,"qK",NULL,15 },
	{ MON_KOMACHI,CLASS_KOMACHI,"","",NULL,3 },
	{ MON_KOMACHI,CLASS_KOMACHI,NULL,"","܂",18 },

	{ MON_EIKI,CLASS_EIKI,NULL,"Xg",NULL,18 },
	{ MON_EIKI,CLASS_EIKI,NULL,"WbWg",NULL,0 },
	{ MON_EIKI,CLASS_EIKI,NULL,"\",NULL,10 },
	{ MON_EIKI,CLASS_EIKI,NULL,"ٔ",NULL,0 },
	{ MON_EIKI,CLASS_EIKI,NULL,"fr",NULL,20 },
	{ MON_EIKI,CLASS_EIKI,NULL,"",NULL,7 },

	{ MON_HATATE,CLASS_HATATE,NULL,"Ă",NULL,16 },
	{ MON_HATATE,CLASS_HATATE,NULL,"tpm}",NULL,12 },
	{ MON_HATATE,CLASS_HATATE,NULL,"Vbg",NULL,2 },
	{ MON_HATATE,CLASS_HATATE,NULL,"V",NULL,14 },
	{ MON_HATATE,CLASS_HATATE,NULL,"TCR",NULL,25 },
	{ MON_HATATE,CLASS_HATATE,NULL,"OtB",NULL,0 },
	{ MON_HATATE,CLASS_HATATE,NULL,"PC͂","",40 },

	{ MON_MAMIZOU,CLASS_MAMIZOU,NULL,"","",28 },
	{ MON_MAMIZOU,CLASS_MAMIZOU,"","||R",NULL,0 },
	{ MON_MAMIZOU,CLASS_MAMIZOU,NULL,"eω",NULL,6 },
	{ MON_MAMIZOU,CLASS_MAMIZOU,NULL,"MC",NULL,3 },
	{ MON_MAMIZOU,CLASS_MAMIZOU,"","ǂ",NULL,0 },

	{ MON_3FAIRIES,CLASS_3_FAIRIES,NULL,"tFA[",NULL,14 },
	{ MON_3FAIRIES,CLASS_3_FAIRIES,NULL,"I[o[hCu",NULL,0 },
	{ MON_3FAIRIES,CLASS_3_FAIRIES,NULL,"gv",NULL,16 },

	{ MON_SEIRAN,CLASS_SEIRAN,NULL,"t@Ri[",NULL,5 },
	{ MON_SEIRAN,CLASS_SEIRAN,NULL,"h[Vbg",NULL,0 },
	{ MON_SEIRAN,CLASS_SEIRAN,NULL,"C[O",NULL,16 },
	{ MON_SEIRAN,CLASS_SEIRAN,NULL,"ieBbN","K",8 },
	{ MON_SEIRAN,CLASS_SEIRAN,"","",NULL,0 },


	{ MON_RINGO,CLASS_RINGO,NULL,"_S",NULL,3 },
	{ MON_RINGO,CLASS_RINGO,NULL,"_S",NULL,12 },
	{ MON_RINGO,CLASS_RINGO,NULL,"Zveo[",NULL,20 },
	{ MON_RINGO,CLASS_RINGO,NULL,"t[",NULL,5 },
	{ MON_RINGO,CLASS_RINGO,NULL,"Oo",NULL,7 },

	{ MON_DOREMY,CLASS_DOREMY,"","",NULL,0 },
	{ MON_DOREMY,CLASS_DOREMY,"","",NULL,8 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"h[",NULL,16 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"h[",NULL,6 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"iCgA","EIuE",20 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"F","",22 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"F","",22 },
	{ MON_DOREMY,CLASS_DOREMY,NULL,"","",22 },


	{ MON_SAGUME,CLASS_SAGUME,"","",NULL,1 },
	{ MON_SAGUME,CLASS_SAGUME,NULL,"G","",16 },
	{ MON_SAGUME,CLASS_SAGUME,NULL,"@",NULL,0 },
	{ MON_SAGUME,CLASS_SAGUME,NULL,"_X","",12 },
	{ MON_SAGUME,CLASS_SAGUME,"","",NULL,5 },

	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,NULL,"w",NULL,15 },
	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,NULL,"n","",15 },
	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,NULL,"GNvX",NULL,1 },
	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,NULL,"CtFm",NULL,5 },
	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,NULL,"tbV","Ah",18 },
	{ MON_CLOWNPIECE,CLASS_CLOWNPIECE,"Ah","XgCv",NULL,4 },

	{ MON_JUNKO,CLASS_JUNKO,"","",NULL,1 },
	{ MON_JUNKO,CLASS_JUNKO,NULL,"E","",30 },
	{ MON_JUNKO,CLASS_JUNKO,NULL,"","Ȃ",18 },
	{ MON_JUNKO,CLASS_JUNKO,NULL,"sA[",NULL,22 },
	{ MON_JUNKO,CLASS_JUNKO,NULL,"mɈŎE",NULL,18 },

	{ MON_HECATIA1,CLASS_HECATIA,NULL,"mCfA",NULL,18 },
	{ MON_HECATIA1,CLASS_HECATIA,NULL,"RY~bN",NULL,18 },

	{ MON_HECATIA2,CLASS_HECATIA,"","~J",NULL,1 },
	{ MON_HECATIA2,CLASS_HECATIA,NULL,"n","",14 },

	{ MON_HECATIA3,CLASS_HECATIA,NULL,"CpNg",NULL,1 },
	{ MON_HECATIA3,CLASS_HECATIA,"","ĂI",NULL,0 },

	{ MON_LARVA,CLASS_LARVA,NULL,"AQn","",20 },
	{ MON_LARVA,CLASS_LARVA,NULL,"^","",25 },
	{ MON_LARVA,CLASS_LARVA,NULL,"ؕ",NULL,3 },

	{ MON_NEMUNO,CLASS_NEMUNO,NULL,"RW","",20 },
	{ MON_NEMUNO,CLASS_NEMUNO,NULL,"S",NULL,6 },
	{ MON_NEMUNO,CLASS_NEMUNO,NULL,"}Ee",NULL,13 },
	{ MON_NEMUNO,CLASS_NEMUNO,NULL,"}[_[",NULL,3 },

	{ MON_AUNN,CLASS_AUNN,NULL,"R}",NULL,13 },
	{ MON_AUNN,CLASS_AUNN,NULL,"]",NULL,2 },
	{ MON_AUNN,CLASS_AUNN,NULL,"","",16 },

	{ MON_NARUMI,CLASS_NARUMI,NULL,"S[",NULL,8 },
	{ MON_NARUMI,CLASS_NARUMI,NULL,"n",NULL,8 },
	{ MON_NARUMI,CLASS_NARUMI,NULL,"Xgv",NULL,1 },
	{ MON_NARUMI,CLASS_NARUMI,NULL,"",NULL,15 },
	{ MON_NARUMI,CLASS_NARUMI,NULL,"",NULL,18 },

	{ MON_MAI,CLASS_MAI,NULL,"ou[",NULL,14 },
	{ MON_MAI,CLASS_MAI,NULL,"^io^",NULL,18 },
	{ MON_MAI,CLASS_MAI,NULL,"_X",NULL,4 },
	{ MON_MAI,CLASS_MAI,NULL,"_X",NULL,15 },

	{ MON_SATONO,CLASS_SATONO,NULL,"rnCh",NULL,18 },
	{ MON_SATONO,CLASS_SATONO,NULL,"Al[",NULL,3 },
	{ MON_SATONO,CLASS_SATONO,NULL,"_X",NULL,4 },
	{ MON_SATONO,CLASS_SATONO,NULL,"_X",NULL,15 },

	{ MON_OKINA,CLASS_OKINA,NULL,"}^[",NULL,12 },
	{ MON_OKINA,CLASS_OKINA,NULL,"hDbJ",NULL,5 },
	{ MON_OKINA,CLASS_OKINA,NULL,"Ö",NULL,18 },
	{ MON_OKINA,CLASS_OKINA,NULL,"","E",40 },
	{ MON_OKINA,CLASS_OKINA,"","ʖ",NULL,6 },
	{ MON_OKINA,CLASS_OKINA,NULL,"w","",23 },

	{ MON_JYOON,CLASS_JYOON,NULL,"o[",NULL,7 },
	{ MON_JYOON,CLASS_JYOON,NULL,"vbN",NULL,18 },
	{ MON_JYOON,CLASS_JYOON,NULL,"80's",NULL,22 },
	{ MON_JYOON,CLASS_JYOON,NULL,"NC[","Iu",16 },

	{ MON_SHION_1,CLASS_SHION,NULL,"",NULL,18 },
	{ MON_SHION_1,CLASS_SHION,NULL,"nR",NULL,13 },
	{ MON_SHION_1,CLASS_SHION,NULL,"",NULL,8 },

	{ MON_SHION_2,CLASS_SHION,NULL,"",NULL,18 },
	{ MON_SHION_2,CLASS_SHION,NULL,"nR",NULL,13 },
	{ MON_SHION_2,CLASS_SHION,NULL,"",NULL,8 },
	{ MON_SHION_2,CLASS_SHION,NULL,"ŋň","",23 },

	{ MON_SUMIREKO_2,CLASS_SUMIREKO,NULL,"Av",NULL,0 },
	{ MON_SUMIREKO_2,CLASS_SUMIREKO,NULL,"eLlVX",NULL,12 },
	{ MON_SUMIREKO_2,CLASS_SUMIREKO,NULL,"dg",NULL,8 },
	{ MON_SUMIREKO_2,CLASS_SUMIREKO,NULL,"G\ebN",NULL,17 },


	{ MON_REIMU,CLASS_REIMU,NULL,"z",NULL,16},
	{ MON_REIMU,CLASS_REIMU,NULL,"",NULL,3 },
	{ MON_REIMU,CLASS_REIMU,NULL,"E",NULL,7 },
	{ MON_REIMU,CLASS_REIMU,NULL,"w",NULL,2 },
	{ MON_REIMU,CLASS_REIMU,"","",NULL,22 },
	{ MON_REIMU,CLASS_REIMU,NULL,"",NULL,20 },
	{ MON_REIMU,CLASS_REIMU,NULL,"",NULL,5 },
	{ MON_REIMU,CLASS_REIMU,NULL,"т",NULL,12 },
	{ MON_REIMU,CLASS_REIMU,NULL,"j[h",NULL,5 },
	{ MON_REIMU,CLASS_REIMU,NULL,"Az",NULL,15 },
	{ MON_REIMU,CLASS_REIMU,NULL,"","",23 },
	{ MON_REIMU,CLASS_REIMU,"","Be֎~ł",NULL,0 },

	{ MON_MARISA,CLASS_MARISA,NULL,"}X^[",NULL,12 },
	{ MON_MARISA,CLASS_MARISA,NULL,"Xp[N",NULL,6 },
	{ MON_MARISA,CLASS_MARISA,NULL,"[U[",NULL,3 },
	{ MON_MARISA,CLASS_MARISA,NULL,"t@Ci",NULL,25 },
	{ MON_MARISA,CLASS_MARISA,NULL,"~L[",NULL,16 },
	{ MON_MARISA,CLASS_MARISA,NULL,"AXeCh",NULL,18 },
	{ MON_MARISA,CLASS_MARISA,NULL,"eI",NULL,5 },
	{ MON_MARISA,CLASS_MARISA,NULL,"X^[",NULL,2 },
	{ MON_MARISA,CLASS_MARISA,NULL,"V[g","EUE",25 },
	{ MON_MARISA,CLASS_MARISA,NULL,"","₷",24 },
	{ MON_MARISA,CLASS_MARISA,"̂悤","d",NULL,1 },
	{ MON_MARISA,CLASS_MARISA,NULL,"C[W",NULL,8 },




	{ 0,0,NULL,"",NULL,0 } //I[_~[
};


//v1.1.51	VA[i̒n`ɎgXt@CƗpJnʒuxyW
const nightmare_gen_map_type	nightmare_gen_map_table[NIGHTMARE_GEN_MAP_TABLE_SIZE] =
{
	//townfile,x,y
	{ "t0000001.txt",5,26 },
	{ "t0000001.txt",13,9 },
	{ "t0000001.txt",13,37 },
	{ "t0000001.txt",18,25 },
	{ "t0000001.txt",60,15 },
	{ "t0000001.txt",84,12 },
	{ "t0000001.txt",120,37 },
	{ "t0000001.txt",130,24 },
	{ "t0000002.txt",75,40 },
	{ "t0000002.txt",2,3 },
	{ "t0000002.txt",130,6 },
	{ "t0000002.txt",22,10 },
	{ "t0000002.txt",4,35 },
	{ "t0000002.txt",30,27 },
	{ "t0000002.txt",70,35 },
	{ "t0000002.txt",90,30 },
	{ "t0000003.txt",110,30 },
	{ "t0000003.txt",1,20 },
	{ "t0000003.txt",80,16 },
	{ "t0000003.txt",45,43 },
	{ "t0000004.txt",35,42 },
	{ "t0000004.txt",35,3 },
	{ "t0000004.txt",130,40 },
	{ "t0000004.txt",132,3 },
	{ "t0000005.txt",70,15 },
	{ "t0000005.txt",70,35 },
	{ "t0000006.txt",84,25 },
	{ "t0000006.txt",60,35 },
	{ "t0000006.txt",95,21 },
	{ "t0000006.txt",120,33 },
	{ "t0000007.txt",103,17 },
	{ "t0000007.txt",48,25 },
	{ "t0000008.txt",100,13 },
	{ "t0000008.txt",50,23 },
	{ "t0000008.txt",83,42 },
	{ "t0000009.txt",55,16 },
	{ "t0000009.txt",6,23 },
	{ "t0000009.txt",110,5 },
	{ "t0000010.txt",60,30 },
	{ "t0000010.txt",30,6 },
	{ "t0000010.txt",128,43 },
	{ "t0000011.txt",80,35 },
	{ "t0000011.txt",30,15 },
	{ "t0000012.txt",70,4 },
	{ "t0000012.txt",70,24 },
	{ "t0000012.txt",97,44 },

};



//v1.1.51 VA[ipie[u
//{stage_level(0-7),rarity,tral,sval,basenum}
const nightmare_treasure_type nightmare_treasure_table[] =
{

	//0:lev20
	{ 0,100,TV_POTION,SV_POTION_CURE_CRITICAL,1 },
	{ 0,100,TV_POTION,SV_POTION_HEROISM,1 },
	{ 0,100,TV_POTION,SV_POTION_RESIST_HEAT,1 },
	{ 0,100,TV_POTION,SV_POTION_RESIST_COLD,1 },
	{ 0,100,TV_POTION,SV_POTION_POISON2,1 },
	{ 0,100,TV_SCROLL,SV_SCROLL_LIGHT,1 },
	{ 0,100,TV_SCROLL,SV_SCROLL_DETECT_ITEM,1 },
	{ 0,100,TV_SCROLL,SV_SCROLL_DETECT_TRAP,1 },
	{ 0,100,TV_SCROLL,SV_SCROLL_DETECT_DOOR,1 },
	{ 0,100,TV_SCROLL,SV_SCROLL_TELEPORT,1 },
	{ 0,100,TV_MATERIAL,SV_MATERIAL_HIKARIGOKE,1 },
	{ 0,100,TV_ALCOHOL,SV_ALCOHOL_ORC,1 },
	{ 0,100,TV_ALCOHOL,SV_ALCOHOL_BEER,1 },
	{ 0,10,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1 },
	{ 0,50,TV_SOUVENIR,SV_SOUVENIR_ULTRASONIC,1 },
	{ 0,50,TV_SWEETS,SV_SWEET_POTATO,1 },

	//1:lev30
	{ 1,100,TV_SCROLL,SV_SCROLL_WORD_OF_RECALL,1 },
	{ 1,100,TV_SCROLL,SV_SCROLL_MAPPING,1 },
	{ 1,100,TV_POTION,SV_POTION_CURE_CRITICAL,1 },
	{ 1,75,TV_POTION,SV_POTION_CURING,1 },
	{ 1,75,TV_POTION,SV_POTION_SPEED,1 },
	{ 1,100,TV_SCROLL,SV_SCROLL_TELEPORT_LEVEL,1 },
	{ 1,100,TV_SCROLL,SV_SCROLL_DISPEL_UNDEAD,1 },
	{ 1,75,TV_SCROLL,SV_SCROLL_SUMMON_KIN,1 },
	{ 1,100,TV_MATERIAL,SV_MATERIAL_HEMATITE,1 },
	{ 1,100,TV_MATERIAL,SV_MATERIAL_MAGNETITE,1 },
	{ 1,100,TV_MATERIAL,SV_MATERIAL_BROKEN_NEEDLE,1 },
	{ 1,50,TV_COMPOUND,SV_COMPOUND_MUSCLE_DRUG,1 },
	{ 1,50,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1 },
	{ 1,70,TV_ALCOHOL,SV_ALCOHOL_REISYU,1 },

	//2:lev40

	{ 2,100,TV_POTION,SV_POTION_CURING,1 },
	{ 2,20,TV_COMPOUND,SV_COMPOUND_NECOMIMI,1 },
	{ 2,100,TV_SCROLL,SV_SCROLL_STAR_REMOVE_CURSE,1 },
	{ 2,70,TV_COMPOUND,SV_COMPOUND_GELSEMIUM_TEA,1 },
	{ 2,80,TV_MATERIAL,SV_MATERIAL_ARSENIC,1 },
	{ 2,70,TV_MATERIAL,SV_MATERIAL_MERCURY,1 },
	{ 2,80,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1 },

	{ 2,100,TV_MATERIAL,SV_MATERIAL_GARNET,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_AMETHYST,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_AQUAMARINE,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_MOONSTONE,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_PERIDOT,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_OPAL,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_TOPAZ,1 },
	{ 2,100,TV_MATERIAL,SV_MATERIAL_LAPISLAZULI,1 },

	{ 2,100,TV_SWEETS,SV_SWEETS_MIRACLE_FRUIT,1 },

	//3:lev50
	{ 3,100,TV_WAND,SV_WAND_TELEPORT_AWAY,1 },
	{ 3,100,TV_WAND,SV_WAND_STONE_TO_MUD,1 },
	{ 3,100,TV_POTION,SV_POTION_HEALING,1 },
	{ 3,100,TV_POTION,SV_POTION_RESISTANCE,1 },
	{ 3,50,TV_COMPOUND,SV_COMPOUND_JEKYLL,1 },
	{ 3,100,TV_WHISTLE,SV_WHISTLE,1 },
	{ 3,80,TV_STAFF,SV_STAFF_SPEED,1 },
	{ 3,100,TV_WAND,SV_WAND_DRAIN_LIFE,1 },
	{ 3,100,TV_SCROLL,SV_SCROLL_STAR_DESTRUCTION,1 },
	{ 3,100,TV_SCROLL,SV_SCROLL_STAR_ENCHANT_ARMOR,1 },
	{ 3,100,TV_SCROLL,SV_SCROLL_STAR_ENCHANT_WEAPON,1 },
	{ 3,100,TV_MATERIAL,SV_MATERIAL_ISHIZAKURA,1 },
	{ 3,100,TV_MATERIAL,SV_MATERIAL_MITHRIL,1 },
	{ 3,70,TV_MATERIAL,SV_MATERIAL_ADAMANTITE,1 },
	{ 3,100,TV_MATERIAL,SV_MATERIAL_NIGHTMARE_FRAGMENT,1 },
	{ 3,30,TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,1 },
	{ 3,100,TV_ALCOHOL,SV_ALCOHOL_REISYU,1 },
	{ 3,100,TV_SWEETS,SV_SWEETS_PEACH,1 },


	//4:lev60
	{ 4,100,TV_POTION,SV_POTION_HEALING,1 },
	{ 4,80,TV_POTION,SV_POTION_RESTORE_MANA,1 },
	{ 4,100,TV_POTION,SV_POTION_ENLIGHTENMENT,1 },
	{ 4,100,TV_POTION,SV_POTION_RESISTANCE,1 },
	{ 4,80,TV_WAND,SV_WAND_DRAGON_BREATH,1 },
	{ 4,100,TV_STAFF,SV_STAFF_DISPEL_EVIL,1 },
	{ 4,60,TV_ROD,SV_ROD_TELEPORT_AWAY,1 },
	{ 4,60,TV_ROD,SV_ROD_MAPPING,1 },
	{ 4,60,TV_ROD,SV_ROD_STONE_TO_MUD,1 },
	{ 4,100,TV_SCROLL,SV_SCROLL_MUNDANITY,1 },
	{ 4,100,TV_SCROLL,SV_SCROLL_PROTECTION_FROM_EVIL,1 },
	{ 4,75,TV_SCROLL,SV_SCROLL_RUNE_OF_PROTECTION,1 },
	{ 4,100,TV_POTION,SV_POTION_DETONATIONS,1 },
	{ 4,80,TV_MATERIAL,SV_MATERIAL_DRAGONSCALE,1 },
	{ 4,100,TV_MATERIAL,SV_MATERIAL_TAKAKUSAGORI,1 },
	{ 4,60,TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,1 },

	//5:lev70
	{ 5,70,TV_POTION,SV_POTION_STAR_HEALING,1 },
	{ 5,100,TV_POTION,SV_POTION_RESTORE_MANA,1 },
	{ 5,100,TV_POTION,SV_POTION_POLYMORPH,1 },
	{ 5,100,TV_POTION,SV_POTION_SELF_KNOWLEDGE,1 },
	{ 5,80,TV_POTION,SV_POTION_NANIKASUZUSHIKUNARU,1 },

	{ 5,100,TV_STAFF,SV_STAFF_DESTRUCTION,1 },
	{ 5,100,TV_ROD,SV_ROD_SPEED,1 },
	{ 5,100,TV_ROD,SV_ROD_DETECTION,1 },
	{ 5,100,TV_SCROLL,SV_SCROLL_SPELL,1 },

	{ 5,100,TV_WAND,SV_WAND_STRIKING,1 },

	{ 5,100,TV_SCROLL,SV_SCROLL_FIRE,1 },
	{ 5,100,TV_SCROLL,SV_SCROLL_ICE,1 },
	{ 5,100,TV_SCROLL,SV_SCROLL_CHAOS,1 },
	{ 5,100,TV_SCROLL,SV_SCROLL_GENOCIDE,1 },

	{ 5,70,TV_MATERIAL,SV_MATERIAL_EMERALD,1 },
	{ 5,70,TV_MATERIAL,SV_MATERIAL_RUBY,1 },
	{ 5,70,TV_MATERIAL,SV_MATERIAL_SAPPHIRE,1 },
	{ 5,80,TV_MATERIAL,SV_MATERIAL_DRAGONNAIL,1 },
	{ 5,100,TV_MATERIAL,SV_MATERIAL_HOPE_FRAGMENT,1 },

	{ 5,100,TV_ALCOHOL,SV_ALCOHOL_NECTAR,1 },
	{ 5,50,TV_SOUVENIR,SV_SOUVENIR_SMARTPHONE,1 },


	//6:lev80

	{ 6,100,TV_POTION,SV_POTION_STAR_HEALING,1 },
	{ 6,100,TV_POTION,SV_POTION_RESTORE_MANA,1 },
	{ 6,75,TV_POTION,SV_POTION_LIFE,1 },
	{ 6,80,TV_COMPOUND,SV_COMPOUND_STAR_DETORNATION,1 },


	{ 6,60,TV_STAFF,SV_STAFF_HOLINESS,1 },
	{ 6,50,TV_STAFF,SV_STAFF_POWER,1 },
	{ 6,40,TV_STAFF,SV_STAFF_HEALING,1 },
	{ 6,30,TV_STAFF,SV_STAFF_MSTORM,1 },
	{ 6,50,TV_WAND,SV_WAND_DISINTEGRATE,1 },
	{ 6,25,TV_WAND,SV_WAND_ROCKETS,1 },

	{ 6,100,TV_ROD,SV_ROD_IDENTIFY,1 },
	{ 6,100,TV_SCROLL,SV_SCROLL_MASS_GENOCIDE,1 },

	{ 6,50,TV_MATERIAL,SV_MATERIAL_IZANAGIOBJECT,1 },
	{ 6,80,TV_MATERIAL,SV_MATERIAL_DIAMOND,1 },

	//7:lev100-127

	{ 7,100,TV_POTION,SV_POTION_LIFE,1 },
	{ 7,100,TV_POTION,SV_POTION_NEW_LIFE,1 },

	{ 7,80,TV_WAND,SV_WAND_ROCKETS,1 },
	{ 7,100,TV_POTION,SV_POTION_LOVE,1 },
	{ 7,100,TV_ALCOHOL,SV_ALCOHOL_GOLDEN_MEAD,1 },

	{ 7,100,TV_MATERIAL,SV_MATERIAL_IZANAGIOBJECT,1 },
	{ 7,30,TV_MATERIAL,SV_MATERIAL_MYSTERIUM,1 },

	{ 7,10,TV_STAFF,SV_STAFF_THE_MAGI,1 },
	{ 7,60,TV_ROD,SV_ROD_HEALING,1 },
	{ 7,40,TV_ROD,SV_ROD_HAVOC,1 },

	{ 7,10,TV_SOUVENIR,SV_SOUVENIR_PHOENIX_FEATHER,1 },
	{ 7,10,TV_SOUVENIR,SV_SOUVENIR_SHILVER_KEY,1 },
	{ 7,10,TV_SCROLL,SV_SCROLL_ARTIFACT,1 },

	{ 7,100,TV_MATERIAL,SV_MATERIAL_METEORICIRON,1 },
	{ 7,5,TV_MATERIAL,SV_MATERIAL_HIHIIROKANE,1 },

	{ 7,50,TV_MUSHROOM,SV_MUSHROOM_MON_SUPER,1 },

	{ 0,0,0,0,0 } //I[_~[
};



//ȂZ̊Tv\ V俎qip
const cptr	nameless_skill_type_desc[JKF1_MAX + 1] =
{
	"_~[","{gU","{[U","r[U","PbgU","uXU",
	"^[U[U","𒆐SƂ鋐{[U","EU","tAS̍U","󕠏[",
	//10
	"","","X^[m","㩊m","ACem",
	"[","S","e|[g","̔","S͍U",
	//20
	"gU","AU","","S","",
	"e","y","uXy","jh","@z",
	//30
	"ǖxړ","͎gp","̋","m","G",
	"ꎞ","@h㏸","h㏸","@̊Z","ꎞB",
	//40
	"ǔ","jЃI[","Ggϐ","ɂ̑ϐ","GbZXt^",
	"GbZXt^","Ӓ","*j*","tAÎ","ӖE",
	//50
	"׏(1d777)","Ee|[gAEFC","Ě","EU+XC","E",
	"jQ","ϗe","Q","","אڍU\͋",
	//60
	"nk","Ӄgbv","K^"

};



